@@ -23,17 +23,20 @@ declare(strict_types=1);
  *
  */
 
+$requirementsFile = [
+	'apiVersion' => 'v1',
+	'fileId' => '.+',
+];
+$requirementsShare = [
+	'apiVersion' => 'v1',
+	'shareToken' => '.+',
+];
+
 return [
 	'ocs' => [
 		/** @see \OCA\Talk\Controller\FilesIntegrationController::getRoomByFileId() */
-		['name' => 'FilesIntegration#getRoomByFileId', 'url' => '/api/{apiVersion}/file/{fileId}', 'verb' => 'GET', 'requirements' => [
-			'apiVersion' => 'v1',
-			'fileId' => '.+'
-		]],
+		['name' => 'FilesIntegration#getRoomByFileId', 'url' => '/api/{apiVersion}/file/{fileId}', 'verb' => 'GET', 'requirements' => $requirementsFile],
 		/** @see \OCA\Talk\Controller\FilesIntegrationController::getRoomByShareToken() */
-		['name' => 'FilesIntegration#getRoomByShareToken', 'url' => '/api/{apiVersion}/publicshare/{shareToken}', 'verb' => 'GET', 'requirements' => [
-			'apiVersion' => 'v1',
-			'shareToken' => '.+',
-		]],
+		['name' => 'FilesIntegration#getRoomByShareToken', 'url' => '/api/{apiVersion}/publicshare/{shareToken}', 'verb' => 'GET', 'requirements' => $requirementsShare],
 	],
 ];
