@@ -23,12 +23,14 @@ declare(strict_types=1);
  *
  */
 
+$requirements = [
+	'apiVersion' => 'v1',
+	'token' => '[a-z0-9]{4,30}',
+];
+
 return [
 	'ocs' => [
 		/** @see \OCA\Talk\Controller\GuestController::setDisplayName() */
-		['name' => 'Guest#setDisplayName', 'url' => '/api/{apiVersion}/guest/{token}/name', 'verb' => 'POST', 'requirements' => [
-			'apiVersion' => 'v1',
-			'token' => '^[a-z0-9]{4,30}$',
-		]],
+		['name' => 'Guest#setDisplayName', 'url' => '/api/{apiVersion}/guest/{token}/name', 'verb' => 'POST', 'requirements' => $requirements],
 	],
 ];
