@@ -23,9 +23,13 @@ declare(strict_types=1);
  *
  */
 
+$requirements = [
+	'apiVersion' => 'v1',
+];
+
 return [
 	'ocs' => [
 		/** @see \OCA\Talk\Controller\PublicShareAuthController::createRoom() */
-		['name' => 'PublicShareAuth#createRoom', 'url' => '/api/{apiVersion}/publicshareauth', 'verb' => 'POST', 'requirements' => ['apiVersion' => 'v1'],],
+		['name' => 'PublicShareAuth#createRoom', 'url' => '/api/{apiVersion}/publicshareauth', 'verb' => 'POST', 'requirements' => $requirements],
 	],
 ];
