@@ -6,7 +6,6 @@ OC.L10N.register(
     "Invalid file provided" : "Ongeldige lêer verskaf",
     "Invalid image" : "Ongeldige beeld",
     "Unknown filetype" : "Onbekende lêertipe",
-    "An error occurred. Please contact your admin." : "'n Fout het voorgekom. Kontak asseblief u administrateur.",
     "Open settings" : "Open instellings",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Verenigde Arabiese Emirate",
@@ -248,10 +247,10 @@ OC.L10N.register(
     "Save changes" : "Bewaar veranderinge",
     "Saving …" : "Word gestoor …",
     "Saved!" : "Gestoor!",
+    "Name" : "Naam",
     "None" : "Geen",
     "User" : "Gebruiker",
     "Users" : "Gebruikers",
-    "Name" : "Naam",
     "All messages" : "Alle boodskappe",
     "Off" : "Af",
     "Language" : "Taal",
@@ -260,19 +259,23 @@ OC.L10N.register(
     "Created at" : "Geskep om",
     "Pending" : "Hangend",
     "Error" : "Fout",
+    "Active" : "Aktief",
     "OK" : "Goed",
     "Checking …" : "Gaan tans na …",
-    "Copy link" : "Kopieer skakel",
-    "Dismiss" : "Ontslaan",
     "Back" : "Terug",
+    "Confirm" : "Bevestig",
+    "Reset" : "Herstel",
+    "Cancel" : "Kanselleer",
+    "Copy link" : "Kopieer skakel",
     "You" : "U",
+    "Collapse" : "Vou In",
     "This conversation is read-only" : "Hierdie gesprek is leesalleen",
     "Favorite" : "Gunsteling",
     "Description" : "Beskrywing",
-    "Notifications" : "Kennisgewings",
+    "Personal" : "Persoonlik",
     "Leave conversation" : "verlaat gesprek",
     "Delete conversation" : "Skrap gesprek",
-    "Enter a password" : "Gee ’n wagwoord",
+    "Submit" : "Dien in",
     "Save" : "Stoor",
     "Edit" : "Wysig",
     "Delete" : "Skrap",
@@ -280,19 +283,28 @@ OC.L10N.register(
     "Login" : "Teken aan",
     "Nickname" : "Bynaam",
     "Client ID" : "Kliënt-ID",
+    "Notifications" : "Kennisgewings",
     "Remove from favorites" : "Verwyder uit gunstelinge",
     "Add to favorites" : "Voeg by gunstelinge",
     "Loading" : "Laai tans..",
     "Groups" : "Groepe",
     "Password protect" : "Beskerm met 'n wagwoord",
+    "Enter password" : "Voer wagwoord in",
     "Add participants" : "Voeg deelnemers toe",
     "Close" : "Sluit",
     "You are currently waiting in the lobby" : "U wag tans in die voorportaal",
+    "Devices" : "Toestelle",
+    "Upload" : "Oplaai",
+    "Files" : " Lêers",
+    "Dismiss" : "Ontslaan",
     "Reply" : "Antwoord",
     "Contact" : "Kontak",
     "Today" : "Vandag",
     "Yesterday" : "Gister",
+    "Group" : "Groep",
     "Settings" : "Instellings",
+    "Send" : "Stuur",
+    "Join" : "Sluit aan",
     "guest" : "gas",
     "Promote to moderator" : "Bevorder na moderator",
     "Remove participant" : "Verwyder deelnemer",
@@ -301,9 +313,8 @@ OC.L10N.register(
     "Privacy" : "Privaatheid",
     "Keyboard shortcuts" : "Sneltoetse",
     "Search" : "Soek",
-    "Send" : "Stuur",
+    "Open sidebar" : "Open kantbalk",
     "Media" : "Media",
-    "Files" : " Lêers",
     "Audio" : "Oudio",
     "Other" : "Ander",
     "Do not disturb" : "Moenie pla nie",
@@ -311,9 +322,6 @@ OC.L10N.register(
     "Default" : "Verstek",
     "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
     "Android app" : "Android-toep",
-    "iOS app" : "iOS-toep",
-    "Saved" : "Bewaar",
-    "Microphone" : "Mikrofoon",
-    "Camera" : "Kamera"
+    "iOS app" : "iOS-toep"
 },
 "nplurals=2; plural=(n != 1);");
