@@ -108,8 +108,9 @@ OC.L10N.register(
     "Invalid file provided" : "Ar restr roet n'eo ket unan aotreet",
     "Invalid image" : "N'eo ket aotreet ar skeudenn",
     "Unknown filetype" : "N'eo ket anavezet stumm ar restr",
-    "An error occurred. Please contact your admin." : "Ur fazi a zo bet. Galvit o merour mar-plij.",
     "Talk mentions" : "Menegoù Talk",
+    "Call in progress" : "Kemenadenn en dro",
+    "You were mentioned" : "Meneget oc'h bet",
     "Write to conversation" : "Skrivañ d'an diviz",
     "Writes event information into a conversation of your choice" : "Skriva titouroù an darvout en diviz o peus c'hoant",
     "%s invited you to a conversation." : "%s en deus kouviet ac'hanoc'h dan diviz",
@@ -120,6 +121,7 @@ OC.L10N.register(
     "Password request: %s" : "Ger-tremen goulennet : %s",
     "Private conversation" : "Diviz prevez",
     "Deleted user (%s)" : "Lemel implijour (%s)",
+    "Dismiss notification" : "Arrest ar gemenadennoù",
     "{user} in {call}" : "{user} e {call}",
     "Deleted user in {call}" : "Lemel implijer e {call}",
     "{guest} (guest) in {call}" : "{guest} (kouviad) e {call}",
@@ -463,11 +465,6 @@ OC.L10N.register(
     "Save changes" : "Enrollañ ar cheñchamantoù",
     "Saving …" : "Orc'h enrolliñ",
     "Saved!" : "Enrollet !",
-    "None" : "Hini ebet",
-    "User" : "Implijer",
-    "Disabled" : "Disaotreañ",
-    "Moderators" : "Habaskaer",
-    "Users" : "Implijer",
     "Commands" : "Urzhioù",
     "Beta" : "Beta",
     "Name" : "Anv",
@@ -476,6 +473,11 @@ OC.L10N.register(
     "Response to" : "Respont da",
     "Enabled for" : "reañ evit",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "An urzhioù a zo ur perzh nevez e Nextcloud Talk. Aotreañ a reont da lakaat da dreiñ ur skrip war ho servijour Nextcloud. Galout a rit krouañ anezho en ur implij hon etrafas linenn urzh. Ur skouer skript jederez a zo posupl kaout en hon {linkstart}diellvadur{linkend}.",
+    "None" : "Hini ebet",
+    "User" : "Implijer",
+    "Disabled" : "Disaotreañ",
+    "Moderators" : "Habaskaer",
+    "Users" : "Implijer",
     "General settings" : "Stummoù hollek",
     "Default notification settings" : "Arventennoù kemenadenn dre ziouer",
     "Default group notification" : "Kemenadenn strollad dre ziouer",
@@ -489,7 +491,6 @@ OC.L10N.register(
     "Hosted high-performance backend" : "Backend a labour buhan osted",
     "URL of this Nextcloud instance" : "URL an azgoulenn Nextcloud",
     "Full name of the user requesting the trial" : "Tout anv an implijer a goulenn an amprouadenn",
-    "Name of the user requesting the trial" : "Anv an implijet a goulenn an amprouadenn",
     "Language" : "Yezh",
     "Country" : "Bro",
     "Request signaling server trial" : "Goulenn amproui arhent ar servijour",
@@ -508,8 +509,6 @@ OC.L10N.register(
     "The trial could not be requested. Please try again later." : "An amprouadenn na c'hell ket bezhañ goulennet. Klaskit en dro goude.",
     "The account could not be deleted. Please try again later." : "Neo ket posupl lemel ar c'hont. Klaskit en dro goude",
     "_%n user_::_%n users_" : ["%n implijer","%n implijer","%n implijer","%n implijer","%n implijer"],
-    "Shared secret" : "Secret rannet",
-    "High-performance backend URL" : "URL ar vackend a labour buhan",
     "Validate SSL certificate" : "Sertifikad SSL gwiriet",
     "Delete this server" : "Lemel ar servijour",
     "Status: Checking connection" : "Stad : Ho gwiriañ ar genstagadenn",
@@ -517,9 +516,10 @@ OC.L10N.register(
     "Error: Server did not respond with proper JSON" : "Fazi : N'eo ket posupl respont gant ur JSON mat",
     "Error: Server responded with: {error}" : "Fazi : Respont a ra ar servijour gant : {error}",
     "Error: Unknown error occurred" : "Fazi : Ur fazi dianv a zo bet",
+    "Shared secret" : "Secret rannet",
+    "High-performance backend URL" : "URL ar vackend a labour buhan",
     "High-performance backend" : "Backend a labour buhan",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour diavaezh arhentañ a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhentañ diabarzh goulo.",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Notennit c''hell an implijourien, evit kemenadennoù gant muioc'h eget 4 implijer gant ur servijour arhent diavaez, kaout kudennoù kenstagadeur ha lakaat kargoù bras var ardivinkoù an impklijour.",
     "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Aliet kreñv eo staliañ ur c'hach rannet pa implijer Nextcloud Talk gant ur Vack-End Labour Huel.",
     "Don't warn about connectivity issues in calls with more than 4 participants" : "N'om pas kemenn diwar ben kudennom kenstagadur er gemennadennoù gant muioc'h eget 4 implijer.",
     "STUN server URL" : "URL ar servijour STUNN",
@@ -534,69 +534,38 @@ OC.L10N.register(
     "Test this server" : "Arnodañ ar servijour-mañ",
     "TURN servers" : "Servijour TURN",
     "OK" : "OK",
+    "Back" : "Distro",
+    "Confirm" : "Kadarnañ",
+    "Cancel" : "Arrest",
     "Copy link" : "Kopiañ al liamm",
     "Waiting for others to join the call …" : "O c'hortoz ma teuio ar re all er gemenadenn ...",
     "You can invite others in the participant tab of the sidebar" : "Galout a rit kouviañ tud gant an daolenn lodek er verenn gostez",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galout a rit kouviañ tud en dolenn lodek er varenn gostez pe rannañ al liamm-mañ evit kouviañ anezho !",
     "Share this link to invite others!" : "Rannit al liamm-mañ gant ar re all !",
-    "Dismiss" : "Arrest",
-    "Show your screen" : "Diskouez ar skramm",
-    "Stop screensharing" : "Echuañ ar rannadenn skramm",
-    "No audio" : "Audio ebet",
     "Mute audio" : "Lac'hañ a audio",
     "Unmute audio" : "Lakaat an odio en dro",
-    "No camera" : "Kamera ebet",
-    "Disable video" : "Lac'han ar video",
-    "Enable video" : "Lakaat ar video en dro",
-    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Lakaat ar video en dro. Ho genstagadenn a vo troc'het evit aotreañ ar video evit ar wech kentañ",
-    "Screensharing options" : "Dibaboù rannañ skramm",
-    "Enable screensharing" : "Aotreañ ar rannan skramm",
-    "Bad sent video and screen quality." : "Fall eo perzh ar skramm ha kasadenn ar video.",
-    "Bad sent screen quality." : "Fall eo perzh ar skramm.",
-    "Bad sent video quality." : "Fall eo perzh ar gasadenn ar video.",
-    "Bad sent audio, video and screen quality." : "Fall eo perzh ar skramm, kasadenn ar video ha kasadenn an audio.",
-    "Bad sent audio and screen quality." : "Fall eo perzh ar skramm ha kasadenn an audio.",
-    "Bad sent audio and video quality." : "Fall eo kasadenn ar video ha kasadenn an audio.",
-    "Bad sent audio quality." : "Fall eo kasadenn an audio.",
-    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Ho kenstagadenn internet pe urzhiataer a labour ha ne c'hell ket ar re all gwellet ho skramm",
-    "Your internet connection or computer are busy and other participants might be unable to see you." : "HO labour eo ho kenstagadenn internet pe ho urzhiataer ha ne c'hell ket ar re all gwellet ac'hanaoc'h.",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Ho kenstagadur internet pe ho urzhiataer a labour hamarteze ne c'hll ket komprenn ha gwellet ac'hnoc'h. Evit gwelaat ar stad klaskit lac'han ar video pa rannit ho skramm.",
-    "Disable screenshare" : "Rannañ skramm disaotreet",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha ne c'hll ket marteze ar re all komprenn ac'hanaoc'h. La'hit ar video evit gwelaat an traoù.",
-    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ho kenstagadenn onternet pe ho urzhiataer a labour ha marteze ne c'hell ket ar re all komprenn ac'hanoc'h.",
-    "Grid view" : "Diskwell ar roued",
-    "Screen sharing is not supported by your browser." : "N'eo ket douget ar rannañ skramm gant ho furcher.",
-    "Screen sharing requires the page to be loaded through HTTPS." : "Ar rannañ skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
-    "Screensharing requires the page to be loaded through HTTPS." : "Ar rannañ-skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
-    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
-    "An error occurred while starting screensharing." : "Ur fazi a zo bet e pad ar rannadenn-skramm.",
-    "Back" : "Distro",
     "Access to camera was denied" : "Nac'het eo bet tizhañ ar c'hamera",
     "Error while accessing camera" : "Ur fazi a zo bet en ur tizhout ar c'hamera",
     "You have been muted by a moderator" : "Mut oc'h bet lakaet gant ar moderatour",
+    "Disable video" : "Lac'han ar video",
+    "Enable video" : "Lakaat ar video en dro",
+    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Lakaat ar video en dro. Ho genstagadenn a vo troc'het evit aotreañ ar video evit ar wech kentañ",
     "You" : "C'hwi",
     "Show screen" : "Diskwell ar skramm",
-    "Mute" : "Mut",
     "Stop following" : "Arrest heuliañ",
+    "Mute" : "Mut",
     "You need to be logged in to upload files" : "Ret eo deoc'h bezhañ deuet-tre evit pellkas restroù",
     "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
-    "Call in progress" : "Kemenadenn en dro",
     "Favorite" : "Pennroll",
-    "Conversation settings" : "Stummoù diviz",
     "Description" : "Deskrivadur",
-    "Notifications" : "Kemennadennoù",
+    "Conversation settings" : "Stummoù diviz",
+    "Personal" : "Personel",
     "Leave conversation" : "Kuitaat an diviz",
     "Delete conversation" : "Lemel an diviz",
-    "You need to promote a new moderator before you can leave the conversation." : "Ret eo deoc'h lakaat unan bennak da moderatour a-rao kuitaat an diviz.",
     "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da lemel  \"{displayName}\" ?",
+    "Submit" : "Kinnig",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
-    "Enter a password" : "Ebarzhiñ ar ger-tremen",
     "Copy conversation link" : "Eilañ al liamm diviz",
-    "Conversation link copied to clipboard." : "Liamm diviz eilet er golver",
-    "The link could not be copied." : "Ne oa ket posupl eilañ al liamm.",
-    "Enable lobby" : "Aotreañ ar sal gortoz",
     "Start time (optional)" : "Amzer kregiñ (dibab)",
     "Save" : "Enrollañ",
     "Edit" : "Cheñch",
@@ -605,12 +574,12 @@ OC.L10N.register(
     "Password" : "Ger-tremen",
     "Login" : "Anv arveriad",
     "Client ID" : "ID kliant",
-    "Choose devices" : "Choazit un ardivink",
+    "Notifications" : "Kemennadennoù",
     "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
     "Add to favorites" : "Ouzhpennañ er pennrolloù",
     "You: {lastMessage}" : "C'hwi : {lastMessage}",
     "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
-    "No matches" : "Kejadenn ebet",
+    "You need to promote a new moderator before you can leave the conversation." : "Ret eo deoc'h lakaat unan bennak da moderatour a-rao kuitaat an diviz.",
     "Loading" : "Kargañ",
     "No search results" : "Disoc'h enklask ebet",
     "Groups" : "Strolladoù",
@@ -621,37 +590,45 @@ OC.L10N.register(
     "Groups and circles" : "Strolladoù ha kelc'hioù",
     "Other sources" : "Orin all",
     "An error occurred while performing the search" : "Ur fazi a zo bet en ur ober an enklask",
+    "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
+    "Password protect" : "Ger-tremen gwarezet",
     "Creating your conversation" : "Krouiñ ho diviz",
     "All set" : "Staliet pep tra",
     "Error while creating the conversation" : "Ur fazi a zo bet en ur krouiñ an diviz",
-    "Link copied to the clipboard!" : "Liamm eilet d'ar golver",
-    "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
-    "Password protect" : "Ger-tremen gwarezet",
     "Create conversation" : "Krouiñ un diviz",
     "Add participants" : "Ouzhpennan tud",
     "Close" : "Serriñ",
-    "Choose a password" : "Choaz ur get-trmenn",
     "Search participants" : "Klask implijer",
     "Conversation name" : "Anv diviz",
-    "Search conversations or users" : "Klask divizoù ha implijourienn",
     "You are currently waiting in the lobby" : "Ho gortoz er sal gortoz emaoc'h",
     "No microphone available" : "Mikro ebet kavet",
     "Select microphone" : "Choaz ur mikro",
     "No camera available" : "Kamera ebet kavet",
     "Select camera" : "Choaz ur c'hamera",
+    "Done" : "Graet",
+    "No audio" : "Audio ebet",
+    "No camera" : "Kamera ebet",
+    "Upload" : "Pellkas",
+    "Files" : "Restroù",
+    "File to share" : "Restr da rannañ",
+    "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
+    "Dismiss" : "Arrest",
     "Reply" : "Respont",
     "Go to file" : "Mont d'ar restr",
+    "Translate" : "Treiñ",
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Share files to the conversation" : "Rannañ restroù d'an diviz",
     "Add emoji" : "Ouzhpennañ un emoji",
     "Send message" : "Kas ur gemenadenn",
-    "File to share" : "Restr da rannañ",
-    "New file" : "Restr nevez",
     "Write message, @ to mention someone …" : "Skrivañ ur gemenadenn, @ evit menegiñ unan bennak ...",
-    "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
+    "Group" : "Stollad",
+    "Share files to the conversation" : "Rannañ restroù d'an diviz",
+    "New file" : "Restr nevez",
     "Settings" : "Arventennoù",
+    "Send" : "Kas",
+    "Add more files" : "Ouzhpennañ muioc'h a restroù",
+    "Join" : "Kejañ",
     "moderator" : "habaskaer",
     "guest" : "kouviad",
     "Demote from moderator" : "Lemel eus ar moderatourienn",
@@ -673,6 +650,10 @@ OC.L10N.register(
     "Chat" : "Chat",
     "Details" : "Munudoù",
     "Projects" : "Raktres",
+    "Search conversations or users" : "Klask divizoù ha implijourienn",
+    "Select conversation" : "Choaz un diviz",
+    "Link to a conversation" : "Liamm d'an diviz",
+    "Choose devices" : "Choazit un ardivink",
     "Attachments folder" : "Teuliad stag",
     "Privacy" : "Prevezder",
     "Search" : "Klask",
@@ -681,22 +662,41 @@ OC.L10N.register(
     "Start call" : "Kregiñ ar gemenadenn",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
     "You will be able to join the call only after a moderator starts it." : "Posupl vo deoc'h mont er gemenadenn goude ma vo bet groget gant ar modertator.",
-    "Toggle fullscreen" : "Lakat/Kuitaat ar skramm a bezh",
-    "Rename conversation" : "Adenvel an diviz",
+    "Open sidebar" : "Digori ar varenn gostez",
+    "Show your screen" : "Diskouez ar skramm",
+    "Stop screensharing" : "Echuañ ar rannadenn skramm",
+    "Screensharing options" : "Dibaboù rannañ skramm",
+    "Enable screensharing" : "Aotreañ ar rannan skramm",
+    "Bad sent video and screen quality." : "Fall eo perzh ar skramm ha kasadenn ar video.",
+    "Bad sent screen quality." : "Fall eo perzh ar skramm.",
+    "Bad sent video quality." : "Fall eo perzh ar gasadenn ar video.",
+    "Bad sent audio, video and screen quality." : "Fall eo perzh ar skramm, kasadenn ar video ha kasadenn an audio.",
+    "Bad sent audio and screen quality." : "Fall eo perzh ar skramm ha kasadenn an audio.",
+    "Bad sent audio and video quality." : "Fall eo kasadenn ar video ha kasadenn an audio.",
+    "Bad sent audio quality." : "Fall eo kasadenn an audio.",
+    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Ho kenstagadenn internet pe urzhiataer a labour ha ne c'hell ket ar re all gwellet ho skramm",
+    "Your internet connection or computer are busy and other participants might be unable to see you." : "HO labour eo ho kenstagadenn internet pe ho urzhiataer ha ne c'hell ket ar re all gwellet ac'hanaoc'h.",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Ho kenstagadur internet pe ho urzhiataer a labour hamarteze ne c'hll ket komprenn ha gwellet ac'hnoc'h. Evit gwelaat ar stad klaskit lac'han ar video pa rannit ho skramm.",
+    "Disable screenshare" : "Rannañ skramm disaotreet",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha ne c'hll ket marteze ar re all komprenn ac'hanaoc'h. La'hit ar video evit gwelaat an traoù.",
+    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Ho kenstagadenn onternet pe ho urzhiataer a labour ha marteze ne c'hell ket ar re all komprenn ac'hanoc'h.",
+    "Screen sharing is not supported by your browser." : "N'eo ket douget ar rannañ skramm gant ho furcher.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Ar rannañ skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
+    "Screensharing requires the page to be loaded through HTTPS." : "Ar rannañ-skramm en deus ezhomm e vefe ar bajenn karget dre HTTPS",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Rannañ  ho skramm a dro nmetken gant  Firefox stumm 52 pe nevezoc'h.",
+    "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
+    "An error occurred while starting screensharing." : "Ur fazi a zo bet e pad ar rannadenn-skramm.",
     "Mute others" : "Lakaat ar re all mut",
-    "Send" : "Kas",
-    "Add more files" : "Ouzhpennañ muioc'h a restroù",
+    "Grid view" : "Diskwell ar roued",
     "No unread mentions" : "Kemenadenn nan-lennet ebet",
     "Say hi to your friends and colleagues!" : "Lâr koukouk d'ho mignoned ha genseurted",
     "Start a conversation" : "Kregiñ un diviz",
-    "You were mentioned" : "Meneget oc'h bet",
     "Message without mention" : "Kemenn hp meneg",
     "Mention myself" : "Meneg ac'hanon",
     "Mention room" : "Sal meneg",
     "The conversation does not exist" : "N'ez eus ket eus an diviz-mañ",
     "Join a conversation or start a new one!" : "Mont en un diviz pe kregiñ unan nevez !",
-    "Select conversation" : "Choaz un diviz",
-    "Link to a conversation" : "Liamm d'an diviz",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Deuet oc'h en diviz dre ur prenestr pe ardivink all. N'eo ket douget evit ar poent gant Nextcloud Talk neuze eo bet sertet an dalc'h.",
     "Join a conversation or start a new one" : "Mont en un diviz pe kregiñ unan nevez ",
     "Calls are not supported in your browser" : "N'eo ket douget ar gemenadennoù gant ho vrowser",
@@ -706,7 +706,6 @@ OC.L10N.register(
     "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
     "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "Media" : "Media",
-    "Files" : "Restroù",
     "Audio" : "Audio",
     "Other" : "All",
     "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
@@ -718,7 +717,6 @@ OC.L10N.register(
     "Join here" : "Kejañ amañ",
     "Leave this page" : "Kuitaat ar bajenn",
     "Nextcloud is in maintenance mode, please reload the page" : "E stumm dalc'h eo Nextcloud, adkargit ar bajenn",
-    "Sending signaling message has failed." : "Kasadenn ar gemenadenn arhentañ a zo c'hwitet.",
     "Lost connection to signaling server. Trying to reconnect." : "Kenstagadenn gant ar servijour arhent kollet. O klask adkemprenn.",
     "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn.",
     "Establishing signaling connection is taking longer than expected …" : "Lakaat an arhent kenstagañ a zo hiroc'h eget gortozet ...",
@@ -746,17 +744,14 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Kit en diviz n'eus forzh peseurt amzer, lec'h pe ardivink.",
     "Android app" : "Meziant Android",
     "iOS app" : "Meziant iOS",
-    "Saved" : "Enrollet",
-    "Add a new server" : "Ouzhpennañ ur servijour nevez",
-    "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha implijourienn all c'hell gwellet ac'hanoc'h. Evit gwelaat ar stad klaskit disaotreañ ar video pa rit ur rannadenn skramm.",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Ho kenstagadenn internet pe ho urzhiataer a labour ha ne c'hell marteze ket  ar re all komprenn ac'hanoc'h ha gwellet ho skramm. Evit gwellat ar stad e vefe gwelloc'h lac'han ar rannañ skramm.",
-    "Chat notifications" : "Kemenadennoù chat",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Ho gortoz er sal gortoz emaoc'h. Ne grog an diviz nemet da {startTime}",
-    "Microphone" : "Mikro :",
-    "Camera" : "Kamera",
-    "[Unknown username]" : "[Anv implijer dianv]",
-    "Upload new files" : "Pelkas ur restr nevez",
-    "Share from Files" : "Rannañ diouzh Restroù",
-    "Display name: " : "Anv tra :"
+    "Name of the user requesting the trial" : "Anv an implijet a goulenn an amprouadenn",
+    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Notennit c''hell an implijourien, evit kemenadennoù gant muioc'h eget 4 implijer gant ur servijour arhent diavaez, kaout kudennoù kenstagadeur ha lakaat kargoù bras var ardivinkoù an impklijour.",
+    "Conversation link copied to clipboard." : "Liamm diviz eilet er golver",
+    "The link could not be copied." : "Ne oa ket posupl eilañ al liamm.",
+    "No matches" : "Kejadenn ebet",
+    "Link copied to the clipboard!" : "Liamm eilet d'ar golver",
+    "Toggle fullscreen" : "Lakat/Kuitaat ar skramm a bezh",
+    "Rename conversation" : "Adenvel an diviz",
+    "Sending signaling message has failed." : "Kasadenn ar gemenadenn arhentañ a zo c'hwitet."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
