@@ -18,6 +18,7 @@ OC.L10N.register(
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkommen til Nextcloud Talk!\nI denne samtale finder du information om nye features tilgængelige i Nextcloud Talk.",
     "New in Talk %s" : "Nyt i Snak %s",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge og Safari kan nu benyttes til at deltage i lyd- og videosamtaler",
+    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-til-en-samtaler er nu vedvarende og kan ikke længere omdannes til gruppesamtaler ved et uheld. Også når en af deltagerne forlader samtalen, slettes samtalen ikke automatisk længere. Kun hvis begge deltagere forlader, slettes samtalen fra serveren",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Nu kan nu sende en notifikation til alle deltagere ved at skrive \"@all\" i chatten",
     "- With the \"arrow-up\" key you can repost your last message" : "- Ved at trykke på \"pil op\" kan du sende din sidste besked igen",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk understøtter nu kommandoer. Send \"/help\" som en chat-besked for at se om din administrator har konfigureret nogen",
@@ -27,14 +28,44 @@ OC.L10N.register(
     "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nu svare direkte på beskeder og dermed give andre brugere mere kontekst om hvad din besked handler om",
     "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Søgninger efter samtaler og deltagere vil nu også filtrere dine eksisterende samtaler, hvilke gør det meget nemmere at finde tidligere samtaler",
     "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nu tilføje brugerdefinerede brugergrupper til samtaler når cirkel-appen er installeret",
+    "- Check out the new grid and call view" : "- Tjek det nye gitter og opkaldsvisning",
+    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Du kan nu uploade og trække og slippe filer direkte fra din enhed til chatten",
+    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Delte filer åbnes nu direkte inde i chatvisningen med fremviserapps",
+    "- You can now search for chats and messages in the unified search in the top bar" : "- Du kan nu søge efter chats og beskeder i den samlede søgning i den øverste bjælke",
+    "- Spice up your messages with emojis from the emoji picker" : "- Krydr dine beskeder med emojis fra emojivælgeren",
+    "- You can now change your camera and microphone while being in a call" : "- Du kan nu skifte kamera og mikrofon, mens du er i et opkald",
+    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Giv dine samtaler en vis kontekst med en beskrivelse, og åbn den, så loggede brugere kan finde den og deltage selv",
+    "- See a read status and send failed messages again" : "- Se en læst status og send mislykkede beskeder igen",
+    "- Raise your hand in a call with the R key" : "- Ræk hånden op i et opkald med R-tasten",
+    "- Join the same conversation and call from multiple devices" : "- Deltag i den samme samtale og opkald fra flere enheder",
+    "- Send voice messages, share your location or contact details" : "- Send talebeskeder, del din placering eller kontaktoplysninger",
+    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Føj grupper til en samtale, og nye gruppemedlemmer vil automatisk blive tilføjet som deltagere",
+    "- A preview of your audio and video is shown before joining a call" : "- En forhåndsvisning af din lyd og video vises, før du deltager i et opkald",
+    "- You can now blur your background in the newly designed call view" : "- Du kan nu sløre din baggrund i den nydesignede opkaldsvisning",
+    "- Moderators can now assign general and individual permissions to participants" : "- Moderatorer kan nu tildele generelle og individuelle tilladelser til deltagere",
+    "- You can now react to chat message" : "- Du kan nu reagere på chatbeskeden",
+    "- In the sidebar you can now find an overview of the latest shared items" : "- I sidebjælken kan du nu finde en oversigt over de seneste delte elementer",
+    "- Use a poll to collect the opinions of others or settle on a date" : "- Brug en meningsmåling til at indsamle andres meninger eller afgør en dato",
+    "- Configure an expiration time for chat messages" : "- Konfigurer en udløbstid for chatbeskeder",
+    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Start opkald uden at underrette andre i store samtaler. Du kan sende individuelle opkaldsmeddelelser, når opkaldet er startet.",
+    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Send chatbeskeder uden at give modtagerne besked, hvis det ikke haster",
     "There are currently no commands available." : "Der er pt ingen kommandoer tilgængelige.",
     "The command does not exist" : "Kommandoen findes ikke",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Der opstod en fejl ved kørsel af kommandoen. Bed venligst en administrator om at kigge i logfilerne.",
     "Talk updates ✅" : "Talk-opdateringer ✅",
+    "Reaction deleted by author" : "Reaktion slettet af forfatter",
     "{actor} created the conversation" : "{actor} oprettede samtalen",
     "You created the conversation" : "Du oprettede samtalen",
+    "An administrator created the conversation" : "En administrator oprettede samtalen",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} omdøbte samtalen fra \"%1$s\" til \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du omdøbte samtalen fra \"%1$s\" til \"%2$s\"",
+    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "En administrator omdøbte samtalen fra \"%1$s\" til \"%2$s\"",
+    "{actor} set the description" : "{actor} indstille beskrivelsen",
+    "You set the description" : "Du satte beskrivelsen",
+    "An administrator set the description" : "En administrator satte beskrivelsen",
+    "{actor} removed the description" : "{actor} fjernede beskrivelsen",
+    "You removed the description" : "Du fjernede beskrivelsen",
+    "An administrator removed the description" : "En administrator fjernede beskrivelsen",
     "{actor} started a call" : "{actor} startede et opkald",
     "You started a call" : "Du startede et opkald",
     "{actor} joined the call" : "{actor} deltog i opkaldet",
@@ -43,31 +74,70 @@ OC.L10N.register(
     "You left the call" : "Du forlod opkaldet",
     "{actor} unlocked the conversation" : "{actor} låste op for samtalen",
     "You unlocked the conversation" : "Du låste op for samtalen",
+    "An administrator unlocked the conversation" : "En administrator låste samtalen op",
     "{actor} locked the conversation" : "{actor} låste samtalen",
     "You locked the conversation" : "Du låste samtalen",
+    "An administrator locked the conversation" : "En administrator låste samtalen",
+    "{actor} limited the conversation to the current participants" : "{actor} begrænsede samtalen til de nuværende deltagere",
+    "You limited the conversation to the current participants" : "Du begrænsede samtalen til de nuværende deltagere",
+    "An administrator limited the conversation to the current participants" : "En administrator begrænsede samtalen til de nuværende deltagere",
+    "{actor} opened the conversation to registered users" : "{actor} åbnede samtalen for registrerede brugere",
+    "You opened the conversation to registered users" : "Du åbnede samtalen for registrerede brugere",
+    "An administrator opened the conversation to registered users" : "En administrator åbnede samtalen for registrerede brugere",
+    "{actor} opened the conversation to registered and guest app users" : "{actor} åbnede samtalen for registrerede og gæsteapp brugere",
+    "You opened the conversation to registered and guest app users" : "Du åbnede samtalen for registrerede og gæsteapp brugere",
+    "An administrator opened the conversation to registered and guest app users" : "En administrator åbnede samtalen for registrerede og gæsteapp brugere",
     "The conversation is now open to everyone" : "Samtalen er nu åben for alle",
     "{actor} opened the conversation to everyone" : "{actor} åbnede samtalen for alle",
     "You opened the conversation to everyone" : "Du åbnede samtalen for alle",
     "{actor} restricted the conversation to moderators" : "{actor} begrænsede samtalen til moderatorer",
     "You restricted the conversation to moderators" : "Du begrænsede samtalen til moderatorer",
+    "{actor} started breakout rooms" : "{actor} started breakout rum",
+    "You started breakout rooms" : "Du startede et breakout rum",
+    "{actor} stopped breakout rooms" : "{actor} stoppede breakout rum",
+    "You stopped breakout rooms" : "Du stoppede breakout rum",
     "{actor} allowed guests" : "{actor} tillod gæster",
     "You allowed guests" : "Du tillod gæster",
+    "An administrator allowed guests" : "En administrator tillod gæster",
     "{actor} disallowed guests" : "{actor} forbød gæster",
     "You disallowed guests" : "Du forbød gæster",
+    "An administrator disallowed guests" : "En administrator afviste gæster",
     "{actor} set a password" : "{actor} indstillede en adgangskode",
     "You set a password" : "Du indstillede en adgangskode",
+    "An administrator set a password" : "En administrator satte et kodeord",
     "{actor} removed the password" : "{actor} fjernede adgangskoden",
     "You removed the password" : "Du fjernede adgangskoden",
+    "An administrator removed the password" : "En administrator fjernede kodeordet",
     "{actor} added {user}" : "{actor} tilføjede {user}",
     "You joined the conversation" : "Du forbandt til samtalen",
     "{actor} joined the conversation" : "{actor} forbandt til samtalen",
     "You added {user}" : "Du tilføjede {user}",
     "{actor} added you" : "{actor} tilføjede dig",
+    "An administrator added you" : "En administrator tilføjede dig",
+    "An administrator added {user}" : "En administrator tilføjede {user}",
     "You left the conversation" : "Du forlod samtalen",
     "{actor} left the conversation" : "{actor} forlod samtalen",
     "{actor} removed {user}" : "{actor} fjernede {user}",
     "You removed {user}" : "Du fjernede {user}",
     "{actor} removed you" : "{actor} fjernede dig",
+    "An administrator removed you" : "En administrator fjernede dig",
+    "An administrator removed {user}" : "En administrator fjernede {user}",
+    "{actor} invited {user}" : "{actor} inviterede {user}",
+    "You invited {user}" : "Du inviterede {user}",
+    "An administrator invited {user}" : "En administrator inviterede {user}",
+    "{federated_user} accepted the invitation" : "{federated_user} tog imod invitationen",
+    "{actor} removed {federated_user}" : "{actor} fjernede {federated_user}",
+    "You removed {federated_user}" : "Du fjernede {federated_user}",
+    "An administrator removed {federated_user}" : "En administrator fjernede {federated_user}",
+    "{federated_user} declined the invitation" : "{federated_user} afviste invitationen",
+    "{actor} added group {group}" : "{actor} tilføjede gruppen {group}",
+    "You added group {group}" : "Du tilføjede en gruppen {group}",
+    "An administrator added group {group}" : "En administrator tilføjede gruppen {group}",
+    "{actor} removed group {group}" : "{actor} fjernede gruppen {group}",
+    "You removed group {group}" : "Du fjernede gruppen {group}",
+    "An administrator removed group {group}" : "En administrator fjernede gruppen {group}",
+    "{actor} added circle {circle}" : "{actor} tilføjede cirklen {circle}",
+    "You added circle {circle}" : "Du tilføjede cirklen {circle}",
     "{actor} promoted {user} to moderator" : "{actor} forfremmede {user} til moderator",
     "You promoted {user} to moderator" : "Du forfremmede {user} til moderator",
     "{actor} promoted you to moderator" : "{actor} forfremmede dig til moderator",
@@ -76,6 +146,7 @@ OC.L10N.register(
     "{actor} demoted you from moderator" : "{actor} degraderede dig fra moderator",
     "{actor} shared a file which is no longer available" : "{actor} delte en fil, der ikke længere er tilgængelig",
     "You shared a file which is no longer available" : "Du delte en fil, der ikke længere er tilgængelig",
+    "You cleared the history of the conversation" : "Du ryddede samtalens historik",
     "%s (guest)" : "%s (gæst)",
     "You missed a call from {user}" : "Du missede et opkald fra {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Opkald med 1 gæst (Varighed {duration})","Opkald med %n gæster (Varighed {duration})"],
@@ -83,14 +154,15 @@ OC.L10N.register(
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Opkald med {user1}, {user2} og {user3} (Varighed {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3} og {user4} (Varighed {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3}, {user4} og {user5} (Varighed {duration})",
+    "Talk conversations" : "Snak samtaler",
     "Talk to %s" : "Tal med %s",
     "File is not shared, or shared but not with the user" : "Filen er ikke delt, eller den er delt men ikke med brugeren",
     "File is too big" : "Filen er for stor",
     "Invalid file provided" : "Der er angivet en ugyldig fil",
     "Invalid image" : "Ugyldigt billede",
     "Unknown filetype" : "Ukendt filtype",
-    "An error occurred. Please contact your admin." : "Der opstod et problem. Kontakt venligst administratoren.",
     "Talk mentions" : "Snak samtaler",
+    "Call in progress" : "Opkald i gang",
     "Write to conversation" : "Skriv til samtale",
     "Writes event information into a conversation of your choice" : "Skriver begivenhedsinformation i en samtale du vælger",
     "%s invited you to a conversation." : "%s inviterede dig til en samtale",
@@ -101,6 +173,7 @@ OC.L10N.register(
     "Password request: %s" : "Password-forespørgsel: %s",
     "Private conversation" : "Privat samtale",
     "Deleted user (%s)" : "Slettet bruger (%s)",
+    "Dismiss notification" : "Fjern notifikation",
     "{user} sent you a private message" : "{user} sendte dig en privat besked",
     "{user} sent a message in conversation {call}" : "{user} sendte en besked i samtalen {call}",
     "A deleted user sent a message in conversation {call}" : "En slettet bruger sendte en besked i samtalen {call}",
@@ -131,6 +204,7 @@ OC.L10N.register(
     "Open settings" : "Indstillinger",
     "Conversations" : "Samtaler",
     "Messages" : "Beskeder",
+    "Avatar image is not square" : "Avatar billedet er ikke kvadratisk",
     "Andorra" : "Andorra",
     "Afghanistan" : "Afghanistan",
     "Albania" : "Albanien",
@@ -239,11 +313,6 @@ OC.L10N.register(
     "Save changes" : "Gem ændringer",
     "Saving …" : "Gemmer…",
     "Saved!" : "Gemt!",
-    "None" : "Ingen",
-    "User" : "ruger",
-    "Disabled" : "Deaktiveret",
-    "Moderators" : "Moderatorer",
-    "Users" : "Brugere",
     "Commands" : "Kommandoer",
     "Beta" : "Beta",
     "Name" : "Navn",
@@ -251,6 +320,11 @@ OC.L10N.register(
     "Script" : "Script",
     "Response to" : "Svar til",
     "Enabled for" : "Aktiveret for",
+    "None" : "Ingen",
+    "User" : "ruger",
+    "Disabled" : "Deaktiveret",
+    "Moderators" : "Moderatorer",
+    "Users" : "Brugere",
     "General settings" : "Generelle indstillinger",
     "Default notification settings" : "Standardindstillinger for notifikationer",
     "Default group notification" : "Standardindstillinger for gruppenotifikation",
@@ -269,11 +343,10 @@ OC.L10N.register(
     "Error" : "Fejl",
     "Blocked" : "Blokeret",
     "Expired" : "Udløbet",
-    "Shared secret" : "Delt hemmelighed",
     "Validate SSL certificate" : "Godkend SSL certifikat",
     "Delete this server" : "Slet denne server",
+    "Shared secret" : "Delt hemmelighed",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver bør eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observer at i opkald med mere end 4 deltagere uden en ekstern signaleringsserver, kan deltagerne opleve problemer med forbindelsen og det kan skabe høj belastning på deltagernes enheder.",
     "Don't warn about connectivity issues in calls with more than 4 participants" : "Vis ikke advarsel om forbindelsesproblemer i samtaler med mere end 4 deltagere",
     "STUN server URL" : "STUN-server URL",
     "STUN servers" : "STUN-servere",
@@ -285,56 +358,41 @@ OC.L10N.register(
     "TURN servers" : "TURN-servere",
     "OK" : "OK",
     "Checking …" : "Tjekker...",
+    "Back" : "Tilbage",
+    "Confirm" : "Bekræft",
+    "Reset" : "Nulstil",
+    "Cancel" : "Annuller",
     "Copy link" : "Kopier link",
+    "Connecting …" : "Forbinder ...",
     "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
     "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre i fanebladet \"deltagere\" i menuen i siden",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i fanebladet \"deltagere\" i menuen i siden, eller dele dette link for at invitere andre!",
     "Share this link to invite others!" : "Del dette link for at invitere andre!",
-    "Dismiss" : "Afvis",
-    "Show your screen" : "Vis din skærm",
-    "Stop screensharing" : "Stop skærmdeling",
-    "More actions" : "Flere handlinger",
-    "No audio" : "Ingen lyd",
     "Mute audio" : "Slå lyden fra",
-    "No camera" : "Intet kamera",
+    "You have been muted by a moderator" : "Du er blevet sat på mute af en moderator",
     "Disable video" : "Deaktiver video",
     "Enable video" : "Slå video til",
-    "Screensharing options" : "Skærmdeling indstillinger",
-    "Enable screensharing" : "Slå skærmdeling til",
-    "Grid view" : "Grid visning",
-    "Screen sharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
-    "Screen sharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden er hentet over HTTPS.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
-    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
-    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
-    "Back" : "Tilbage",
-    "You have been muted by a moderator" : "Du er blevet sat på mute af en moderator",
     "You" : "Dig",
     "Show screen" : "Vis skærm",
     "Mute" : "Mute",
+    "Collapse" : "Sammenfold",
+    "Expand" : "Udvid",
     "You need to be logged in to upload files" : "Du skal være logget ind for at kunne uploade filer",
     "Drop your files to upload" : "Drop dine filer for at uploade",
-    "Call in progress" : "Opkald i gang",
     "Favorite" : "Foretrukken",
+    "Description" : "Beskrivelse",
     "Restricted" : "Begrænset",
     "Conversation settings" : "Samtale indstillinger",
-    "Description" : "Beskrivelse",
-    "Notifications" : "Notifikationer",
-    "Meeting settings" : "Møde indstillinger",
+    "Personal" : "Personlig",
+    "Meeting" : "Møde",
+    "Permissions" : "Rettigheder",
+    "Danger zone" : "Farezone",
     "Leave conversation" : "Forlad samtale",
     "Delete conversation" : "Slet samtale",
-    "You need to promote a new moderator before you can leave the conversation." : "Du skal udnævne en ny moderator før du kan forlade samtalen.",
     "Do you really want to delete \"{displayName}\"?" : "Er du sikker på at du vil slette \"{displayName}\"?",
-    "Allow guests" : "Tillad gæster",
+    "Submit" : "Tilføj",
     "Password protection" : "Adgangskodebeskyttelse",
-    "Enter a password" : "Enter a password",
     "Copy conversation link" : "Kopier samtalelink",
-    "Conversation link copied to clipboard." : "Samtalelink kopieret til udklipsholder",
-    "The link could not be copied." : "Linket kunne ikke kopieres.",
-    "Open conversation to registered users" : "Begynd en samtale til registrerede brugere",
-    "Enable lobby" : "Aktiver lobby",
     "Start time (optional)" : "Starttid (valgfri)",
     "Save" : "Gem",
     "Edit" : "Rediger",
@@ -345,13 +403,14 @@ OC.L10N.register(
     "Login" : "Login",
     "Nickname" : "Kaldenavn",
     "Client ID" : "Klient-ID",
-    "Calls" : "Opkald",
+    "Notifications" : "Notifikationer",
     "Mark as read" : "Marker som læst",
+    "Mark as unread" : "Marker som ulæst",
     "Remove from favorites" : "Fjernet fra favoritter",
     "Add to favorites" : "Føj til favoritter",
     "You: {lastMessage}" : "Dig: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
-    "No matches" : "Ingen matches",
+    "You need to promote a new moderator before you can leave the conversation." : "Du skal udnævne en ny moderator før du kan forlade samtalen.",
     "Loading" : "Indlæser",
     "No search results" : "Ingen søgeresultater",
     "Groups" : "Grupper",
@@ -360,45 +419,56 @@ OC.L10N.register(
     "Groups and circles" : "Grupper og cirkler",
     "Other sources" : "Andre kilder",
     "An error occurred while performing the search" : "Der opstod en fejl under søgningen",
-    "Creating your conversation" : "Opret din samtale",
-    "All set" : "Samtalen er klar",
-    "Error while creating the conversation" : "Fejl under oprettelse af samtalen",
-    "Link copied to the clipboard!" : "Link kopieret til udklipsholderen!",
     "Create a new group conversation" : "Opret en ny gruppesamtale",
     "Allow guests to join via link" : "Tillad gæster at deltage via link",
     "Password protect" : "Beskyt med adgangskode",
+    "Creating your conversation" : "Opret din samtale",
+    "All set" : "Samtalen er klar",
+    "Error while creating the conversation" : "Fejl under oprettelse af samtalen",
     "Create conversation" : "Opret samtale",
     "Add participants" : "Tilføj deltagere",
     "Close" : "Luk",
-    "Choose a password" : "Vælg en adgangskode",
     "Search participants" : "Find deltagere",
     "Conversation name" : "Samtalenavn",
-    "Search conversations or users" : "Søg samtaler eller kontakter",
     "You are currently waiting in the lobby" : "Du venter nu i lobbyen",
+    "Devices" : "Enhed",
+    "Done" : "Færdig",
+    "No audio" : "Ingen lyd",
+    "No camera" : "Intet kamera",
+    "Upload" : "Send",
+    "Files" : "Filer",
+    "File to share" : "Vælg fil til deling",
+    "Invalid path selected" : "Ugyldig filsti valgt",
     "Unread messages" : "Ulæste beskedder",
     "Message sent" : "Beskeden blev sendt",
     "The message has been forwarded to {selectedConversationName}" : "Beskeden er videresendt til {selectedConversationName}",
+    "Dismiss" : "Afvis",
     "Forward message" : "Videresend besked",
     "Choose a conversation to forward the selected message." : "Vælg en samtale at videresende den valgte besked til.",
     "Error while forwarding message" : "Der opstod en fejl ved videresendelse af beskeden.",
     "Reply" : "Besvar",
+    "Reply privately" : "Svar privat",
     "Copy message link" : "Kopier besked link",
-    "Mark as unread" : "Marker som ulæst",
     "Go to file" : "Gå til fil",
+    "Translate" : "Oversæt",
     "Contact" : "Kontakt",
     "No messages" : "Ingen beskeder",
     "Today" : "I dag",
     "Yesterday" : "I går",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Create new poll" : "Opret ny afstemning",
+    "Add emoji" : "Tilføj emoji",
     "Send message" : "Send besked",
-    "File to share" : "Vælg fil til deling",
-    "New file" : "Ny fil",
     "Write message, @ to mention someone …" : "Skriv besked, brug @ for at nævne en bruger ...",
+    "Group" : "Gruppe",
+    "Upload from device" : "Upload fra enhed",
+    "Create new poll" : "Opret ny afstemning",
+    "Share from {nextcloud}" : "Del fra {nextcloud}",
+    "New file" : "Ny fil",
     "Blank" : "Tom",
-    "Invalid path selected" : "Ugyldig filsti valgt",
     "Settings" : "Indstillinger",
     "Create poll" : "Opret afstemning",
+    "Send" : "Send",
+    "Join" : "Deltag",
     "moderator" : "moderator",
     "guest" : "Gæst",
     "Demote from moderator" : "Degrader fra moderator",
@@ -419,13 +489,45 @@ OC.L10N.register(
     "Details" : "Detaljer",
     "Projects" : "Projekter",
     "Show all files" : "Vis alle filer",
+    "Search conversations or users" : "Søg samtaler eller kontakter",
+    "Select conversation" : "Vælg samtale",
+    "Link to a conversation" : "Link til samtale",
+    "Choose devices" : "Vælg enheder",
+    "Attachments folder" : "Mappe til vedhæftede filer",
     "Privacy" : "Privatliv",
+    "Share my read-status and show the read-status of others" : "Del min læsestatus og vis andres læsestatus",
+    "Sounds" : "Lyde",
+    "Play sounds when participants join or leave a call" : "Afspil lyde, når deltagere tilslutter sig eller forlader et opkald",
+    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Lyde til chat og opkaldsmeddelelser kan justeres i de personlige indstillinger.",
     "Keyboard shortcuts" : "Tastaturgenveje",
+    "Speed up your Talk experience with these quick shortcuts." : "Optimer din Talk-oplevelse med disse tastaturgenveje.",
+    "Focus the chat input" : "Fokuser chat funktionen",
+    "Unfocus the chat input to use shortcuts" : "Fjern fokus på chat funktionen for at bruge genveje",
+    "Fullscreen the chat or call" : "Fuldskærm for chat eller opkald",
     "Search" : "Søg",
+    "Shortcuts while in a call" : "Genveje under et opkald",
+    "Camera on and off" : "Kamera til og fra",
+    "Microphone on and off" : "Mikrofon til og fra",
+    "Push to talk or push to mute" : "Tryk for at tale eller tryk for at slå lyden fra",
+    "Raise or lower hand" : "Løft eller sænk hånden",
+    "Choose the folder in which attachments should be saved." : "Vælg den mappe, hvori vedhæftede filer skal gemmes.",
+    "Select location for attachments" : "Select location for attachments",
     "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
     "Start call" : "Start opkald",
-    "Rename conversation" : "Omdøb samtale",
-    "Send" : "Send",
+    "Open sidebar" : "Åbn sidebar",
+    "Open chat" : "Åbn chat",
+    "Show your screen" : "Vis din skærm",
+    "Stop screensharing" : "Stop skærmdeling",
+    "Screensharing options" : "Skærmdeling indstillinger",
+    "Enable screensharing" : "Slå skærmdeling til",
+    "Screen sharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden er hentet over HTTPS.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
+    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
+    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
+    "Grid view" : "Grid visning",
     "No unread mentions" : "Ingen ulæste samtaler",
     "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
     "Start a conversation" : "Start en samtale",
@@ -434,12 +536,9 @@ OC.L10N.register(
     "Mention room" : "Nævn rum",
     "The conversation does not exist" : "Samtalen findes ikke",
     "Join a conversation or start a new one!" : "Deltag i en samtale eller start en ny!",
-    "Select conversation" : "Vælg samtale",
-    "Link to a conversation" : "Link til samtale",
     "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
     "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
     "Media" : "Medier",
-    "Files" : "Filer",
     "Polls" : "Afstemning",
     "Locations" : "Sted",
     "Audio" : "Audio",
@@ -447,7 +546,6 @@ OC.L10N.register(
     "Do not disturb" : "Forstyr ikke",
     "Away" : "Ikke tilstede",
     "Error while sharing file" : "Fejl ved deling af fil",
-    "Sending signaling message has failed." : "Kunne ikke sende signalerings-besked",
     "Default" : "Standard",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Det virker som om du snakker mens lyden er slået fra, slå den til hvis du vil have at andre skal høre dig",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Dette tager lidt længere end forventet. Er medie-rettigheder allerede givet (eller nægtet)? Hvis ja så prøv at genstarte din browser, for lyd og video virker ikke lige nu",
@@ -467,14 +565,14 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
     "Android app" : "Android app",
     "iOS app" : "iOS app",
-    "Saved" : "Gemt",
-    "Add a new server" : "Tilføj en ny server",
-    "Chat notifications" : "Chat-notifikationer",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du venter nu i lobbyen. Dette møde er planlagt til {startTime}",
-    "Camera" : "Kamera",
-    "[Unknown username]" : "[Ukendt brugernavn]",
-    "Upload new files" : "Upload nye filer",
-    "Share from Files" : "Del fra Filer",
-    "Display name: " : "Vist navn:"
+    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observer at i opkald med mere end 4 deltagere uden en ekstern signaleringsserver, kan deltagerne opleve problemer med forbindelsen og det kan skabe høj belastning på deltagernes enheder.",
+    "More actions" : "Flere handlinger",
+    "Conversation link copied to clipboard." : "Samtalelink kopieret til udklipsholder",
+    "The link could not be copied." : "Linket kunne ikke kopieres.",
+    "No matches" : "Ingen matches",
+    "Link copied to the clipboard!" : "Link kopieret til udklipsholderen!",
+    "Sounds can currently not be played in Safari browser and iPad and iPhone devices due to technical restrictions by the manufacturer." : "Lyde kan i øjeblikket ikke afspilles i Safari-browseren og iPad- og iPhone-enheder på grund af tekniske begrænsninger fra producenten.",
+    "Rename conversation" : "Omdøb samtale",
+    "Sending signaling message has failed." : "Kunne ikke sende signalerings-besked"
 },
 "nplurals=2; plural=(n != 1);");
