@@ -4,12 +4,14 @@ OC.L10N.register(
     "Other activities" : "Alia aktivado",
     "Talk" : "Paroli",
     "Guest" : "Gasto",
+    "Talk conversations" : "Buŝaj konversacioj",
     "Talk to %s" : "Paroli al %s",
     "File is too big" : "Dosiero tro grandas",
     "Invalid file provided" : "Nevalida dosiero provizita",
     "Invalid image" : "Nevalida bildo",
     "Unknown filetype" : "Nekonata dosiertipo",
-    "An error occurred. Please contact your admin." : "Eraro okazis. Bonvolu kontakti vian administranton.",
+    "Dismiss notification" : "Forsendi sciigon",
+    "Avatar image is not square" : "Avatarbildo ne estas kvadrata",
     "Andorra" : "Andoro",
     "United Arab Emirates" : "Unuiĝintaj Arabaj Emirlandoj",
     "Afghanistan" : "Afganujo",
@@ -252,12 +254,12 @@ OC.L10N.register(
     "Save changes" : "Konservi ŝanĝojn",
     "Saving …" : "Konservado...",
     "Saved!" : "Konservita!",
+    "Beta" : "Beta",
+    "Name" : "Nomo",
     "None" : "Nenio",
     "User" : "Uzanto",
     "Disabled" : "Malŝaltita",
     "Users" : "Uzantoj",
-    "Beta" : "Beta",
-    "Name" : "Nomo",
     "Language" : "Lingvo",
     "Country" : "Lando",
     "Status" : "Stato",
@@ -267,18 +269,19 @@ OC.L10N.register(
     "Blocked" : "Barita",
     "Expired" : "Senvalidiĝis",
     "OK" : "Bone",
-    "Copy link" : "Kopii ligilon",
-    "Dismiss" : "Preterpasi",
-    "More actions" : "Pliaj agoj",
-    "Grid view" : "Krada vido",
     "Back" : "Antaŭen",
+    "Confirm" : "Konfirmi",
+    "Reset" : "Restarigi",
+    "Cancel" : "Nuligi",
+    "Copy link" : "Kopii ligilon",
     "You" : "Vi",
+    "Collapse" : "Maletendi",
     "Favorite" : "Pliŝatata",
-    "Restricted" : "Limigita",
     "Description" : "Priskribo",
-    "Notifications" : "Sciigoj",
+    "Restricted" : "Limigita",
+    "Personal" : "Persona",
+    "Submit" : "Sendi",
     "Password protection" : "Protektita per pasvorto",
-    "Enter a password" : "Entajpu pasvorton",
     "Save" : "Konservi",
     "Edit" : "Modifi",
     "Delete" : "Forigi",
@@ -287,6 +290,7 @@ OC.L10N.register(
     "Login" : "Login",
     "Nickname" : "Kromnomo",
     "Client ID" : "Klientidentigilo",
+    "Notifications" : "Sciigoj",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
     "Add to favorites" : "Aldoni al pliŝataĵoj",
     "Loading" : "Ŝargado",
@@ -294,12 +298,21 @@ OC.L10N.register(
     "Circles" : "Rondoj",
     "Password protect" : "Protekti per pasvorto",
     "Close" : "Malfermi",
+    "Devices" : "Aparatoj",
+    "Done" : "Farita",
+    "Upload" : "Alŝuti",
+    "Files" : "Dosieroj",
+    "Dismiss" : "Preterpasi",
     "Reply" : "Respondi",
+    "Translate" : "Traduku",
     "Contact" : "Kontakto",
     "Today" : "Hodiaŭ",
     "Yesterday" : "Hieraŭ",
+    "Group" : "Grupo",
     "Create new poll" : "Krei novan enketon",
     "Settings" : "Agordoj",
+    "Send" : "Sendi",
+    "Join" : "Aliĝi",
     "guest" : "gasto",
     "No results" : "Neniu rezulto",
     "Add users or groups" : "Add users or groups",
@@ -308,8 +321,8 @@ OC.L10N.register(
     "Privacy" : "Privateco",
     "Keyboard shortcuts" : "Fulmoklavoj",
     "Search" : "Serĉi",
-    "Send" : "Sendi",
-    "Files" : "Dosieroj",
+    "Open sidebar" : "Malfermi flankopanelon",
+    "Grid view" : "Krada vido",
     "Polls" : "Enketilo",
     "Audio" : "Sonaĵo",
     "Other" : "Alia",
@@ -317,7 +330,6 @@ OC.L10N.register(
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
     "Android app" : "Android-aplikaĵo",
     "iOS app" : "iOS-aplikaĵo",
-    "Saved" : "Konservita",
-    "Camera" : "Fotilo"
+    "More actions" : "Pliaj agoj"
 },
 "nplurals=2; plural=(n != 1);");
