@@ -17,11 +17,11 @@ OC.L10N.register(
     "Invalid file provided" : "Archivo proporcionado inválido",
     "Invalid image" : "Imagen inválida",
     "Unknown filetype" : "Tipo de archivo desconocido",
-    "An error occurred. Please contact your admin." : "Se presentó un error. Por favor contacta a tu adminsitrador. ",
     "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
     "Conversations" : "Conversaciones",
+    "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "This conversation has ended" : "Esta conversación ha terminado",
@@ -29,11 +29,11 @@ OC.L10N.register(
     "Everyone" : "Todos",
     "Save changes" : "Guardar cambios",
     "Saved!" : "¡Guardado!",
+    "Name" : "Nombre",
     "None" : "Ninguno",
     "User" : "Usuario",
     "Disabled" : "Deshabilitado",
     "Users" : "Ususarios",
-    "Name" : "Nombre",
     "General settings" : "Configuraciones generales",
     "Language" : "Idioma",
     "Country" : "País",
@@ -43,45 +43,37 @@ OC.L10N.register(
     "Error" : "Error",
     "Blocked" : "Bloqueado",
     "Expired" : "Expirado",
-    "Shared secret" : "Secreto compartido",
     "Validate SSL certificate" : "Validar certificado SSL",
+    "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
     "OK" : "OK",
     "Checking …" : "Verificando ...",
+    "Back" : "Atrás",
+    "Confirm" : "Confirmar",
+    "Reset" : "Restablecer",
+    "Cancel" : "Cancelar",
     "Copy link" : "Copiar liga",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
-    "Dismiss" : "Descartar",
-    "Show your screen" : "Mostrar tu pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
-    "More actions" : "Más acciones",
-    "No audio" : "Sin audio",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
-    "Screensharing options" : "Opciones de compartir pantalla",
-    "Enable screensharing" : "Habilitar compartir pantalla",
-    "Grid view" : "Vista de cuadrícula",
-    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
-    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
-    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
-    "Back" : "Atrás",
     "You" : "Tú",
     "Show screen" : "Mostrar pantalla",
+    "Collapse" : "Colapsar",
     "Favorite" : "Hacer favorito",
-    "Restricted" : "Restringido",
     "Description" : "Descripción",
-    "Notifications" : "Notificaciones",
+    "Restricted" : "Restringido",
+    "Personal" : "Personal",
+    "Permissions" : "Permisos",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Borrar conversación",
+    "Submit" : "Enviar",
     "Password protection" : "Protección con contraseña",
-    "Enter a password" : "Ingresa una contraseña",
     "Save" : "Guardar",
     "Edit" : "Editar",
     "Delete" : "Borrar",
@@ -90,7 +82,7 @@ OC.L10N.register(
     "Login" : "Iniciar sesión",
     "Nickname" : "Apodo",
     "Client ID" : "ID del cliente",
-    "Calls" : "Llamadas",
+    "Notifications" : "Notificaciones",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
     "Loading" : "Cargando",
@@ -99,14 +91,22 @@ OC.L10N.register(
     "Password protect" : "Proteger con contraseña",
     "Close" : "Cerrar",
     "Conversation name" : "Nombre de la conversación",
+    "Devices" : "Dispositivos",
+    "No audio" : "Sin audio",
+    "Upload" : "Cargar",
+    "Files" : "Archivos",
+    "Dismiss" : "Descartar",
     "Reply" : "Responder",
+    "Translate" : "Traducir",
     "Contact" : "Contacto",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Group" : "Grupo",
     "Create new poll" : "Crear nueva encuesta",
     "Settings" : "Configuraciones ",
     "Create poll" : "Crear encuesta",
+    "Send" : "Enviar",
     "moderator" : "moderador",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
@@ -119,10 +119,17 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "Rename conversation" : "Renombrar conversación",
-    "Send" : "Enviar",
+    "Show your screen" : "Mostrar tu pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Screensharing options" : "Opciones de compartir pantalla",
+    "Enable screensharing" : "Habilitar compartir pantalla",
+    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
+    "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
+    "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Grid view" : "Vista de cuadrícula",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
-    "Files" : "Archivos",
     "Polls" : "Encuestas",
     "Audio" : "Audio",
     "Other" : "Otro",
@@ -139,6 +146,7 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
-    "Saved" : "Guardado"
+    "More actions" : "Más acciones",
+    "Rename conversation" : "Renombrar conversación"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
