@@ -76,23 +76,25 @@ OC.L10N.register(
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "تماس با {user1} ، {user2} و {user3} (مدت زمان {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "تماس با {user1} ، {user2} ، {user3} و {user4} (مدت زمان {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "تماس با {user1} ، {user2} ، {user3} ، {user4} و {user5} (مدت زمان {duration})",
+    "Talk conversations" : "مکالمات صحبت کنید",
     "Talk to %s" : "صحبت کردن %s",
     "File is not shared, or shared but not with the user" : "پرونده به اشتراک گذاشته نمی شود ، یا به اشتراک گذاشته اما با کاربر به اشتراک گذاشته نمی شود",
     "File is too big" : "فایل خیلی بزرگ است",
     "Invalid file provided" : "فایل داده‌شده نا معتبر است",
     "Invalid image" : "عکس نامعتبر",
     "Unknown filetype" : "نوع فایل ناشناخته",
-    "An error occurred. Please contact your admin." : "یک خطا رخ داده است. لطفا با مدیر سیستم تماس بگیرید.",
     "Write to conversation" : "برای مکالمه بنویسید",
     "Writes event information into a conversation of your choice" : "اطلاعات رویداد را در گفتگوی مورد نظر شما می نویسد",
     "%s invited you to a conversation." : "%s شما را به یک گفتگو دعوت کرد",
     "You were invited to a conversation." : "شما به یک گفتگو دعوت شده اید",
     "Private conversation" : "مکالمه خصوصی",
+    "Dismiss notification" : "رد کردن اعلان",
     "{user} invited you to a private conversation" : "{user} شما را به یک گفتگوی خصوصی دعوت کرد",
     "{user} invited you to a group conversation: {call}" : "{user} شما را به یک گفتگو گروهی دعوت کرد: {call}",
     "Open settings" : "تنظیمات را باز کنید",
     "Conversations" : "گفتگو",
     "Messages" : "پیام ها",
+    "Avatar image is not square" : "تصویر آواتار مربع نیست",
     "There is no such account registered." : "این حساب کاربری ثبت نام نشده است.",
     "United Arab Emirates" : "امارات متحده عربی",
     "Afghanistan" : "افغانستان",
@@ -249,14 +251,16 @@ OC.L10N.register(
     "Limit to groups" : "محدود کردن به گروه ها",
     "Everyone" : "همه",
     "Save changes" : "ذخیره تغییرات",
+    "Saving …" : "ذخیره کردن …",
     "Saved!" : "ذخیره!",
+    "Beta" : "بتا",
+    "Name" : "نام",
     "None" : "هیچ‌کدام",
     "User" : "User",
     "Disabled" : "غیرفعال شده",
     "Users" : "کاربران",
-    "Beta" : "بتا",
-    "Name" : "نام",
     "General settings" : "تنظیمات عمومی",
+    "Default notification settings" : "تنظیمات اعلان پیش‌فرض",
     "Off" : "خاموش",
     "Language" : "زبان",
     "Country" : "کشور",
@@ -268,23 +272,27 @@ OC.L10N.register(
     "Active" : "فعال کردن",
     "Expired" : "منقضی شده",
     "OK" : "تایید",
+    "Back" : "بازگشت",
+    "Confirm" : "تائید",
+    "Reset" : "بازنشاندن",
+    "Cancel" : "لغو",
     "Copy link" : "کپی کردن لینک",
     "You can invite others in the participant tab of the sidebar" : "شما می‌توانید دیگران را از زبانه اعضا در نوارکناری دعوت کنید",
     "Share this link to invite others!" : "این پیوند را به اشتراک بگذارید تا دیگران را دعوت کنید!",
-    "Dismiss" : "پنهان کن",
-    "More actions" : "اقدامات بیشتر",
-    "Grid view" : "نمایش گرید",
-    "Back" : "بازگشت",
     "You" : "شما",
+    "Collapse" : "فروکش  کردن",
+    "Expand" : "بسط دادن",
     "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
     "Favorite" : "برگزیده",
     "Description" : "توضیحات",
-    "Notifications" : "آگاهی‌ها",
+    "Conversation settings" : "تنظیمات گفتگو",
+    "Personal" : "شخصی",
+    "Meeting" : "ملاقات",
+    "Permissions" : "مجوزها",
     "Leave conversation" : "ترک صحبت",
     "Delete conversation" : "مکالمه را حذف کنید",
-    "Allow guests" : "اجازه میهمانان",
+    "Submit" : "ارسال",
     "Password protection" : "Password protection",
-    "Enter a password" : "یک گذرواژه وارد کنید",
     "Save" : "ذخیره",
     "Edit" : "ویرایش",
     "Delete" : "حذف",
@@ -293,36 +301,47 @@ OC.L10N.register(
     "Login" : "ورود",
     "Nickname" : "نام مستعار",
     "Client ID" : "شناسه مشتری",
+    "Notifications" : "آگاهی‌ها",
     "Mark as read" : "علامت به عنوان خوانده‌شده",
-    "Remove from favorites" : "Remove from favorites",
-    "Add to favorites" : "Add to favorites",
+    "Mark as unread" : "علامت به عنوان خوانده‌نشده",
+    "Remove from favorites" : "حذف از برگزیده‌ها",
+    "Add to favorites" : "افزودن به برگزیده‌ها",
+    "No matches found" : "جستجو حاصلی دربرنداشت",
     "Open conversations" : "مکالمه جدید",
     "Loading" : "در حال بار گزاری",
+    "No search results" : "جستجو نتیجه‌ای نداشت",
     "Groups" : "گروه ها",
     "Circles" : "حلقه ها",
     "Create a new group conversation" : "ساخت گفتگوی گروهی جدید",
-    "Password protect" : "نگهداری کردن رمز عبور",
+    "Password protect" : "محافظت با گذرواژه",
     "Add participants" : "افزودن عضو",
     "Close" : "بستن",
     "Conversation name" : "نام مکالمه",
+    "Upload" : "بارگذاری",
+    "Files" : "فایل ها",
+    "File to share" : "فایل برای اشتراک‌گذاری",
+    "Invalid path selected" : "مسیر نامعتبر انتخاب شده است",
     "Unread messages" : "پیام‌های خوانده نشده",
     "Message sent" : "پیام ارسال شد",
+    "Dismiss" : "پنهان کن",
     "Reply" : "پاسخ",
-    "Mark as unread" : "علامت به عنوان خوانده‌نشده",
+    "Translate" : "ترجمه",
     "Contact" : "مخاطب",
     "Today" : "Today",
     "Yesterday" : "دیروز",
-    "Record voice message" : "ضبط پیام صوتی",
-    "Create new poll" : "نظرسنجی جدید ایجاد کنید",
     "Send message" : "پیام فرستادن",
-    "File to share" : "فایل برای اشتراک‌گذاری",
+    "Group" : "گروه",
+    "Create new poll" : "نظرسنجی جدید ایجاد کنید",
+    "Record voice message" : "ضبط پیام صوتی",
     "New file" : "پروندهٔ تازه",
-    "Invalid path selected" : "مسیر نامعتبر انتخاب شده است",
     "Settings" : "تنظیمات",
+    "Send" : "ارسال",
+    "Join" : "ملحق شدن",
     "guest" : "میهمان",
     "Demote from moderator" : "عزل از مدیر",
     "Promote to moderator" : "ترفیع به مدیر",
     "Remove participant" : "شرکت کننده را حذف کنید",
+    "Integrations" : "یکپارچگی‌ها",
     "Searching …" : "جستجوکردن …",
     "No results" : "نتیجه ای یافت نشد",
     "Add users or groups" : "کاربران یا گروه ها را اضافه کنید",
@@ -333,14 +352,14 @@ OC.L10N.register(
     "Privacy" : "حریم خصوصی",
     "Keyboard shortcuts" : "میان بر صفحه ی کلید",
     "Search" : "جستجو کردن",
-    "Rename conversation" : "تغییر نام مکالمه",
-    "Send" : "ارسال",
-    "Say hi to your friends and colleagues!" : "به رفقا و همدرس‌هایتان سلام کنید!",
+    "Recording" : "ضبط جلسه",
+    "Open sidebar" : "باز کردن نوار کناری",
+    "Grid view" : "نمایش گرید",
+    "Say hi to your friends and colleagues!" : "به رفقا و هم‌قطاران‌تان سلام کنید!",
     "Start a conversation" : "مکالمه را شروع کنید",
     "Join a conversation or start a new one!" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید!",
     "Join a conversation or start a new one" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید",
     "Media" : "رسانه‌ها",
-    "Files" : "فایل ها",
     "Polls" : "نظرسنجی ها",
     "Locations" : "مکانها",
     "Audio" : "صدا",
@@ -351,9 +370,7 @@ OC.L10N.register(
     "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
     "Android app" : "اپ اندروید",
     "iOS app" : "اپ iOS",
-    "Saved" : "ذخیره شد",
-    "Camera" : "دوربین",
-    "Upload new files" : "فایل‌های جدید را آپلود کنید",
-    "Share from Files" : "اشتراک‌گذاری از فایل‌ها"
+    "More actions" : "اقدامات بیشتر",
+    "Rename conversation" : "تغییر نام مکالمه"
 },
 "nplurals=2; plural=(n > 1);");
