@@ -67,17 +67,19 @@ OC.L10N.register(
     "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
     "You deleted a message" : "מחקת הודעה",
     "You missed a call from {user}" : "החמצת שיחה עם {user}",
+    "Talk conversations" : "דיוני שיח",
     "File is too big" : "הקובץ גדול מדי",
     "Invalid file provided" : "הקובץ שסופק שגוי",
     "Invalid image" : "תמונה לא חוקית",
     "Unknown filetype" : "סוג קובץ לא מוכר",
-    "An error occurred. Please contact your admin." : "אירעה שגיאה. יש ליצור קשר עם המנהל שלך.",
+    "Call in progress" : "מתנהלת שיחה",
     "Conversation invitation" : "הזמנה לדיון",
     "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
     "Meeting ID" : "מזהה פגישה",
     "Password request: %s" : "בקשת ססמה: %s",
     "Private conversation" : "דיון פרטי",
     "Deleted user (%s)" : "משתמש שנמחק (%s)",
+    "Dismiss notification" : "התעלמות מהתראה",
     "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
     "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
     "Join call" : "הצטרפות לשיחה",
@@ -90,6 +92,7 @@ OC.L10N.register(
     "Messages" : "הודעות",
     "{user}" : "{user}",
     "Messages in other conversations" : "הודעות בדיונים אחרים",
+    "Avatar image is not square" : "התמונה המייצגת אינה מרובעת",
     "The email address is invalid." : "כתובת הדוא״ל שגויה.",
     "Andorra" : "אנדורה",
     "United Arab Emirates" : "איחוד האמירויות הערביות",
@@ -353,11 +356,6 @@ OC.L10N.register(
     "Save changes" : "שמירת שינויים",
     "Saving …" : "מתבצעת שמירה…",
     "Saved!" : "נשמר!",
-    "None" : "אין",
-    "User" : "משתמש",
-    "Disabled" : "מושבת",
-    "Moderators" : "מפקחים",
-    "Users" : "משתמשים",
     "Commands" : "פקודות",
     "Beta" : "בטא",
     "Name" : "שם",
@@ -365,6 +363,11 @@ OC.L10N.register(
     "Script" : "סקריפט",
     "Response to" : "תגובה אל",
     "Enabled for" : "מופעל עבור",
+    "None" : "אין",
+    "User" : "משתמש",
+    "Disabled" : "מושבת",
+    "Moderators" : "מפקחים",
+    "Users" : "משתמשים",
     "General settings" : "הגדרות כלליות",
     "All messages" : "כל ההודעות",
     "Off" : "כבוי",
@@ -379,12 +382,12 @@ OC.L10N.register(
     "Expired" : "פג",
     "Matterbridge integration" : "שילוב עם Matterbridge",
     "Enable Matterbridge integration" : "הפעלת שילוב עם Matterbridge",
-    "Downloading …" : "מתבצעת הורדה…",
     "Installed version: {version}" : "גרסה מותקנת: {version}",
+    "Downloading …" : "מתבצעת הורדה…",
     "Failed to execute Matterbridge binary." : "הפעלת הבינרי של Matterbridge נכשלה.",
-    "Shared secret" : "סוד משותף",
     "Validate SSL certificate" : "אימות אישור SSL",
     "Delete this server" : "מחיקת השרת הזה",
+    "Shared secret" : "סוד משותף",
     "STUN server URL" : "כתובת שרת STUN",
     "STUN servers" : "שרתי STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
@@ -394,45 +397,34 @@ OC.L10N.register(
     "TURN servers" : "שרתי TURN",
     "OK" : "אישור",
     "Checking …" : "מתבצעת בדיקה…",
+    "Back" : "חזרה",
+    "Confirm" : "אימות",
+    "Reset" : "איפוס",
+    "Cancel" : "ביטול",
     "Copy link" : "העתקת קישור",
     "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
     "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
     "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
-    "Dismiss" : "התעלמות",
-    "Show your screen" : "הצגת המסך שלך",
-    "Stop screensharing" : "הפסקת שיתוף המסך",
-    "More actions" : "פעולות נוספות",
-    "No audio" : "אין שמע",
     "Mute audio" : "השתקת שמע",
     "Disable video" : "השבתת וידאו",
     "Enable video" : "הפעלת וידאו",
-    "Screensharing options" : "אפשרויות שיתוף מסך",
-    "Enable screensharing" : "הפעלת שיתוף מסך",
-    "Speaker view" : "תצוגת דובר",
-    "Grid view" : "תצוגת טבלה",
-    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
-    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
-    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
-    "Back" : "חזרה",
     "You" : "אני",
     "Show screen" : "הצגת מסך",
+    "Collapse" : "קיווץ",
     "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
-    "Call in progress" : "מתנהלת שיחה",
     "Favorite" : "סימון כמועדף",
+    "Description" : "תיאור",
     "Restricted" : "מוגבלת",
     "Conversation settings" : "הגדרות דיון",
-    "Description" : "תיאור",
-    "Notifications" : "התראות",
+    "Personal" : "אישי",
+    "Meeting" : "מפגש",
+    "Permissions" : "הרשאות",
     "Leave conversation" : "יציאה מהדיון",
     "Delete conversation" : "מחיקת דיון",
-    "Allow guests" : "לאפשר אורחים",
+    "Submit" : "שליחה",
     "Password protection" : "הגנה בססמה",
-    "Enter a password" : "נא להקליד ססמה",
     "Copy conversation link" : "העתקת קישור דיון",
-    "Enable lobby" : "הפעלת לובי",
     "Start time (optional)" : "מועד התחלה (רשות)",
     "Save" : "שמירה",
     "Edit" : "עריכה",
@@ -471,50 +463,60 @@ OC.L10N.register(
     "Jabber ID" : "מזהה Jabber",
     "unknown state" : "מצב לא ידוע",
     "Bridge saved" : "הגישור נשמר",
-    "Calls" : "שיחות",
-    "Choose devices" : "בחירת התקנים",
+    "Notifications" : "התראות",
     "Mark as read" : "סימון כנקרא",
+    "Mark as unread" : "סימון כלא נקרא",
     "Remove from favorites" : "הסרה מהמועדפים",
     "Add to favorites" : "הוספה למועדפים",
+    "No matches found" : "לא נמצאו התאמות",
     "Loading" : "בטעינה",
     "Groups" : "קבוצות",
     "Circles" : "מעגלים",
     "Groups and circles" : "קבוצות ומעגלים",
     "Other sources" : "מקורות אחרים",
     "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
+    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
+    "Password protect" : "הגנה בססמה",
     "Creating your conversation" : "הדיון שלך נוצר",
     "All set" : "הכול מוכן",
     "Error while creating the conversation" : "שגיאה ביצירת הדיון",
-    "Link copied to the clipboard!" : "הקישור הועתק ללוח הגזירים!",
-    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
-    "Password protect" : "הגנה בססמה",
     "Create conversation" : "יצירת דיון",
     "Add participants" : "הוספת משתתפים",
     "Close" : "סגירה",
-    "Choose a password" : "בחירת ססמה",
     "Search participants" : "חיפוש משתתפים",
     "Conversation name" : "שם דיון",
     "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
+    "Devices" : "מכשירים",
+    "Done" : "הסתיים",
+    "No audio" : "אין שמע",
+    "Upload" : "העלאה",
+    "Files" : "קבצים",
+    "File to share" : "קובץ לשיתוף",
+    "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Unread messages" : "הודעות שלא נקראו",
     "Message sent" : "הודעה נשלחה",
     "Deleting message" : "ההודעה נמחקה",
+    "Dismiss" : "התעלמות",
     "Reply" : "תגובה",
-    "Mark as unread" : "סימון כלא נקרא",
     "Go to file" : "מעבר לקובץ",
+    "Translate" : "תרגום",
     "Contact" : "איש/אשת קשר",
     "No messages" : "אין הודעות",
     "Today" : "היום",
     "Yesterday" : "מחר",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Share files to the conversation" : "שיתוף קבצים לדיון",
-    "Create new poll" : "יצירת סקר חדש",
     "Add emoji" : "הוספת אמוג׳י",
     "Send message" : "שליחת הודעה",
-    "File to share" : "קובץ לשיתוף",
+    "Write message, @ to mention someone …" : "כתבו תגובה, השתמשו ב-@ לתיוג משתמש",
+    "Group" : "קבוצה",
+    "Share files to the conversation" : "שיתוף קבצים לדיון",
+    "Create new poll" : "יצירת סקר חדש",
     "New file" : "קובץ חדש",
-    "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Settings" : "הגדרות",
     "Create poll" : "יצירת סקר",
+    "Send" : "שליחה",
+    "Add more files" : "הוספת קבצים נוספים",
+    "Join" : "הצטרף",
     "moderator" : "מפקח/ת",
     "guest" : "אורח",
     "Demote from moderator" : "הורדה מדרגת פיקוח",
@@ -534,6 +536,9 @@ OC.L10N.register(
     "Chat" : "צ׳אט",
     "Details" : "פרטים",
     "Projects" : "מיזמים",
+    "Select conversation" : "בחירת דיון",
+    "Link to a conversation" : "קישור לדיון",
+    "Choose devices" : "בחירת התקנים",
     "Attachments folder" : "תיקיית הקבצים המצורפים",
     "Privacy" : "פרטיות",
     "Keyboard shortcuts" : "קיצורי מקלדת",
@@ -541,10 +546,19 @@ OC.L10N.register(
     "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
     "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
     "Start call" : "התחלת שיחה",
-    "Rename conversation" : "שינוי שם הדיון",
+    "Open sidebar" : "פתיחת סרגל הצד",
+    "Show your screen" : "הצגת המסך שלך",
+    "Stop screensharing" : "הפסקת שיתוף המסך",
+    "Screensharing options" : "אפשרויות שיתוף מסך",
+    "Enable screensharing" : "הפעלת שיתוף מסך",
+    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
+    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
+    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
     "Mute others" : "השתקה של אחרים",
-    "Send" : "שליחה",
-    "Add more files" : "הוספת קבצים נוספים",
+    "Speaker view" : "תצוגת דובר",
+    "Grid view" : "תצוגת טבלה",
     "No unread mentions" : "אין אזכורים שלא נקראו",
     "Say hi to your friends and colleagues!" : "על הדרך לראות מה עם חבריך לעבודה!",
     "Start a conversation" : "התחלת דיון",
@@ -553,13 +567,11 @@ OC.L10N.register(
     "Mention room" : "אזכור חדר",
     "The conversation does not exist" : "הדיון לא קיים",
     "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
-    "Select conversation" : "בחירת דיון",
-    "Link to a conversation" : "קישור לדיון",
     "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
     "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
     "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
-    "Files" : "קבצים",
+    "Media" : "מדיה",
     "Polls" : "סקרים",
     "Locations" : "מיקומים",
     "Audio" : "שמע",
@@ -581,14 +593,9 @@ OC.L10N.register(
     "Signaling servers" : "שרתי איתות",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
-    "Saved" : "נשמר",
-    "Add a new server" : "הוספת שרת חדש",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "בנך בהמתנה בלובי. פגישה זו זומנה ל־{startTime}",
-    "Microphone" : "מיקרופון",
-    "Camera" : "מצלמה",
-    "[Unknown username]" : "[שם משתמש לא ידוע]",
-    "Upload new files" : "העלאת קבצים חדשים",
-    "Share from Files" : "שיתוף מקבצים",
-    "Display name: " : "שם תצוגה:"
+    "More actions" : "פעולות נוספות",
+    "Link copied to the clipboard!" : "הקישור הועתק ללוח הגזירים!",
+    "Rename conversation" : "שינוי שם הדיון",
+    "Exit fullscreen (F)" : "יציאה ממסך מלא (F)"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
