@@ -62,13 +62,13 @@ OC.L10N.register(
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal við {user1}, {user2} og {user3} (tímalengd {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3} og {user4} (tímalengd {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3}, {user4} og {user5} (tímalengd {duration})",
+    "Talk conversations" : "Samtöl",
     "Talk to %s" : "Tala við %s",
     "File is not shared, or shared but not with the user" : "Skránni er ekki deilt, eða henni er deilt en ekki með notandanum",
     "File is too big" : "Skrá er of stór",
     "Invalid file provided" : "Ógild skrá gefin",
     "Invalid image" : "Ógild mynd",
     "Unknown filetype" : "Óþekkt skráategund",
-    "An error occurred. Please contact your admin." : "Villa kom upp. Hafðu samband við kerfisstjóra.",
     "%s invited you to a conversation." : "%s bauð þér að taka þátt í samtali.",
     "You were invited to a conversation." : "Þér var boðið að taka þátt í samtali.",
     "Conversation invitation" : "Boð í samtal",
@@ -77,6 +77,7 @@ OC.L10N.register(
     "Password request: %s" : "Beiðni um lykilorð: %s",
     "Private conversation" : "Einkasamtal",
     "Deleted user (%s)" : "Eyddi notanda (%s)",
+    "Dismiss notification" : "Afgreiða tilkynningu",
     "{user} sent you a private message" : "{user} sendi þér einkaskilaboð",
     "{user} sent a message in conversation {call}" : "{user} sendi skilaboð í samtali {call}",
     "A deleted user sent a message in conversation {call}" : "Eyddur notandi sendi skilaboð í samtali {call}",
@@ -98,6 +99,7 @@ OC.L10N.register(
     "Open settings" : "Opna stillingar",
     "Conversations" : "Samtöl",
     "Messages" : "Skilaboð",
+    "Avatar image is not square" : "Auðkennismynd er ekki ferningslaga",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Sameinuðu arabísku furstadæmin",
     "Afghanistan" : "Afganistan",
@@ -356,11 +358,6 @@ OC.L10N.register(
     "Save changes" : "Vista breytingar",
     "Saving …" : "Vista …",
     "Saved!" : "Vistað!",
-    "None" : "Enginn",
-    "User" : "Notandi",
-    "Disabled" : "Óvirkt",
-    "Moderators" : "Umsjónarmenn",
-    "Users" : "Notendur",
     "Commands" : "Skipanir",
     "Beta" : "BETA-prófunarútgáfa",
     "Name" : "Nafn",
@@ -368,6 +365,11 @@ OC.L10N.register(
     "Script" : "Skrifta",
     "Response to" : "Svar til",
     "Enabled for" : "Virkjað fyrir",
+    "None" : "Enginn",
+    "User" : "Notandi",
+    "Disabled" : "Óvirkt",
+    "Moderators" : "Umsjónarmenn",
+    "Users" : "Notendur",
     "General settings" : "Almennar stillingar",
     "All messages" : "Öll skilaboð",
     "@-mentions only" : "@-mentions only",
@@ -381,11 +383,10 @@ OC.L10N.register(
     "Blocked" : "Útilokaður",
     "Active" : "Virkt",
     "Expired" : "Útrunnið",
-    "Shared secret" : "Sameiginlegur leynilykill",
     "Validate SSL certificate" : "Sannreyna SSL-skilríki",
     "Delete this server" : "Eyða þessum þjóni",
+    "Shared secret" : "Sameiginlegur leynilykill",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Athugaðu að samtöl með fleiri en 4 þátttakendum og án merkjasendingaþjóns geta orðið fyrir truflunum í tengingum ásamt því að valda miklu álagi á tengdum tækjum.",
     "STUN server URL" : "URL-slóð STUN-þjóns",
     "STUN servers" : "STUN-þjónar",
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-miðlari er notaður til að ákvarða opinbert vistfang þátttakenda á bak við beini.",
@@ -396,43 +397,34 @@ OC.L10N.register(
     "TURN servers" : "TURN-miðlarar",
     "OK" : "Í lagi",
     "Checking …" : "Athuga …",
+    "Back" : "Til baka",
+    "Confirm" : "Staðfesta",
+    "Reset" : "Endurstilla",
+    "Cancel" : "Hætta við",
     "Copy link" : "Afrita tengil",
     "Connecting …" : "Tengist ...",
     "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
     "You can invite others in the participant tab of the sidebar" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins eða deilt þessum tengli til að bjóða öðrum!",
     "Share this link to invite others!" : "Deildu þessum tengli til að bjóða öðrum!",
-    "Dismiss" : "Hafna",
-    "Show your screen" : "Birta skjáinn þinn",
-    "Stop screensharing" : "Hætta skjádeilingu",
-    "More actions" : "Fleiri aðgerðir",
-    "No audio" : "Ekkert hljóð",
     "Mute audio" : "Þagga hljóð",
+    "You have been muted by a moderator" : "You have been muted by a moderator",
     "Disable video" : "Gera myndskeið óvirk",
     "Enable video" : "Virkja myndskeið",
-    "Screensharing options" : "Valkostir skjádeilingar",
-    "Enable screensharing" : "Virkja skjádeilingu",
-    "Grid view" : "Reitasýn",
-    "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
-    "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
-    "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
-    "Back" : "Til baka",
-    "You have been muted by a moderator" : "You have been muted by a moderator",
     "You" : "Þú",
     "Show screen" : "Birta skjá",
+    "Collapse" : "Fella saman",
     "This conversation is read-only" : "This conversation is read-only",
     "Favorite" : "Eftirlæti",
-    "Restricted" : "Takmarkað",
     "Description" : "Lýsing",
-    "Notifications" : "Tilkynningar",
+    "Restricted" : "Takmarkað",
+    "Personal" : "Persónulegt",
+    "Meeting" : "Fundur",
+    "Permissions" : "Heimildir",
     "Leave conversation" : "Hætta í samtali",
     "Delete conversation" : "Eyða samtali",
-    "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
-    "Allow guests" : "Leyfa gesti",
+    "Submit" : "Senda inn",
     "Password protection" : "Verndun með lykilorði",
-    "Enter a password" : "Settu inn lykilorð",
     "Start time (optional)" : "Upphafstími (valfrjálst)",
     "Save" : "Vista",
     "Edit" : "Breyta",
@@ -443,25 +435,37 @@ OC.L10N.register(
     "Login" : "Innskráning",
     "Nickname" : "Stuttnefni",
     "Client ID" : "Biðlaraauðkenni",
-    "Calls" : "Samtöl",
+    "Notifications" : "Tilkynningar",
     "Mark as read" : "Merkja sem lesið",
+    "Mark as unread" : "Merkja allt sem ólesið",
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
     "Add to favorites" : "Bæta í eftirlæti",
+    "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
+    "No matches found" : "Engar samsvaranir fundust",
     "Loading" : "Hleð inn",
     "Groups" : "Hópar",
     "Circles" : "Hringir",
     "Create a new group conversation" : "Create a new group conversation",
     "Password protect" : "Verja með lykilorði",
+    "Enter password" : "Enter password",
     "Add participants" : "Bæta við þátttakanda",
     "Close" : "Loka",
     "Conversation name" : "Heiti samtals",
     "You are currently waiting in the lobby" : "You are currently waiting in the lobby",
+    "Devices" : "Tæki",
+    "Done" : "Lokið",
+    "No audio" : "Ekkert hljóð",
+    "Upload" : "Senda inn",
+    "Files" : "Skrár",
+    "File to share" : "Skrá til að deila",
+    "Invalid path selected" : "Ógild slóð valin",
     "Unread messages" : "Ólesin skilaboð",
     "Message sent" : "Skilaboðin hafa verið send",
+    "Dismiss" : "Hafna",
     "Reply" : "Svara",
     "Copy message link" : "Afrita skilaboðatengil",
-    "Mark as unread" : "Merkja allt sem ólesið",
     "Go to file" : "Fara í skrá",
+    "Translate" : "Þýða",
     "Contact" : "Tengiliður",
     "Poll" : "Poll",
     "End poll" : "End poll",
@@ -469,15 +473,16 @@ OC.L10N.register(
     "Today" : "Í dag",
     "Yesterday" : "Í gær",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Create new poll" : "Búa til nýja könnun",
     "Send message" : "Senda skilaboð",
-    "File to share" : "Skrá til að deila",
-    "New file" : "Ný skrá",
     "Write message, @ to mention someone …" : "Write message, @ to mention someone …",
+    "Group" : "Hópur",
+    "Create new poll" : "Búa til nýja könnun",
+    "New file" : "Ný skrá",
     "Blank" : "Tóm",
-    "Invalid path selected" : "Ógild slóð valin",
     "Settings" : "Stillingar",
     "Create poll" : "Búa til könnun",
+    "Send" : "Senda",
+    "Join" : "Taka þátt",
     "moderator" : "umsjónarmaður",
     "guest" : "gestanotandi",
     "Demote from moderator" : "Láta hætta sem umsjónarmann",
@@ -491,19 +496,28 @@ OC.L10N.register(
     "Details" : "Details",
     "Projects" : "Verkefni",
     "No shared items" : "No shared items",
+    "Select conversation" : "Veldu samtal",
+    "Link to a conversation" : "Tengill á samtal",
     "Privacy" : "Gagnaleynd",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Search" : "Search",
     "Start call" : "Hefja samtal",
-    "Rename conversation" : "Endurnefna samtal",
-    "Send" : "Senda",
+    "Open sidebar" : "Opna hliðarspjald",
+    "Open chat" : "Opna spjall",
+    "Show your screen" : "Birta skjáinn þinn",
+    "Stop screensharing" : "Hætta skjádeilingu",
+    "Screensharing options" : "Valkostir skjádeilingar",
+    "Enable screensharing" : "Virkja skjádeilingu",
+    "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Skjádeiling virkar aðeins með Firefox útgáfu 52 eða nýrri.",
+    "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
+    "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
+    "Grid view" : "Reitasýn",
     "Say hi to your friends and colleagues!" : "Segðu hæ við vini þína og samstarfsmenn!",
     "Start a conversation" : "Hefja samtal",
-    "Select conversation" : "Veldu samtal",
-    "Link to a conversation" : "Tengill á samtal",
     "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
     "Media" : "Margmiðlunargögn",
-    "Files" : "Skrár",
     "Polls" : "Kannanir",
     "Locations" : "Staðsetningar",
     "Audio" : "Hljóð",
@@ -527,10 +541,8 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
     "Android app" : "Android-forrit",
     "iOS app" : "iOS-forrit",
-    "Saved" : "Vistað",
-    "Add a new server" : "Bæta við nýjum þjóni",
-    "Microphone" : "Microphone",
-    "Camera" : "Myndavél",
-    "Message link copied to clipboard." : "Skilaboðatengill afritaður á klippispjald."
+    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Athugaðu að samtöl með fleiri en 4 þátttakendum og án merkjasendingaþjóns geta orðið fyrir truflunum í tengingum ásamt því að valda miklu álagi á tengdum tækjum.",
+    "More actions" : "Fleiri aðgerðir",
+    "Rename conversation" : "Endurnefna samtal"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
