@@ -17,21 +17,21 @@ OC.L10N.register(
     "Invalid file provided" : "არასწორი ფაილი",
     "Invalid image" : "არასწორი სურათი",
     "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
-    "An error occurred. Please contact your admin." : "წარმოიშვა შეცდომა. გთხოვთ დაუკავშირდეთ თქვენს ადმინისტრატორს.",
     "Join call" : "შეუერთდით ზარს",
     "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
     "Open settings" : "პარამეტრების გახსნა",
+    "Avatar image is not square" : "ავატარის სურათი არაა კვადრატი",
     "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
     "Leave call" : "ზარის დატოვება",
     "Limit to groups" : "ლიმიტი ჯგუფებზე",
     "Everyone" : "ყველა",
     "Save changes" : "ცვილებების შენახვა",
     "Saved!" : "შენახულია!",
+    "Name" : "სახელი",
     "None" : "არც ერთი",
     "User" : "მომხმარებელი",
     "Disabled" : "არაა მოქმედი",
     "Users" : "მომხმარებლები",
-    "Name" : "სახელი",
     "General settings" : "მთავარი პარამეტრები",
     "Language" : "ენა",
     "Country" : "ქვეყანა",
@@ -41,41 +41,34 @@ OC.L10N.register(
     "Error" : "შეცდომა",
     "Blocked" : "დაბლოკილია",
     "Expired" : "გაუქმდა",
-    "Shared secret" : "გაზიარებული საიდუმლო",
     "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
+    "Shared secret" : "გაზიარებული საიდუმლო",
     "STUN servers" : "STUN სერვერები",
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
     "TURN server protocols" : "TURN სერვერის პროტოკოლები",
     "OK" : "კარგი",
     "Checking …" : "მოწმდება ...",
+    "Back" : "უკან",
+    "Confirm" : "დადასტურება",
+    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
+    "Cancel" : "უარყოფა",
     "Copy link" : "ბმულის კოპირება",
     "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
     "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
     "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
-    "Dismiss" : "დათხოვნა",
-    "Show your screen" : "თქვენი ეკრანის ჩვენება",
-    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
-    "More actions" : "მეტი ქმედება",
     "Mute audio" : "ხმის ჩახშობა",
     "Disable video" : "ვიდეოს გათიშვა",
     "Enable video" : "ვიდეოს ამოქმედება",
-    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
-    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
-    "Grid view" : "ბადისებური ხედი",
-    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
-    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
-    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
-    "Back" : "უკან",
     "You" : "თქვენ",
     "Show screen" : "ეკრანის ჩვენება",
+    "Collapse" : "აკეცვა",
     "Favorite" : "რჩეული",
-    "Restricted" : "აკრძალული",
     "Description" : "აღწერილობა",
-    "Notifications" : "შეტყობინებები",
+    "Restricted" : "აკრძალული",
+    "Personal" : "პირადი",
+    "Permissions" : "უფლებები",
+    "Submit" : "გაგზავნა",
     "Password protection" : "პაროლით თავდაცვა",
-    "Enter a password" : "შეიყვანეთ პაროლი",
     "Save" : "შენახვა",
     "Edit" : "შეცვლა",
     "Delete" : "წაშლა",
@@ -84,8 +77,9 @@ OC.L10N.register(
     "Login" : "ავტორიზაცია",
     "Nickname" : "ნიკნეიმი",
     "Client ID" : "კლიენტის ID",
-    "Calls" : "ზარები",
+    "Notifications" : "შეტყობინებები",
     "Mark as read" : "წაკითხულად მონიშვნა",
+    "Mark as unread" : "წაუკითხავად მონიშვნა",
     "Remove from favorites" : "რჩეულებიდან ამოშლა",
     "Add to favorites" : "რჩეულებში დამატება",
     "Loading" : "იტვირთება",
@@ -94,16 +88,23 @@ OC.L10N.register(
     "Password protect" : "პაროლით დაცვა",
     "Close" : "დახურვა",
     "Conversation name" : "საუბრის სახელწოდება",
+    "Devices" : "მოწყობილობები",
+    "Done" : "დასრულდა",
+    "Upload" : "ატვირთვა",
+    "Files" : "ფაილები",
     "Message sent" : "წერილი გაგზავნილია",
+    "Dismiss" : "დათხოვნა",
     "Reply" : "პასუხი",
-    "Mark as unread" : "წაუკითხავად მონიშვნა",
+    "Translate" : "გადათარგმნეთ",
     "Contact" : "კონტაქტი",
     "Today" : "დღეს",
     "Yesterday" : "გუშინ",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Group" : "ჯგუფი",
     "Create new poll" : "ახალი გამოკითხვის შექმნა",
     "Settings" : "პარამეტრები",
     "Create poll" : "გამოკითხვის შექმნა",
+    "Send" : "გაგზავნა",
     "moderator" : "მოდერატორი",
     "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
     "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
@@ -116,8 +117,16 @@ OC.L10N.register(
     "Privacy" : "კონფიდენციალურობა",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
     "Search" : "ძიება",
-    "Send" : "გაგზავნა",
-    "Files" : "ფაილები",
+    "Show your screen" : "თქვენი ეკრანის ჩვენება",
+    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
+    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
+    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
+    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
+    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
+    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
+    "Grid view" : "ბადისებური ხედი",
     "Polls" : "გამოკითხვები",
     "Audio" : "აუდიო",
     "Other" : "სხვა",
@@ -133,6 +142,6 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
     "Android app" : "Android აპლიკაცია",
     "iOS app" : "iOS აპლიკაცია",
-    "Saved" : "დამახსოვრდა"
+    "More actions" : "მეტი ქმედება"
 },
 "nplurals=2; plural=(n!=1);");
