@@ -91,9 +91,18 @@ OC.L10N.register(
     "{actor} invited {user}" : "{actor} pakvietė naudotoją {user}",
     "You invited {user}" : "Jūs pakvietėte naudotoją {user}",
     "An administrator invited {user}" : "Administratorius pakvietė naudotoją {user}",
+    "{actor} added group {group}" : "{actor} pridėjo grupę {group}",
+    "You added group {group}" : "Jūs pridėjote grupę {group}",
+    "An administrator added group {group}" : "Administratorius pridėjo grupę {group}",
     "{actor} removed group {group}" : "{actor} pašalino grupę {group}",
     "You removed group {group}" : "Jūs pašalinote grupę {group}",
     "An administrator removed group {group}" : "Administratorius pašalino grupę {group}",
+    "{actor} added circle {circle}" : "{actor} pridėjo ratą {circle}",
+    "You added circle {circle}" : "Jūs pridėjote ratą {circle}",
+    "An administrator added circle {circle}" : "Administratorius pridėjo ratą {circle}",
+    "{actor} removed circle {circle}" : "{actor} pašalino ratą {circle}",
+    "You removed circle {circle}" : "Jūs pašalinote ratą {circle}",
+    "An administrator removed circle {circle}" : "Administratorius pašalino ratą {circle}",
     "{actor} promoted {user} to moderator" : "{actor} paaukštino naudotoją {user} į moderatorius",
     "You promoted {user} to moderator" : "Jūs paaukštinote naudotoją {user} į moderatorius",
     "{actor} promoted you to moderator" : "{actor} paaukštino jus į moderatorius",
@@ -134,7 +143,6 @@ OC.L10N.register(
     "Invalid file provided" : "Pateiktas neteisingas failas",
     "Invalid image" : "Netinkamas paveikslas",
     "Unknown filetype" : "Nežinomas failo tipas",
-    "An error occurred. Please contact your admin." : "Įvyko klaida. Susisiekite su savo administratoriumi.",
     "Talk mentions" : "Paminėjimai pokalbiuose",
     "Write to conversation" : "Rašyti į pokalbį",
     "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
@@ -148,6 +156,7 @@ OC.L10N.register(
     "Password request: %s" : "Slaptažodžio prašymas: %s",
     "Private conversation" : "Privatus pokalbis",
     "Deleted user (%s)" : "Ištrintas naudotojas (%s)",
+    "Dismiss notification" : "Atmesti pranešimą",
     "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
     "{user} sent a message in conversation {call}" : "{user} išsiuntė žinutę pokalbyje {call}",
     "A deleted user sent a message in conversation {call}" : "Ištrintas naudotojas išsiuntė žinutę pokalbyje {call}",
@@ -181,6 +190,7 @@ OC.L10N.register(
     "Conversations" : "Pokalbiai",
     "Messages" : "Žinutės",
     "{user}" : "{user}",
+    "Avatar image is not square" : "Avataro paveikslas nėra kvadratinis",
     "Something unexpected happened." : "Nutiko kažkas netikėto.",
     "The URL is invalid." : "URL yra neteisingas.",
     "An HTTPS URL is required." : "Reikalingas HTTPS URL.",
@@ -392,19 +402,20 @@ OC.L10N.register(
     "Everyone" : "Visi",
     "Users and moderators" : "Naudotojai ir moderatoriai",
     "Moderators only" : "Tik moderatoriai",
+    "Disable calls" : "Išjungti skambučius",
     "Save changes" : "Įrašyti pakeitimus",
     "Saving …" : "Įrašoma …",
     "Saved!" : "Įrašyta!",
-    "None" : "Nėra",
-    "User" : "Naudotojas",
-    "Disabled" : "Išjungta",
-    "Moderators" : "Moderatoriai",
-    "Users" : "Naudotojai",
     "Commands" : "Komandos",
     "Beta" : "Beta",
     "Name" : "Vardas",
     "Command" : "Komanda",
     "Script" : "Scenarijus",
+    "None" : "Nėra",
+    "User" : "Naudotojas",
+    "Disabled" : "Išjungta",
+    "Moderators" : "Moderatoriai",
+    "Users" : "Naudotojai",
     "General settings" : "Bendri nustatymai",
     "Integration into other apps" : "Integracija į kitas programėles",
     "Allow conversations on files" : "Leisti pokalbius failuose",
@@ -428,30 +439,37 @@ OC.L10N.register(
     "_%n user_::_%n users_" : ["%n naudotojas","%n naudotojai","%n naudotojų","%n naudotojas"],
     "Matterbridge integration" : "„Matterbridge“ integracija",
     "Enable Matterbridge integration" : "Įjungti „Matterbridge“ integraciją",
-    "Downloading …" : "Atsisiunčiama…",
     "Installed version: {version}" : "Įdiegta versija: {version}",
-    "SIP configuration" : "SIP konfigūracija",
-    "Phone number (Country)" : "Telefono numeris (Šalis)",
+    "Downloading …" : "Atsisiunčiama…",
     "Delete this server" : "Ištrinti šį serverį",
     "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
     "Error: Cannot connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
-    "Could not get version" : "Nepavyko gauti versijos",
     "Error: Unknown error occurred" : "Klaida: Įvyko nežinoma klaida",
+    "SIP configuration" : "SIP konfigūracija",
+    "Phone number (Country)" : "Telefono numeris (Šalis)",
+    "Could not get version" : "Nepavyko gauti versijos",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Didesniems diegimams pasirinktinai turėtų būti naudojamas signalinis serveris. Palikite tuščią norėdami naudoti vidinį signalinį serverį.",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Turėkite omenyje, kad skambučiuose su daugiau kaip 4 dalyviais be išorinio signalinio serverio, dalyviai gali patirti ryšio problemas ir sukelti didelę apkrovą dalyvaujantiems įrenginiams.",
     "Don't warn about connectivity issues in calls with more than 4 participants" : "Neįspėti apie jungiamumo problemas skambučiuose su daugiau kaip 4 dalyviais",
     "STUN server URL" : "STUN serverio URL",
     "STUN servers" : "STUN serveriai",
-    "{option1} and {option2}" : "{option1} ir {option2}",
-    "{option} only" : "tik {option}",
+    "Add a new STUN server" : "Pridėti naują STUN serverį",
+    "STUN settings saved" : "STUN nustatymai įrašyti",
     "TURN server URL" : "TURN serverio URL",
     "TURN server secret" : "TURN serverio paslaptis",
     "TURN server protocols" : "TURN serverio protokolai",
+    "{option1} and {option2}" : "{option1} ir {option2}",
+    "{option} only" : "tik {option}",
     "Test this server" : "Išbandyti šį serverį",
     "TURN servers" : "TURN serveriai",
+    "Add a new TURN server" : "Pridėti naują TURN serverį",
+    "TURN settings saved" : "TURN nustatymai įrašyti",
     "Failed" : "Nepavyko",
     "OK" : "Gerai",
     "Checking …" : "Tikrinama…",
+    "Back" : "Atgal",
+    "Confirm" : "Patvirtinti",
+    "Reset" : "Atstatyti",
+    "Cancel" : "Atsisakyti",
     "{nickName} raised their hand." : "{nickName} pakėlė ranką.",
     "A participant raised their hand." : "Dalyvis pakėlė ranką.",
     "Previous page of videos" : "Ankstesnis vaizdo įrašų puslapis",
@@ -462,85 +480,56 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje arba bendrindami šią nuorodą, skirtą pakviesti kitus asmenis!",
     "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
-    "Conversation link copied to clipboard" : "Pokalbio nuoroda nukopijuota į iškarpinę",
-    "The link could not be copied" : "Nepavyko nukopijuoti nuorodos",
-    "Dismiss" : "Atmesti",
-    "Show your screen" : "Rodyti savo ekraną",
-    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
-    "Lower hand" : "Nuleisti ranką",
-    "Lower hand (R)" : "Nuleisti ranką (R)",
-    "More actions" : "Daugiau veiksmų",
-    "Raise hand" : "Pakelti ranką",
-    "Raise hand (R)" : "Pakelti ranką (R)",
-    "Blur background" : "Sulieti foną",
-    "Disable background blur" : "Išjungti fono suliejimą",
     "You are not allowed to enable audio" : "Jums neleidžiama įjungti garsą",
-    "No audio" : "Nėra jokio garso",
     "Mute audio" : "Nutildyti garsą",
     "Mute audio (M)" : "Nutildyti garsą (M)",
     "Unmute audio" : "Įjungti garsą",
     "Unmute audio (M)" : "Įjungti garsą (M)",
+    "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
+    "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
     "You are not allowed to enable video" : "Jums neleidžiama įjungti vaizdą",
-    "No camera" : "Nėra kameros",
     "Disable video" : "Išjungti vaizdą",
     "Disable video (V)" : "Išjungti vaizdą (V)",
     "Enable video" : "Įjungti vaizdą",
     "Enable video (V)" : "Įjungti vaizdą (V)",
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
-    "Screensharing options" : "Ekrano bendrinimo parinktys",
-    "Enable screensharing" : "Įjungti ekrano bendrinimą",
-    "Disable screenshare" : "Išjungti ekrano bendrinimą",
-    "Grid view" : "Tinklelio rodinys",
-    "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
-    "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
-    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
-    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
-    "Back" : "Atgal",
-    "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
-    "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
     "You" : "Jūs",
     "Show screen" : "Rodyti ekraną",
     "Mute" : "Nutildyti",
     "Connection could not be established …" : "Nepavyko užmegzti ryšio…",
     "Connection problems …" : "Ryšio problemos…",
+    "Collapse" : "Suskleisti",
+    "Scroll to bottom" : "Slinkti į apačią",
     "This conversation is read-only" : "Šis pokalbis yra tik skaitymui",
     "Drop your files to upload" : "Tempkite failus, norėdami juos išsiųsti",
     "Favorite" : "Mėgstamas",
+    "Description" : "Aprašas",
+    "Edit conversation description" : "Taisyti pokalbio aprašą",
+    "Enter a description for this conversation" : "Įveskite šio pokalbio aprašą",
+    "Error while updating conversation description" : "Klaida atnaujinant pokalbio aprašą",
     "Restricted" : "Apribota",
     "Conversation settings" : "Pokalbio nustatymai",
-    "Description" : "Aprašas",
-    "Enter a description for this conversation" : "Įveskite šio pokalbio aprašą",
-    "Notifications" : "Pranešimai",
-    "Meeting settings" : "Susitikimo nustatymai",
+    "Personal" : "Asmeniniai",
+    "Meeting" : "Susitikimas",
+    "Permissions" : "Leidimai",
     "Danger zone" : "Pavojinga zona",
-    "Error while updating conversation description" : "Klaida atnaujinant pokalbio aprašą",
     "Be careful, these actions cannot be undone." : "Būkite atsargūs, šių veiksmų nebegalėsite atšaukti.",
     "Leave conversation" : "Išeiti iš pokalbio",
     "Delete conversation" : "Ištrinti pokalbį",
-    "You need to promote a new moderator before you can leave the conversation." : "Prieš išeidami iš pokalbio, turite paaukštinti naują moderatorių.",
     "Do you really want to delete \"{displayName}\"?" : "Ar tikrai norite ištrinti \"{displayName}\"?",
     "Error while deleting conversation" : "Klaida ištrinant pokalbį",
     "Error while clearing chat history" : "Klaida išvalant pokalbio istoriją",
-    "_%n week_::_%n weeks_" : ["%n savaitė","%n savaitės","%n savaičių","%n savaitė"],
-    "_%n day_::_%n days_" : ["%n diena","%n dienos","%n dienų","%n diena"],
+    "Submit" : "Pateikti",
     "_%n hour_::_%n hours_" : ["%n valanda","%n valandos","%n valandų","%n valanda"],
-    "Allow guests to use a public link to join this conversation." : "Leisti svečiams naudotis viešąja nuoroda, kad prisijungtų prie šio pokalbio.",
-    "Allow guests" : "Leisti svečius",
+    "_%n day_::_%n days_" : ["%n diena","%n dienos","%n dienų","%n diena"],
+    "_%n week_::_%n weeks_" : ["%n savaitė","%n savaitės","%n savaičių","%n savaitė"],
     "Password protection" : "Apsauga slaptažodžiu",
-    "Enter a password" : "Enter a password",
     "Save password" : "Įrašyti slaptažodį",
     "Copy conversation link" : "Kopijuoti pokalbio nuorodą",
     "Conversation password has been saved" : "Pokalbio slaptažodis įrašytas",
     "Conversation password has been removed" : "Pokalbio slaptažodis pašalintas",
     "Error occurred while saving conversation password" : "Įrašant pokalbio slaptažodį įvyko klaida",
-    "Conversation link copied to clipboard." : "Pokalbio nuoroda nukopijuota į iškarpinę.",
-    "The link could not be copied." : "Nepavyko nukopijuoti nuorodos.",
     "Invitations sent" : "Pakvietimai išsiųsti",
-    "This conversation will be shown in search results" : "Šis pokalbis bus rodomas paieškos rezultatuose",
-    "Enable lobby" : "Įjungti laukimo salę",
     "Start time (optional)" : "Pradžios laikas (nebūtinas)",
     "Lock conversation" : "Užrakinti pokalbį",
     "Error occurred when locking the conversation" : "Užrakinant pokalbį, įvyko klaida",
@@ -576,19 +565,17 @@ OC.L10N.register(
     "MUC server URL" : "MUC serverio URL",
     "Jabber ID" : "Jabber ID",
     "unknown state" : "nežinoma būsena",
-    "Calls" : "Skambučiai",
+    "Notifications" : "Pranešimai",
     "Notify about calls in this conversation" : "Pranešti apie skambučius šiame pokalbyje",
-    "Allow participants to join from a phone." : "Leisti dalyviams prisijungti iš telefono.",
-    "Submit conversation description" : "Pateikti pokalbio aprašą",
-    "Edit conversation description" : "Taisyti pokalbio aprašą",
-    "The description must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Aprašas privalo būti trumpesnis arba lygiai {maxLength} simbolių ilgio. Jūsų dabartinis tekstas yra {charactersCount} simbolių ilgio.",
-    "Choose devices" : "Pasirinkti įrenginius",
     "Mark as read" : "Žymėti kaip skaitytą",
+    "Mark as unread" : "Žymėti kaip neskaitytą",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
     "Joining conversation …" : "Prisijungiama prie pokalbio…",
     "You: {lastMessage}" : "Jūs: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
+    "You need to promote a new moderator before you can leave the conversation." : "Prieš išeidami iš pokalbio, turite paaukštinti naują moderatorių.",
+    "No matches found" : "Nerasta jokių atitikmenų",
     "Open conversations" : "Atverti pokalbius",
     "Loading" : "Įkeliama",
     "No search results" : "Nėra paieškos rezultatų",
@@ -601,62 +588,66 @@ OC.L10N.register(
     "Groups and circles" : "Grupės ir ratai",
     "Other sources" : "Kiti šaltiniai",
     "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
-    "Creating your conversation" : "Kuriamas jūsų pokalbis",
-    "All set" : "Viskas paruošta",
-    "Error while creating the conversation" : "Klaida kuriant pokalbį",
-    "Link copied to the clipboard!" : "Nuoroda nukopijuota į iškarpinę!",
     "Create a new group conversation" : "Sukurti naują grupės pokalbį",
     "Allow guests to join via link" : "Leisti svečiams prisijungti per nuorodą",
     "Password protect" : "Apsaugoti slaptažodžiu",
+    "Creating your conversation" : "Kuriamas jūsų pokalbis",
+    "All set" : "Viskas paruošta",
+    "Error while creating the conversation" : "Klaida kuriant pokalbį",
     "Create conversation" : "Sukurti pokalbį",
     "Add participants" : "Pridėti dalyvius",
     "Close" : "Užverti",
     "Search participants" : "Ieškoti dalyvių",
     "Cancel search" : "Atsisakyti paieškos",
     "Conversation name" : "Pokalbio pavadinimas",
-    "Search conversations or users" : "Ieškoti pokalbių ar naudotojų",
     "You are currently waiting in the lobby" : "Šiuo metu laukiate laukimo salėje",
     "No microphone available" : "Nėra prieinamo mikrofono",
     "Select microphone" : "Pasirinkti mikrofoną",
     "No camera available" : "Nėra prieinamos kameros",
     "Select camera" : "Pasirinkti kamerą",
+    "Devices" : "Įrenginiai",
+    "Done" : "Atlikta",
+    "No audio" : "Nėra jokio garso",
+    "No camera" : "Nėra kameros",
+    "Upload" : "Įkelti",
+    "Files" : "Failai",
+    "File to share" : "Failas, kurį bendrinti",
+    "Invalid path selected" : "Pasirinktas neteisingas kelias",
     "Unread messages" : "Neskaitytos žinutės",
     "Message sent" : "Žinutė išsiųsta",
     "You are not allowed to share files" : "Jums neleidžiama bendrinti failų",
     "You cannot send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį",
     "Message deleted successfully" : "Žinutė sėkmingai ištrinta",
+    "Dismiss" : "Atmesti",
     "Forward message" : "Persiųsti žinutę",
     "Error while forwarding message" : "Klaida persiunčiant žinutę",
     "Reply" : "Atsakyti",
     "Reply privately" : "Atsakyti privačiai",
     "Copy message link" : "Kopijuoti žinutės nuorodą",
-    "Mark as unread" : "Žymėti kaip neskaitytą",
     "Go to file" : "Pereiti į failą",
+    "Translate" : "Verskite",
     "React with {emoji}" : "Reaguoti naudojant {emoji}",
     "React with another emoji" : "Reaguoti kita šypsenėle",
-    "Message link copied to clipboard" : "Žinutės nuoroda nukopijuota į iškarpinę",
     "Your browser does not support playing audio files" : "Jūsų naršyklė nepalaiko garso įrašo failų atkūrimo",
     "Contact" : "Adresatas",
     "Remove {fileName}" : "Šalinti {fileName}",
     "Poll" : "Apklausa",
     "See results" : "Rodyti rezultatus",
     "No messages" : "Nėra laiškų",
-    "Scroll to bottom" : "Slinkti į apačią",
     "Today" : "Šiandien",
     "Yesterday" : "Vakar",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Microphone either not available or disabled in settings" : "Mikrofonas arba neprieinamas, arba išjungtas nustatymuose",
-    "Create new poll" : "Sukurti naują apklausą",
     "Add emoji" : "Pridėti šypsenėlę",
     "Send message" : "Siųsti žinutę",
+    "This conversation has been locked" : "Šis pokalbis užrakintas",
+    "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
+    "Group" : "Grupė",
+    "Create new poll" : "Sukurti naują apklausą",
+    "Microphone either not available or disabled in settings" : "Mikrofonas arba neprieinamas, arba išjungtas nustatymuose",
     "Create and share a new file" : "Sukurti ir bendrinti naują failą",
     "Name of the new file" : "Naujo failo pavadinimas",
     "Create file" : "Sukurti failą",
-    "File to share" : "Failas, kurį bendrinti",
     "New file" : "Naujas failas",
-    "This conversation has been locked" : "Šis pokalbis užrakintas",
-    "Write message, @ to mention someone …" : "Rašykite žinutę, naudokite @ norėdami kažką paminėti…",
-    "Invalid path selected" : "Pasirinktas neteisingas kelias",
     "Error while creating file" : "Klaida kuriant failą",
     "Question" : "Klausimas",
     "Answers" : "Atsakymai",
@@ -664,9 +655,12 @@ OC.L10N.register(
     "Settings" : "Nustatymai",
     "Private poll" : "Privati apklausa",
     "Create poll" : "Sukurti apklausą",
+    "Send" : "Siųsti",
+    "Add more files" : "Pridėti daugiau failų",
     "Enable the microphone" : "Įjungti mikrofoną",
     "Enable the camera" : "Įjungti kamerą",
     "Share the screen" : "Bendrinti ekraną",
+    "Join" : "Prisijungti",
     "Disable lobby" : "Išjungti laukimo salę",
     "moderator" : "moderatorius",
     "guest" : "svečias",
@@ -697,6 +691,8 @@ OC.L10N.register(
     "Show all files" : "Rodyti visus failus",
     "Meeting ID: {meetingId}" : "Susitikimo ID: {meetingId}",
     "Your PIN: {attendeePin}" : "Jūsų PIN kodas: {attendeePin}",
+    "Search conversations or users" : "Ieškoti pokalbių ar naudotojų",
+    "Choose devices" : "Pasirinkti įrenginius",
     "Attachments folder" : "Priedų aplankas",
     "Privacy" : "Privatumas",
     "Sounds" : "Garsai",
@@ -712,12 +708,28 @@ OC.L10N.register(
     "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
     "Your privacy setting has been saved" : "Jūsų privatumo nustatymas įrašytas",
     "Start call" : "Pradėti skambutį",
-    "Toggle fullscreen" : "Perjungti visą ekraną",
-    "Rename conversation" : "Pervadinti pokalbį",
-    "Exit fullscreen (F)" : "Išeiti iš viso ekrano (F)",
-    "Fullscreen (F)" : "Visas ekranas (F)",
-    "Send" : "Siųsti",
-    "Add more files" : "Pridėti daugiau failų",
+    "Open sidebar" : "Atverti šoninę juostą",
+    "Open chat" : "Atverti pokalbį",
+    "Show your screen" : "Rodyti savo ekraną",
+    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
+    "Disable background blur" : "Išjungti fono suliejimą",
+    "Blur background" : "Sulieti foną",
+    "You are not allowed to enable screensharing" : "Jums neleidžiama įjungti ekrano bendrinimo",
+    "Screensharing options" : "Ekrano bendrinimo parinktys",
+    "Enable screensharing" : "Įjungti ekrano bendrinimą",
+    "Disable screenshare" : "Išjungti ekrano bendrinimą",
+    "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Ekrano bendrinimas veikia tik naudojant Firefox 52 arba naujesnę versiją.",
+    "Screensharing extension is required to share your screen." : "Norint bendrinti ekraną yra reikalingas ekrano bendrinimo plėtinys.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Norėdami bendrinti savo ekraną, naudokite kitą naršyklę, tokią kaip Firefox ar Chrome.",
+    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
+    "Grid view" : "Tinklelio rodinys",
+    "Raise hand" : "Pakelti ranką",
+    "Raise hand (R)" : "Pakelti ranką (R)",
+    "Lower hand" : "Nuleisti ranką",
+    "Lower hand (R)" : "Nuleisti ranką (R)",
     "No unread mentions" : "Nėra neskaitytų paminėjimų",
     "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
     "Start a conversation" : "Pradėti pokalbį",
@@ -734,7 +746,6 @@ OC.L10N.register(
     "Access to camera is only possible with HTTPS" : "Prieiga prie kameros yra įmanoma tik naudojant HTTPS",
     "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
     "Media" : "Medija",
-    "Files" : "Failai",
     "Polls" : "Apklausos",
     "Locations" : "Vietos",
     "Other" : "Kita",
@@ -742,6 +753,8 @@ OC.L10N.register(
     "Do not disturb" : "Netrukdyti",
     "Away" : "Atsitraukęs",
     "Error while sharing file" : "Klaida bendrinant failą",
+    "Conversation link copied to clipboard" : "Pokalbio nuoroda nukopijuota į iškarpinę",
+    "The link could not be copied" : "Nepavyko nukopijuoti nuorodos",
     "An error happened when trying to share your file" : "Bandant bendrinti jūsų failą įvyko klaida",
     "{guest} (guest)" : "{guest} (svečias)",
     "Could not post message: {errorMessage}" : "Nepavyko paskelbti žinutės: {errorMessage}",
@@ -750,7 +763,6 @@ OC.L10N.register(
     "Failed to join the conversation. Try to reload the page." : "Nepavyko prisijungti prie pokalbio. Pabandykite įkelti puslapį iš naujo.",
     "Leave this page" : "Išeiti iš šio puslapio",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud yra techninės priežiūros veiksenoje, įkelkite puslapį iš naujo",
-    "Sending signaling message has failed." : "Nepavyko išsiųsti signalinės žinutės.",
     "Establishing signaling connection is taking longer than expected …" : "Signalinio ryšio užmezgimas trunka ilgiau nei tikėtasi…",
     "Failed to establish signaling connection. Retrying …" : "Nepavyko užmegzti signalinio ryšio. Bandoma iš naujo…",
     "Default" : "Numatytoji",
@@ -773,17 +785,18 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
     "Android app" : "Android programėlė",
     "iOS app" : "iOS programėlė",
-    "Saved" : "Įrašyta",
-    "Add a new server" : "Pridėti naują serverį",
-    "Error while accessing camera: it is likely in use by another program" : "Klaida gaunant prieigą prie kameros: tikėtina, kad ją naudoja kita programa",
-    "Chat notifications" : "Pokalbio pranešimai",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Šiuo metu laukiate laukimo salėje. Šio susitikimo pradžia yra suplanuota {startTime}",
-    "Microphone" : "Mikrofonas",
-    "Camera" : "Kamera",
-    "Message link copied to clipboard." : "Žinutės nuoroda nukopijuota į iškarpinę.",
-    "[Unknown username]" : "[Nežinomas naudotojo vardas]",
-    "Upload new files" : "Išsiųsti naujus failus",
-    "Share from Files" : "Bendrinti iš Failų",
-    "Display name: " : "Rodomas vardas: "
+    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Turėkite omenyje, kad skambučiuose su daugiau kaip 4 dalyviais be išorinio signalinio serverio, dalyviai gali patirti ryšio problemas ir sukelti didelę apkrovą dalyvaujantiems įrenginiams.",
+    "More actions" : "Daugiau veiksmų",
+    "Conversation link copied to clipboard." : "Pokalbio nuoroda nukopijuota į iškarpinę.",
+    "The link could not be copied." : "Nepavyko nukopijuoti nuorodos.",
+    "Submit conversation description" : "Pateikti pokalbio aprašą",
+    "The description must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Aprašas privalo būti trumpesnis arba lygiai {maxLength} simbolių ilgio. Jūsų dabartinis tekstas yra {charactersCount} simbolių ilgio.",
+    "Link copied to the clipboard!" : "Nuoroda nukopijuota į iškarpinę!",
+    "Message link copied to clipboard" : "Žinutės nuoroda nukopijuota į iškarpinę",
+    "Toggle fullscreen" : "Perjungti visą ekraną",
+    "Rename conversation" : "Pervadinti pokalbį",
+    "Exit fullscreen (F)" : "Išeiti iš viso ekrano (F)",
+    "Fullscreen (F)" : "Visas ekranas (F)",
+    "Sending signaling message has failed." : "Nepavyko išsiųsti signalinės žinutės."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
