@@ -155,6 +155,7 @@ OC.L10N.register(
     "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} го заврши повикот со {user1}, {user2}, {user3} и {user4} (Времетраење {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Повик со {user1}, {user2}, {user3}, {user4} и {user5} (Времетраење {duration})",
     "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} го заврши повикот со {user1}, {user2}, {user3}, {user4} и {user5} (Времетраење {duration})",
+    "Talk conversations" : "Talk разговори",
     "Talk to %s" : "Разговор со %s",
     "File is not shared, or shared but not with the user" : "Датотеката не е споделена, или е споделена но не со корисници",
     "No account available to delete." : "Нема сметка достапна за бришење.",
@@ -163,8 +164,9 @@ OC.L10N.register(
     "Invalid file provided" : "Доставена е невалидна датотека",
     "Invalid image" : "Невалидна фотографија",
     "Unknown filetype" : "Непознат тип на датотека",
-    "An error occurred. Please contact your admin." : "Настана грешка. Контактирате со администраторот.",
     "Talk mentions" : "Спомнувања",
+    "Call in progress" : "Повик е во тек",
+    "You were mentioned" : "Споменати сте",
     "Write to conversation" : "Пишивајте во разговорот",
     "Writes event information into a conversation of your choice" : "Напишете информации за настанот во разговорот по ваш избор",
     "%s invited you to a conversation." : "%s ве покани на разговор.",
@@ -179,6 +181,7 @@ OC.L10N.register(
     "Password request: %s" : "Барање за лозинка: %s",
     "Private conversation" : "Приватен разговор",
     "Deleted user (%s)" : "Избришан корисник (%s)",
+    "Dismiss notification" : "Отфрли известување",
     "{user1} shared room {roomName} on {remoteServer} with you" : "{user1} сподели соба {roomName} на {remoteServer} со вас",
     "{user} in {call}" : "{user} во {call}",
     "Deleted user in {call}" : "Избришан корисник во {call}",
@@ -217,7 +220,7 @@ OC.L10N.register(
     "Open settings" : "Отвори параметри",
     "The hosted signaling server is now configured and will be used." : "Signaling сервер е конфигуриран и сега ќе се користи.",
     "The hosted signaling server was removed and will not be used anymore." : "Signaling серверот е избришан и нема да се користи повеќе.",
-    "Contact via Talk" : "Контактирај преку Talk",
+    "Contact via Talk" : "Разговор",
     "Open Talk" : "Започни разговор",
     "Conversations" : "Разговори",
     "Messages" : "Пораки",
@@ -225,6 +228,7 @@ OC.L10N.register(
     "Messages in {conversation}" : "Пораки во {conversation}",
     "{user} in {conversation}" : "{user} во {conversation}",
     "Messages in other conversations" : "Пораки во други разговори",
+    "Avatar image is not square" : "Сликата за Аватар не е квадратна",
     "Something unexpected happened." : "Се случи нешто неочекувано.",
     "The URL is invalid." : "Невалидна URL адреса.",
     "An HTTPS URL is required." : "Потебна е HTTPS URL.",
@@ -511,11 +515,6 @@ OC.L10N.register(
     "Save changes" : "Зачувај ги промените",
     "Saving …" : "Зачувува ...",
     "Saved!" : "Зачувано!",
-    "None" : "Ништо",
-    "User" : "Корисник",
-    "Disabled" : "Оневозможен",
-    "Moderators" : "Модератори",
-    "Users" : "Корисници",
     "Commands" : "Команди",
     "Beta" : "Бета",
     "Name" : "Име",
@@ -524,6 +523,11 @@ OC.L10N.register(
     "Response to" : "Одговори на",
     "Enabled for" : "Овозможено за",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Командите се нова бета опција во Nextcloud Talk. Тие ви дозволуваат да извршувате скрипти на вашиот сервер Nextcloud. Можете да ги дефинирате со нашиот интерфејс на командната линија. Пример за скрипта на калкулатор може да се најде во нашата {linkstart}документација{linkend}.",
+    "None" : "Ништо",
+    "User" : "Корисник",
+    "Disabled" : "Оневозможен",
+    "Moderators" : "Модератори",
+    "Users" : "Корисници",
     "General settings" : "Општи параметри",
     "Default notification settings" : "Стандардни поставки за известување",
     "Default group notification" : "Стандардни групни известувања",
@@ -549,105 +553,73 @@ OC.L10N.register(
     "_%n user_::_%n users_" : ["1 корисник","%n корисници"],
     "Matterbridge integration" : "Мост интеграција",
     "Enable Matterbridge integration" : "Овозможи мост интеграција",
+    "Installed version: {version}" : "Инсталирана верзија: {version}",
     "Downloading …" : "Преземање ...",
     "Install Talk Matterbridge" : "Инсталирај мост интеграција",
-    "Installed version: {version}" : "Инсталирана верзија: {version}",
-    "SIP configuration" : "SIP конфигурација",
     "Delete this server" : "Избриши го овој сервер",
     "Status: Checking connection" : "Статус: Проверка на врската",
     "OK: Running version: {version}" : "OK: Стартувана верзија: {version}",
     "Error: Server did not respond with proper JSON" : "Грешка: Серверот не одговори со соодветна JSON",
     "Error: Server responded with: {error}" : "Грешка: Серверот одговори со: {error}",
     "Error: Unknown error occurred" : "Грешка: Се појави непозната грешка",
+    "SIP configuration" : "SIP конфигурација",
     "STUN server URL" : "STUN сервер URL",
     "STUN servers" : "STUN сервери",
+    "TURN server URL" : "TURN сервер URL",
     "{option1} and {option2}" : "{option1} и {option2}",
     "{option} only" : "само {option}",
-    "TURN server URL" : "TURN сервер URL",
     "Test this server" : "Тестирај го овој сервер",
     "TURN servers" : "TURN сервери",
     "Failed" : "Неуспешно",
     "OK" : "Добро",
     "Checking …" : "Проверка ...",
+    "Back" : "Назад",
+    "Confirm" : "Потврди",
+    "Reset" : "Ресетирање",
+    "Cancel" : "Откажи",
     "Copy link" : "Копирај линк",
     "Connecting …" : "Поврзување ...",
     "Waiting for others to join the call …" : "Чекање на останатите да се приклучат кон повикот ...",
     "You can invite others in the participant tab of the sidebar" : "Можете да поканите други учесници во картичката за учесници во страничната лента",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Можете да поканите други учесници во картичката за учесници во страничната лента или да ја споделите оваа врска за да поканите други учесници!",
     "Share this link to invite others!" : "Споделете ја оваа врска за да поканите други учесници!",
-    "Dismiss" : "Отфрли",
-    "Show your screen" : "Прикажи го вашиот екран",
-    "Stop screensharing" : "Запри споделување на екран",
-    "More actions" : "Повеќе акции",
-    "No audio" : "Нема аудио",
     "Mute audio" : "Занеми (Mute) аудио",
     "Mute audio (M)" : "Занеми (Mute) го аудиото (М)",
     "Unmute audio" : "Одзанеми (Unmute) го аудиото",
     "Unmute audio (M)" : "Одзанеми (Unmute) го аудиото (М)",
+    "Access to camera was denied" : "Нема пристап до камерата",
+    "Error while accessing camera" : "Грешка при пристап до камера",
+    "You have been muted by a moderator" : "Администраторот ве занеми",
     "You are not allowed to enable video" : "Не сте овластени да го овозможите видеото",
-    "No camera" : "Нема камера",
     "Disable video" : "Оневозможи видео",
     "Disable video (V)" : "Овозможи видео (V)",
     "Enable video" : "Овозможи видео",
     "Enable video (V)" : "Оневозможи видео (V)",
     "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Овозможи видео (V) - Вашата врска ќе биде кратко прекината при овозможување на видеото за прв пат",
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Овозможи видео. Вашата врска ќе биде кратко прекината при овозможување на видеото за прв пат",
-    "You are not allowed to enable screensharing" : "Не сте овластени да го овозможите споделување на екранот",
-    "No screensharing" : "Нема споделување на екран",
-    "Screensharing options" : "Опции за споделување на екранот",
-    "Enable screensharing" : "Овозможи споделување на екранот",
-    "Bad sent video and screen quality." : "Лош квалитет на испратено видео и квалитет на екран.",
-    "Bad sent screen quality." : "Лош квалитет на испратен екран.",
-    "Bad sent video quality." : "Лош квалитет на испратено видео",
-    "Bad sent audio, video and screen quality." : "Лош квалитет на испратено аудио, видео и квалитет на екран.",
-    "Bad sent audio and screen quality." : "Лош квалитет на испратено аудио и квалитет на екран.",
-    "Bad sent audio and video quality." : "Лош квалитет на испратено аудио и видео.",
-    "Bad sent audio quality." : "Лош квалитет на испратено аудио",
-    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
-    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
-    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да го видат вашиот екран.",
-    "Your internet connection or computer are busy and other participants might be unable to see you." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат.",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
-    "Disable screenshare" : "Оневозможи споделување на екранот",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео.",
-    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат.",
-    "Speaker view" : "Поглед на тој што зборува",
-    "Grid view" : "Мрежа",
-    "Screen sharing is not supported by your browser." : "Споделување на екранот не е поддржано од вашиот пребарувач.",
-    "Screen sharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
-    "Screensharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
-    "Screensharing extension is required to share your screen." : "Потребен е додаток за споделување на вашиот екран.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран.",
-    "An error occurred while starting screensharing." : "Настана грешка при обидот за стартување на споделување на екранот.",
-    "Back" : "Назад",
-    "Access to camera was denied" : "Нема пристап до камерата",
-    "Error while accessing camera" : "Грешка при пристап до камера",
-    "You have been muted by a moderator" : "Администраторот ве занеми",
     "You" : "Ти",
     "Show screen" : "Прикажи екран",
     "Mute" : "Занеми",
     "Connection could not be established …" : "Врската неможе да се воспостави ...",
+    "Collapse" : "Собери",
+    "Scroll to bottom" : "Скролај до долу",
     "You need to be logged in to upload files" : "Треба да бидете најавени за да можете да прикачите датотеки",
     "This conversation is read-only" : "Разговорот е само за читање",
     "Drop your files to upload" : "Повлечи датотеки за да прикачите",
-    "Call in progress" : "Повик е во тек",
     "Favorite" : "Омилен",
+    "Description" : "Опис",
+    "Enter a description for this conversation" : "Внесете опис за овој разговор",
+    "The file must be a PNG or JPG" : "Датотеката мора да биде PNG или JPG",
     "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Уреди ги стандардните дозволи за учесниците во овој разговор. Овие параметри не влијаат на модераторите.",
-    "Warning: Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Предупредување: секогаш кога се менуваат дозволите во овој дел, приспособените дозволи претходно доделени на поединечни учесници ќе бидат изгубени.",
     "All permissions" : "Сите дозволи",
     "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Учесниците имаат дозвола да започнат повик, да се придружуваат на повик, да овозможат аудио и видео и да споделуваат екран.",
     "Restricted" : "Ограничена",
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Учесниците може да се придружуваат на повици, но не можат да овозможат аудио или видео, ниту да споделуваат екран додека модераторот рачно не им даде дозвола.",
     "Conversation settings" : "Параметри за разговор",
-    "Description" : "Опис",
-    "Enter a description for this conversation" : "Внесете опис за овој разговор",
-    "Notifications" : "Известувања",
-    "Device check" : "Проверка на уредот",
+    "Personal" : "Лично",
     "Always show the device preview screen before joining a call in this conversation." : "Секогаш прикажувај го екранот за преглед на уредот пред да се придружите на повик во овој разговор. ",
-    "Guests access" : "Гостински пристап",
-    "Participants permissions" : "Дозволи за учесници",
-    "Meeting settings" : "Параметри за состаноци",
+    "Meeting" : "Средба",
+    "Permissions" : "Дозволи",
     "Danger zone" : "Опасна зона",
     "Be careful, these actions cannot be undone." : "Бидете внимателни, овие дејства не можат да повратат.",
     "Leave conversation" : "Напушти разговор",
@@ -656,28 +628,18 @@ OC.L10N.register(
     "Permanently delete this conversation." : "Трајно избришете го овој разговор",
     "Delete chat messages" : "Избришете ги пораките од разгоровот",
     "Permanently delete all the messages in this conversation." : "Трајно избришете ги сите пораки во овој разговор.",
-    "You need to promote a new moderator before you can leave the conversation." : "Треба да промовирате нов модератор пред да го напуштите разговорот.",
     "Do you really want to delete \"{displayName}\"?" : "Дали навистина сакате да го избришете \"{displayName}\"?",
     "Delete all chat messages" : "Избришете ги сите пораки од разгоровот",
-    "Allow guests to use a public link to join this conversation." : "Дозволете гостите да користат јавен линк за да се приклучат на разговоров.",
-    "Allow guests" : "Овозможи гости",
-    "Set a password to restrict who can use the public link." : "Поставете лозинка за да ограничите кој може да ја користи јавната врска.",
+    "Submit" : "Испрати",
     "Password protection" : "Заштитено со лозинка",
-    "Enter a password" : "Внесете лозинка",
     "Save password" : "Зачувај лозинка",
     "Copy conversation link" : "копирај линк од разговорот",
     "Resend invitations" : "Повторно испратете ги поканите",
     "Error occurred while allowing guests" : "Настана грешка при обидот за овозможување на гостите",
     "Error occurred while disallowing guests" : "Настана грешка при обидот за оневозможување на гостите",
-    "Conversation link copied to clipboard." : "Линк до разговорот е копиран во клипборд.",
-    "The link could not be copied." : "Линкот неможе да се копира.",
     "Invitations sent" : "Поканите се испратени",
-    "Open conversation to registered users" : "Отворен разговор за регистрирани корисници",
     "Also open to guest app users" : "Отворено и за гостинските корисници на апликации",
-    "Enabling the lobby only allows moderators to post messages." : "Овозможувањето на лобито им овозможува само на модераторите да објавуваат пораки.",
-    "Enable lobby" : "Овозможи лоби",
     "Start time (optional)" : "Време на почеток (опционално)",
-    "Locking the conversation prevents anyone to post messages or start calls." : "Заклучувањето на разговорот спречува некој да објавува пораки или да започнува повици.",
     "Lock conversation" : "Заклучи разговор",
     "Save" : "Зачувај",
     "Edit" : "Уреди",
@@ -696,17 +658,17 @@ OC.L10N.register(
     "Login" : "Login",
     "Nickname" : "Прекар",
     "Client ID" : "Клиент ИД",
-    "Chat messages" : "Пораки",
-    "Calls" : "Повици",
+    "Notifications" : "Известувања",
     "Notify about calls in this conversation" : "Извести ме за повиците во овој разговор",
-    "Choose devices" : "Избери уреди",
     "Conversation actions" : "Дејства за разговорот",
     "Mark as read" : "Означи како прочитано",
+    "Mark as unread" : "Означи како непрочитано",
     "Remove from favorites" : "Отстрани од фаворити",
     "Add to favorites" : "Додади во фаворити",
     "You: {lastMessage}" : "Ти: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
-    "No matches" : "Нема совпаѓања",
+    "You need to promote a new moderator before you can leave the conversation." : "Треба да промовирате нов модератор пред да го напуштите разговорот.",
+    "No matches found" : "Не се пронајдени совпаѓања",
     "Loading" : "Се вчитува",
     "No search results" : "Нема резултати од пребарувањето",
     "Groups" : "Групи",
@@ -718,52 +680,57 @@ OC.L10N.register(
     "Groups and circles" : "Групи и кругови",
     "Other sources" : "Други извори",
     "An error occurred while performing the search" : "Настана грешка при обидот за пребарување",
-    "Creating your conversation" : "Креирање на вашиот разговор",
-    "Error while creating the conversation" : "Грешка при креирање на разговор",
-    "Link copied to the clipboard!" : "Линкот е копиран во клипборд!",
     "Create a new group conversation" : "Креирајте нов групен разговор",
     "Allow guests to join via link" : "Дозволи им на гостите да се приклучат преку линк",
     "Password protect" : "Заштити со лозинка",
+    "Creating your conversation" : "Креирање на вашиот разговор",
+    "Error while creating the conversation" : "Грешка при креирање на разговор",
     "Create conversation" : "Креирајте разговор",
     "Add participants" : "Додади учесници",
     "Close" : "Затвори",
-    "Choose a password" : "Избери лозинка",
     "Search participants" : "Барај учесници",
     "Conversation name" : "Име на разговорот",
-    "Search conversations or users" : "Пребарување на разговори или корисници",
     "You are currently waiting in the lobby" : "Моментално чекате во лобито",
     "No microphone available" : "Нема микрофон",
     "Select microphone" : "Избери микрофон",
     "No camera available" : "Нема камера",
     "Select camera" : "Избери камера",
+    "Devices" : "Уреди",
+    "Done" : "Готово",
+    "No audio" : "Нема аудио",
+    "No camera" : "Нема камера",
+    "Upload" : "Прикачи",
+    "Files" : "Датотеки",
+    "File to share" : "Датотека за споделување",
+    "Invalid path selected" : "Избрана невалидна патека",
     "Unread messages" : "Непрочитани пораки",
     "Message sent" : "Пораката е испратена",
     "The message has been forwarded to {selectedConversationName}" : "Пораката е препратена до {selectedConversationName}",
+    "Dismiss" : "Отфрли",
     "Forward message" : "Препрати порака",
     "Choose a conversation to forward the selected message." : "Избери разговор за да препратите избраната порака.",
     "Error while forwarding message" : "Грешка при препраќање на пораката",
     "Reply" : "Одговор",
     "Copy message link" : "Копирај линк на пораката",
-    "Mark as unread" : "Означи како непрочитано",
     "Go to file" : "Оди до датотеката",
-    "Message link copied to clipboard" : "Линкот до пораката е копиран во клипборд",
+    "Translate" : "Преведи",
     "Contact" : "Контакт",
     "No messages" : "Нема пораки",
-    "Scroll to bottom" : "Скролај до долу",
     "Today" : "Денес",
     "Yesterday" : "Вчера",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Share files to the conversation" : "Сподели датотеки во разговорот",
     "Add emoji" : "Додади емотикон",
     "Send message" : "Испрати порака",
-    "File to share" : "Датотека за споделување",
-    "New file" : "Нова датотека",
     "This conversation has been locked" : "Разговорот е заклучен",
     "No permission to post messages in this conversation" : "Немате дозвола да испратите порака во овој разговор",
     "Write message, @ to mention someone …" : "Напиши порака, @ за да спомнете некој ...",
+    "Group" : "Група",
+    "Share files to the conversation" : "Сподели датотеки во разговорот",
+    "New file" : "Нова датотека",
     "Blank" : "Празно",
-    "Invalid path selected" : "Избрана невалидна патека",
     "Settings" : "Параметри",
+    "Send" : "Испрати",
+    "Add more files" : "Додади повеќе датотеки",
     "Start a call" : "Повик",
     "Skip the lobby" : "Прескокни го лобито",
     "Can post messages and reactions" : "Може да се пишуваат пораки и рекции",
@@ -774,16 +741,17 @@ OC.L10N.register(
     "Updating permissions" : "Ажурирање на дозволи",
     "In this conversation <strong>{user}</strong> can:" : "Во овој разговор <strong>{user}</strong> може:",
     "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Уреди ги стандардните дозволи за учесниците во <strong>{conversationName}</strong>",
+    "Join" : "Приклучи се",
     "Disable lobby" : "Оневозможи лоби",
     "moderator" : "модератор",
     "bot" : "бот",
     "guest" : "гостин",
     "Demote from moderator" : "Деградирај од модератор",
     "Promote to moderator" : "Промовирај во модератор",
-    "Grant all permissions" : "Додели ги сите дозволи",
-    "Remove all permissions" : "Острани ги сите дозволи",
     "Resend invitation" : "Повторно испратете ги поканите",
     "Send call notification" : "Испрати известување за повик",
+    "Grant all permissions" : "Додели ги сите дозволи",
+    "Remove all permissions" : "Острани ги сите дозволи",
     "Remove group and members" : "Избриши група и членови",
     "Remove participant" : "Отстрани учесник",
     "Settings for participant \"{user}\"" : "Параметри за учесникот \"{user}\"",
@@ -833,14 +801,17 @@ OC.L10N.register(
     "Show all other" : "Прикажи ги сите останати",
     "Meeting ID: {meetingId}" : "Состанок ID: {meetingId}",
     "Your PIN: {attendeePin}" : "Вашиот ПИН: {attendeePin}",
+    "Search conversations or users" : "Пребарување на разговори или корисници",
+    "Select conversation" : "Избери разговор",
+    "Link to a conversation" : "Линк до разговорот",
+    "No conversations found" : "Нема пронајдено разговори",
     "Save name" : "Зачувај име",
-    "Display name: <strong>{name}</strong>" : "Име за приказ: <strong>{name}</strong>",
+    "Choose devices" : "Избери уреди",
     "Attachments folder" : "Папка со прилози",
     "Privacy" : "Приватност",
     "Share my read-status and show the read-status of others" : "Сподели го мојот статус на читање и прикажете го статусот на читање на другите",
     "Sounds" : "Звуци",
     "Play sounds when participants join or leave a call" : "Репродуцирајте звуци кога учесниците се придружуваат или оставаат повик",
-    "Sounds can currently not be played in Safari browser and iPad and iPhone devices due to technical restrictions by the manufacturer." : "Звуците во моментов не може да се репродуцираат во прелистувачот Safari и уредите iPad и iPhone поради технички ограничувања од производителот.",
     "Sounds for chat and call notifications can be adjusted in the personal settings." : "Звуците за чет и известувања за повици може да се прилагодат во личните поставки.",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
     "Speed up your Talk experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
@@ -862,32 +833,53 @@ OC.L10N.register(
     "Failed to save sounds setting" : "Неуспешно зачувување на параметрите за звуци",
     "Sounds setting saved" : "Параматрите за звуци се зачувани",
     "Error while saving sounds setting" : "Грешка при зачувување на параметрите за звуци",
-    "End meeting for all" : "Заврши состанокот за сите",
     "Start call silently" : "Започни товок повик",
     "Start call" : "Повик",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Разговорот беше ажуриран, треба повторно да ја вчитате страницата пред да започнете или да се придружите на повик.",
     "You will be able to join the call only after a moderator starts it." : "Ќе може да се придружите на повикот само откако модераторот ќе го започне.",
-    "Toggle fullscreen" : "Вклучи на цел екран",
-    "Rename conversation" : "Преименувај разговор",
-    "Mute others" : "Занеми ги останатите",
-    "Exit fullscreen (F)" : "Излез од цел екран (F)",
-    "Fullscreen (F)" : "Приказ на цел екран (F)",
+    "Open sidebar" : "Отвори странична лента",
+    "Open chat" : "Започни разговор",
     "You have new unread messages in the chat." : "Имате непрочитана порака во разговор.",
     "You have been mentioned in the chat." : "Бевте споменати во разговор.",
-    "Send" : "Испрати",
-    "Add more files" : "Додади повеќе датотеки",
+    "Show your screen" : "Прикажи го вашиот екран",
+    "Stop screensharing" : "Запри споделување на екран",
+    "You are not allowed to enable screensharing" : "Не сте овластени да го овозможите споделување на екранот",
+    "No screensharing" : "Нема споделување на екран",
+    "Screensharing options" : "Опции за споделување на екранот",
+    "Enable screensharing" : "Овозможи споделување на екранот",
+    "Bad sent video and screen quality." : "Лош квалитет на испратено видео и квалитет на екран.",
+    "Bad sent screen quality." : "Лош квалитет на испратен екран.",
+    "Bad sent video quality." : "Лош квалитет на испратено видео",
+    "Bad sent audio, video and screen quality." : "Лош квалитет на испратено аудио, видео и квалитет на екран.",
+    "Bad sent audio and screen quality." : "Лош квалитет на испратено аудио и квалитет на екран.",
+    "Bad sent audio and video quality." : "Лош квалитет на испратено аудио и видео.",
+    "Bad sent audio quality." : "Лош квалитет на испратено аудио",
+    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
+    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
+    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да го видат вашиот екран.",
+    "Your internet connection or computer are busy and other participants might be unable to see you." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат.",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
+    "Disable screenshare" : "Оневозможи споделување на екранот",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео.",
+    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат.",
+    "Screen sharing is not supported by your browser." : "Споделување на екранот не е поддржано од вашиот пребарувач.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
+    "Screensharing requires the page to be loaded through HTTPS." : "За безбедно споделување на екран треба да се поврзете преку безбедна врска HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Споделување на екранот е поддржано со Firefox верзија 52 или понова.",
+    "Screensharing extension is required to share your screen." : "Потребен е додаток за споделување на вашиот екран.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Користете друг прелистувач како Firefox или Chrome за да го споделите вашиот екран.",
+    "An error occurred while starting screensharing." : "Настана грешка при обидот за стартување на споделување на екранот.",
+    "Mute others" : "Занеми ги останатите",
+    "Speaker view" : "Поглед на тој што зборува",
+    "Grid view" : "Мрежа",
     "No unread mentions" : "Нема непрочитани спомнувања",
     "Say hi to your friends and colleagues!" : "Кажи им здраво на твојте пријатели и колеги!",
     "Start a conversation" : "Започни разговор",
-    "You were mentioned" : "Споменати сте",
     "Message without mention" : "Пораки без спомнувања",
     "Mention myself" : "Спомни се себеси",
     "Mention room" : "Спомни соба",
     "The conversation does not exist" : "Разговорот не постои",
     "Join a conversation or start a new one!" : "Приклучи се кон разговор или започни нов!",
-    "No conversations found" : "Нема пронајдено разговори",
-    "Select conversation" : "Избери разговор",
-    "Link to a conversation" : "Линк до разговорот",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Се приклучивте на разговорот во друг прозорец или уред. Ова во моментов не е поддржано, па оваа сесија е затворена.",
     "Join a conversation or start a new one" : "Приклучи се кон разговор или започни нов",
     "Post to a conversation" : "Објави во разговор",
@@ -904,7 +896,6 @@ OC.L10N.register(
     "Access to camera is only possible with HTTPS" : "Пристап до камерата е возможен само преку безбедноска врска HTTPS",
     "An error occurred while fetching the participants" : "Настана грешка при обидот за вчитување на учесниците",
     "Media" : "Медија",
-    "Files" : "Датотеки",
     "Polls" : "Анкети",
     "Voice messages" : "Говорни пораки",
     "Locations" : "Локации",
@@ -943,21 +934,17 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Придружете се на разговор во секое време, каде и да било, на кој било уред.",
     "Android app" : "Android апликација",
     "iOS app" : "iOS апликација",
-    "Saved" : "Зачувано",
-    "Add a new server" : "Додади нов сервер",
-    "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве гледаат. За да ја подобрите ситуацијата, обидете се да го оневозможите вашето видео додека правите споделување на екранот.",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Вашата интернет-врска или компјутер се зафатени и другите учесници можеби нема да можат да ве разберат и видат вашиот екран. За да ја подобрите ситуацијата, обидете се да го оневозможите споделувањето екран.",
-    "Error while accessing camera: it is likely in use by another program" : "Грешка при пристап до камера: веројатно е во употреба од друга програма",
-    "Chat notifications" : "Известувања за разговор",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Моментално чекате во лобито. Состанокот е закажан во {startTime}",
-    "Microphone" : "Микрофон",
-    "Camera" : "Камера",
-    "Message link copied to clipboard." : "Линкот до пораката е копиран во клипборд.",
-    "[Unknown username]" : "[Непознато корисничко име]",
-    "Upload new files" : "Прикачи нови датотеки",
-    "Share from Files" : "Сподели од датотеките",
-    "Invitation was sent to {actorId}." : "Покана е испратена до {actorId}.",
-    "Display name: " : "Име:",
-    "Video on and off" : "Вклучување и исклучување на видеото"
+    "More actions" : "Повеќе акции",
+    "Conversation link copied to clipboard." : "Линк до разговорот е копиран во клипборд.",
+    "The link could not be copied." : "Линкот неможе да се копира.",
+    "No matches" : "Нема совпаѓања",
+    "Link copied to the clipboard!" : "Линкот е копиран во клипборд!",
+    "Message link copied to clipboard" : "Линкот до пораката е копиран во клипборд",
+    "Display name: <strong>{name}</strong>" : "Име за приказ: <strong>{name}</strong>",
+    "Sounds can currently not be played in Safari browser and iPad and iPhone devices due to technical restrictions by the manufacturer." : "Звуците во моментов не може да се репродуцираат во прелистувачот Safari и уредите iPad и iPhone поради технички ограничувања од производителот.",
+    "Toggle fullscreen" : "Вклучи на цел екран",
+    "Rename conversation" : "Преименувај разговор",
+    "Exit fullscreen (F)" : "Излез од цел екран (F)",
+    "Fullscreen (F)" : "Приказ на цел екран (F)"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
