@@ -12,6 +12,7 @@ OC.L10N.register(
     "_%n other_::_%n others_" : ["én annen person","%n andre"],
     "{actor} invited you to {call}" : "{actor} inviterte deg til {call}",
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du ble invitert til et <strong>samtale</strong>, eller fikk et <strong>anrop</strong>",
+    "Other activities" : "Andre aktiviteter",
     "Talk" : "Samtale",
     "Guest" : "Gjest",
     "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkommen til Nextcloud Talk!\nI denne samtalen vil vi informere deg om Nextcloud Talks nye funksjoner.",
@@ -71,12 +72,12 @@ OC.L10N.register(
     "You shared a file which is no longer available" : "Du delte en fil som ikke lenger er tilgjengelig",
     "%s (guest)" : "%s (gjest)",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtale med %n gjest (Varighet {duration})","Samtale med %n gjester (Varighet {duration})"],
+    "Talk conversations" : "Talk-samtaler",
     "Talk to %s" : "Snakk med %s",
     "File is too big" : "Filen er for stor",
     "Invalid file provided" : "Ugyldig fil oppgitt",
     "Invalid image" : "Ugyldig bilde",
     "Unknown filetype" : "Ukjent filtype",
-    "An error occurred. Please contact your admin." : "Det oppstod en feil. Kontakt din administrator.",
     "Talk mentions" : "Talk nevner",
     "Write to conversation" : "Skrive til samtalen",
     "You were invited to a conversation." : "Du ble invitert til en samtale.",
@@ -89,6 +90,7 @@ OC.L10N.register(
     "Your PIN" : "Din PIN",
     "Private conversation" : "Privat samtale",
     "Deleted user (%s)" : "Slettet bruker (%s)",
+    "Dismiss notification" : "Ingen varsel",
     "{user} in {call}" : "{user} i {call}",
     "Deleted user in {call}" : "Slett bruker i {call}",
     "{guest} (guest) in {call}" : "{guest} (gjest) i {call}",
@@ -107,6 +109,7 @@ OC.L10N.register(
     "Messages in {conversation}" : "Meldinger i {conversation}",
     "{user} in {conversation}" : "{user} i {conversation}",
     "Messages in other conversations" : "Meldinger i andre samtaler",
+    "Avatar image is not square" : "Avatarbilde er ikke firkantet",
     "Something unexpected happened." : "Noe uventet inntraff.",
     "The URL is invalid." : "Nettadressen er ugyldig.",
     "An HTTPS URL is required." : "En HTTPS URL er påkrevd.",
@@ -365,17 +368,13 @@ OC.L10N.register(
     "Share this file" : "Del denne filen",
     "Join conversation" : "Delta i samtale",
     "Request password" : "Forespør om passord",
+    "This conversation has ended" : "Denne samtalen er avsluttet",
     "Limit to groups" : "Begrens til grupper",
     "Everyone" : "Alle",
     "Moderators only" : "Kun moderatorer",
     "Save changes" : "Lagre endringer",
     "Saving …" : "Lagrer...",
     "Saved!" : "Lagret!",
-    "None" : "Ingen",
-    "User" : "Bruker",
-    "Disabled" : "Deaktivert",
-    "Moderators" : "Moderatorer",
-    "Users" : "Brukere",
     "Commands" : "Kommandoer",
     "Beta" : "Beta",
     "Name" : "Navn",
@@ -384,6 +383,11 @@ OC.L10N.register(
     "Response to" : "Svar til",
     "Enabled for" : "Aktivert for",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Kommandoer er en ny beta funksjon i Nextcloud Talk. De tillater deg å kjøre skript på din Nextcloud server. Du kan definere dem med ditt kommandolinje grensesnitt. F.eks. et kalkulatorskript kan bli funnet i vår {linkstart}dokumentasjon{linkend}.",
+    "None" : "Ingen",
+    "User" : "Bruker",
+    "Disabled" : "Deaktivert",
+    "Moderators" : "Moderatorer",
+    "Users" : "Brukere",
     "General settings" : "Generelle innstillinger",
     "All messages" : "Alle meldinger",
     "Off" : "ett kvarter",
@@ -398,17 +402,17 @@ OC.L10N.register(
     "Active" : "Aktiv",
     "Expired" : "Utløpt",
     "_%n user_::_%n users_" : ["%n bruker","%n brukere"],
+    "Installed version: {version}" : "Installert versjon: {version}",
     "Downloading …" : "Laster ned …",
     "Install Talk Matterbridge" : "Installer Talk Matterbridge",
-    "Installed version: {version}" : "Installert versjon: {version}",
-    "SIP configuration" : "SIP innstillinger",
-    "Restrict SIP configuration" : "Begrens SIP innstillinger",
-    "Enable SIP configuration" : "Aktiver SIP innstillinger",
-    "Shared secret" : "Delt hemmelighet",
-    "Phone number (Country)" : "Telefonnumer (fast)",
     "Validate SSL certificate" : "Bekreft SSL-sertifikat",
     "Delete this server" : "Slett denne serveren",
     "Status: Checking connection" : "Status: Sjekker tilkobling",
+    "Shared secret" : "Delt hemmelighet",
+    "SIP configuration" : "SIP innstillinger",
+    "Restrict SIP configuration" : "Begrens SIP innstillinger",
+    "Enable SIP configuration" : "Aktiver SIP innstillinger",
+    "Phone number (Country)" : "Telefonnumer (fast)",
     "STUN server URL" : "STUN server URL",
     "STUN servers" : "STUN-server",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server brukes til å fastsette den offentlige IP-adressen for deltagere bak en ruter.",
@@ -417,6 +421,11 @@ OC.L10N.register(
     "Test this server" : "Test denne serveren",
     "OK" : "OK",
     "Checking …" : "Sjekker…",
+    "Back" : "Tilbake",
+    "Confirm" : "Bekreft",
+    "Reset" : "Tilbakestill",
+    "Cancel" : "Avbryt",
+    "Post message" : "Send melding",
     "A participant raised their hand." : "En deltaker løftet hånden.",
     "Previous page of videos" : "Forrige side med videoer",
     "Next page of videos" : "Neste side med videoer",
@@ -425,54 +434,39 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre fra deltagerfanen i sidepanel",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i deltagerfanen av sidepanel eller dele denne lenke for å invitere andre!",
     "Share this link to invite others!" : "Klikk denne lenken for å invitere andre.",
-    "Dismiss" : "Forkast",
-    "Show your screen" : "Vis din skjerm",
-    "Stop screensharing" : "Stopp skjermdeling",
-    "Lower hand" : "Senk hånden",
-    "More actions" : "Flere handlinger",
-    "Raise hand" : "Løft hånden",
-    "No audio" : "Ingen lyd",
     "Mute audio" : "Slå av lyd",
     "Unmute audio" : "Slå på lyd",
-    "No camera" : "Ikke noe kamera",
     "Disable video" : "Skru av video",
     "Enable video" : "Skru på video",
-    "Screensharing options" : "Skjermdelingsvalg",
-    "Enable screensharing" : "Skru på skjermdeling",
-    "Grid view" : "Rutenett-visning",
-    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
-    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
-    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
-    "Back" : "Tilbake",
     "You" : "Du",
     "Show screen" : "Vis skjerm",
     "Mute" : "Dempe",
+    "Collapse" : "Skjul",
+    "Expand" : "Ekspander",
     "Conversation messages" : "Samtale meldinger",
-    "Post message" : "Send melding",
     "You need to be logged in to upload files" : "Du må være på logget for å laste opp filer",
+    "Drop your files to upload" : "Dropp filer for å laste opp",
     "Favorite" : "Merk som favoritt",
+    "Description" : "Beskrivelse",
     "Restricted" : "Begrenset",
     "Conversation settings" : "Samtale innstillinger",
-    "Description" : "Beskrivelse",
-    "Notifications" : "Varsler",
-    "Guests access" : "Gjeste tilgang",
-    "Meeting settings" : "Møte innstillinger",
+    "Personal" : "Personlig",
+    "Meeting" : "Møte",
+    "Permissions" : "Rettigheter",
     "Leave conversation" : "Forlat samtale",
     "Delete conversation" : "Slett samtale",
     "Delete chat messages" : "Slett melding",
     "Do you really want to delete \"{displayName}\"?" : "Vil du virkelig slette \"{displayName}\"?",
     "Delete all chat messages" : "Slett alle meldinger",
     "Error while clearing chat history" : "Det oppsto en feil. Kan ikke slette meldingslogg",
-    "Allow guests" : "Tillat gjester",
+    "Submit" : "Send inn",
+    "Guest access" : "Gjestetilgang",
     "Password protection" : "Passordbeskyttelse",
-    "Enter a password" : "Skriv inn et passord",
     "Save password" : "Lagre passord",
     "Copy conversation link" : "Kopier samtale lenke",
     "Conversation password has been saved" : "Samtale passord er lagret",
     "Conversation password has been removed" : "Samtale passord er fjernet",
-    "Enable lobby" : "Aktiver lobby",
+    "Invitations sent" : "Invitasjoner sendt",
     "Meeting start time" : "Møtets starttidspunkt",
     "Start time (optional)" : "Starttidspunkt (valgfri)",
     "Start time has been updated" : "Starttidspunkt har blitt oppdatert",
@@ -481,19 +475,19 @@ OC.L10N.register(
     "Edit" : "Rediger",
     "More information" : "Mer informasjon",
     "Delete" : "Slett",
+    "Talk conversation" : "Talk-samtale",
     "Password" : "Passord",
     "API token" : "API-symbol",
     "Login" : "Logg inn",
     "Nickname" : "Kallenavn",
     "Client ID" : "Klient-ID",
-    "Chat messages" : "Samtalemeldinger",
-    "Calls" : "Samtaler",
+    "Notifications" : "Varsler",
     "Mark as read" : "Merk som lest",
+    "Mark as unread" : "Merk som ulest",
     "Remove from favorites" : "Fjern fra favoritter",
     "Add to favorites" : "Legg til i favoritter",
     "You: {lastMessage}" : "Du: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
-    "No matches" : "Ingen treff",
     "Conversation list" : "Samtaleliste",
     "Loading" : "Laster",
     "No search results" : "Ingen søkeresultater",
@@ -506,38 +500,52 @@ OC.L10N.register(
     "Users and circles" : "Brukere og sirkler",
     "Groups and circles" : "Grupper og sirkler",
     "Other sources" : "Andre kilder",
-    "Creating your conversation" : "Opprett din samtale",
     "Password protect" : "Passordbeskyttelse",
+    "Creating your conversation" : "Opprett din samtale",
     "Create conversation" : "Opprett samtale",
     "Add participants" : "Legg til deltager",
     "Close" : "Lukk",
-    "Choose a password" : "Velg et passord",
     "Search participants" : "Søk etter deltakere",
     "Conversation name" : "Samtalenavn",
-    "Search conversations or users" : "Søk etter samtaler eller brukere",
+    "Search …" : "Søk...",
     "You are currently waiting in the lobby" : "Du venter for øyeblikket i lobbyen",
     "No microphone available" : "Ingen mikrofon er tilgjengelig",
     "Select microphone" : "Velg mikrofon",
     "No camera available" : "Ingen kamera tilgjengelig",
     "Select camera" : "Velg kamera",
+    "Devices" : "Enheter",
+    "Done" : "Ferdig",
+    "No audio" : "Ingen lyd",
+    "No camera" : "Ikke noe kamera",
+    "Blur" : "Uklar",
+    "Upload" : "Last opp",
+    "Files" : "Filer",
+    "File to share" : "Fil for deling",
+    "Invalid path selected" : "Ugyldig angitt sti",
     "Unread messages" : "Uleste meldinger",
     "Sending message" : "Sender melding",
     "Message sent" : "Melding sendt",
     "Only normal chat messages can be deleted" : "Kun vanlige meldinger kan slettes",
+    "Dismiss" : "Forkast",
     "Reply" : "Svar",
-    "Mark as unread" : "Merk som ulest",
     "Contact" : "Kontakt",
+    "{stack} in {board}" : "{stack} i {board}",
     "Poll" : "Avstemning",
     "No messages" : "Ingen meldinger",
     "Today" : "I dag",
     "Yesterday" : "I går",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Create new poll" : "Opprett ny avstemning",
+    "Add emoji" : "Legg til emoji",
     "Send message" : "Send melding",
+    "Group" : "Gruppe",
+    "Upload from device" : "Last opp fra enhet",
+    "Create new poll" : "Opprett ny avstemning",
     "New file" : "Ny fil",
-    "Invalid path selected" : "Ugyldig angitt sti",
+    "Blank" : "Blank",
     "Settings" : "Innstillinger",
     "Create poll" : "Opprett avstemning",
+    "Send" : "Send",
+    "Join" : "Bli med",
     "moderator" : "moderator",
     "guest" : "gjest",
     "Demote from moderator" : "Fjern moderatorstatus",
@@ -557,16 +565,28 @@ OC.L10N.register(
     "Details" : "Detaljer",
     "Projects" : "Prosjekter",
     "Show all files" : "Vis alle filer",
+    "Search conversations or users" : "Søk etter samtaler eller brukere",
     "Privacy" : "Personvern",
     "Keyboard shortcuts" : "Tastatursnarveier",
     "Search" : "Søk",
     "Start call" : "Start samtale",
-    "Rename conversation" : "Endre navn på samtale",
-    "Send" : "Send",
+    "Open sidebar" : "Åpne sidepanel",
+    "Open chat" : "Åpne Chat",
+    "Show your screen" : "Vis din skjerm",
+    "Stop screensharing" : "Stopp skjermdeling",
+    "Screensharing options" : "Skjermdelingsvalg",
+    "Enable screensharing" : "Skru på skjermdeling",
+    "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
+    "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Bruk en annen nettleser som Firefox eller Chrome for å dele skjermen din.",
+    "An error occurred while starting screensharing." : "En feil inntraff under oppstart av skjermdeling.",
+    "Grid view" : "Rutenett-visning",
+    "Raise hand" : "Løft hånden",
+    "Lower hand" : "Senk hånden",
     "Start a conversation" : "Start en samtale",
     "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
     "Media" : "Media",
-    "Files" : "Filer",
     "Polls" : "Avstemninger",
     "Locations" : "Steder",
     "Audio" : "Lyd",
@@ -587,8 +607,8 @@ OC.L10N.register(
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signalserver kan alternativt brukes for større installasjoner. La stå tom for å bruke intern signalserver.",
     "Android app" : "Android-app",
     "iOS app" : "iOS-app",
-    "Saved" : "Lagret",
-    "Microphone" : "Mikrofon",
-    "Camera" : "Kamera"
+    "More actions" : "Flere handlinger",
+    "No matches" : "Ingen treff",
+    "Rename conversation" : "Endre navn på samtale"
 },
 "nplurals=2; plural=(n != 1);");
