@@ -7,9 +7,10 @@ OC.L10N.register(
     "Invalid file provided" : "U dha kartelë e pavlefshme",
     "Invalid image" : "Figurë e pavlefshme",
     "Unknown filetype" : "Lloj i panjohur skedari",
-    "An error occurred. Please contact your admin." : "Ndodhi një gabim. Ju lutemi, lidhuni me përgjegjësin tuaj.",
+    "Dismiss notification" : "Hiq lajmërimin",
     "Open settings" : "Hap rregullimet",
     "Conversations" : "Bisedat",
+    "Avatar image is not square" : "Imazhi avatar nuk është katror",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Emiratet e Bashkuara Arabe",
     "Afghanistan" : "Afganistani",
@@ -154,11 +155,11 @@ OC.L10N.register(
     "Everyone" : "Kushdo",
     "Save changes" : "Ruaj ndryshimet",
     "Saved!" : "I/E ruajtur!",
+    "Name" : "Emri",
     "None" : "Asnjë",
     "User" : "Përdorues",
     "Disabled" : "I çaktivizuar",
     "Users" : "Përdoruesit",
-    "Name" : "Emri",
     "General settings" : "Opsjonet e Pergjithshme",
     "Language" : "Gjuha",
     "Country" : "Vend",
@@ -170,30 +171,25 @@ OC.L10N.register(
     "TURN server protocols" : "Protokollet e serverit TURN",
     "OK" : "OK",
     "Checking …" : "Duke kontrolluar ...",
+    "Back" : "Prapa",
+    "Confirm" : "Konfirmo",
+    "Reset" : "Rivendos",
+    "Cancel" : "Anullo",
     "Copy link" : "Kopjo linkun",
     "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
-    "Dismiss" : "Hiq",
-    "Show your screen" : "Shfaq ekranin tënd",
-    "Stop screensharing" : "Ndalo ndarjen e ekranit",
-    "More actions" : "Më tepër veprime ",
     "Mute audio" : "Mute audio",
     "Disable video" : "Çaktivizo video",
-    "Grid view" : "Pamje galeri",
-    "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
-    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
-    "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
-    "Back" : "Prapa",
     "You" : "Ju",
+    "Collapse" : "Tkurre",
     "Favorite" : "I/E Preferuar",
-    "Restricted" : "I/E kufizuar",
     "Description" : "Përshkrim",
-    "Notifications" : "Njoftimet",
+    "Restricted" : "I/E kufizuar",
+    "Personal" : "Personale",
+    "Permissions" : "Lejet",
     "Leave conversation" : "Largohuni nga biseda",
     "Delete conversation" : "Fshijeni bisedën",
+    "Submit" : "Dërgo",
     "Password protection" : "Password protection",
-    "Enter a password" : "Fusni një fjalëkalim",
     "Save" : "Ruaj",
     "Edit" : "Përpuno",
     "Delete" : "Fshij",
@@ -202,8 +198,9 @@ OC.L10N.register(
     "Login" : "Hyrje",
     "Nickname" : "Nofkë",
     "Client ID" : "ID klienti",
-    "Calls" : "Thirrjet",
+    "Notifications" : "Njoftimet",
     "Mark as read" : "Shënoje si të lexuar",
+    "Mark as unread" : "Shënoje si të palexuar",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
     "Loading" : "Duke ngarkuar",
@@ -212,17 +209,24 @@ OC.L10N.register(
     "Password protect" : "Mbroje me fjalëkalim",
     "Close" : "Mbylleni",
     "Conversation name" : "Emri i bisedës",
+    "Devices" : "Pajisjet",
+    "Done" : "U bë",
+    "Upload" : "Ngarkoni",
+    "Files" : "Skedarët",
     "Message sent" : "Mesazhi u dërgua",
+    "Dismiss" : "Hiq",
     "Reply" : "Përgjigju",
-    "Mark as unread" : "Shënoje si të palexuar",
+    "Translate" : "Përkthe",
     "Contact" : "Kontakt",
     "Today" : "Sot",
     "Yesterday" : "Dje",
-    "Create new poll" : "Krijo sondazh të ri",
     "Send message" : "Dërgo mesazh",
+    "Group" : "Grup",
+    "Create new poll" : "Krijo sondazh të ri",
     "New file" : "Skedë e re",
     "Settings" : "Rregullimet",
     "Create poll" : "Krijo sondazh",
+    "Send" : "Dërgo",
     "guest" : "vizitor",
     "No results" : "Asnjë rezultat",
     "Add users or groups" : "Add users or groups",
@@ -230,11 +234,17 @@ OC.L10N.register(
     "Privacy" : "Privatësia",
     "Keyboard shortcuts" : "Shkurtoret e tastierës",
     "Search" : "Kërko",
-    "Rename conversation" : "Riemërtojeni bisedën",
-    "Send" : "Dërgo",
+    "Open sidebar" : "Hapni sidebar-in",
+    "Show your screen" : "Shfaq ekranin tënd",
+    "Stop screensharing" : "Ndalo ndarjen e ekranit",
+    "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
+    "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Ju lutem përdorni një browser tjetër si Firefox ose Chrome për të ndarë ekranin tuaj.",
+    "An error occurred while starting screensharing." : "Ndodhi një gabim gjatë fillimit të ndarjes së ekranit.",
+    "Grid view" : "Pamje galeri",
     "Start a conversation" : "Filloni një bisedë",
     "Media" : "Media",
-    "Files" : "Skedarët",
     "Polls" : "Sondazhe",
     "Audio" : "Audio",
     "Other" : "Tjetër",
@@ -249,7 +259,7 @@ OC.L10N.register(
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
     "Android app" : "Aplikacion Android",
     "iOS app" : "Aplikacion iOS",
-    "Saved" : "U ruajt",
-    "Camera" : "Kamera"
+    "More actions" : "Më tepër veprime ",
+    "Rename conversation" : "Riemërtojeni bisedën"
 },
 "nplurals=2; plural=(n != 1);");
