@@ -45,6 +45,7 @@ OC.L10N.register(
     "- Moderators can now assign general and individual permissions to participants" : "- Moderatorer kan nu tilldela allmänna och individuella behörigheter till deltagare",
     "- You can now react to chat message" : "- Du kan nu reagera på textmeddelande",
     "- In the sidebar you can now find an overview of the latest shared items" : "- I marginallisten kan du nu hitta en översikt över de senast delade objekten",
+    "- Link various items using the new smart-picker by typing a \"/\"" : "- Länka olika objekt med nya smart-picker genom att skriva ett \"/\"",
     "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
     "The command does not exist" : "Kommandot finns inte",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Ett fel inträffade under körning av kommandot. Be en administratör att kontrollera loggarna.",
@@ -136,6 +137,7 @@ OC.L10N.register(
     "An administrator demoted {user} from moderator" : "En administratör tog bort {user} som moderator",
     "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
     "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
+    "{actor} deleted a message" : "{actor} raderade ett meddelande",
     "%s (guest)" : "%s (gäst)",
     "You missed a call from {user}" : "Du missade ett samtal från {user}",
     "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtal med %n gäst (Varaktighet {duration})","Samtal med %n gäster (Varaktighet {duration})"],
@@ -143,14 +145,15 @@ OC.L10N.register(
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal med {user1}, {user2} och {user3} (Varade {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} (Varade {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
+    "Talk conversations" : "Talk-konversationer",
     "Talk to %s" : "Prata med %s",
     "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
     "File is too big" : "Filen är för stor",
     "Invalid file provided" : "Ogiltig fil tillhandahölls",
     "Invalid image" : "Ogiltig bild",
     "Unknown filetype" : "Okänd filtyp",
-    "An error occurred. Please contact your admin." : "Ett fel har inträffat. Kontakta din administratör.",
     "Talk mentions" : "Talk-omnämnanden",
+    "Call in progress" : "Samtal pågår",
     "Write to conversation" : "Skriv till konversation",
     "Writes event information into a conversation of your choice" : "Skriver händelseinformation till en konversation du väljer",
     "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
@@ -165,6 +168,8 @@ OC.L10N.register(
     "Password request: %s" : "Lösenordsförfrågan: %s",
     "Private conversation" : "Privat konversation",
     "Deleted user (%s)" : "Raderad användare (%s)",
+    "Share to chat" : "Dela till chatt",
+    "Dismiss notification" : "Avfärda notifiering",
     "{user} in {call}" : "{user} i {call}",
     "Deleted user in {call}" : "Tog bort användare från {call}",
     "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
@@ -197,6 +202,7 @@ OC.L10N.register(
     "Open settings" : "Öppna inställningar",
     "Conversations" : "Konversationer",
     "Messages" : "Meddelanden",
+    "Avatar image is not square" : "Profilbilden är inte fyrkantig",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Förenade arabemiraten",
     "Afghanistan" : "Afghanistan",
@@ -451,6 +457,7 @@ OC.L10N.register(
     "Request password" : "Begär lösenord",
     "Error requesting the password." : "Fel vid begäran av lösenord.",
     "This conversation has ended" : "Denna konversation har avslutats",
+    "Close Talk sidebar" : "Stäng Talk sidofält",
     "Limit to groups" : "Begränsa till grupper",
     "When at least one group is selected, only people of the listed groups can be part of conversations." : "När minst en grupp väljs kan bara personer i de angivna grupperna ingå i konversationer.",
     "Guests can still join public conversations." : "Gäster kan fortfarande delta i publika konversationer.",
@@ -466,11 +473,6 @@ OC.L10N.register(
     "Save changes" : "Spara ändringar",
     "Saving …" : "Sparar ...",
     "Saved!" : "Sparat!",
-    "None" : "Ingen",
-    "User" : "Användare",
-    "Disabled" : "Inaktiverad",
-    "Moderators" : "Moderatorer",
-    "Users" : "Användare",
     "Commands" : "Kommandon",
     "Beta" : "Beta",
     "Name" : "Namn",
@@ -478,6 +480,11 @@ OC.L10N.register(
     "Script" : "Skript",
     "Response to" : "Svar till",
     "Enabled for" : "Aktiverad för",
+    "None" : "Ingen",
+    "User" : "Användare",
+    "Disabled" : "Inaktiverad",
+    "Moderators" : "Moderatorer",
+    "Users" : "Användare",
     "General settings" : "Allmänna inställningar",
     "Default notification settings" : "Standardinställningar meddelanden",
     "Default group notification" : "Standard gruppmeddelande",
@@ -497,9 +504,8 @@ OC.L10N.register(
     "Blocked" : "Blockerar",
     "Active" : "Aktiv",
     "Expired" : "Utgånget",
-    "Downloading …" : "Hämtar …",
     "Installed version: {version}" : "Installerad version: {version}",
-    "Shared secret" : "Delad hemlighet",
+    "Downloading …" : "Hämtar …",
     "Validate SSL certificate" : "Validera SSL-certifikat",
     "Delete this server" : "Ta bort denna server",
     "Status: Checking connection" : "Status: Kontrollerar anslutning",
@@ -507,74 +513,62 @@ OC.L10N.register(
     "Error: Server did not respond with proper JSON" : "Error: Servern svarade inte med korrekt JSON",
     "Error: Server responded with: {error}" : "Error: Servern svarade med: {error}",
     "Error: Unknown error occurred" : "Error: Okänt fel inträffade",
+    "Shared secret" : "Delad hemlighet",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver bör eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observera att samtal med fler än 4 deltagare utan extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
     "Don't warn about connectivity issues in calls with more than 4 participants" : "Varna inte om anslutningsproblem i samtal med fler än 4 deltagare",
     "STUN server URL" : "STUN-serverwebbadress",
     "STUN servers" : "STUN-servrar",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
-    "{option1} and {option2}" : "{option1} och {option2}",
-    "{option} only" : "endast {option}",
     "TURN server URL" : "TURN-serverwebbadress",
     "TURN server secret" : "TURN-server hemlighet",
     "TURN server protocols" : "TURN-server protokoll",
+    "{option1} and {option2}" : "{option1} och {option2}",
+    "{option} only" : "endast {option}",
     "Test this server" : "Testa denna server",
     "TURN servers" : "TURN-servrar",
     "OK" : "OK",
     "Checking …" : "Kontrollerar...",
+    "Back" : "Tillbaka",
+    "Confirm" : "Bekräfta",
+    "Reset" : "Återställ",
+    "Cancel" : "Avbryt",
     "Copy link" : "Kopiera länk",
     "Connecting …" : "Ansluter…",
     "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
     "You can invite others in the participant tab of the sidebar" : "Du kan bjuda in andra på fliken deltagare i sidofältet",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan bjuda in andra på fliken deltagare i sidofältet eller dela den här länken!",
     "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
-    "Dismiss" : "Avfärda",
-    "Show your screen" : "Visa din skärm",
-    "Stop screensharing" : "Stoppa skärmdelning",
-    "More actions" : "Fler händelser",
-    "No audio" : "Inget ljud",
     "Mute audio" : "Stäng av ljudet",
     "Unmute audio" : "Aktivera ljud",
-    "No camera" : "Ingen kamera",
+    "You have been muted by a moderator" : "Du har tystats av en moderator",
     "Disable video" : "Stäng av video",
     "Enable video" : "Aktivera video",
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video. Din anslutning får ett kort avbrott när du aktiverar video första gången",
-    "Screensharing options" : "Skärmdelningsalternativ",
-    "Enable screensharing" : "Tillåt skärmdelning",
-    "Grid view" : "Rutnätsvy",
-    "Screen sharing is not supported by your browser." : "Skärmdelning stöds inte av din webbläsare.",
-    "Screen sharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver att sidan läses in via HTTPS.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Skärmdelning fungerar endast med Firefox version 52 eller nyare.",
-    "Screensharing extension is required to share your screen." : "Skärmdelningstillägg krävs för att dela din skärm.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome för att dela din skärm.",
-    "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
-    "Back" : "Tillbaka",
-    "You have been muted by a moderator" : "Du har tystats av en moderator",
     "You" : "Du",
     "Show screen" : "Visa skärm",
-    "Mute" : "Tyst",
     "Stop following" : "Sluta följa",
+    "Mute" : "Tyst",
+    "Collapse" : "Dölj",
+    "Expand" : "Utöka",
     "You need to be logged in to upload files" : "Du måste vara inloggad för att ladda upp filer",
     "Drop your files to upload" : "Släpp dina filer för att ladda upp",
-    "Call in progress" : "Samtal pågår",
     "Favorite" : "Favorit",
+    "Description" : "Beskrivning",
+    "The file must be a PNG or JPG" : "Filen måste vara en PNG eller JPG",
     "Restricted" : "Begränsad",
     "Conversation settings" : "Konversationsinställningar",
-    "Description" : "Beskrivning",
-    "Notifications" : "Aviseringar",
+    "Personal" : "Personligt",
+    "Meeting" : "Möte",
+    "Permissions" : "Behörigheter",
+    "Danger zone" : "Riskzon",
     "Leave conversation" : "Lämna konversationen",
     "Delete conversation" : "Ta bort konversationen",
-    "You need to promote a new moderator before you can leave the conversation." : "Du måste tilldela en ny moderator innan du kan lämna konversationen.",
     "Do you really want to delete \"{displayName}\"?" : "Vill du verkligen radera \"{displayName}\"?",
-    "Allow guests" : "Tillåt gäster",
+    "Submit" : "Skicka",
     "Password protection" : "Lösenordsskydd",
-    "Enter a password" : "Ange ett lösenord",
+    "Enter new password" : "Ange nytt lösenord",
     "Copy conversation link" : "Kopiera konversationslänk",
-    "Conversation link copied to clipboard." : "Konversationslänk kopierad till urklipp.",
-    "The link could not be copied." : "Länken kunde inte kopieras.",
-    "Open conversation to registered users" : "Öppna konversation för registrerade användare",
-    "Enable lobby" : "Aktivera lobbyn",
+    "Open conversation to registered users, showing it in search results" : "Öppna konversationen för registrerade användare och visa den i sökresultaten",
     "Start time (optional)" : "Starttid (valfritt)",
     "Save" : "Spara",
     "Edit" : "Ändra",
@@ -582,6 +576,7 @@ OC.L10N.register(
     "Delete" : "Radera",
     "Nextcloud URL" : "Nextcloud-URL",
     "Nextcloud user" : "Nextcloud-användare",
+    "Talk conversation" : "Talk-konversation",
     "Matrix server URL" : "Matrix server-URL",
     "Matrix channel" : "Matrix-kanal",
     "Mattermost user" : "Mattermost-användare",
@@ -596,13 +591,15 @@ OC.L10N.register(
     "Client ID" : "Klient-ID",
     "Jabber ID" : "Jabber-id",
     "Bridge saved" : "Brygga sparad",
-    "Calls" : "Samtal",
+    "Notifications" : "Aviseringar",
     "Mark as read" : "Markera som läst",
+    "Mark as unread" : "Markera som oläst",
     "Remove from favorites" : "Ta bort från favoriter",
     "Add to favorites" : "Lägg till som favorit",
     "You: {lastMessage}" : "Du: {lastMessage}",
     "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
-    "No matches" : "Inga träffar",
+    "You need to promote a new moderator before you can leave the conversation." : "Du måste tilldela en ny moderator innan du kan lämna konversationen.",
+    "No matches found" : "Inga träffar hittades",
     "Loading" : "Läser in",
     "No search results" : "Inga sökresultat",
     "Groups" : "Grupper",
@@ -613,40 +610,62 @@ OC.L10N.register(
     "Groups and circles" : "Grupper och cirklar",
     "Other sources" : "Andra källor",
     "An error occurred while performing the search" : "Ett fel uppstod när sökningen utfördes",
+    "Create a new group conversation" : "Skapa en ny gruppkonversation",
+    "Password protect" : "Lösenordsskydda",
+    "Enter password" : "Ange lösenord",
     "Creating your conversation" : "Skapar din konversation",
     "All set" : "Allt klart",
     "Error while creating the conversation" : "Fel uppstod när konversationen skulle skapas",
-    "Link copied to the clipboard!" : "Länken kopierad till urklipp!",
-    "Create a new group conversation" : "Skapa en ny gruppkonversation",
-    "Password protect" : "Lösenordsskydda",
     "Create conversation" : "Skapa konversation",
     "Add participants" : "Lägg till deltagare",
     "Close" : "Stäng",
-    "Choose a password" : "Välj ett lösenord",
     "Search participants" : "Sök deltagare",
+    "Cancel search" : "Avbryt sökning",
     "Conversation name" : "Konversationens namn",
-    "Search conversations or users" : "Sök konversationer eller användare",
+    "Search …" : "Sök ...",
     "You are currently waiting in the lobby" : "Du väntar för närvarande i lobbyn",
+    "No microphone available" : "Ingen mikrofon tillgänglig",
+    "No camera available" : "Ingen kamera tillgänglig",
+    "Devices" : "Enheter",
+    "Done" : "Klar",
+    "No audio" : "Inget ljud",
+    "No camera" : "Ingen kamera",
+    "Blur" : "Suddig",
+    "Upload" : "Ladda upp",
+    "Files" : "Filer",
+    "File to share" : "Fil att dela",
+    "Invalid path selected" : "Ogiltig sökväg vald",
     "Unread messages" : "Olästa meddelanden",
     "Message sent" : "Meddelande skickat",
+    "You are not allowed to share files" : "Du tillåẗs inte dela filer",
+    "Dismiss" : "Avfärda",
     "Reply" : "Svara",
-    "Mark as unread" : "Markera som oläst",
     "Go to file" : "Gå till fil",
+    "Translate" : "Översätt",
+    "Translate from" : "Översätt från",
     "Contact" : "Kontakt",
+    "{stack} in {board}" : "{stack} i {board}",
     "No messages" : "Inga meddelanden",
     "Today" : "Idag",
     "Yesterday" : "Igår",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Share files to the conversation" : "Dela filer till konversationen",
-    "Create new poll" : "Skapa ny omröstning",
+    "Add emoji" : "Lägg till emoji",
     "Send message" : "Skicka meddelande",
-    "File to share" : "Fil att dela",
-    "New file" : "Ny fil",
     "Write message, @ to mention someone …" : "Skriv meddelande, @ för att nämna någon ...",
+    "Group" : "Grupp",
+    "Share files to the conversation" : "Dela filer till konversationen",
+    "Upload from device" : "Ladda upp från enheten",
+    "Create new poll" : "Skapa ny omröstning",
+    "Share from {nextcloud}" : "Dela från {nextcloud}",
+    "Create and share a new file" : "Skapa och dela en ny fil",
+    "New file" : "Ny fil",
     "Blank" : "Tom",
-    "Invalid path selected" : "Ogiltig sökväg vald",
     "Settings" : "Inställningar",
+    "Private poll" : "Privat omröstning",
     "Create poll" : "Skapa omröstning",
+    "Send" : "Skicka",
+    "Share the screen" : "Dela skärmen",
+    "Join" : "Gå med",
     "moderator" : "moderator",
     "guest" : "gäst",
     "Demote from moderator" : "Degradera från moderator",
@@ -656,6 +675,7 @@ OC.L10N.register(
     "Add groups" : "Lägg till grupper",
     "Add emails" : "Lägg till e-post",
     "Add circles" : "Lägg till cirklar",
+    "Integrations" : "Integrationer",
     "Searching …" : "Söker ...",
     "No results" : "Inga resultat",
     "Search for more users" : "Sök efter fler användare",
@@ -668,18 +688,36 @@ OC.L10N.register(
     "Search or add participants" : "Sök eller lägg till deltagare",
     "Chat" : "Chat",
     "Details" : "Detaljer",
+    "Shared items" : "Delade objekt",
     "Projects" : "Projekt",
+    "No shared items" : "Inga delade objekt",
     "Show all files" : "Visa alla filer",
+    "Search conversations or users" : "Sök konversationer eller användare",
+    "Select conversation" : "Välj konversation",
+    "Link to a conversation" : "Länka till en konversation",
     "Privacy" : "Integritet",
+    "Play sounds when participants join or leave a call" : "Spela upp ljud när deltagare går med eller lämnar ett samtal",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Search" : "Sök",
     "Error while setting attachment folder" : "Fel vid inställning av mapp för bilagor",
     "Start call" : "Starta samtal",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal.",
     "You will be able to join the call only after a moderator starts it." : "Du kommer att kunna gå med i samtalet först när en moderator startar det.",
-    "Toggle fullscreen" : "Växla helskärm",
-    "Rename conversation" : "Byt namn på konversation",
-    "Send" : "Skicka",
+    "Open sidebar" : "Öppna sidofältet",
+    "Open chat" : "Öppna chatt",
+    "Show your screen" : "Visa din skärm",
+    "Stop screensharing" : "Stoppa skärmdelning",
+    "Screensharing options" : "Skärmdelningsalternativ",
+    "Enable screensharing" : "Tillåt skärmdelning",
+    "Disable screenshare" : "Inaktivera skärmdelning",
+    "Screen sharing is not supported by your browser." : "Skärmdelning stöds inte av din webbläsare.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver att sidan läses in via HTTPS.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Skärmdelning fungerar endast med Firefox version 52 eller nyare.",
+    "Screensharing extension is required to share your screen." : "Skärmdelningstillägg krävs för att dela din skärm.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome för att dela din skärm.",
+    "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
+    "Grid view" : "Rutnätsvy",
     "No unread mentions" : "Inga olästa omnämnanden",
     "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
     "Start a conversation" : "Starta en konversation",
@@ -688,12 +726,11 @@ OC.L10N.register(
     "Mention room" : "Nämn rum",
     "The conversation does not exist" : "Konversationen finns inte",
     "Join a conversation or start a new one!" : "Anslut till en konversation eller starta en ny!",
-    "Select conversation" : "Välj konversation",
-    "Link to a conversation" : "Länka till en konversation",
     "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
+    "Share to a conversation" : "Dela till en konversation",
+    "Share to conversation" : "Dela till konversation",
     "An error occurred while fetching the participants" : "Ett fel uppstod när deltagarna hämtades",
     "Media" : "Media",
-    "Files" : "Filer",
     "Polls" : "Omröstningar",
     "Locations" : "Platser",
     "Audio" : "Ljud",
@@ -703,7 +740,6 @@ OC.L10N.register(
     "Away" : "Iväg",
     "Error while sharing file" : "Fel vid delning av fil",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud är i underhållsläge, ladda om sidan igen",
-    "Sending signaling message has failed." : "Misslyckades skicka signalmeddelande.",
     "Establishing signaling connection is taking longer than expected …" : "Det tar längre tid än förväntat att upprätta signalanslutning ...",
     "Failed to establish signaling connection. Retrying …" : "Det gick inte att upprätta signalanslutning. Försöker igen ...",
     "Default" : "Standard",
@@ -716,6 +752,8 @@ OC.L10N.register(
     "WebRTC is not supported in your browser" : "WebRTC är inte kompatibelt med din webbläsare",
     "Please use a different browser like Firefox or Chrome" : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome",
     "Error while accessing microphone & camera" : "Fel vid åtkomst till mikrofon och kamera",
+    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Vi har upptäckt flera felaktiga inloggningsförsök från din IP-adress. Ditt nästa inloggningsförsök kommer därför att fördröjas med upp till 30 sekunder.",
+    "This conversation is password-protected." : "Konversationen är lösenordsskyddad.",
     "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
     "Specify commands the users can use in chats" : "Ange kommandon som användare kan använda i chattar",
     "TURN server" : "TURN-server",
@@ -726,14 +764,14 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Gå med i konversationer när som helst, var som helst, på alla enheter.",
     "Android app" : "Android-app",
     "iOS app" : " iOS-app",
-    "Saved" : "Sparad",
-    "Add a new server" : "Lägg till ny server",
-    "Chat notifications" : "Chatt-aviseringar",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
-    "Camera" : "Kamera",
-    "[Unknown username]" : "[Okänt användarnamn]",
-    "Upload new files" : "Ladda upp nya filer",
-    "Share from Files" : "Dela från Filer",
-    "Display name: " : "Visningsnamn:"
+    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observera att samtal med fler än 4 deltagare utan extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
+    "More actions" : "Fler händelser",
+    "Conversation link copied to clipboard." : "Konversationslänk kopierad till urklipp.",
+    "The link could not be copied." : "Länken kunde inte kopieras.",
+    "No matches" : "Inga träffar",
+    "Link copied to the clipboard!" : "Länken kopierad till urklipp!",
+    "Toggle fullscreen" : "Växla helskärm",
+    "Rename conversation" : "Byt namn på konversation",
+    "Sending signaling message has failed." : "Misslyckades skicka signalmeddelande."
 },
 "nplurals=2; plural=(n != 1);");
