@@ -158,8 +158,9 @@ OC.L10N.register(
     "Invalid file provided" : "Tệp đã cung cấp không hợp lệ",
     "Invalid image" : "Ảnh không hợp lệ",
     "Unknown filetype" : "Loại tệp không xác định",
-    "An error occurred. Please contact your admin." : "Lỗi đã xảy ra. Liên hệ với quản trị viên",
     "Talk mentions" : "Đề cập trong cuộc trò chuyện",
+    "Call in progress" : "Cuộc gọi đang chờ",
+    "You were mentioned" : "Bạn đã được nhắc tới",
     "Write to conversation" : "Viết vào cuộc trò chuyên",
     "Writes event information into a conversation of your choice" : "Viết thông tin sự kiện vào một cuộc trò chuyện bạn chọn",
     "%s invited you to a conversation." : "%s đã được mời vào cuộc trò chuyện",
@@ -174,6 +175,7 @@ OC.L10N.register(
     "Password request: %s" : "Yêu cầu mật khẩu: %s",
     "Private conversation" : "Cuộc trò chuyện bí mật",
     "Deleted user (%s)" : "Người dùng đã xóa (%s)",
+    "Dismiss notification" : "Bỏ qua thông báo ",
     "{user1} shared room {roomName} on {remoteServer} with you" : "{user1} đã chia sẻ cuộc gọi {roomName} trên {remoteServer} với bạn",
     "{user} in {call}" : "{user} trong {call}",
     "Deleted user in {call}" : "Người dùng đã xóa trong {call}",
@@ -271,17 +273,17 @@ OC.L10N.register(
     "Save changes" : "Lưu thay đổi",
     "Saving …" : "Đang lưu ...",
     "Saved!" : "Đã lưu!",
-    "None" : "Không có",
-    "User" : "Người dùng",
-    "Disabled" : "Tắt",
-    "Moderators" : "Người kiểm duyệt",
-    "Users" : "Người dùng",
     "Commands" : "Lệnh",
     "Name" : "Tên",
     "Command" : "Lệnh",
     "Response to" : "Phản hồi với",
     "Enabled for" : "Đã bật cho",
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "Lệnh là một tính năng beta mới trong vWorkspace Talk. Chúng cho phép bạn chạy các tập lệnh trên máy chủ vWorkspace của bạn. Bạn có thể xác định chúng bằng giao diện dòng lệnh của chúng tôi. Có thể tìm thấy ví dụ về tập lệnh máy tính trong {linkstart} tài liệu {linkend} của chúng tôi.",
+    "None" : "Không có",
+    "User" : "Người dùng",
+    "Disabled" : "Tắt",
+    "Moderators" : "Người kiểm duyệt",
+    "Users" : "Người dùng",
     "General settings" : "Cài đặt chung",
     "Default notification settings" : "Cài đặt thông báo mặc định",
     "Default group notification" : "Thông báo nhóm mặc định",
@@ -295,7 +297,6 @@ OC.L10N.register(
     "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Đối tác Struktur AG của chúng tôi cung cấp một dịch vụ mà một máy chủ báo hiệu được lưu trữ có thể được yêu cầu. Đối với điều này, bạn chỉ cần điền vào biểu mẫu bên dưới và vWorkspace của bạn sẽ yêu cầu nó. Sau khi máy chủ được thiết lập cho bạn, thông tin đăng nhập sẽ tự động được điền. Điều này sẽ ghi đè cài đặt máy chủ báo hiệu hiện có.",
     "URL of this Nextcloud instance" : "URL của phiên bản vWorkspace này",
     "Full name of the user requesting the trial" : "Tên đầy đủ của người dùng yêu cầu bản dùng thử",
-    "Name of the user requesting the trial" : "Tên của người dùng yêu cầu bản dùng thử",
     "Language" : "Ngôn ngữ",
     "Country" : "Quốc gia",
     "Request signaling server trial" : "Yêu cầu dùng thử máy chủ báo hiệu",
@@ -316,24 +317,13 @@ OC.L10N.register(
     "_%n user_::_%n users_" : ["%n người dùng"],
     "Matterbridge integration" : "Tích hợp Matterbridge ",
     "Enable Matterbridge integration" : "Bật tích hợp Matterbridge",
-    "Downloading …" : "Đang tải ...",
-    "Install Talk Matterbridge" : "Cài đặt Talk Matterbridge",
     "Installed version: {version}" : "Phiên bản đã cài đặt: {version}",
     "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/.../nextcloud/apps/talk_matterbridge/bin/\"." : "Nhị phân Matterbridge có quyền không chính xác. Hãy đảm bảo rằng tệp nhị phân Matterbridge thuộc sở hữu của đúng người dùng và có thể được thực thi.",
     "Matterbridge binary was not found or couldn't be executed." : "Nhị phân Matterbridge không được tìm thấy hoặc không thể được thực thi",
     "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Bạn cũng có thể đặt đường dẫn đến nhị phân Matterbridge theo cách thủ công thông qua cấu hình. Kiểm tra {linkstart} tài liệu tích hợp Matterbridge {linkend} để biết thêm thông tin.",
-    "An error occurred while installing the Matterbridge app." : "Đã xảy ra lỗi khi cài đặt ứng dụng Matterbridge.",
-    "An error occurred while installing the Talk Matterbridge. Please install it manually." : "Đã xảy ra lỗi khi cài đặt Talk Matterbridge. Vui lòng cài đặt nó theo cách thủ công.",
+    "Downloading …" : "Đang tải ...",
+    "Install Talk Matterbridge" : "Cài đặt Talk Matterbridge",
     "Failed to execute Matterbridge binary." : "Không thực thi được mã nhị phân Matterbridge.",
-    "SIP configuration" : "Cấu hình SIP",
-    "SIP configuration is only possible with a high-performance backend." : "Cấu hình SIP chỉ có thể thực hiện được với phần backend hiệu suất cao.",
-    "Restrict SIP configuration" : "Hạn chế cấu hình SIP",
-    "Only users of the following groups can enable SIP in conversations they moderate" : "Chỉ những người dùng thuộc các nhóm sau mới có thể bật SIP trong các cuộc trò chuyện mà họ kiểm duyệt",
-    "Enable SIP configuration" : "Bật cấu hình SIP",
-    "Shared secret" : "Chia sẽ mật khẩu",
-    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Thông tin này được gửi trong thư điện tử mời cũng như hiển thị trong thanh bên cho tất cả những người tham gia.",
-    "Phone number (Country)" : "Số điện thoại (Quốc gia)",
-    "High-performance backend URL" : "URL backend hiệu suất cao",
     "Validate SSL certificate" : "Xác thực chứng chỉ SSL",
     "Delete this server" : "Xóa máy chủ này",
     "Status: Checking connection" : "Trạng thái: Đang kiểm tra kết nối",
@@ -341,27 +331,40 @@ OC.L10N.register(
     "Error: Server did not respond with proper JSON" : "Lỗi: Máy chủ không phản hồi với JSON thích hợp",
     "Error: Server responded with: {error}" : "Lỗi: Máy chủ phản hồi: {error}",
     "Error: Unknown error occurred" : "Lỗi: Đã xảy ra lỗi không xác định",
+    "Shared secret" : "Chia sẽ mật khẩu",
+    "SIP configuration" : "Cấu hình SIP",
+    "SIP configuration is only possible with a high-performance backend." : "Cấu hình SIP chỉ có thể thực hiện được với phần backend hiệu suất cao.",
+    "Restrict SIP configuration" : "Hạn chế cấu hình SIP",
+    "Enable SIP configuration" : "Bật cấu hình SIP",
+    "Only users of the following groups can enable SIP in conversations they moderate" : "Chỉ những người dùng thuộc các nhóm sau mới có thể bật SIP trong các cuộc trò chuyện mà họ kiểm duyệt",
+    "Phone number (Country)" : "Số điện thoại (Quốc gia)",
+    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Thông tin này được gửi trong thư điện tử mời cũng như hiển thị trong thanh bên cho tất cả những người tham gia.",
+    "High-performance backend URL" : "URL backend hiệu suất cao",
     "High-performance backend" : "Backend hiệu suất cao",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Một máy chủ báo hiệu bên ngoài nên được tùy chọn sử dụng cho các cài đặt lớn hơn. Để trống để sử dụng máy chủ báo hiệu nội bộ.",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Xin lưu ý rằng các cuộc gọi có hơn 4 người tham gia mà không có máy chủ báo hiệu bên ngoài, người tham gia có thể gặp sự cố kết nối và gây tải cao cho các thiết bị tham gia.",
     "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Chúng tôi khuyên bạn nên thiết lập bộ nhớ đệm phân tán khi sử dụng vWorkspace Talk cùng với Back-end hiệu suất cao.",
     "Don't warn about connectivity issues in calls with more than 4 participants" : "Không cảnh báo về sự cố kết nối trong cuộc gọi có hơn 4 người tham gia",
     "STUN server URL" : "URL máy chủ STUN",
     "STUN servers" : "Máy chủ STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Máy chủ STUN được sử dụng để xác định địa chỉ IP công khai của người tham gia phía sau bộ định tuyến.",
     "TURN server schemes" : "Lược đồ máy chủ TURN",
-    "{option1} and {option2}" : "{option1} và {option2}",
-    "{option} only" : "Chỉ {option}",
     "TURN server URL" : "URL máy chủ TURN",
     "TURN server secret" : "Bảo mật máy chủ TURN",
     "TURN server protocols" : "Giao thức máy chủ TURN",
     "{schema} scheme must be used with a domain" : "Lược đồ {schema} phải được sử dụng với một miền",
+    "{option1} and {option2}" : "{option1} và {option2}",
+    "{option} only" : "Chỉ {option}",
     "OK: Successful ICE candidates returned by the TURN server" : "OK: Các ứng viên ICE thành công do máy chủ TURN trả về",
     "Error: No working ICE candidates returned by the TURN server" : "Lỗi: Không có ứng cử viên ICE nào đang hoạt động được máy chủ TURN trả về",
     "Testing whether the TURN server returns ICE candidates" : "Kiểm tra xem máy chủ TURN có trả về các ứng viên ICE hay không",
     "Test this server" : "Kiểm tra máy chủ này",
     "TURN servers" : "Máy chủ TURN",
     "OK" : "OK",
+    "Back" : "Quay lại",
+    "Confirm" : "Xác nhận",
+    "Reset" : "Đặt lại",
+    "Cancel" : "Hủy",
+    "Post message" : "Đăng tin nhắn",
     "{nickName} raised their hand." : "{nickName} giơ tay.",
     "A participant raised their hand." : "Một người tham gia giơ tay.",
     "Previous page of videos" : "Trang trước của video",
@@ -374,77 +377,41 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Bạn có thể mời những người khác trong tab người tham gia của thanh bên hoặc chia sẻ liên kết này để mời những người khác!",
     "Share this link to invite others!" : "Chia sẻ liên kết này để mời những người khác!",
-    "Dismiss" : "Bỏ qua",
-    "Show your screen" : "Hiện màn hình của bạn",
-    "Stop screensharing" : "Ngừng chia sẽ màn hình",
-    "Lower hand" : "Đặt tay xuống",
-    "More actions" : "Nhiều hành động hơn",
-    "Raise hand" : "Giơ tay",
-    "No audio" : "Không có âm thanh",
     "Mute audio" : "Tắt âm thanh",
     "Unmute audio" : "Bật âm thanh",
-    "No camera" : "Không có máy ảnh",
-    "Disable video" : "Tắt Video",
-    "Enable video" : "Bật Video",
-    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Bật video. Kết nối của bạn sẽ bị gián đoạn trong thời gian ngắn khi bật video lần đầu tiên",
-    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
-    "Enable screensharing" : "Bật chia sẽ màn hình",
-    "Bad sent video and screen quality." : "Chất lượng màn hình và video đã gửi kém.",
-    "Bad sent screen quality." : "Chất lượng màn hình đã gửi kém.",
-    "Bad sent video quality." : "Chất lượng video đã gửi kém.",
-    "Bad sent audio, video and screen quality." : "Chất lượng âm thanh, video và màn hình được gửi kém.",
-    "Bad sent audio and screen quality." : "Chất lượng âm thanh và màn hình đã gửi kém.",
-    "Bad sent audio and video quality." : "Chất lượng âm thanh và video được gửi kém.",
-    "Bad sent audio quality." : "Chất lượng âm thanh đã gửi kém.",
-    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không nhìn thấy màn hình của bạn.",
-    "Your internet connection or computer are busy and other participants might be unable to see you." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không nhìn thấy bạn.",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu và nhìn thấy bạn. Để cải thiện tình hình, hãy thử tắt video của bạn trong khi thực hiện chia sẻ màn hình.",
-    "Disable screenshare" : "Tắt chia sẻ màn hình",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu và nhìn thấy bạn. Để cải thiện tình hình, hãy thử tắt video của bạn.",
-    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu bạn.",
-    "Speaker view" : "Chế độ xem người gọi điện",
-    "Grid view" : "Xem dạng Lưới",
-    "Screen sharing is not supported by your browser." : "Chia sẻ màn hình không được trình duyệt của bạn hỗ trợ.",
-    "Screen sharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang được tải qua HTTPS.",
-    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
-    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
-    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
-    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
-    "Back" : "Quay lại",
     "Access to camera was denied" : "Quyền truy cập vào máy ảnh đã bị từ chối",
     "Error while accessing camera" : "Lỗi khi truy cập máy ảnh",
     "You have been muted by a moderator" : "Bạn đã bị người kiểm duyệt tắt tiếng",
+    "Disable video" : "Tắt Video",
+    "Enable video" : "Bật Video",
+    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Bật video. Kết nối của bạn sẽ bị gián đoạn trong thời gian ngắn khi bật video lần đầu tiên",
     "You" : "Bạn",
     "Show screen" : "Hiện màn hình",
-    "Mute" : "Tắt tiếng",
     "Stop following" : "Ngừng theo dõi",
+    "Mute" : "Tắt tiếng",
+    "Collapse" : "Thu gọn",
+    "Expand" : "Mở rộng",
     "Conversation messages" : "Tin nhắn đàm thoại",
-    "Post message" : "Đăng tin nhắn",
+    "Scroll to bottom" : "Cuộn xuống dưới cùng",
     "You need to be logged in to upload files" : "Bạn cần đăng nhập để tải tệp lên",
     "This conversation is read-only" : "Cuộc trò chuyện này ở chế độ chỉ đọc",
     "Drop your files to upload" : "Thả tệp của bạn để tải lên",
-    "Call in progress" : "Cuộc gọi đang chờ",
     "Favorite" : "Ưa thích",
+    "Description" : "Mô tả",
+    "Edit conversation description" : "Chỉnh sửa mô tả cuộc trò chuyện",
+    "Error while updating conversation description" : "Lỗi khi cập nhật mô tả cuộc trò chuyện",
     "Restricted" : "Bị giới hạn",
     "Conversation settings" : "Cài đặt cuộc trò chuyện",
-    "Description" : "Mô tả",
-    "Notifications" : "Thông báo",
-    "Guests access" : "Khách truy cập",
-    "Meeting settings" : "Cài đặt cuộc họp",
+    "Personal" : "Cá nhân",
+    "Meeting" : "Cuộc họp",
     "Danger zone" : "Khu vực nguy hiểm",
-    "Error while updating conversation description" : "Lỗi khi cập nhật mô tả cuộc trò chuyện",
     "Be careful, these actions cannot be undone." : "Hãy cẩn thận, không thể hoàn tác những hành động này.",
     "Leave conversation" : "Rời khỏi cuộc đàm thoại",
     "Delete conversation" : "Xóa cuộc trò chuyện",
-    "You need to promote a new moderator before you can leave the conversation." : "Bạn cần chọn người kiểm duyệt mới trước khi có thể rời khỏi cuộc trò chuyện.",
     "Do you really want to delete \"{displayName}\"?" : "Bạn có thực sự muốn xóa \"{displayName}\" không?",
     "Error while deleting conversation" : "Lỗi khi xóa cuộc trò chuyện",
-    "Allow guests to use a public link to join this conversation." : "Cho phép khách sử dụng liên kết công khai để tham gia cuộc trò chuyện này.",
-    "Allow guests" : "Cho phép khách",
-    "Set a password to restrict who can use the public link." : "Đặt mật khẩu để hạn chế ai có thể sử dụng liên kết công khai.",
+    "Submit" : "Gửi đi",
     "Password protection" : "Password protection",
-    "Enter a password" : "Nhập mật khẩu",
     "Save password" : "Lưu mật khẩu",
     "Copy conversation link" : "Sao chép liên kết cuộc trò chuyện",
     "Resend invitations" : "Gửi lại lời mời",
@@ -453,27 +420,18 @@ OC.L10N.register(
     "Error occurred while saving conversation password" : "Đã xảy ra lỗi khi lưu mật khẩu cuộc trò chuyện",
     "Error occurred while allowing guests" : "Đã xảy ra lỗi khi cho phép khách",
     "Error occurred while disallowing guests" : "Đã xảy ra lỗi khi không cho phép khách",
-    "Conversation link copied to clipboard." : "Đã sao chép liên kết cuộc trò chuyện vào khay nhớ tạm.",
-    "The link could not be copied." : "Không thể sao chép liên kết.",
     "Invitations sent" : "Lời mời đã được gửi",
     "Error occurred when sending invitations" : "Đã xảy ra lỗi khi gửi lời mời",
-    "Open conversation to registered users" : "Mở cuộc trò chuyện với người dùng đã đăng ký",
-    "This conversation will be shown in search results" : "Cuộc trò chuyện này sẽ được hiển thị trong kết quả tìm kiếm",
     "Also open to guest app users" : "Mở cho người dùng ứng dụng khách",
     "Error occurred when opening or limiting the conversation" : "Đã xảy ra lỗi khi mở hoặc giới hạn cuộc trò chuyện",
-    "Enabling the lobby only allows moderators to post messages." : "Bật sảnh chỉ cho phép người kiểm duyệt đăng tin.",
-    "This will also remove non-moderators from the ongoing call." : "Điều này cũng sẽ xóa những người không kiểm duyệt khỏi cuộc gọi đang diễn ra.",
-    "Enable lobby" : "Bật sảnh đợi",
-    "After the time limit the lobby will be automatically disabled." : "Sau thời gian giới hạn, sảnh đợi sẽ tự động bị vô hiệu hóa.",
     "Meeting start time" : "Thời gian bắt đầu cuộc họp",
     "Start time (optional)" : "Thời gian bắt đầu (tùy chọn)",
     "Error occurred when restricting the conversation to moderator" : "Đã xảy ra lỗi khi giới hạn cuộc trò chuyện với người kiểm duyệt",
     "Error occurred when opening the conversation to everyone" : "Đã xảy ra lỗi khi mở cuộc trò chuyện với mọi người",
     "Start time has been updated" : "Thời gian bắt đầu đã được cập nhật",
     "Error occurred while updating start time" : "Đã xảy ra lỗi khi cập nhật thời gian bắt đầu",
-    "Locking the conversation prevents anyone to post messages or start calls." : "Khóa cuộc trò chuyện sẽ ngăn không cho bất kỳ ai đăng tin nhắn hoặc bắt đầu cuộc gọi.",
-    "This will also terminate the ongoing call." : "Điều này cũng sẽ kết thúc cuộc gọi đang diễn ra.",
     "Lock conversation" : "Khóa cuộc trò chuyện",
+    "This will also terminate the ongoing call." : "Điều này cũng sẽ kết thúc cuộc gọi đang diễn ra.",
     "Error occurred when locking the conversation" : "Đã xảy ra lỗi khi khóa cuộc trò chuyện",
     "Error occurred when unlocking the conversation" : "Đã xảy ra lỗi khi mở khóa cuộc trò chuyện",
     "Save" : "Lưu",
@@ -531,25 +489,19 @@ OC.L10N.register(
     "not running, check Matterbridge log" : "không chạy, kiểm tra nhật kí Matterbridge",
     "not running" : "không chạy",
     "Bridge saved" : "Cầu nối đã được lưu",
-    "Calls" : "Cuộc gọi",
-    "Allow participants to join from a phone." : "Cho phép tham gia từ điện thoại.",
-    "Enable SIP dial-in" : "Bật quay số SIP",
+    "Notifications" : "Thông báo",
     "SIP dial-in is now enabled" : "Quay số SIP hiện đã được bật",
     "SIP dial-in is now disabled" : "Tính năng quay số SIP hiện đã bị tắt",
     "Error occurred when enabling SIP dial-in" : "Đã xảy ra lỗi khi bật quay số SIP",
     "Error occurred when disabling SIP dial-in" : "Đã xảy ra lỗi khi tắt quay số SIP",
-    "Cancel editing description" : "Hủy chỉnh sửa mô tả",
-    "Submit conversation description" : "Gửi mô tả cuộc trò chuyện",
-    "Edit conversation description" : "Chỉnh sửa mô tả cuộc trò chuyện",
-    "The description must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Mô tả phải dài ít hơn hoặc bằng {maxLength} ký tự. Văn bản hiện tại của bạn dài {characterCount} ký tự.",
-    "Choose devices" : "Chọn thiết bị",
     "Conversation actions" : "Hoạt động cuộc trò chuyện",
     "Mark as read" : "Đánh dấu đã đọc",
+    "Mark as unread" : "Đánh dấu là chưa đọc",
     "Remove from favorites" : "Xóa khỏi ưa thích",
     "Add to favorites" : "Thêm vào ưa thích",
     "Joining conversation …" : "Tham gia cuộc trò chuyện …",
     "You: {lastMessage}" : "Bạn: {lastMessage}",
-    "No matches" : "Không phù hợp",
+    "You need to promote a new moderator before you can leave the conversation." : "Bạn cần chọn người kiểm duyệt mới trước khi có thể rời khỏi cuộc trò chuyện.",
     "Conversation list" : "Danh sách cuộc trò chuyện",
     "Open conversations" : "Mở cuộc trò chuyện",
     "Loading" : "Đang tải",
@@ -563,25 +515,29 @@ OC.L10N.register(
     "Groups and circles" : "Nhóm và vòng kết nối",
     "Other sources" : "Những nguồn khác",
     "An error occurred while performing the search" : "Đã xảy ra lỗi khi thực hiện tìm kiếm",
-    "Creating your conversation" : "Tạo cuộc trò chuyện của bạn",
-    "All set" : "Tất cả các thiết lập",
-    "Error while creating the conversation" : "Lỗi khi tạo cuộc trò chuyện",
-    "Link copied to the clipboard!" : "Đã sao chép liên kết vào khay nhớ tạm!",
     "Create a new group conversation" : "Tạo một cuộc trò chuyện nhóm mới",
     "Allow guests to join via link" : "Cho phép khách tham gia qua liên kết",
     "Password protect" : "Mật khẩu bảo vệ",
+    "Creating your conversation" : "Tạo cuộc trò chuyện của bạn",
+    "All set" : "Tất cả các thiết lập",
+    "Error while creating the conversation" : "Lỗi khi tạo cuộc trò chuyện",
     "Create conversation" : "Tạo cuộc trò chuyện",
     "Add participants" : "Thêm người tham gia",
     "Close" : "Đóng",
-    "Choose a password" : "Chọn mật khẩu",
     "Search participants" : "Tìm kiếm người tham gia",
     "Conversation name" : "Tên đàm thoại",
-    "Search conversations or users" : "Tìm kiếm cuộc trò chuyện hoặc người dùng",
     "You are currently waiting in the lobby" : "Bạn hiện đang đợi ở sảnh đợi",
     "No microphone available" : "Không có micrô",
     "Select microphone" : "Chọn micrô",
     "No camera available" : "Không có camera khả dụng",
     "Select camera" : "Chọn camera",
+    "Done" : "Hoàn thành",
+    "No audio" : "Không có âm thanh",
+    "No camera" : "Không có máy ảnh",
+    "Upload" : "Tải lên",
+    "Files" : "Tệp",
+    "File to share" : "Tệp để chia sẻ",
+    "Invalid path selected" : "Đường dẫn đã chọn không hợp lệ",
     "Unread messages" : "Tin nhắn chưa đọc",
     "Sending message" : "Đang gửi tin nhắn",
     "Message sent" : "Tin nhắn đã gửi",
@@ -594,30 +550,32 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Không thể xóa tin nhắn vì nó quá cũ",
     "Only normal chat messages can be deleted" : "Chỉ những tin nhắn trò chuyện bình thường mới có thể bị xóa",
     "An error occurred while deleting the message" : "Đã xảy ra lỗi khi xóa tin nhắn",
+    "Dismiss" : "Bỏ qua",
     "Reply" : "Trả l",
     "Reply privately" : "Trả lời riêng tư",
     "Copy message link" : "Sao chép liên kết tin nhắn",
-    "Mark as unread" : "Đánh dấu là chưa đọc",
     "Go to file" : "Tới tập tin",
+    "Translate" : "Dịch",
     "Contact" : "Liên hệ",
     "{stack} in {board}" : "{stack} trong {board}",
     "Deck Card" : "Thẻ bài",
     "No messages" : "Không có tin nhắn",
-    "Scroll to bottom" : "Cuộn xuống dưới cùng",
     "Today" : "Hôm nay",
     "Yesterday" : "Hôm qua",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Share files to the conversation" : "Chia sẻ tệp với cuộc trò chuyện",
     "Add emoji" : "Thêm biểu tượng cảm xúc",
     "Send message" : "Gửi thông điệp",
-    "File to share" : "Tệp để chia sẻ",
-    "New file" : "Tập tin mới",
     "This conversation has been locked" : "Cuộc trò chuyện này đã bị khóa",
     "No permission to post messages in this conversation" : "Không có quyền đăng tin nhắn trong cuộc trò chuyện này",
     "Write message, @ to mention someone …" : "Viết tin nhắn, @ để nhắc đến ai đó…",
+    "Group" : "Nhóm",
+    "Share files to the conversation" : "Chia sẻ tệp với cuộc trò chuyện",
+    "New file" : "Tập tin mới",
     "Blank" : "‎Trống‎",
-    "Invalid path selected" : "Đường dẫn đã chọn không hợp lệ",
     "Settings" : "Thiết lập",
+    "Send" : "Gửi",
+    "Add more files" : "Thêm nhiều tập tin",
+    "Join" : "Tham gia",
     "Disable lobby" : "Vô hiệu hóa sảnh đợi",
     "moderator" : "Người kiểm duyệt",
     "guest" : "khách",
@@ -656,11 +614,15 @@ OC.L10N.register(
     "Show all files" : "Hiện tất cả tệp",
     "Meeting ID: {meetingId}" : "Mã cuộc họp: {meetingId}",
     "Your PIN: {attendeePin}" : "Mã PIN của bạn: {attendeePin}",
+    "Search conversations or users" : "Tìm kiếm cuộc trò chuyện hoặc người dùng",
+    "Select conversation" : "Chọn cuộc trò chuyện",
+    "Link to a conversation" : "Liên kết đến một cuộc trò chuyện",
+    "No conversations found" : "Không tìm thấy cuộc trò chuyện nào",
+    "Choose devices" : "Chọn thiết bị",
     "Attachments folder" : "Thư mục đính kèm",
     "Privacy" : "Bảo mật",
     "Share my read-status and show the read-status of others" : "Chia sẻ trạng thái đã đọc của tôi và hiển thị trạng thái đã đọc của những người khác",
     "Sounds" : "Âm thanh",
-    "Sounds can currently not be played in Safari browser and iPad and iPhone devices due to technical restrictions by the manufacturer." : "Âm thanh hiện không thể phát trong trình duyệt Safari và các thiết bị iPad và iPhone do các hạn chế kỹ thuật của nhà sản xuất.",
     "Keyboard shortcuts" : "Phím tắt",
     "Speed up your Talk experience with these quick shortcuts." : "Tăng tốc trải nghiệm Talk của bạn bằng các phím tắt nhanh này.",
     "Focus the chat input" : "Tập trung vào đầu vào trò chuyện",
@@ -680,23 +642,44 @@ OC.L10N.register(
     "Start call" : "Bắt đầu cuộc gọi",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "vWorkspace Talk đã được cập nhật, bạn cần tải lại trang trước khi có thể bắt đầu hoặc tham gia cuộc gọi.",
     "You will be able to join the call only after a moderator starts it." : "Bạn sẽ chỉ có thể tham gia cuộc gọi sau khi người kiểm duyệt bắt đầu cuộc gọi.",
-    "Toggle fullscreen" : "Bật chế độ toàn màn hình",
-    "Rename conversation" : "Đổi tên cuộc đàm thoại",
+    "Open sidebar" : "Mở thanh bên",
+    "Show your screen" : "Hiện màn hình của bạn",
+    "Stop screensharing" : "Ngừng chia sẽ màn hình",
+    "Screensharing options" : "Tùy chọn chia sẻ màn hình",
+    "Enable screensharing" : "Bật chia sẽ màn hình",
+    "Bad sent video and screen quality." : "Chất lượng màn hình và video đã gửi kém.",
+    "Bad sent screen quality." : "Chất lượng màn hình đã gửi kém.",
+    "Bad sent video quality." : "Chất lượng video đã gửi kém.",
+    "Bad sent audio, video and screen quality." : "Chất lượng âm thanh, video và màn hình được gửi kém.",
+    "Bad sent audio and screen quality." : "Chất lượng âm thanh và màn hình đã gửi kém.",
+    "Bad sent audio and video quality." : "Chất lượng âm thanh và video được gửi kém.",
+    "Bad sent audio quality." : "Chất lượng âm thanh đã gửi kém.",
+    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không nhìn thấy màn hình của bạn.",
+    "Your internet connection or computer are busy and other participants might be unable to see you." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không nhìn thấy bạn.",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu và nhìn thấy bạn. Để cải thiện tình hình, hãy thử tắt video của bạn trong khi thực hiện chia sẻ màn hình.",
+    "Disable screenshare" : "Tắt chia sẻ màn hình",
+    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu và nhìn thấy bạn. Để cải thiện tình hình, hãy thử tắt video của bạn.",
+    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu bạn.",
+    "Screen sharing is not supported by your browser." : "Chia sẻ màn hình không được trình duyệt của bạn hỗ trợ.",
+    "Screen sharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang được tải qua HTTPS.",
+    "Screensharing requires the page to be loaded through HTTPS." : "Chia sẻ màn hình yêu cầu trang phải tải qua HTTPS.",
+    "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
+    "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
+    "An error occurred while starting screensharing." : "Đã xảy ra lỗi khi bắt đầu chia sẻ màn hình.",
     "Mute others" : "Tắt tiếng người khác",
-    "Send" : "Gửi",
-    "Add more files" : "Thêm nhiều tập tin",
+    "Speaker view" : "Chế độ xem người gọi điện",
+    "Grid view" : "Xem dạng Lưới",
+    "Raise hand" : "Giơ tay",
+    "Lower hand" : "Đặt tay xuống",
     "No unread mentions" : "Không có đề cập nào chưa đọc",
     "Say hi to your friends and colleagues!" : "Gửi lòi chào đến bạn bè và đồng nghiệp",
     "Start a conversation" : "Bắt đầu một cuộc Đàm thoại",
-    "You were mentioned" : "Bạn đã được nhắc tới",
     "Message without mention" : "Tin nhắn không đề cập",
     "Mention myself" : "Nhắc đến chính mình",
     "Mention room" : "Nhắc đến phòng",
     "The conversation does not exist" : "Cuộc trò chuyện không tồn tại",
     "Join a conversation or start a new one!" : "Tham gia một cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới!",
-    "No conversations found" : "Không tìm thấy cuộc trò chuyện nào",
-    "Select conversation" : "Chọn cuộc trò chuyện",
-    "Link to a conversation" : "Liên kết đến một cuộc trò chuyện",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Bạn đã tham gia cuộc trò chuyện trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ nên phiên này đã bị đóng.",
     "Join a conversation or start a new one" : "Tham gia cuộc trò chuyện hoặc bắt đầu một cuộc trò chuyện mới",
     "Post to a conversation" : "Đăng lên một cuộc trò chuyện",
@@ -709,7 +692,6 @@ OC.L10N.register(
     "Access to camera is only possible with HTTPS" : "Chỉ có thể truy cập vào camera với HTTPS",
     "An error occurred while fetching the participants" : "Đã xảy ra lỗi khi tìm nạp những người tham gia",
     "Media" : "Phương tiện",
-    "Files" : "Tệp",
     "Locations" : "Các địa điểm",
     "Audio" : "Âm thanh",
     "Other" : "Khác",
@@ -725,7 +707,6 @@ OC.L10N.register(
     "Join here" : "Tham gia tại đây",
     "Leave this page" : "Rời khỏi trang này",
     "Nextcloud is in maintenance mode, please reload the page" : "vWorkspace đang ở chế độ bảo trì, vui lòng tải lại trang",
-    "Sending signaling message has failed." : "Gửi tin nhắn báo hiệu không thành công.",
     "Lost connection to signaling server. Trying to reconnect." : "Mất kết nối với máy chủ báo hiệu. Đang cố gắng kết nối lại.",
     "Lost connection to signaling server. Try to reload the page manually." : "Mất kết nối với máy chủ báo hiệu. Cố gắng tải lại trang theo cách thủ công.",
     "Establishing signaling connection is taking longer than expected …" : "Việc thiết lập kết nối báo hiệu mất nhiều thời gian hơn dự kiến…",
@@ -754,24 +735,21 @@ OC.L10N.register(
     "Join conversations at any time, anywhere, on any device." : "Tham gia các cuộc trò chuyện mọi lúc, mọi nơi, trên mọi thiết bị.",
     "Android app" : "Ứng dụng Android",
     "iOS app" : "Ứng dụng IOS",
-    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}appstore{linkend}." : "Bạn có thể cài đặt Matterbridge để liên kết vWorkspace Talk với một số dịch vụ khác. Quá trình tải xuống và cài đặt ứng dụng có thể mất một chút thời gian. Trong trường hợp hết thời gian, vui lòng cài đặt thủ công từ {linkstart2} appstore {linkend}.",
-    "Saved" : "Đã lưu",
-    "Add a new server" : "Thêm một máy chủ mới",
-    "Your internet connection or computer are busy and other participants might be unable to see you. To improve the situation try to disable your video while doing a screenshare." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không nhìn thấy bạn. Để cải thiện tình hình, hãy thử tắt video của bạn trong khi thực hiện chia sẻ màn hình.",
-    "Your internet connection or computer are busy and other participants might be unable to understand and see your screen. To improve the situation try to disable your screenshare." : "Kết nối internet hoặc máy tính của bạn đang bận và những người tham gia khác có thể không hiểu và nhìn thấy màn hình của bạn. Để cải thiện tình hình, hãy thử tắt tính năng chia sẻ màn hình của bạn.",
-    "Error while accessing camera: it is likely in use by another program" : "Lỗi khi truy cập máy ảnh: nó có thể đang được chương trình khác sử dụng",
-    "Chat notifications" : "Thông báo trò chuyện",
-    "Set the notification level for the current conversation. This will affect only the notifications you receive." : "Đặt mức thông báo cho cuộc trò chuyện hiện tại. Điều này sẽ chỉ ảnh hưởng đến các thông báo bạn nhận được.",
-    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Bạn hiện đang đợi ở sảnh. Cuộc họp này được lên lịch vào {startTime}",
-    "Microphone" : "Micrô",
-    "Camera" : "Camera",
-    "Message link copied to clipboard." : "Đã sao chép liên kết tin nhắn vào khay nhớ tạm.",
-    "Upload new files" : "Tải lên các tệp mới",
-    "Share from Files" : "Chia sẻ từ Thư mục",
-    "Invitation was sent to {actorId}." : "Lời mời đã được gửi đến {actorId}.",
-    "Display name: " : "Tên hiển thị:",
-    "Video on and off" : "Bật và tắt video",
-    "Deck card has been posted to the selected <a href=\"{link}\">conversation</a>." : "Bộ bài đã được đăng lên <a href=\"{link}\">cuộc đối thoại</a> đã chọn.",
-    "An error occurred while posting deck card to conversation." : "Đã xảy ra lỗi khi đăng bộ bài lên cuộc trò chuyện."
+    "Name of the user requesting the trial" : "Tên của người dùng yêu cầu bản dùng thử",
+    "An error occurred while installing the Matterbridge app." : "Đã xảy ra lỗi khi cài đặt ứng dụng Matterbridge.",
+    "An error occurred while installing the Talk Matterbridge. Please install it manually." : "Đã xảy ra lỗi khi cài đặt Talk Matterbridge. Vui lòng cài đặt nó theo cách thủ công.",
+    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Xin lưu ý rằng các cuộc gọi có hơn 4 người tham gia mà không có máy chủ báo hiệu bên ngoài, người tham gia có thể gặp sự cố kết nối và gây tải cao cho các thiết bị tham gia.",
+    "More actions" : "Nhiều hành động hơn",
+    "Conversation link copied to clipboard." : "Đã sao chép liên kết cuộc trò chuyện vào khay nhớ tạm.",
+    "The link could not be copied." : "Không thể sao chép liên kết.",
+    "Cancel editing description" : "Hủy chỉnh sửa mô tả",
+    "Submit conversation description" : "Gửi mô tả cuộc trò chuyện",
+    "The description must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Mô tả phải dài ít hơn hoặc bằng {maxLength} ký tự. Văn bản hiện tại của bạn dài {characterCount} ký tự.",
+    "No matches" : "Không phù hợp",
+    "Link copied to the clipboard!" : "Đã sao chép liên kết vào khay nhớ tạm!",
+    "Sounds can currently not be played in Safari browser and iPad and iPhone devices due to technical restrictions by the manufacturer." : "Âm thanh hiện không thể phát trong trình duyệt Safari và các thiết bị iPad và iPhone do các hạn chế kỹ thuật của nhà sản xuất.",
+    "Toggle fullscreen" : "Bật chế độ toàn màn hình",
+    "Rename conversation" : "Đổi tên cuộc đàm thoại",
+    "Sending signaling message has failed." : "Gửi tin nhắn báo hiệu không thành công."
 },
 "nplurals=1; plural=0;");
