@@ -29,14 +29,17 @@ use OC\Memcache\ArrayCache;
 use OC\Memcache\NullCache;
 use OCA\Talk\Events\ChatEvent;
 use OCA\Talk\Events\ChatParticipantEvent;
-use OCA\Talk\Manager;
+use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Model\Attendee;
+use OCA\Talk\Model\Poll;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\AttachmentService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\PollService;
+use OCA\Talk\Service\RoomService;
 use OCA\Talk\Share\RoomShareProvider;
+use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Collaboration\Reference\IReferenceManager;
 use OCP\Comments\IComment;
@@ -80,15 +83,14 @@ class ChatManager {
 	public const VERB_REACTION = 'reaction';
 	public const VERB_REACTION_DELETED = 'reaction_deleted';
 
-	/** @var ICommentsManager|CommentsManager
-	 */
-	private $commentsManager;
+	private CommentsManager $commentsManager;
 	private IEventDispatcher $dispatcher;
 	private IDBConnection $connection;
 	private INotificationManager $notificationManager;
 	private IManager $shareManager;
 	private RoomShareProvider $shareProvider;
 	private ParticipantService $participantService;
+	private RoomService $roomService;
 	private PollService $pollService;
 	private Notifier $notifier;
 	protected ITimeFactory $timeFactory;
@@ -97,19 +99,22 @@ class ChatManager {
 	protected AttachmentService $attachmentService;
 	protected IReferenceManager $referenceManager;
 
-	public function __construct(CommentsManager $commentsManager,
-								IEventDispatcher $dispatcher,
-								IDBConnection $connection,
-								INotificationManager $notificationManager,
-								IManager $shareManager,
-								RoomShareProvider $shareProvider,
-								ParticipantService $participantService,
-								PollService $pollService,
-								Notifier $notifier,
-								ICacheFactory $cacheFactory,
-								ITimeFactory $timeFactory,
-								AttachmentService $attachmentService,
-								IReferenceManager $referenceManager) {
+	public function __construct(
+		CommentsManager $commentsManager,
+		IEventDispatcher $dispatcher,
+		IDBConnection $connection,
+		INotificationManager $notificationManager,
+		IManager $shareManager,
+		RoomShareProvider $shareProvider,
+		ParticipantService $participantService,
+		RoomService $roomService,
+		PollService $pollService,
+		Notifier $notifier,
+		ICacheFactory $cacheFactory,
+		ITimeFactory $timeFactory,
+		AttachmentService $attachmentService,
+		IReferenceManager $referenceManager,
+	) {
 		$this->commentsManager = $commentsManager;
 		$this->dispatcher = $dispatcher;
 		$this->connection = $connection;
@@ -117,6 +122,7 @@ class ChatManager {
 		$this->shareManager = $shareManager;
 		$this->shareProvider = $shareProvider;
 		$this->participantService = $participantService;
+		$this->roomService = $roomService;
 		$this->pollService = $pollService;
 		$this->notifier = $notifier;
 		$this->cache = $cacheFactory->createDistributed('talk/lastmsgid');
@@ -186,7 +192,7 @@ class ChatManager {
 
 			if (!$shouldSkipLastMessageUpdate) {
 				// Update last_message
-				$chat->setLastMessage($comment);
+				$this->roomService->setLastMessage($chat, $comment);
 				$this->unreadCountCache->clear($chat->getId() . '-');
 			}
 
@@ -194,6 +200,17 @@ class ChatManager {
 				$this->notifier->notifyOtherParticipant($chat, $comment, [], false);
 			}
 
+			if (!$shouldSkipLastMessageUpdate && $sendNotifications) {
+				// Update the read-marker for the author when it is a "relevant" system message,
+				// e.g. sharing an item to the chat
+				try {
+					$participant = $this->participantService->getParticipantByActor($chat, $actorType, $actorId);
+					$this->participantService->updateLastReadMessage($participant, (int) $comment->getId());
+				} catch (ParticipantNotFoundException) {
+					// Participant not found => No read-marker update needed
+				}
+			}
+
 			$this->dispatcher->dispatch(self::EVENT_AFTER_SYSTEM_MESSAGE_SEND, $event);
 		} catch (NotFoundException $e) {
 		}
@@ -226,7 +243,7 @@ class ChatManager {
 			$this->commentsManager->save($comment);
 
 			// Update last_message
-			$chat->setLastMessage($comment);
+			$this->roomService->setLastMessage($chat, $comment);
 			$this->unreadCountCache->clear($chat->getId() . '-');
 
 			$this->dispatcher->dispatch(self::EVENT_AFTER_SYSTEM_MESSAGE_SEND, $event);
@@ -275,12 +292,14 @@ class ChatManager {
 		try {
 			$this->commentsManager->save($comment);
 
+			$this->participantService->updateLastReadMessage($participant, (int) $comment->getId());
+
 			// Update last_message
 			if ($comment->getActorType() !== 'bots' || $comment->getActorId() === 'changelog') {
-				$chat->setLastMessage($comment);
+				$this->roomService->setLastMessage($chat, $comment);
 				$this->unreadCountCache->clear($chat->getId() . '-');
 			} else {
-				$chat->setLastActivity($comment->getCreationDateTime());
+				$this->roomService->setLastActivity($chat, $comment->getCreationDateTime());
 			}
 
 			$alreadyNotifiedUsers = [];
@@ -353,6 +372,60 @@ class ChatManager {
 		$this->shareManager->deleteShare($share);
 	}
 
+	/**
+	 * @param Room $room
+	 * @param Participant $participant
+	 * @param array $messageData
+	 * @throws ShareNotFound
+	 */
+	public function removePollOnMessageDelete(Room $room, Participant $participant, array $messageData, \DateTime $deletionTime): void {
+		if (!isset($messageData['message'], $messageData['parameters']['objectType'], $messageData['parameters']['objectId'])
+			|| $messageData['message'] !== 'object_shared'
+			|| $messageData['parameters']['objectType'] !== 'talk-poll') {
+			// Not a poll share
+			return;
+		}
+
+		try {
+			$poll = $this->pollService->getPoll($room->getId(), (int)$messageData['parameters']['objectId']);
+		} catch (DoesNotExistException $e) {
+			return;
+		}
+
+		if ($poll->getStatus() === Poll::STATUS_CLOSED) {
+			$closingMessages = $this->commentsManager->searchForObjects(
+				json_encode([
+					'message' => 'poll_closed',
+					'parameters' => [
+						'poll' => [
+							'type' => 'talk-poll',
+							'id' => $poll->getId(),
+							'name' => $poll->getQuestion(),
+						],
+					],
+				], JSON_THROW_ON_ERROR),
+				'chat',
+				[(string) $room->getId()],
+				'system',
+				0
+			);
+			foreach ($closingMessages as $closingMessage) {
+				$this->deleteMessage($room, $closingMessage, $participant, $deletionTime);
+			}
+		}
+
+		if (!$participant->hasModeratorPermissions(false)) {
+			$attendee = $participant->getAttendee();
+			if (!($attendee->getActorType() === $poll->getActorType()
+				&& $attendee->getActorId() === $poll->getActorId())) {
+				// Only moderators or the poll creator can delete it
+				return;
+			}
+		}
+
+		$this->pollService->deleteByPollId($poll->getId());
+	}
+
 	/**
 	 * @param Room $chat
 	 * @param IComment $comment
@@ -365,6 +438,7 @@ class ChatManager {
 		if ($comment->getVerb() === self::VERB_OBJECT_SHARED) {
 			$messageData = json_decode($comment->getMessage(), true);
 			$this->unshareFileOnMessageDelete($chat, $participant, $messageData);
+			$this->removePollOnMessageDelete($chat, $participant, $messageData, $deletionTime);
 		}
 
 		$comment->setMessage(
@@ -403,6 +477,8 @@ class ChatManager {
 
 		$this->participantService->resetChatDetails($chat);
 
+		$this->pollService->deleteByRoomId($chat->getId());
+
 		return $this->addSystemMessage(
 			$chat,
 			$actorType,
@@ -446,7 +522,7 @@ class ChatManager {
 	}
 
 	public function getLastReadMessageFromLegacy(Room $chat, IUser $user): int {
-		$marker = $this->commentsManager->getReadMark('chat', $chat->getId(), $user);
+		$marker = $this->commentsManager->getReadMark('chat', (string) $chat->getId(), $user);
 		if ($marker === null) {
 			return 0;
 		}
@@ -536,12 +612,13 @@ class ChatManager {
 	 * @param int $timeout
 	 * @param IUser|null $user
 	 * @param bool $includeLastKnown
+	 * @param bool $markNotificationsAsRead (defaults to true)
 	 * @return IComment[] the messages found (only the id, actor type and id,
 	 *         creation date and message are relevant), or an empty array if the
 	 *         timeout expired.
 	 */
-	public function waitForNewMessages(Room $chat, int $offset, int $limit, int $timeout, ?IUser $user, bool $includeLastKnown): array {
-		if ($user instanceof IUser) {
+	public function waitForNewMessages(Room $chat, int $offset, int $limit, int $timeout, ?IUser $user, bool $includeLastKnown, bool $markNotificationsAsRead = true): array {
+		if ($markNotificationsAsRead && $user instanceof IUser) {
 			$this->notifier->markMentionNotificationsRead($chat, $user->getUID());
 		}
 
@@ -659,7 +736,7 @@ class ChatManager {
 	 * @return IComment[]
 	 */
 	public function getMessagesById(Room $chat, array $commentIds): array {
-		$comments = $this->commentsManager->getCommentsById($commentIds);
+		$comments = $this->commentsManager->getCommentsById(array_map('strval', $commentIds));
 
 		$comments = array_filter($comments, static function (IComment $comment) use ($chat) {
 			return $comment->getObjectType() === 'chat'
@@ -697,14 +774,14 @@ class ChatManager {
 			array_unshift($results, [
 				'id' => 'all',
 				'label' => $roomDisplayName,
-				'source' => 'calls'
+				'source' => 'calls',
 			]);
 		}
 		return $results;
 	}
 
 	private function searchIsPartOfConversationNameOrAtAll(string $search, string $roomDisplayName): bool {
-		if (stripos($roomDisplayName, $search) === 0) {
+		if (stripos($roomDisplayName, $search) !== false) {
 			return true;
 		}
 		if (strpos('all', $search) === 0) {
@@ -719,4 +796,45 @@ class ChatManager {
 	public function deleteExpiredMessages(): void {
 		$this->commentsManager->deleteCommentsExpiredAtObject('chat', '');
 	}
+
+	public function fileOfMessageExists(string $message): bool {
+		$parameters = $this->getParametersFromMessage($message);
+		try {
+			$this->shareProvider->getShareById($parameters['share']);
+		} catch (ShareNotFound $e) {
+			return false;
+		}
+		return true;
+	}
+
+	public function isSharedFile(string $message): bool {
+		$parameters = $this->getParametersFromMessage($message);
+		return !empty($parameters['share']);
+	}
+
+	protected function getParametersFromMessage(string $message): array {
+		$data = json_decode($message, true);
+		if (!\is_array($data) || !array_key_exists('parameters', $data) || !is_array($data['parameters'])) {
+			return [];
+		}
+		return $data['parameters'];
+	}
+
+	/**
+	 * When receive a list of comments, filter the comments,
+	 * removing all that have shares of file that no more exists
+	 *
+	 * @param IComment[] $comments
+	 * @return IComment[]
+	 */
+	public function filterCommentsWithNonExistingFiles(array $comments): array {
+		return array_filter($comments, function (IComment $comment) {
+			if ($this->isSharedFile($comment->getMessage())) {
+				if (!$this->fileOfMessageExists($comment->getMessage())) {
+					return false;
+				}
+			}
+			return true;
+		});
+	}
 }
