@@ -32,6 +32,7 @@ use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Message;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
+use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Share\RoomShareProvider;
 use OCP\Comments\IComment;
 use OCP\Federation\ICloudIdManager;
@@ -53,6 +54,7 @@ class SystemMessage {
 	protected IUserManager $userManager;
 	protected IGroupManager $groupManager;
 	protected GuestManager $guestManager;
+	protected ParticipantService $participantService;
 	protected IPreviewManager $previewManager;
 	protected RoomShareProvider $shareProvider;
 	protected PhotoCache $photoCache;
@@ -74,18 +76,22 @@ class SystemMessage {
 	/** @var string[] */
 	protected array $guestNames = [];
 
-	public function __construct(IUserManager $userManager,
-								IGroupManager $groupManager,
-								GuestManager $guestManager,
-								IPreviewManager $previewManager,
-								RoomShareProvider $shareProvider,
-								PhotoCache $photoCache,
-								IRootFolder $rootFolder,
-								ICloudIdManager $cloudIdManager,
-								IURLGenerator $url) {
+	public function __construct(
+		IUserManager $userManager,
+		IGroupManager $groupManager,
+		GuestManager $guestManager,
+		ParticipantService $participantService,
+		IPreviewManager $previewManager,
+		RoomShareProvider $shareProvider,
+		PhotoCache $photoCache,
+		IRootFolder $rootFolder,
+		ICloudIdManager $cloudIdManager,
+		IURLGenerator $url,
+	) {
 		$this->userManager = $userManager;
 		$this->groupManager = $groupManager;
 		$this->guestManager = $guestManager;
+		$this->participantService = $participantService;
 		$this->previewManager = $previewManager;
 		$this->shareProvider = $shareProvider;
 		$this->photoCache = $photoCache;
@@ -220,6 +226,16 @@ class SystemMessage {
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You restricted the conversation to moderators');
 			}
+		} elseif ($message === 'breakout_rooms_started') {
+			$parsedMessage = $this->l->t('{actor} started breakout rooms');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You started breakout rooms');
+			}
+		} elseif ($message === 'breakout_rooms_stopped') {
+			$parsedMessage = $this->l->t('{actor} stopped breakout rooms');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You stopped breakout rooms');
+			}
 		} elseif ($message === 'guests_allowed') {
 			$parsedMessage = $this->l->t('{actor} allowed guests');
 			if ($currentUserIsActor) {
@@ -397,8 +413,16 @@ class SystemMessage {
 				$parsedParameters['file'] = $this->getFileFromShare($participant, $parameters['share']);
 				$parsedMessage = '{file}';
 				$metaData = $parameters['metaData'] ?? [];
-				if (isset($metaData['messageType']) && $metaData['messageType'] === 'voice-message') {
-					$chatMessage->setMessageType('voice-message');
+				if (isset($metaData['messageType'])) {
+					if ($metaData['messageType'] === 'voice-message') {
+						$chatMessage->setMessageType('voice-message');
+					} elseif ($metaData['messageType'] === 'record-audio') {
+						$chatMessage->setMessageType('record-audio');
+					} elseif ($metaData['messageType'] === 'record-video') {
+						$chatMessage->setMessageType('record-video');
+					} else {
+						$chatMessage->setMessageType(ChatManager::VERB_MESSAGE);
+					}
 				} else {
 					$chatMessage->setMessageType(ChatManager::VERB_MESSAGE);
 				}
@@ -493,6 +517,16 @@ class SystemMessage {
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You cleared the history of the conversation');
 			}
+		} elseif ($message === 'avatar_set') {
+			$parsedMessage = $this->l->t('{actor} set the conversation picture');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You set the conversation picture');
+			}
+		} elseif ($message === 'avatar_removed') {
+			$parsedMessage = $this->l->t('{actor} removed the conversation picture');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You removed the conversation picture');
+			}
 		} elseif ($message === 'poll_closed') {
 			$parsedParameters['poll'] = $parameters['poll'];
 			$parsedParameters['poll']['id'] = (string) $parsedParameters['poll']['id'];
@@ -500,6 +534,28 @@ class SystemMessage {
 			if ($currentUserIsActor) {
 				$parsedMessage = $this->l->t('You ended the poll {poll}');
 			}
+		} elseif ($message === 'recording_started') {
+			$parsedMessage = $this->l->t('{actor} started the video recording');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You started the video recording');
+			}
+		} elseif ($message === 'recording_stopped') {
+			$parsedMessage = $this->l->t('{actor} stopped the video recording');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You stopped the video recording');
+			}
+		} elseif ($message === 'audio_recording_started') {
+			$parsedMessage = $this->l->t('{actor} started the audio recording');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You started the audio recording');
+			}
+		} elseif ($message === 'audio_recording_stopped') {
+			$parsedMessage = $this->l->t('{actor} stopped the audio recording');
+			if ($currentUserIsActor) {
+				$parsedMessage = $this->l->t('You stopped the audio recording');
+			}
+		} elseif ($message === 'recording_failed') {
+			$parsedMessage = $this->l->t('The recording failed');
 		} elseif ($message === 'poll_voted') {
 			$parsedParameters['poll'] = $parameters['poll'];
 			$parsedParameters['poll']['id'] = (string) $parsedParameters['poll']['id'];
@@ -571,7 +627,7 @@ class SystemMessage {
 	 * @throws ShareNotFound
 	 */
 	protected function getFileFromShare(Participant $participant, string $shareId): array {
-		$share = $this->shareProvider->getShareById($shareId);
+		$share = $this->shareProvider->getShareById((int) $shareId);
 
 		if (!$participant->isGuest()) {
 			if ($share->getShareOwner() !== $participant->getAttendee()->getActorId()) {
@@ -784,7 +840,7 @@ class SystemMessage {
 
 	protected function getGuestName(Room $room, string $actorType, string $actorId): string {
 		try {
-			$participant = $room->getParticipantByActor($actorType, $actorId);
+			$participant = $this->participantService->getParticipantByActor($room, $actorType, $actorId);
 			$name = $participant->getAttendee()->getDisplayName();
 			if ($name === '' && $actorType === Attendee::ACTOR_EMAILS) {
 				$name = $actorId;
@@ -844,9 +900,10 @@ class SystemMessage {
 	protected function parseCall(string $message, array $parameters, array $params): array {
 		if ($message === 'call_ended_everyone') {
 			if ($params['actor']['type'] === 'user') {
-				$flipped = array_flip($parameters['users']);
-				unset($flipped[$params['actor']['id']]);
-				$parameters['users'] = array_flip($flipped);
+				$entry = array_keys($parameters['users'], $params['actor']['id'], true);
+				foreach ($entry as $i) {
+					unset($parameters['users'][$i]);
+				}
 			} else {
 				$parameters['guests']--;
 			}
