@@ -36,6 +36,7 @@ use OCA\Talk\Events\RemoveUserEvent;
 use OCA\Talk\Events\RoomEvent;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
+use OCA\Talk\Model\BreakoutRoom;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
@@ -56,6 +57,9 @@ use OCP\Server;
 use OCP\Share\IShare;
 use Symfony\Component\EventDispatcher\GenericEvent;
 
+/**
+ * @template-implements IEventListener<Event>
+ */
 class Listener implements IEventListener {
 	protected IRequest $request;
 	protected ChatManager $chatManager;
@@ -64,12 +68,14 @@ class Listener implements IEventListener {
 	protected IUserSession $userSession;
 	protected ITimeFactory $timeFactory;
 
-	public function __construct(IRequest $request,
-								ChatManager $chatManager,
-								TalkSession $talkSession,
-								ISession $session,
-								IUserSession $userSession,
-								ITimeFactory $timeFactory) {
+	public function __construct(
+		IRequest $request,
+		ChatManager $chatManager,
+		TalkSession $talkSession,
+		ISession $session,
+		IUserSession $userSession,
+		ITimeFactory $timeFactory,
+	) {
 		$this->request = $request;
 		$this->chatManager = $chatManager;
 		$this->talkSession = $talkSession;
@@ -96,6 +102,8 @@ class Listener implements IEventListener {
 		$dispatcher->addListener('OCP\Share::postShare', self::class . '::fixMimeTypeOfVoiceMessage');
 		$dispatcher->addListener(RoomShareProvider::EVENT_SHARE_FILE_AGAIN, self::class . '::fixMimeTypeOfVoiceMessage');
 		$dispatcher->addListener(Room::EVENT_AFTER_SET_MESSAGE_EXPIRATION, self::class . '::afterSetMessageExpiration');
+		$dispatcher->addListener(Room::EVENT_AFTER_SET_CALL_RECORDING, self::class . '::setCallRecording');
+		$dispatcher->addListener(Room::EVENT_AFTER_AVATAR_SET, self::class . '::avatarChanged');
 	}
 
 	public static function sendSystemMessageAboutBeginOfCall(ModifyParticipantEvent $event): void {
@@ -232,7 +240,13 @@ class Listener implements IEventListener {
 		$room = $event->getRoom();
 		$listener = Server::get(self::class);
 
-		if ($event->isTimerReached()) {
+		if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
+			if ($event->getNewValue() === Webinary::LOBBY_NONE) {
+				$listener->sendSystemMessage($room, 'breakout_rooms_started');
+			} else {
+				$listener->sendSystemMessage($room, 'breakout_rooms_stopped');
+			}
+		} elseif ($event->isTimerReached()) {
 			$listener->sendSystemMessage($room, 'lobby_timer_reached');
 		} elseif ($event->getNewValue() === Webinary::LOBBY_NONE) {
 			$listener->sendSystemMessage($room, 'lobby_none');
@@ -370,6 +384,10 @@ class Listener implements IEventListener {
 		$listener = Server::get(self::class);
 		$manager = Server::get(Manager::class);
 
+		$request = Server::get(IRequest::class);
+		if ($request->getParam('_route') === 'ocs.spreed.Recording.shareToChat') {
+			return;
+		}
 		$room = $manager->getRoomByToken($share->getSharedWith());
 		$metaData = Server::get(IRequest::class)->getParam('talkMetaData') ?? '';
 		$metaData = json_decode($metaData, true);
@@ -483,4 +501,65 @@ class Listener implements IEventListener {
 			]
 		);
 	}
+
+	public static function setCallRecording(ModifyRoomEvent $event): void {
+		$recordingHasStarted = in_array($event->getOldValue(), [Room::RECORDING_NONE, Room::RECORDING_VIDEO_STARTING, Room::RECORDING_AUDIO_STARTING, Room::RECORDING_FAILED])
+			&& in_array($event->getNewValue(), [Room::RECORDING_VIDEO, Room::RECORDING_AUDIO]);
+		$recordingHasStopped = in_array($event->getOldValue(), [Room::RECORDING_VIDEO, Room::RECORDING_AUDIO])
+			&& $event->getNewValue() === Room::RECORDING_NONE;
+		$recordingHasFailed = in_array($event->getOldValue(), [Room::RECORDING_VIDEO, Room::RECORDING_AUDIO])
+			&& $event->getNewValue() === Room::RECORDING_FAILED;
+
+		if (!$recordingHasStarted && !$recordingHasStopped && !$recordingHasFailed) {
+			return;
+		}
+
+		$actor = $event->getActor();
+		if ($recordingHasStopped && $actor === null) {
+			// No actor means the recording was stopped by the end of the call.
+			// So we are not generating a system message
+			return;
+		}
+
+		$prefix = self::getCallRecordingPrefix($event);
+		$suffix = self::getCallRecordingSuffix($event);
+		$systemMessage = $prefix . 'recording_' . $suffix;
+
+		$listener = Server::get(self::class);
+		$listener->sendSystemMessage($event->getRoom(), $systemMessage, [], $actor);
+	}
+
+	private static function getCallRecordingSuffix(ModifyRoomEvent $event): string {
+		$newStatus = $event->getNewValue();
+		$startStatus = [
+			Room::RECORDING_VIDEO,
+			Room::RECORDING_AUDIO,
+		];
+		if (in_array($newStatus, $startStatus)) {
+			return 'started';
+		}
+		if ($newStatus === Room::RECORDING_FAILED) {
+			return 'failed';
+		}
+		return 'stopped';
+	}
+
+	private static function getCallRecordingPrefix(ModifyRoomEvent $event): string {
+		$newValue = $event->getNewValue();
+		$oldValue = $event->getOldValue();
+		$isAudioStatus = $newValue === Room::RECORDING_AUDIO
+			|| ($oldValue === Room::RECORDING_AUDIO && $newValue !== Room::RECORDING_FAILED);
+		return $isAudioStatus ? 'audio_' : '';
+	}
+
+	public static function avatarChanged(ModifyRoomEvent $event): void {
+		if ($event->getNewValue()) {
+			$message = 'avatar_set';
+		} else {
+			$message = 'avatar_removed';
+		}
+
+		$listener = Server::get(self::class);
+		$listener->sendSystemMessage($event->getRoom(), $message);
+	}
 }
