@@ -27,12 +27,18 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Controller;
 
+use OCA\Talk\Middleware\Attribute\RequireCallEnabled;
+use OCA\Talk\Middleware\Attribute\RequireModeratorOrNoLobby;
+use OCA\Talk\Middleware\Attribute\RequireParticipant;
+use OCA\Talk\Middleware\Attribute\RequirePermission;
+use OCA\Talk\Middleware\Attribute\RequireReadWriteConversation;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\RoomService;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\IRequest;
@@ -44,12 +50,14 @@ class CallController extends AEnvironmentAwareController {
 	private IUserManager $userManager;
 	private ITimeFactory $timeFactory;
 
-	public function __construct(string $appName,
-								IRequest $request,
-								ParticipantService $participantService,
-								RoomService $roomService,
-								IUserManager $userManager,
-								ITimeFactory $timeFactory) {
+	public function __construct(
+		string $appName,
+		IRequest $request,
+		ParticipantService $participantService,
+		RoomService $roomService,
+		IUserManager $userManager,
+		ITimeFactory $timeFactory,
+	) {
 		parent::__construct($appName, $request);
 		$this->participantService = $participantService;
 		$this->roomService = $roomService;
@@ -57,15 +65,11 @@ class CallController extends AEnvironmentAwareController {
 		$this->timeFactory = $timeFactory;
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireCallEnabled
-	 * @RequireParticipant
-	 * @RequireReadWriteConversation
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireCallEnabled]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequireReadWriteConversation]
 	public function getPeersForCall(): DataResponse {
 		$timeout = $this->timeFactory->getTime() - Session::SESSION_TIMEOUT;
 		$result = [];
@@ -99,17 +103,11 @@ class CallController extends AEnvironmentAwareController {
 		return new DataResponse($result);
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireCallEnabled
-	 * @RequireParticipant
-	 * @RequireReadWriteConversation
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @param int|null $flags
-	 * @param int|null $forcePermissions
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireCallEnabled]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequireReadWriteConversation]
 	public function joinCall(?int $flags = null, ?int $forcePermissions = null, bool $silent = false): DataResponse {
 		$this->participantService->ensureOneToOneRoomIsFilled($this->room);
 
@@ -132,15 +130,10 @@ class CallController extends AEnvironmentAwareController {
 		return new DataResponse();
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireCallEnabled
-	 * @RequireParticipant
-	 * @RequirePermissions(permissions=call-start)
-	 *
-	 * @param int $attendeeId
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireCallEnabled]
+	#[RequireParticipant]
+	#[RequirePermission(permission: RequirePermission::START_CALL)]
 	public function ringAttendee(int $attendeeId): DataResponse {
 		if ($this->room->getCallFlag() === Participant::FLAG_DISCONNECTED) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
@@ -157,13 +150,8 @@ class CallController extends AEnvironmentAwareController {
 		return new DataResponse();
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 *
-	 * @param int flags
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireParticipant]
 	public function updateCallFlags(int $flags): DataResponse {
 		$session = $this->participant->getSession();
 		if (!$session instanceof Session) {
@@ -180,12 +168,11 @@ class CallController extends AEnvironmentAwareController {
 	}
 
 	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 *
 	 * @param bool $all whether to also terminate the call for all participants
 	 * @return DataResponse
 	 */
+	#[PublicPage]
+	#[RequireParticipant]
 	public function leaveCall(bool $all = false): DataResponse {
 		$session = $this->participant->getSession();
 		if (!$session instanceof Session) {
