@@ -31,6 +31,11 @@ use OCA\Talk\Chat\MessageParser;
 use OCA\Talk\Chat\ReactionManager;
 use OCA\Talk\GuestManager;
 use OCA\Talk\MatterbridgeManager;
+use OCA\Talk\Middleware\Attribute\RequireModeratorOrNoLobby;
+use OCA\Talk\Middleware\Attribute\RequireModeratorParticipant;
+use OCA\Talk\Middleware\Attribute\RequireParticipant;
+use OCA\Talk\Middleware\Attribute\RequirePermission;
+use OCA\Talk\Middleware\Attribute\RequireReadWriteConversation;
 use OCA\Talk\Model\Attachment;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Message;
@@ -38,11 +43,14 @@ use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\AttachmentService;
+use OCA\Talk\Service\AvatarService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\SessionService;
 use OCA\Talk\Share\RoomShareProvider;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\NoAdminRequired;
+use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Collaboration\AutoComplete\IManager;
@@ -71,6 +79,7 @@ class ChatController extends AEnvironmentAwareController {
 	private ParticipantService $participantService;
 	private SessionService $sessionService;
 	protected AttachmentService $attachmentService;
+	protected avatarService $avatarService;
 	private GuestManager $guestManager;
 	/** @var string[] */
 	protected array $guestNames;
@@ -87,29 +96,32 @@ class ChatController extends AEnvironmentAwareController {
 	protected ITrustedDomainHelper $trustedDomainHelper;
 	private IL10N $l;
 
-	public function __construct(string $appName,
-								?string $UserId,
-								IRequest $request,
-								IUserManager $userManager,
-								IAppManager $appManager,
-								ChatManager $chatManager,
-								ReactionManager $reactionManager,
-								ParticipantService $participantService,
-								SessionService $sessionService,
-								AttachmentService $attachmentService,
-								GuestManager $guestManager,
-								MessageParser $messageParser,
-								RoomShareProvider $shareProvider,
-								IManager $autoCompleteManager,
-								IUserStatusManager $statusManager,
-								MatterbridgeManager $matterbridgeManager,
-								SearchPlugin $searchPlugin,
-								ISearchResult $searchResult,
-								ITimeFactory $timeFactory,
-								IEventDispatcher $eventDispatcher,
-								IValidator $richObjectValidator,
-								ITrustedDomainHelper $trustedDomainHelper,
-								IL10N $l) {
+	public function __construct(
+		string $appName,
+		?string $UserId,
+		IRequest $request,
+		IUserManager $userManager,
+		IAppManager $appManager,
+		ChatManager $chatManager,
+		ReactionManager $reactionManager,
+		ParticipantService $participantService,
+		SessionService $sessionService,
+		AttachmentService $attachmentService,
+		avatarService $avatarService,
+		GuestManager $guestManager,
+		MessageParser $messageParser,
+		RoomShareProvider $shareProvider,
+		IManager $autoCompleteManager,
+		IUserStatusManager $statusManager,
+		MatterbridgeManager $matterbridgeManager,
+		SearchPlugin $searchPlugin,
+		ISearchResult $searchResult,
+		ITimeFactory $timeFactory,
+		IEventDispatcher $eventDispatcher,
+		IValidator $richObjectValidator,
+		ITrustedDomainHelper $trustedDomainHelper,
+		IL10N $l,
+	) {
 		parent::__construct($appName, $request);
 
 		$this->userId = $UserId;
@@ -120,6 +132,7 @@ class ChatController extends AEnvironmentAwareController {
 		$this->participantService = $participantService;
 		$this->sessionService = $sessionService;
 		$this->attachmentService = $attachmentService;
+		$this->avatarService = $avatarService;
 		$this->guestManager = $guestManager;
 		$this->messageParser = $messageParser;
 		$this->shareProvider = $shareProvider;
@@ -161,13 +174,11 @@ class ChatController extends AEnvironmentAwareController {
 		if (!$chatMessage->getVisibility()) {
 			$response = new DataResponse([], Http::STATUS_CREATED);
 			if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
-				$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+				$response->addHeader('X-Chat-Last-Common-Read', (string) $this->chatManager->getLastCommonReadMessage($this->room));
 			}
 			return $response;
 		}
 
-		$this->participantService->updateLastReadMessage($this->participant, (int) $comment->getId());
-
 		$data = $chatMessage->toArray($this->getResponseFormat());
 		if ($parentMessage instanceof Message) {
 			$data['parent'] = $parentMessage->toArray($this->getResponseFormat());
@@ -175,18 +186,12 @@ class ChatController extends AEnvironmentAwareController {
 
 		$response = new DataResponse($data, Http::STATUS_CREATED);
 		if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
-			$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+			$response->addHeader('X-Chat-Last-Common-Read', (string) $this->chatManager->getLastCommonReadMessage($this->room));
 		}
 		return $response;
 	}
 
 	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireReadWriteConversation
-	 * @RequirePermissions(permissions=chat)
-	 * @RequireModeratorOrNoLobby
-	 *
 	 * Sends a new chat message to the given room.
 	 *
 	 * The author and timestamp are automatically set to the current user/guest
@@ -201,7 +206,16 @@ class ChatController extends AEnvironmentAwareController {
 	 *         "404 Not found" if the room or session for a guest user was not
 	 *         found".
 	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequirePermission(permission: RequirePermission::CHAT)]
+	#[RequireReadWriteConversation]
 	public function sendMessage(string $message, string $actorDisplayName = '', string $referenceId = '', int $replyTo = 0, bool $silent = false): DataResponse {
+		if (trim($message) === '') {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+		}
+
 		[$actorType, $actorId] = $this->getActorInfo($actorDisplayName);
 		if (!$actorId) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
@@ -238,12 +252,6 @@ class ChatController extends AEnvironmentAwareController {
 	}
 
 	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireReadWriteConversation
-	 * @RequirePermissions(permissions=chat)
-	 * @RequireModeratorOrNoLobby
-	 *
 	 * Sends a rich-object to the given room.
 	 *
 	 * The author and timestamp are automatically set to the current user/guest
@@ -258,6 +266,11 @@ class ChatController extends AEnvironmentAwareController {
 	 *         "404 Not found" if the room or session for a guest user was not
 	 *         found".
 	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequirePermission(permission: RequirePermission::CHAT)]
+	#[RequireReadWriteConversation]
 	public function shareObjectToChat(string $objectType, string $objectId, string $metaData = '', string $actorDisplayName = '', string $referenceId = ''): DataResponse {
 		[$actorType, $actorId] = $this->getActorInfo($actorDisplayName);
 		if (!$actorId) {
@@ -270,6 +283,7 @@ class ChatController extends AEnvironmentAwareController {
 		}
 		$data['type'] = $objectType;
 		$data['id'] = $objectId;
+		$data['icon-url'] = $this->avatarService->getAvatarUrl($this->room);
 
 		if (isset($data['link']) && !$this->trustedDomainHelper->isTrustedUrl($data['link'])) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
@@ -337,10 +351,6 @@ class ChatController extends AEnvironmentAwareController {
 	}
 
 	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireModeratorOrNoLobby
-	 *
 	 * Receives chat messages from the given room.
 	 *
 	 * - Receiving the history ($lookIntoFuture=0):
@@ -367,7 +377,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * will be 0, yet the status will still be 200. Also note that
 	 * `X-Chat-Last-Given` may reference a message not visible and thus not
 	 * returned, but it should be used nevertheless as the $lastKnownMessageId
-	 * for the follow up query.
+	 * for the follow-up query.
 	 *
 	 * @param int $lookIntoFuture Polling for new messages (1) or getting the history of the chat (0)
 	 * @param int $limit Number of chat messages to receive (100 by default, 200 at most)
@@ -380,6 +390,7 @@ class ChatController extends AEnvironmentAwareController {
 	 *                           if your client does this itself via chat/{token}/read set to 0
 	 * @param int $includeLastKnown Include the $lastKnownMessageId in the messages when 1 (default 0)
 	 * @param int $noStatusUpdate When the user status should not be automatically set to online set to 1 (default 0)
+	 * @param int $markNotificationsAsRead Set to 0 when notifications should not be marked as read (default 1)
 	 * @return DataResponse an array of chat messages, "404 Not found" if the
 	 *         room token was not valid or "304 Not modified" if there were no messages;
 	 *         each chat message is an array with
@@ -387,14 +398,18 @@ class ChatController extends AEnvironmentAwareController {
 	 *         'actorDisplayName', 'timestamp' (in seconds and UTC timezone) and
 	 *         'message'.
 	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
 	public function receiveMessages(int $lookIntoFuture,
-									int $limit = 100,
-									int $lastKnownMessageId = 0,
-									int $lastCommonReadId = 0,
-									int $timeout = 30,
-									int $setReadMarker = 1,
-									int $includeLastKnown = 0,
-									int $noStatusUpdate = 0): DataResponse {
+		int $limit = 100,
+		int $lastKnownMessageId = 0,
+		int $lastCommonReadId = 0,
+		int $timeout = 30,
+		int $setReadMarker = 1,
+		int $includeLastKnown = 0,
+		int $noStatusUpdate = 0,
+		int $markNotificationsAsRead = 1): DataResponse {
 		$limit = min(200, $limit);
 		$timeout = min(30, $timeout);
 
@@ -443,11 +458,15 @@ class ChatController extends AEnvironmentAwareController {
 
 		$currentUser = $this->userManager->get($this->userId);
 		if ($lookIntoFuture) {
-			$comments = $this->chatManager->waitForNewMessages($this->room, $lastKnownMessageId, $limit, $timeout, $currentUser, (bool) $includeLastKnown);
+			$comments = $this->chatManager->waitForNewMessages($this->room, $lastKnownMessageId, $limit, $timeout, $currentUser, (bool)$includeLastKnown, (bool)$markNotificationsAsRead);
 		} else {
-			$comments = $this->chatManager->getHistory($this->room, $lastKnownMessageId, $limit, (bool) $includeLastKnown);
+			$comments = $this->chatManager->getHistory($this->room, $lastKnownMessageId, $limit, (bool)$includeLastKnown);
 		}
 
+		return $this->prepareCommentsAsDataResponse($comments);
+	}
+
+	protected function prepareCommentsAsDataResponse(array $comments, int $lastCommonReadId = 0): DataResponse {
 		if (empty($comments)) {
 			$response = new DataResponse([], Http::STATUS_NOT_MODIFIED);
 			if ($lastCommonReadId && $this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
@@ -457,7 +476,7 @@ class ChatController extends AEnvironmentAwareController {
 					// As per "section 10.3.5 of RFC 2616" entity headers shall be
 					// stripped out on 304: https://stackoverflow.com/a/17822709
 					$response->setStatus(Http::STATUS_OK);
-					$response->addHeader('X-Chat-Last-Common-Read', $newLastCommonRead);
+					$response->addHeader('X-Chat-Last-Common-Read', (string) $newLastCommonRead);
 				}
 			}
 			return $response;
@@ -466,12 +485,19 @@ class ChatController extends AEnvironmentAwareController {
 		$this->preloadShares($comments);
 
 		$i = 0;
+		$now = $this->timeFactory->getDateTime();
 		$messages = $commentIdToIndex = $parentIds = [];
 		foreach ($comments as $comment) {
 			$id = (int) $comment->getId();
 			$message = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
 			$this->messageParser->parseMessage($message);
 
+			$expireDate = $message->getComment()->getExpireDate();
+			if ($expireDate instanceof \DateTime && $expireDate < $now) {
+				$commentIdToIndex[$id] = null;
+				continue;
+			}
+
 			if (!$message->getVisibility()) {
 				$commentIdToIndex[$id] = null;
 				continue;
@@ -522,6 +548,12 @@ class ChatController extends AEnvironmentAwareController {
 						continue;
 					}
 
+					$expireDate = $message->getComment()->getExpireDate();
+					if ($expireDate instanceof \DateTime && $expireDate < $now) {
+						$commentIdToIndex[$id] = null;
+						continue;
+					}
+
 					$loadedParents[$parentId] = [
 						'id' => (int) $parentId,
 						'deleted' => true,
@@ -543,9 +575,9 @@ class ChatController extends AEnvironmentAwareController {
 
 		$newLastKnown = end($comments);
 		if ($newLastKnown instanceof IComment) {
-			$response->addHeader('X-Chat-Last-Given', $newLastKnown->getId());
+			$response->addHeader('X-Chat-Last-Given', (string) $newLastKnown->getId());
 			/**
-			 * This falsely set the read marker on new messages although you
+			 * This falsely set the read marker on new messages, although you
 			 * navigated away to a different chat already. So we removed this
 			 * and instead update the read marker before your next waiting.
 			 * So when you are still there, it will just have a wrong read
@@ -556,13 +588,34 @@ class ChatController extends AEnvironmentAwareController {
 			 * }
 			 */
 			if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
-				$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+				$response->addHeader('X-Chat-Last-Common-Read', (string) $this->chatManager->getLastCommonReadMessage($this->room));
 			}
 		}
 
 		return $response;
 	}
 
+	/**
+	 * @param int $messageId The focused message which should be in the "middle" of the returned context
+	 * @param int $limit Number of chat messages to receive in both directions (50 by default, 100 at most, might return 201 messages)
+	 * @return DataResponse
+	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	public function getMessageContext(
+		int $messageId,
+		int $limit = 50): DataResponse {
+		$limit = min(100, $limit);
+
+		$currentUser = $this->userManager->get($this->userId);
+		$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $limit, true);
+		$commentsHistory = array_reverse($commentsHistory);
+		$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false);
+
+		return $this->prepareCommentsAsDataResponse(array_merge($commentsHistory, $commentsFuture));
+	}
+
 	protected function loadSelfReactions(array $messages, array $commentIdToIndex): array {
 		// Get message ids with reactions
 		$messageIdsWithReactions = array_map(
@@ -607,16 +660,11 @@ class ChatController extends AEnvironmentAwareController {
 		return $messages;
 	}
 
-	/**
-	 * @NoAdminRequired
-	 * @RequireParticipant
-	 * @RequireReadWriteConversation
-	 * @RequirePermissions(permissions=chat)
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @param int $messageId
-	 * @return DataResponse
-	 */
+	#[NoAdminRequired]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequirePermission(permission: RequirePermission::CHAT)]
+	#[RequireReadWriteConversation]
 	public function deleteMessage(int $messageId): DataResponse {
 		try {
 			$message = $this->chatManager->getComment($this->room, (string) $messageId);
@@ -632,7 +680,8 @@ class ChatController extends AEnvironmentAwareController {
 		$isOwnMessage = $isOwnMessage || ($message->getActorType() === Attendee::ACTOR_BRIDGED && $attendee->getActorId() === MatterbridgeManager::BRIDGE_BOT_USERID);
 		if (!$isOwnMessage
 			&& (!$this->participant->hasModeratorPermissions(false)
-				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE)) {
+				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE
+				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE_FORMER)) {
 			// Actor is not a moderator or not the owner of the message
 			return new DataResponse([], Http::STATUS_FORBIDDEN);
 		}
@@ -674,22 +723,19 @@ class ChatController extends AEnvironmentAwareController {
 
 		$response = new DataResponse($data, $bridge['enabled'] ? Http::STATUS_ACCEPTED : Http::STATUS_OK);
 		if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
-			$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+			$response->addHeader('X-Chat-Last-Common-Read', (string) $this->chatManager->getLastCommonReadMessage($this->room));
 		}
 		return $response;
 	}
 
-	/**
-	 * @NoAdminRequired
-	 * @RequireModeratorParticipant
-	 * @RequireReadWriteConversation
-	 *
-	 * @return DataResponse
-	 */
+	#[NoAdminRequired]
+	#[RequireModeratorParticipant]
+	#[RequireReadWriteConversation]
 	public function clearHistory(): DataResponse {
 		$attendee = $this->participant->getAttendee();
 		if (!$this->participant->hasModeratorPermissions(false)
-				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE) {
+				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE
+				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 			// Actor is not a moderator or not the owner of the message
 			return new DataResponse([], Http::STATUS_FORBIDDEN);
 		}
@@ -710,33 +756,24 @@ class ChatController extends AEnvironmentAwareController {
 
 		$response = new DataResponse($data, $bridge['enabled'] ? Http::STATUS_ACCEPTED : Http::STATUS_OK);
 		if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
-			$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+			$response->addHeader('X-Chat-Last-Common-Read', (string) $this->chatManager->getLastCommonReadMessage($this->room));
 		}
 		return $response;
 	}
 
-	/**
-	 * @NoAdminRequired
-	 * @RequireParticipant
-	 *
-	 * @param int $lastReadMessage
-	 * @return DataResponse
-	 */
+	#[NoAdminRequired]
+	#[RequireParticipant]
 	public function setReadMarker(int $lastReadMessage): DataResponse {
 		$this->participantService->updateLastReadMessage($this->participant, $lastReadMessage);
 		$response = new DataResponse();
 		if ($this->participant->getAttendee()->getReadPrivacy() === Participant::PRIVACY_PUBLIC) {
-			$response->addHeader('X-Chat-Last-Common-Read', $this->chatManager->getLastCommonReadMessage($this->room));
+			$response->addHeader('X-Chat-Last-Common-Read', (string) $this->chatManager->getLastCommonReadMessage($this->room));
 		}
 		return $response;
 	}
 
-	/**
-	 * @NoAdminRequired
-	 * @RequireParticipant
-	 *
-	 * @return DataResponse
-	 */
+	#[NoAdminRequired]
+	#[RequireParticipant]
 	public function markUnread(): DataResponse {
 		$message = $this->room->getLastMessage();
 		$unreadId = 0;
@@ -759,14 +796,9 @@ class ChatController extends AEnvironmentAwareController {
 		return $this->setReadMarker($unreadId);
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @param int $limit
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
 	public function getObjectsSharedInRoomOverview(int $limit = 7): DataResponse {
 		$limit = min(20, $limit);
 
@@ -778,50 +810,38 @@ class ChatController extends AEnvironmentAwareController {
 			Attachment::TYPE_MEDIA,
 			Attachment::TYPE_OTHER,
 			Attachment::TYPE_POLL,
+			Attachment::TYPE_RECORDING,
 			Attachment::TYPE_VOICE,
 		];
 
 		$messages = [];
 		$messageIdsByType = [];
+		// Get all attachments
 		foreach ($objectTypes as $objectType) {
 			$attachments = $this->attachmentService->getAttachmentsByType($this->room, $objectType, 0, $limit);
 			$messageIdsByType[$objectType] = array_map(static fn (Attachment $attachment): int => $attachment->getMessageId(), $attachments);
 		}
-		$comments = $this->chatManager->getMessagesById($this->room, array_merge(...array_values($messageIdsByType)));
 
-		foreach ($comments as $comment) {
-			$message = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
-			$this->messageParser->parseMessage($message);
-
-			if (!$message->getVisibility()) {
-				continue;
-			}
-
-			$messages[(int) $comment->getId()] = $message->toArray($this->getResponseFormat());
-		}
+		$messages = $this->getMessagesForRoom(array_merge(...array_values($messageIdsByType)));
 
 		$messagesByType = [];
+		// Convert list of $messages to array grouped by type
 		foreach ($objectTypes as $objectType) {
 			$messagesByType[$objectType] = [];
 
 			foreach ($messageIdsByType[$objectType] as $messageId) {
-				$messagesByType[$objectType][] = $messages[$messageId];
+				if (isset($messages[$messageId])) {
+					$messagesByType[$objectType][] = $messages[$messageId];
+				}
 			}
 		}
 
 		return new DataResponse($messagesByType, Http::STATUS_OK);
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @param string $objectType
-	 * @param int $lastKnownMessageId
-	 * @param int $limit
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
 	public function getObjectsSharedInRoom(string $objectType, int $lastKnownMessageId = 0, int $limit = 100): DataResponse {
 		$offset = max(0, $lastKnownMessageId);
 		$limit = min(200, $limit);
@@ -829,7 +849,7 @@ class ChatController extends AEnvironmentAwareController {
 		$attachments = $this->attachmentService->getAttachmentsByType($this->room, $objectType, $offset, $limit);
 		$messageIds = array_map(static fn (Attachment $attachment): int => $attachment->getMessageId(), $attachments);
 
-		$messages = $this->getMessagesForRoom($this->room, $messageIds);
+		$messages = $this->getMessagesForRoom($messageIds);
 
 		$response = new DataResponse($messages, Http::STATUS_OK);
 
@@ -841,14 +861,23 @@ class ChatController extends AEnvironmentAwareController {
 		return $response;
 	}
 
-	protected function getMessagesForRoom(Room $room, array $messageIds): array {
-		$comments = $this->chatManager->getMessagesById($room, $messageIds);
+	protected function getMessagesForRoom(array $messageIds): array {
+		$comments = $this->chatManager->getMessagesById($this->room, $messageIds);
+		$this->preloadShares($comments);
 
 		$messages = [];
+		$comments = $this->chatManager->filterCommentsWithNonExistingFiles($comments);
 		foreach ($comments as $comment) {
-			$message = $this->messageParser->createMessage($room, $this->participant, $comment, $this->l);
+			$message = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
+
 			$this->messageParser->parseMessage($message);
 
+			$now = $this->timeFactory->getDateTime();
+			$expireDate = $message->getComment()->getExpireDate();
+			if ($expireDate instanceof \DateTime && $expireDate < $now) {
+				continue;
+			}
+
 			if (!$message->getVisibility()) {
 				continue;
 			}
@@ -859,18 +888,11 @@ class ChatController extends AEnvironmentAwareController {
 		return $messages;
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireReadWriteConversation
-	 * @RequirePermissions(permissions=chat)
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @param string $search
-	 * @param int $limit
-	 * @param bool $includeStatus
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequirePermission(permission: RequirePermission::CHAT)]
+	#[RequireReadWriteConversation]
 	public function mentions(string $search, int $limit = 20, bool $includeStatus = false): DataResponse {
 		$this->searchPlugin->setContext([
 			'itemType' => 'chat',
