@@ -28,6 +28,10 @@ namespace OCA\Talk\Controller;
 
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Exceptions\WrongPermissionsException;
+use OCA\Talk\Middleware\Attribute\RequireModeratorOrNoLobby;
+use OCA\Talk\Middleware\Attribute\RequireParticipant;
+use OCA\Talk\Middleware\Attribute\RequirePermission;
+use OCA\Talk\Middleware\Attribute\RequireReadWriteConversation;
 use OCA\Talk\Model\Poll;
 use OCA\Talk\Model\Vote;
 use OCA\Talk\Room;
@@ -35,6 +39,7 @@ use OCA\Talk\Service\AttachmentService;
 use OCA\Talk\Service\PollService;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\DB\Exception;
@@ -48,13 +53,15 @@ class PollController extends AEnvironmentAwareController {
 	protected ITimeFactory $timeFactory;
 	protected LoggerInterface $logger;
 
-	public function __construct(string $appName,
-								IRequest $request,
-								ChatManager $chatManager,
-								PollService $pollService,
-								AttachmentService $attachmentService,
-								ITimeFactory $timeFactory,
-								LoggerInterface $logger) {
+	public function __construct(
+		string $appName,
+		IRequest $request,
+		ChatManager $chatManager,
+		PollService $pollService,
+		AttachmentService $attachmentService,
+		ITimeFactory $timeFactory,
+		LoggerInterface $logger,
+	) {
 		parent::__construct($appName, $request);
 		$this->pollService = $pollService;
 		$this->attachmentService = $attachmentService;
@@ -63,21 +70,14 @@ class PollController extends AEnvironmentAwareController {
 		$this->logger = $logger;
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireReadWriteConversation
-	 * @RequirePermissions(permissions=chat)
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @param string $question
-	 * @param array $options
-	 * @param int $resultMode
-	 * @param int $maxVotes
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
+	#[RequirePermission(permission: RequirePermission::CHAT)]
+	#[RequireReadWriteConversation]
 	public function createPoll(string $question, array $options, int $resultMode, int $maxVotes): DataResponse {
-		if ($this->room->getType() === Room::TYPE_ONE_TO_ONE) {
+		if ($this->room->getType() !== Room::TYPE_GROUP
+			&& $this->room->getType() !== Room::TYPE_PUBLIC) {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
@@ -120,14 +120,9 @@ class PollController extends AEnvironmentAwareController {
 		return new DataResponse($this->renderPoll($poll, []), Http::STATUS_CREATED);
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @param int $pollId
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
 	public function showPoll(int $pollId): DataResponse {
 		try {
 			$poll = $this->pollService->getPoll($this->room->getId(), $pollId);
@@ -145,14 +140,13 @@ class PollController extends AEnvironmentAwareController {
 	}
 
 	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireModeratorOrNoLobby
-	 *
 	 * @param int $pollId
 	 * @param int[] $optionIds
 	 * @return DataResponse
 	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
 	public function votePoll(int $pollId, array $optionIds = []): DataResponse {
 		try {
 			$poll = $this->pollService->getPoll($this->room->getId(), $pollId);
@@ -192,14 +186,9 @@ class PollController extends AEnvironmentAwareController {
 		return new DataResponse($this->renderPoll($poll, $votedSelf));
 	}
 
-	/**
-	 * @PublicPage
-	 * @RequireParticipant
-	 * @RequireModeratorOrNoLobby
-	 *
-	 * @param int $pollId
-	 * @return DataResponse
-	 */
+	#[PublicPage]
+	#[RequireModeratorOrNoLobby]
+	#[RequireParticipant]
 	public function closePoll(int $pollId): DataResponse {
 		try {
 			$poll = $this->pollService->getPoll($this->room->getId(), $pollId);
