@@ -28,8 +28,8 @@ namespace OCA\Talk\Controller;
 use GuzzleHttp\Exception\ConnectException;
 use OCA\Talk\Config;
 use OCA\Talk\Events\SignalingEvent;
-use OCA\Talk\Exceptions\RoomNotFoundException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
+use OCA\Talk\Exceptions\RoomNotFoundException;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Session;
@@ -40,6 +40,8 @@ use OCA\Talk\Service\SessionService;
 use OCA\Talk\Signaling\Messages;
 use OCA\Talk\TalkSession;
 use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\Attribute\BruteForceProtection;
+use OCP\AppFramework\Http\Attribute\PublicPage;
 use OCP\AppFramework\Http\DataResponse;
 use OCP\AppFramework\OCSController;
 use OCP\AppFramework\Utility\ITimeFactory;
@@ -51,6 +53,7 @@ use OCP\IDBConnection;
 use OCP\IRequest;
 use OCP\IUser;
 use OCP\IUserManager;
+use OCP\Security\Bruteforce\IThrottler;
 use Psr\Log\LoggerInterface;
 
 class SignalingController extends OCSController {
@@ -59,7 +62,6 @@ class SignalingController extends OCSController {
 
 	public const EVENT_BACKEND_SIGNALING_ROOMS = self::class . '::signalingBackendRoom';
 
-	private IConfig $serverConfig;
 	private Config $talkConfig;
 	private \OCA\Talk\Signaling\Manager $signalingManager;
 	private TalkSession $session;
@@ -75,25 +77,27 @@ class SignalingController extends OCSController {
 	private LoggerInterface $logger;
 	private ?string $userId;
 
-	public function __construct(string $appName,
-								IRequest $request,
-								IConfig $serverConfig,
-								Config $talkConfig,
-								\OCA\Talk\Signaling\Manager $signalingManager,
-								TalkSession $session,
-								Manager $manager,
-								ParticipantService $participantService,
-								SessionService $sessionService,
-								IDBConnection $connection,
-								Messages $messages,
-								IUserManager $userManager,
-								IEventDispatcher $dispatcher,
-								ITimeFactory $timeFactory,
-								IClientService $clientService,
-								LoggerInterface $logger,
-								?string $UserId) {
+	public function __construct(
+		string $appName,
+		IRequest $request,
+		IConfig $serverConfig,
+		Config $talkConfig,
+		\OCA\Talk\Signaling\Manager $signalingManager,
+		TalkSession $session,
+		Manager $manager,
+		ParticipantService $participantService,
+		SessionService $sessionService,
+		IDBConnection $connection,
+		Messages $messages,
+		IUserManager $userManager,
+		IEventDispatcher $dispatcher,
+		ITimeFactory $timeFactory,
+		IClientService $clientService,
+		IThrottler $throttler,
+		LoggerInterface $logger,
+		?string $UserId,
+	) {
 		parent::__construct($appName, $request);
-		$this->serverConfig = $serverConfig;
 		$this->talkConfig = $talkConfig;
 		$this->signalingManager = $signalingManager;
 		$this->session = $session;
@@ -111,15 +115,52 @@ class SignalingController extends OCSController {
 	}
 
 	/**
-	 * @PublicPage
-	 * @BruteForceProtection(action=talkRoomToken)
+	 * Check if the current request is coming from an allowed recording backend.
 	 *
-	 * @param string $token
-	 * @return DataResponse
+	 * The backends are sending the custom header "Talk-Recording-Random"
+	 * containing at least 32 bytes random data, and the header
+	 * "Talk-Recording-Checksum", which is the SHA256-HMAC of the random data
+	 * and the body of the request, calculated with the shared secret from the
+	 * configuration.
+	 *
+	 * @param string $data
+	 * @return bool
 	 */
+	private function validateRecordingBackendRequest(string $data): bool {
+		$random = $this->request->getHeader('Talk-Recording-Random');
+		if (empty($random) || strlen($random) < 32) {
+			$this->logger->debug("Missing random");
+			return false;
+		}
+		$checksum = $this->request->getHeader('Talk-Recording-Checksum');
+		if (empty($checksum)) {
+			$this->logger->debug("Missing checksum");
+			return false;
+		}
+		$hash = hash_hmac('sha256', $random . $data, $this->talkConfig->getRecordingSecret());
+		return hash_equals($hash, strtolower($checksum));
+	}
+
+	#[PublicPage]
+	#[BruteForceProtection(action: 'talkRoomToken')]
+	#[BruteForceProtection(action: 'talkRecordingSecret')]
 	public function getSettings(string $token = ''): DataResponse {
+		$isRecordingRequest = false;
+
+		if (!empty($this->request->getHeader('Talk-Recording-Random')) || !empty($this->request->getHeader('Talk-Recording-Checksum'))) {
+			if (!$this->validateRecordingBackendRequest('')) {
+				$response = new DataResponse([], Http::STATUS_UNAUTHORIZED);
+				$response->throttle(['action' => 'talkRecordingSecret']);
+				return $response;
+			}
+
+			$isRecordingRequest = true;
+		}
+
 		try {
-			if ($token !== '') {
+			if ($token !== '' && $isRecordingRequest) {
+				$room = $this->manager->getRoomByToken($token);
+			} elseif ($token !== '') {
 				$room = $this->manager->getRoomForUserByToken($token, $this->userId);
 			} else {
 				// FIXME Soft-fail for legacy support in mobile apps
@@ -127,7 +168,7 @@ class SignalingController extends OCSController {
 			}
 		} catch (RoomNotFoundException $e) {
 			$response = new DataResponse([], Http::STATUS_NOT_FOUND);
-			$response->throttle(['token' => $token]);
+			$response->throttle(['token' => $token, 'action' => 'talkRoomToken']);
 			return $response;
 		}
 
@@ -188,7 +229,7 @@ class SignalingController extends OCSController {
 	}
 
 	/**
-	 * Only available for logged in users because guests can not use the apps
+	 * Only available for logged-in users because guests can not use the apps
 	 * right now.
 	 *
 	 * @param int $serverId
@@ -250,13 +291,7 @@ class SignalingController extends OCSController {
 		}
 	}
 
-	/**
-	 * @PublicPage
-	 *
-	 * @param string $token
-	 * @param string $messages
-	 * @return DataResponse
-	 */
+	#[PublicPage]
 	public function signaling(string $token, string $messages): DataResponse {
 		if ($this->talkConfig->getSignalingMode() !== Config::SIGNALING_INTERNAL) {
 			return new DataResponse('Internal signaling disabled.', Http::STATUS_BAD_REQUEST);
@@ -280,7 +315,7 @@ class SignalingController extends OCSController {
 
 					if ($decodedMessage['type'] === 'control') {
 						$room = $this->manager->getRoomForSession($this->userId, $message['sessionId']);
-						$participant = $room->getParticipantBySession($message['sessionId']);
+						$participant = $this->participantService->getParticipantBySession($room, $message['sessionId']);
 
 						if (!$participant->hasModeratorPermissions(false)) {
 							break;
@@ -296,12 +331,7 @@ class SignalingController extends OCSController {
 		return new DataResponse($response);
 	}
 
-	/**
-	 * @PublicPage
-	 *
-	 * @param string $token
-	 * @return DataResponse
-	 */
+	#[PublicPage]
 	public function pullMessages(string $token): DataResponse {
 		if ($this->talkConfig->getSignalingMode() !== Config::SIGNALING_INTERNAL) {
 			return new DataResponse('Internal signaling disabled.', Http::STATUS_BAD_REQUEST);
@@ -318,7 +348,7 @@ class SignalingController extends OCSController {
 			}
 
 			$room = $this->manager->getRoomForSession($this->userId, $sessionId);
-			$participant = $room->getParticipantBySession($sessionId); // FIXME this causes another query
+			$participant = $this->participantService->getParticipantBySession($room, $sessionId); // FIXME this causes another query
 
 			$pingTimestamp = $this->timeFactory->getTime();
 			if ($participant->getSession() instanceof Session) {
@@ -373,7 +403,7 @@ class SignalingController extends OCSController {
 				if ($this->userId) {
 					// For logged in users we check if they are still part of the public conversation,
 					// if not they were removed instead of having a conflict.
-					$room->getParticipant($this->userId, false);
+					$this->participantService->getParticipant($room, $this->userId, false);
 				}
 
 				// Session was killed, make the UI redirect to an error
@@ -392,7 +422,7 @@ class SignalingController extends OCSController {
 
 	/**
 	 * @param Room $room
-	 * @param int pingTimestamp
+	 * @param int $pingTimestamp
 	 * @return array[]
 	 */
 	protected function getUsersInRoom(Room $room, int $pingTimestamp): array {
@@ -476,11 +506,10 @@ class SignalingController extends OCSController {
 	 * See sections "Backend validation" in
 	 * https://nextcloud-spreed-signaling.readthedocs.io/en/latest/standalone-signaling-api-v1/#backend-requests
 	 *
-	 * @PublicPage
-	 * @BruteForceProtection(action=talkSignalingSecret)
-	 *
 	 * @return DataResponse
 	 */
+	#[PublicPage]
+	#[BruteForceProtection(action: 'talkSignalingSecret')]
 	public function backend(): DataResponse {
 		$json = $this->getInputStream();
 		if (!$this->validateBackendRequest($json)) {
@@ -491,7 +520,7 @@ class SignalingController extends OCSController {
 					'message' => 'The request could not be authenticated.',
 				],
 			]);
-			$response->throttle();
+			$response->throttle(['action' => 'talkSignalingSecret']);
 			return $response;
 		}
 
@@ -599,20 +628,20 @@ class SignalingController extends OCSController {
 
 			if ($sessionId) {
 				try {
-					$participant = $room->getParticipantBySession($sessionId);
+					$participant = $this->participantService->getParticipantBySession($room, $sessionId);
 				} catch (ParticipantNotFoundException $e) {
 					if ($action === 'join') {
 						// If the user joins the session might not be known to the server yet.
 						// In this case we load by actor information and use the session id as new session.
 						try {
-							$participant = $room->getParticipantByActor($actorType, $actorId);
+							$participant = $this->participantService->getParticipantByActor($room, $actorType, $actorId);
 						} catch (ParticipantNotFoundException $e) {
 						}
 					}
 				}
 			} else {
 				try {
-					$participant = $room->getParticipantByActor($actorType, $actorId);
+					$participant = $this->participantService->getParticipantByActor($room, $actorType, $actorId);
 				} catch (ParticipantNotFoundException $e) {
 				}
 			}
@@ -636,13 +665,13 @@ class SignalingController extends OCSController {
 
 			if ($sessionId) {
 				try {
-					$participant = $room->getParticipantBySession($sessionId);
+					$participant = $this->participantService->getParticipantBySession($room, $sessionId);
 				} catch (ParticipantNotFoundException $e) {
 				}
 			} elseif (!empty($userId)) {
 				// User trying to join room.
 				try {
-					$participant = $room->getParticipant($userId, false);
+					$participant = $this->participantService->getParticipant($room, $userId, false);
 				} catch (ParticipantNotFoundException $e) {
 				}
 			}
