@@ -27,13 +27,17 @@ namespace OCA\Talk\Dashboard;
 
 use OCA\Talk\Chat\MessageParser;
 use OCA\Talk\Config;
-use OCA\Talk\Exceptions\NotAllowedToUseTalkException;
 use OCA\Talk\Manager;
+use OCA\Talk\Model\BreakoutRoom;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
+use OCA\Talk\Service\AvatarService;
+use OCA\Talk\Service\ParticipantService;
+use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\Dashboard\IAPIWidget;
 use OCP\Dashboard\IButtonWidget;
+use OCP\Dashboard\IConditionalWidget;
 use OCP\Dashboard\IIconWidget;
 use OCP\Dashboard\IOptionWidget;
 use OCP\Dashboard\Model\WidgetButton;
@@ -45,11 +49,16 @@ use OCP\IUser;
 use OCP\IUserSession;
 use OCP\Util;
 
-class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidget {
-	private IURLGenerator $url;
-	private IL10N $l10n;
-	private Manager $manager;
-	private MessageParser $messageParser;
+class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidget, IConditionalWidget {
+	protected IUserSession $userSession;
+	protected Config $talkConfig;
+	protected IURLGenerator $url;
+	protected IL10N $l10n;
+	protected Manager $manager;
+	protected AvatarService $avatarService;
+	protected ParticipantService $participantService;
+	protected MessageParser $messageParser;
+	protected ITimeFactory $timeFactory;
 
 	public function __construct(
 		IUserSession $userSession,
@@ -57,19 +66,20 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 		IURLGenerator $url,
 		IL10N $l10n,
 		Manager $manager,
-		MessageParser $messageParser
+		AvatarService $avatarService,
+		ParticipantService $participantService,
+		MessageParser $messageParser,
+		ITimeFactory $timeFactory,
 	) {
-		$user = $userSession->getUser();
-		if ($user instanceof IUser && $talkConfig->isDisabledForUser($user)) {
-			// This is dirty and will log everytime a user opens the dashboard or requests the api,
-			// so we should look for a different solution in the server.
-			throw new NotAllowedToUseTalkException();
-		}
-
+		$this->userSession = $userSession;
+		$this->talkConfig = $talkConfig;
 		$this->url = $url;
 		$this->l10n = $l10n;
 		$this->manager = $manager;
+		$this->avatarService = $avatarService;
+		$this->participantService = $participantService;
 		$this->messageParser = $messageParser;
+		$this->timeFactory = $timeFactory;
 	}
 
 	/**
@@ -100,6 +110,14 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 		return 'dashboard-talk-icon';
 	}
 
+	/**
+	 * @inheritDoc
+	 */
+	public function isEnabled(): bool {
+		$user = $this->userSession->getUser();
+		return !($user instanceof IUser && $this->talkConfig->isDisabledForUser($user));
+	}
+
 	public function getWidgetOptions(): WidgetOptions {
 		return new WidgetOptions(true);
 	}
@@ -142,12 +160,20 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 	public function getItems(string $userId, ?string $since = null, int $limit = 7): array {
 		$rooms = $this->manager->getRoomsForUser($userId, [], true);
 
-		$rooms = array_filter($rooms, static function (Room $room) use ($userId) {
-			$participant = $room->getParticipant($userId);
+		$rooms = array_filter($rooms, function (Room $room) use ($userId) {
+			if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
+				return false;
+			}
+
+			$participant = $this->participantService->getParticipant($room, $userId);
 			$attendee = $participant->getAttendee();
 			return $room->getCallFlag() !== Participant::FLAG_DISCONNECTED
 				|| $attendee->getLastMentionMessage() > $attendee->getLastReadMessage()
-				|| ($room->getType() === Room::TYPE_ONE_TO_ONE && $room->getLastMessage() && $room->getLastMessage()->getId() > $attendee->getLastReadMessage());
+				|| (
+					($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER)
+					&& $room->getLastMessage()
+					&& $room->getLastMessage()->getId() > $attendee->getLastReadMessage()
+				);
 		});
 
 		uasort($rooms, [$this, 'sortRooms']);
@@ -163,14 +189,18 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 	}
 
 	protected function prepareRoom(Room $room, string $userId): WidgetItem {
-		$participant = $room->getParticipant($userId);
+		$participant = $this->participantService->getParticipant($room, $userId);
 		$subtitle = '';
 
 		$lastMessage = $room->getLastMessage();
 		if ($lastMessage instanceof IComment) {
 			$message = $this->messageParser->createMessage($room, $participant, $room->getLastMessage(), $this->l10n);
 			$this->messageParser->parseMessage($message);
-			if ($message->getVisibility()) {
+
+			$now = $this->timeFactory->getDateTime();
+			$expireDate = $message->getComment()->getExpireDate();
+			if ((!$expireDate instanceof \DateTime || $expireDate >= $now)
+				&& $message->getVisibility()) {
 				$placeholders = $replacements = [];
 
 				foreach ($message->getMessageParameters() as $placeholder => $parameter) {
@@ -196,38 +226,10 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 			$room->getDisplayName($userId),
 			$subtitle,
 			$this->url->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()]),
-			$this->getRoomIconUrl($room, $userId)
+			$this->avatarService->getAvatarUrl($room)
 		);
 	}
 
-	protected function getRoomIconUrl(Room $room, string $userId): string {
-		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
-			$participants = json_decode($room->getName(), true);
-
-			foreach ($participants as $p) {
-				if ($p !== $userId) {
-					return $this->url->linkToRouteAbsolute(
-						'core.avatar.getAvatar',
-						[
-							'userId' => $p,
-							'size' => 64,
-						]
-					);
-				}
-			}
-		} elseif ($room->getObjectType() === 'file') {
-			return $this->url->getAbsoluteURL($this->url->imagePath('core', 'filetypes/file.svg'));
-		} elseif ($room->getObjectType() === 'share:password') {
-			return $this->url->getAbsoluteURL($this->url->imagePath('core', 'actions/password.svg'));
-		} elseif ($room->getObjectType() === 'emails') {
-			return $this->url->getAbsoluteURL($this->url->imagePath('core', 'actions/mail.svg'));
-		} elseif ($room->getType() === Room::TYPE_PUBLIC) {
-			return $this->url->getAbsoluteURL($this->url->imagePath('core', 'actions/public.svg'));
-		}
-
-		return $this->url->getAbsoluteURL($this->url->imagePath('core', 'actions/group.svg'));
-	}
-
 	protected function sortRooms(Room $roomA, Room $roomB): int {
 		if ($roomA->getCallFlag() !== $roomB->getCallFlag()) {
 			return $roomA->getCallFlag() !== Participant::FLAG_DISCONNECTED ? -1 : 1;
