@@ -29,8 +29,10 @@ class AddEmailEvent extends RoomEvent {
 	protected string $email;
 
 
-	public function __construct(Room $room,
-								string $email) {
+	public function __construct(
+		Room $room,
+		string $email,
+	) {
 		parent::__construct($room);
 		$this->email = $email;
 	}
