@@ -36,12 +36,15 @@ use OCP\EventDispatcher\IEventListener;
 use OCP\Files\IRootFolder;
 use OCP\ICacheFactory;
 use OCP\IConfig;
+use OCP\IGroupManager;
 use OCP\IUser;
 use OCP\IUserSession;
 use OCP\Util;
 
 /**
  * Helper class to add the Talk UI to the sidebar of the Files app.
+ *
+ * @template-implements IEventListener<Event>
  */
 class TemplateLoader implements IEventListener {
 	use TInitialState;
@@ -50,13 +53,16 @@ class TemplateLoader implements IEventListener {
 	private IRootFolder $rootFolder;
 	private IUserSession $userSession;
 
-	public function __construct(IInitialState $initialState,
-								ICacheFactory $memcacheFactory,
-								Config $talkConfig,
-								IConfig $serverConfig,
-								IAppManager $appManager,
-								IRootFolder $rootFolder,
-								IUserSession $userSession) {
+	public function __construct(
+		IInitialState $initialState,
+		ICacheFactory $memcacheFactory,
+		Config $talkConfig,
+		IConfig $serverConfig,
+		IAppManager $appManager,
+		IRootFolder $rootFolder,
+		IUserSession $userSession,
+		IGroupManager $groupManager,
+	) {
 		$this->initialState = $initialState;
 		$this->memcacheFactory = $memcacheFactory;
 		$this->talkConfig = $talkConfig;
@@ -64,6 +70,7 @@ class TemplateLoader implements IEventListener {
 		$this->appManager = $appManager;
 		$this->rootFolder = $rootFolder;
 		$this->userSession = $userSession;
+		$this->groupManager = $groupManager;
 	}
 
 
@@ -93,9 +100,10 @@ class TemplateLoader implements IEventListener {
 			return;
 		}
 
-		Util::addStyle(Application::APP_ID, 'At');
 		Util::addStyle(Application::APP_ID, 'icons');
-		Util::addScript(Application::APP_ID, 'talk-files-sidebar');
+		if (strpos(\OC::$server->getRequest()->getPathInfo(), '/apps/maps') !== 0) {
+			Util::addScript(Application::APP_ID, 'talk-files-sidebar');
+		}
 
 		if ($user instanceof IUser) {
 			$this->publishInitialStateForUser($user, $this->rootFolder, $this->appManager);
