@@ -55,39 +55,41 @@ use OCP\Server;
 class Manager {
 	public const EVENT_TOKEN_GENERATE = self::class . '::generateNewToken';
 
-	private IDBConnection $db;
-	private IConfig $config;
-	private Config $talkConfig;
-	private IAppManager $appManager;
-	private AttendeeMapper $attendeeMapper;
-	private SessionMapper $sessionMapper;
-	private ParticipantService $participantService;
-	private ISecureRandom $secureRandom;
-	private IUserManager $userManager;
-	private IGroupManager $groupManager;
-	private ICommentsManager $commentsManager;
-	private TalkSession $talkSession;
-	private IEventDispatcher $dispatcher;
+	protected IDBConnection $db;
+	protected IConfig $config;
+	protected Config $talkConfig;
+	protected IAppManager $appManager;
+	protected AttendeeMapper $attendeeMapper;
+	protected SessionMapper $sessionMapper;
+	protected ParticipantService $participantService;
+	protected ISecureRandom $secureRandom;
+	protected IUserManager $userManager;
+	protected IGroupManager $groupManager;
+	protected ICommentsManager $commentsManager;
+	protected TalkSession $talkSession;
+	protected IEventDispatcher $dispatcher;
 	protected ITimeFactory $timeFactory;
-	private IHasher $hasher;
-	private IL10N $l;
+	protected IHasher $hasher;
+	protected IL10N $l;
 
-	public function __construct(IDBConnection $db,
-								IConfig $config,
-								Config $talkConfig,
-								IAppManager $appManager,
-								AttendeeMapper $attendeeMapper,
-								SessionMapper $sessionMapper,
-								ParticipantService $participantService,
-								ISecureRandom $secureRandom,
-								IUserManager $userManager,
-								IGroupManager $groupManager,
-								CommentsManager $commentsManager,
-								TalkSession $talkSession,
-								IEventDispatcher $dispatcher,
-								ITimeFactory $timeFactory,
-								IHasher $hasher,
-								IL10N $l) {
+	public function __construct(
+		IDBConnection $db,
+		IConfig $config,
+		Config $talkConfig,
+		IAppManager $appManager,
+		AttendeeMapper $attendeeMapper,
+		SessionMapper $sessionMapper,
+		ParticipantService $participantService,
+		ISecureRandom $secureRandom,
+		IUserManager $userManager,
+		IGroupManager $groupManager,
+		CommentsManager $commentsManager,
+		TalkSession $talkSession,
+		IEventDispatcher $dispatcher,
+		ITimeFactory $timeFactory,
+		IHasher $hasher,
+		IL10N $l,
+	) {
 		$this->db = $db;
 		$this->config = $config;
 		$this->talkConfig = $talkConfig;
@@ -125,6 +127,44 @@ class Manager {
 		$result->closeCursor();
 	}
 
+	/**
+	 * @param array $data
+	 * @return Room
+	 */
+	public function createRoomObjectFromData(array $data): Room {
+		return $this->createRoomObject(array_merge([
+			'r_id' => 0,
+			'type' => 0,
+			'read_only' => 0,
+			'listable' => 0,
+			'message_expiration' => 0,
+			'lobby_state' => 0,
+			'sip_enabled' => 0,
+			'assigned_hpb' => null,
+			'token' => '',
+			'name' => '',
+			'description' => '',
+			'password' => '',
+			'avatar' => '',
+			'remote_server' => '',
+			'remote_token' => '',
+			'active_guests' => 0,
+			'default_permissions' => 0,
+			'call_permissions' => 0,
+			'call_flag' => 0,
+			'active_since' => null,
+			'last_activity' => null,
+			'last_message' => 0,
+			'comment_id' => null,
+			'lobby_timer' => null,
+			'object_type' => '',
+			'object_id' => '',
+			'breakout_room_mode' => 0,
+			'breakout_room_status' => 0,
+			'call_recording' => 0,
+		], $data));
+	}
+
 	/**
 	 * @param array $row
 	 * @return Room
@@ -160,7 +200,6 @@ class Manager {
 			$this->db,
 			$this->dispatcher,
 			$this->timeFactory,
-			$this->hasher,
 			(int) $row['r_id'],
 			(int) $row['type'],
 			(int) $row['read_only'],
@@ -173,6 +212,7 @@ class Manager {
 			(string) $row['name'],
 			(string) $row['description'],
 			(string) $row['password'],
+			(string) $row['avatar'],
 			(string) $row['remote_server'],
 			(string) $row['remote_token'],
 			(int) $row['active_guests'],
@@ -185,7 +225,10 @@ class Manager {
 			$lastMessage,
 			$lobbyTimer,
 			(string) $row['object_type'],
-			(string) $row['object_id']
+			(string) $row['object_id'],
+			(int) $row['breakout_room_mode'],
+			(int) $row['breakout_room_status'],
+			(int) $row['call_recording']
 		);
 	}
 
@@ -383,18 +426,21 @@ class Manager {
 		$rooms = $this->getRoomsForUser($user->getUID());
 		foreach ($rooms as $room) {
 			if ($this->participantService->getNumberOfUsers($room) === 1) {
-				$room->deleteRoom();
+				Server::get(RoomService::class)->deleteRoom($room);
 			} else {
-				$this->participantService->removeUser($room, $user, Room::PARTICIPANT_REMOVED);
+				$this->participantService->removeUser($room, $user, Room::PARTICIPANT_REMOVED_ALL);
 			}
 		}
 
 		$leftRooms = $this->getLeftOneToOneRoomsForUser($user->getUID());
 		foreach ($leftRooms as $room) {
-			// We are changing the room type and name so a potential follow up
+			// We are changing the room type and name so a potential follow-up
 			// user with the same user-id can not reopen the one-to-one conversation.
-			Server::get(RoomService::class)->setType($room, Room::TYPE_GROUP, true);
-			$room->setName($user->getDisplayName(), '');
+			/** @var RoomService $roomService */
+			$roomService = Server::get(RoomService::class);
+			$roomService->setType($room, Room::TYPE_ONE_TO_ONE_FORMER, true);
+			$roomService->setName($room, $user->getDisplayName(), '');
+			$roomService->setReadOnly($room, Room::READ_ONLY);
 		}
 	}
 
@@ -449,7 +495,8 @@ class Manager {
 			))
 			->where($query->expr()->isNull('a.id'))
 			->andWhere($query->expr()->in('r.type', $query->createNamedParameter($allowedRoomTypes, IQueryBuilder::PARAM_INT_ARRAY)))
-			->andWhere($query->expr()->in('r.listable', $query->createNamedParameter($allowedListedTypes, IQueryBuilder::PARAM_INT_ARRAY)));
+			->andWhere($query->expr()->in('r.listable', $query->createNamedParameter($allowedListedTypes, IQueryBuilder::PARAM_INT_ARRAY)))
+			->orderBy('r.id', 'ASC');
 
 		if ($term !== '') {
 			$query->andWhere(
@@ -745,7 +792,8 @@ class Manager {
 		$helper->selectRoomsTable($query);
 		$query->from('talk_rooms', 'r')
 			->where($query->expr()->eq('r.object_type', $query->createNamedParameter($objectType)))
-			->andWhere($query->expr()->eq('r.object_id', $query->createNamedParameter($objectId)));
+			->andWhere($query->expr()->eq('r.object_id', $query->createNamedParameter($objectId)))
+			->orderBy('r.id', 'ASC');
 
 		$result = $query->executeQuery();
 		$row = $result->fetch();
@@ -763,6 +811,34 @@ class Manager {
 		return $this->createRoomObject($row);
 	}
 
+	/**
+	 * @param string $objectType
+	 * @param string $objectId
+	 * @return Room[]
+	 */
+	public function getMultipleRoomsByObject(string $objectType, string $objectId, bool $orderById = false): array {
+		$query = $this->db->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->where($query->expr()->eq('r.object_type', $query->createNamedParameter($objectType)))
+			->andWhere($query->expr()->eq('r.object_id', $query->createNamedParameter($objectId)));
+
+		if ($orderById) {
+			$query->orderBy('id', 'ASC');
+		}
+
+		$result = $query->executeQuery();
+		$rooms = [];
+		while ($row = $result->fetch()) {
+			$room = $this->createRoomObject($row);
+			$rooms[] = $room;
+		}
+		$result->closeCursor();
+
+		return $rooms;
+	}
+
 	/**
 	 * @param string|null $userId
 	 * @param string|null $sessionId
@@ -887,7 +963,7 @@ class Manager {
 		$room = $this->createRoomObject($row);
 
 		try {
-			$room->getParticipant($userId, false);
+			$this->participantService->getParticipant($room, $userId, false);
 		} catch (ParticipantNotFoundException $e) {
 			$user = $this->userManager->get($userId);
 			$this->participantService->addUsers($room, [[
@@ -927,8 +1003,14 @@ class Manager {
 
 		$insert->executeStatement();
 		$roomId = $insert->getLastInsertId();
-
-		$room = $this->getRoomById($roomId);
+		$room = $this->createRoomObjectFromData([
+			'r_id' => $roomId,
+			'name' => $name,
+			'type' => $type,
+			'token' => $token,
+			'object_type' => $objectType,
+			'object_id' => $objectId,
+		]);
 
 		$event = new RoomEvent($room);
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_ROOM_CREATE, $event);
@@ -959,23 +1041,37 @@ class Manager {
 		$qb->executeStatement();
 		$roomId = $qb->getLastInsertId();
 
-		return $this->getRoomById($roomId);
+		return $this->createRoomObjectFromData([
+			'r_id' => $roomId,
+			'name' => $name,
+			'type' => $type,
+			'token' => $token,
+			'remote_token' => $remoteToken,
+			'remote_server' => $remoteServer,
+		]);
 	}
 
-	public function resolveRoomDisplayName(Room $room, string $userId): string {
+	public function resolveRoomDisplayName(Room $room, string $userId, bool $forceName = false): string {
 		if ($room->getObjectType() === 'share:password') {
 			return $this->l->t('Password request: %s', [$room->getName()]);
 		}
+
 		if ($room->getType() === Room::TYPE_CHANGELOG) {
 			return $this->l->t('Talk updates ✅');
 		}
+
+		if ($forceName) {
+			return $room->getName();
+		}
+
 		if ($userId === '' && $room->getType() !== Room::TYPE_PUBLIC) {
 			return $this->l->t('Private conversation');
 		}
 
-
 		if ($room->getType() !== Room::TYPE_ONE_TO_ONE && $room->getName() === '') {
-			$room->setName($this->getRoomNameByParticipants($room));
+			/** @var RoomService $roomService */
+			$roomService = Server::get(RoomService::class);
+			$roomService->setName($room, $this->getRoomNameByParticipants($room), '');
 		}
 
 		// Set the room name to the other participant for one-to-one rooms
@@ -1013,9 +1109,9 @@ class Manager {
 			try {
 				if ($userId === '') {
 					$sessionId = $this->talkSession->getSessionForRoom($room->getToken());
-					$room->getParticipantBySession($sessionId);
+					$this->participantService->getParticipantBySession($room, $sessionId);
 				} else {
-					$room->getParticipant($userId, false);
+					$this->participantService->getParticipant($room, $userId, false);
 				}
 			} catch (ParticipantNotFoundException $e) {
 				// Do not leak the name of rooms the user is not a part of
@@ -1068,7 +1164,7 @@ class Manager {
 	 * @return string
 	 */
 	protected function getNewToken(): string {
-		$entropy = (int) $this->config->getAppValue('spreed', 'token_entropy', 8);
+		$entropy = (int) $this->config->getAppValue('spreed', 'token_entropy', '8');
 		$entropy = max(8, $entropy); // For update cases
 		$digitsOnly = $this->talkConfig->isSIPConfigured();
 		if ($digitsOnly) {
@@ -1099,7 +1195,7 @@ class Manager {
 		}
 
 		$entropy++;
-		$this->config->setAppValue('spreed', 'token_entropy', $entropy);
+		$this->config->setAppValue('spreed', 'token_entropy', (string) $entropy);
 		return $this->generateNewToken($query, $entropy, $digitsOnly);
 	}
 
