@@ -59,18 +59,20 @@ class MatterbridgeManager {
 	private LoggerInterface $logger;
 	private ITimeFactory $timeFactory;
 
-	public function __construct(IDBConnection $db,
-								IConfig $config,
-								IURLGenerator $urlGenerator,
-								IUserManager $userManager,
-								Manager $manager,
-								ParticipantService $participantService,
-								ChatManager $chatManager,
-								IAuthTokenProvider $tokenProvider,
-								ISecureRandom $random,
-								IAvatarManager $avatarManager,
-								LoggerInterface $logger,
-								ITimeFactory $timeFactory) {
+	public function __construct(
+		IDBConnection $db,
+		IConfig $config,
+		IURLGenerator $urlGenerator,
+		IUserManager $userManager,
+		Manager $manager,
+		ParticipantService $participantService,
+		ChatManager $chatManager,
+		IAuthTokenProvider $tokenProvider,
+		ISecureRandom $random,
+		IAvatarManager $avatarManager,
+		LoggerInterface $logger,
+		ITimeFactory $timeFactory,
+	) {
 		$this->avatarManager = $avatarManager;
 		$this->db = $db;
 		$this->config = $config;
@@ -293,7 +295,7 @@ class MatterbridgeManager {
 
 		// check if the bot user is member of the room and add or remove it
 		try {
-			$room->getParticipant(self::BRIDGE_BOT_USERID, false);
+			$this->participantService->getParticipant($room, self::BRIDGE_BOT_USERID, false);
 			if (!$isBridgeEnabled) {
 				$this->participantService->removeUser($room, $botUser, Room::PARTICIPANT_REMOVED);
 			}
@@ -422,7 +424,7 @@ class MatterbridgeManager {
 				$content .= sprintf('	Login = "%s"', $part['login']) . "\n";
 				$content .= sprintf('	Password = "%s"', $part['password']) . "\n";
 				if ($part['skiptls']) {
-					$content .= sprintf('	SkipTLSVerify = true') . "\n";
+					$content .= '	SkipTLSVerify = true' . "\n";
 				}
 				$content .= '	PrefixMessagesWithNick = true' . "\n";
 				$content .= '	RemoteNickFormat = "[{PROTOCOL}] <{NICK}> "' . "\n\n";
@@ -472,13 +474,13 @@ class MatterbridgeManager {
 					$content .= sprintf('	NickServPassword = "%s"', $part['nickservpassword']) . "\n";
 				}
 				if ($part['usetls']) {
-					$content .= sprintf('	UseTLS = true') . "\n";
+					$content .= '	UseTLS = true' . "\n";
 				}
 				if ($part['usesasl']) {
-					$content .= sprintf('	UseSASL = true') . "\n";
+					$content .= '	UseSASL = true' . "\n";
 				}
 				if ($part['skiptls']) {
-					$content .= sprintf('	SkipTLSVerify = true') . "\n";
+					$content .= '	SkipTLSVerify = true' . "\n";
 				}
 				$content .= '	PrefixMessagesWithNick = true' . "\n";
 				$content .= '	RemoteNickFormat = "[{PROTOCOL}] <{NICK}> "' . "\n\n";
@@ -497,7 +499,7 @@ class MatterbridgeManager {
 				$content .= sprintf('	Muc = "%s"', $part['muc']) . "\n";
 				$content .= sprintf('	Nick = "%s"', $part['nick']) . "\n";
 				if ($part['skiptls']) {
-					$content .= sprintf('	SkipTLSVerify = true') . "\n";
+					$content .= '	SkipTLSVerify = true' . "\n";
 				}
 				$content .= '	PrefixMessagesWithNick = true' . "\n";
 				$content .= '	RemoteNickFormat = "[{PROTOCOL}] <{NICK}> "' . "\n\n";
