@@ -36,11 +36,15 @@ use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
+use OCA\Talk\Service\AvatarService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Webinary;
+use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\ICommentsManager;
 use OCP\Comments\NotFoundException;
+use OCP\Files\IRootFolder;
 use OCP\HintException;
+use OCP\IGroupManager;
 use OCP\IL10N;
 use OCP\IURLGenerator;
 use OCP\IUser;
@@ -61,13 +65,18 @@ class Notifier implements INotifier {
 	protected IURLGenerator $url;
 	protected Config $config;
 	protected IUserManager $userManager;
+	protected IGroupManager $groupManager;
 	protected GuestManager $guestManager;
 	private IShareManager $shareManager;
 	protected Manager $manager;
 	protected ParticipantService $participantService;
+	protected AvatarService $avatarService;
 	protected INotificationManager $notificationManager;
 	protected ICommentsManager $commentManager;
 	protected MessageParser $messageParser;
+	protected IURLGenerator $urlGenerator;
+	protected IRootFolder $rootFolder;
+	protected ITimeFactory $timeFactory;
 	protected Definitions $definitions;
 	protected AddressHandler $addressHandler;
 
@@ -76,30 +85,42 @@ class Notifier implements INotifier {
 	/** @var Participant[][] */
 	protected array $participants = [];
 
-	public function __construct(IFactory $lFactory,
-								IURLGenerator $url,
-								Config $config,
-								IUserManager $userManager,
-								GuestManager $guestManager,
-								IShareManager $shareManager,
-								Manager $manager,
-								ParticipantService $participantService,
-								INotificationManager $notificationManager,
-								CommentsManager $commentManager,
-								MessageParser $messageParser,
-								Definitions $definitions,
-								AddressHandler $addressHandler) {
+	public function __construct(
+		IFactory $lFactory,
+		IURLGenerator $url,
+		Config $config,
+		IUserManager $userManager,
+		IGroupManager $groupManager,
+		GuestManager $guestManager,
+		IShareManager $shareManager,
+		Manager $manager,
+		ParticipantService $participantService,
+		AvatarService $avatarService,
+		INotificationManager $notificationManager,
+		CommentsManager $commentManager,
+		MessageParser $messageParser,
+		IURLGenerator $urlGenerator,
+		IRootFolder $rootFolder,
+		ITimeFactory $timeFactory,
+		Definitions $definitions,
+		AddressHandler $addressHandler,
+	) {
 		$this->lFactory = $lFactory;
 		$this->url = $url;
 		$this->config = $config;
 		$this->userManager = $userManager;
+		$this->groupManager = $groupManager;
 		$this->guestManager = $guestManager;
 		$this->shareManager = $shareManager;
 		$this->manager = $manager;
 		$this->participantService = $participantService;
+		$this->avatarService = $avatarService;
 		$this->notificationManager = $notificationManager;
 		$this->commentManager = $commentManager;
 		$this->messageParser = $messageParser;
+		$this->urlGenerator = $urlGenerator;
+		$this->rootFolder = $rootFolder;
+		$this->timeFactory = $timeFactory;
 		$this->definitions = $definitions;
 		$this->addressHandler = $addressHandler;
 	}
@@ -180,7 +201,7 @@ class Notifier implements INotifier {
 		}
 
 		try {
-			$participant = $room->getParticipant($userId, false);
+			$participant = $this->participantService->getParticipant($room, $userId, false);
 			$this->participants[$roomId][$userId] = $participant;
 			return $participant;
 		} catch (ParticipantNotFoundException $e) {
@@ -244,6 +265,12 @@ class Notifier implements INotifier {
 			->setLink($this->url->linkToRouteAbsolute('spreed.Page.showCall', ['token' => $room->getToken()]));
 
 		$subject = $notification->getSubject();
+		if ($subject === 'record_file_stored' || $subject === 'transcript_file_stored' || $subject === 'transcript_failed') {
+			return $this->parseStoredRecording($notification, $room, $participant, $l);
+		}
+		if ($subject === 'record_file_store_fail') {
+			return $this->parseStoredRecordingFail($notification, $room, $participant, $l);
+		}
 		if ($subject === 'invitation') {
 			return $this->parseInvitation($notification, $room, $l);
 		}
@@ -260,7 +287,7 @@ class Notifier implements INotifier {
 			}
 			return $this->parseCall($notification, $room, $l);
 		}
-		if ($subject === 'reply' || $subject === 'mention' || $subject === 'chat' || $subject === 'reaction') {
+		if ($subject === 'reply' || $subject === 'mention' || $subject === 'mention_direct' || $subject === 'mention_group' || $subject === 'mention_all' || $subject === 'chat' || $subject === 'reaction') {
 			if ($room->getLobbyState() !== Webinary::LOBBY_NONE &&
 				$participant instanceof Participant &&
 				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
@@ -283,6 +310,118 @@ class Notifier implements INotifier {
 		return $temp;
 	}
 
+	protected function parseStoredRecordingFail(
+		INotification $notification,
+		Room $room,
+		Participant $participant,
+		IL10N $l
+	): INotification {
+		$notification
+			->setRichSubject(
+				$l->t('Failed to upload call recording'),
+			)
+			->setRichMessage(
+				$l->t('The recording server failed to upload recording of call {call}. Please reach out to the administration.'),
+				[
+					'call' => [
+						'type' => 'call',
+						'id' => $room->getId(),
+						'name' => $room->getDisplayName($participant->getAttendee()->getActorId()),
+						'call-type' => $this->getRoomType($room),
+						'icon-url' => $this->avatarService->getAvatarUrl($room),
+					],
+				]
+			);
+		return $notification;
+	}
+
+	protected function parseStoredRecording(
+		INotification $notification,
+		Room $room,
+		Participant $participant,
+		IL10N $l
+	): INotification {
+		$parameters = $notification->getSubjectParameters();
+		try {
+			$userFolder = $this->rootFolder->getUserFolder($notification->getUser());
+			/** @var \OCP\Files\File[] */
+			$files = $userFolder->getById($parameters['objectId']);
+			/** @var \OCP\Files\File $file */
+			$file = array_shift($files);
+			$path = $userFolder->getRelativePath($file->getPath());
+		} catch (\Throwable $th) {
+			throw new AlreadyProcessedException();
+		}
+
+		$shareAction = $notification->createAction()
+			->setParsedLabel($l->t('Share to chat'))
+			->setPrimary(true)
+			->setLink(
+				$this->urlGenerator->linkToOCSRouteAbsolute(
+					'spreed.Recording.shareToChat',
+					[
+						'apiVersion' => 'v1',
+						'fileId' => $file->getId(),
+						'timestamp' => $notification->getDateTime()->getTimestamp(),
+						'token' => $room->getToken()
+					]
+				),
+				IAction::TYPE_POST
+			);
+		$dismissAction = $notification->createAction()
+			->setParsedLabel($l->t('Dismiss notification'))
+			->setLink(
+				$this->urlGenerator->linkToOCSRouteAbsolute(
+					'spreed.Recording.notificationDismiss',
+					[
+						'apiVersion' => 'v1',
+						'token' => $room->getToken(),
+						'timestamp' => $notification->getDateTime()->getTimestamp(),
+					]
+				),
+				IAction::TYPE_DELETE
+			);
+
+		if ($notification->getSubject() === 'record_file_stored') {
+			$subject = $l->t('Call recording now available');
+			$message = $l->t('The recording for the call in {call} was uploaded to {file}.');
+		} elseif ($notification->getSubject() === 'transcript_file_stored') {
+			$subject = $l->t('Transcript now available');
+			$message = $l->t('The transcript for the call in {call} was uploaded to {file}.');
+		} else {
+			$subject = $l->t('Failed to transcript call recording');
+			$message = $l->t('The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration.');
+		}
+
+		$notification
+			->setRichSubject($subject)
+			->setRichMessage(
+				$message,
+				[
+					'call' => [
+						'type' => 'call',
+						'id' => $room->getId(),
+						'name' => $room->getDisplayName($participant->getAttendee()->getActorId()),
+						'call-type' => $this->getRoomType($room),
+						'icon-url' => $this->avatarService->getAvatarUrl($room),
+					],
+					'file' => [
+						'type' => 'file',
+						'id' => $file->getId(),
+						'name' => $file->getName(),
+						'path' => $path,
+						'link' => $this->url->linkToRouteAbsolute('files.viewcontroller.showFile', ['fileid' => $file->getId()]),
+					],
+				]);
+
+		if ($notification->getSubject() !== 'transcript_failed') {
+			$notification->addParsedAction($shareAction);
+			$notification->addParsedAction($dismissAction);
+		}
+
+		return $notification;
+	}
+
 	/**
 	 * @throws HintException
 	 */
@@ -365,6 +504,7 @@ class Notifier implements INotifier {
 			'id' => $room->getId(),
 			'name' => $room->getDisplayName($notification->getUser()),
 			'call-type' => $this->getRoomType($room),
+			'icon-url' => $this->avatarService->getAvatarUrl($room),
 		];
 
 		$messageParameters = $notification->getMessageParameters();
@@ -385,6 +525,12 @@ class Notifier implements INotifier {
 			throw new AlreadyProcessedException();
 		}
 
+		$now = $this->timeFactory->getDateTime();
+		$expireDate = $message->getComment()->getExpireDate();
+		if ($expireDate instanceof \DateTime && $expireDate < $now) {
+			throw new AlreadyProcessedException();
+		}
+
 		if ($message->getMessageType() === ChatManager::VERB_MESSAGE_DELETED) {
 			throw new AlreadyProcessedException();
 		}
@@ -423,7 +569,7 @@ class Notifier implements INotifier {
 				'id' => $message->getComment()->getId(),
 				'name' => $shortenMessage,
 			];
-			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 				$subject = "{user}\n{message}";
 			} elseif ($richSubjectUser) {
 				$subject = $l->t('{user} in {call}') . "\n{message}";
@@ -438,7 +584,7 @@ class Notifier implements INotifier {
 				}
 			}
 		} elseif ($notification->getSubject() === 'chat') {
-			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 				$subject = $l->t('{user} sent you a private message');
 			} elseif ($richSubjectUser) {
 				$subject = $l->t('{user} sent a message in conversation {call}');
@@ -453,7 +599,7 @@ class Notifier implements INotifier {
 				}
 			}
 		} elseif ($notification->getSubject() === 'reply') {
-			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 				$subject = $l->t('{user} replied to your private message');
 			} elseif ($richSubjectUser) {
 				$subject = $l->t('{user} replied to your message in conversation {call}');
@@ -474,7 +620,7 @@ class Notifier implements INotifier {
 				'name' => $subjectParameters['reaction'],
 			];
 
-			if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+			if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 				$subject = $l->t('{user} reacted with {reaction} to your private message');
 			} elseif ($richSubjectUser) {
 				$subject = $l->t('{user} reacted with {reaction} to your message in conversation {call}');
@@ -488,18 +634,70 @@ class Notifier implements INotifier {
 					$subject = $l->t('A guest reacted with {reaction} to your message in conversation {call}');
 				}
 			}
-		} elseif ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+		} elseif ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 			$subject = $l->t('{user} mentioned you in a private conversation');
 		} elseif ($richSubjectUser) {
-			$subject = $l->t('{user} mentioned you in conversation {call}');
+			if ($notification->getSubject() === 'mention_group') {
+				$groupName = $this->groupManager->getDisplayName($subjectParameters['sourceId']) ?? $subjectParameters['sourceId'];
+				$richSubjectParameters['group'] = [
+					'type' => 'user-group',
+					'id' => $subjectParameters['sourceId'],
+					'name' => $groupName,
+				];
+
+				$subject = $l->t('{user} mentioned group {group} in conversation {call}');
+			} elseif ($notification->getSubject() === 'mention_all') {
+				$subject = $l->t('{user} mentioned everyone in conversation {call}');
+			} else {
+				$subject = $l->t('{user} mentioned you in conversation {call}');
+			}
 		} elseif (!$isGuest) {
-			$subject = $l->t('A deleted user mentioned you in conversation {call}');
+			if ($notification->getSubject() === 'mention_group') {
+				$groupName = $this->groupManager->getDisplayName($subjectParameters['sourceId']) ?? $subjectParameters['sourceId'];
+				$richSubjectParameters['group'] = [
+					'type' => 'user-group',
+					'id' => $subjectParameters['sourceId'],
+					'name' => $groupName,
+				];
+
+				$subject = $l->t('A deleted user mentioned group {group} in conversation {call}');
+			} elseif ($notification->getSubject() === 'mention_all') {
+				$subject = $l->t('A deleted user mentioned everyone in conversation {call}');
+			} else {
+				$subject = $l->t('A deleted user mentioned you in conversation {call}');
+			}
 		} else {
 			try {
 				$richSubjectParameters['guest'] = $this->getGuestParameter($room, $comment->getActorId());
-				$subject = $l->t('{guest} (guest) mentioned you in conversation {call}');
+				if ($notification->getSubject() === 'mention_group') {
+					$groupName = $this->groupManager->getDisplayName($subjectParameters['sourceId']) ?? $subjectParameters['sourceId'];
+					$richSubjectParameters['group'] = [
+						'type' => 'user-group',
+						'id' => $subjectParameters['sourceId'],
+						'name' => $groupName,
+					];
+
+					$subject = $l->t('{guest} (guest) mentioned group {group} in conversation {call}');
+				} elseif ($notification->getSubject() === 'mention_all') {
+					$subject = $l->t('{guest} (guest) mentioned everyone in conversation {call}');
+				} else {
+					$subject = $l->t('{guest} (guest) mentioned you in conversation {call}');
+				}
 			} catch (ParticipantNotFoundException $e) {
-				$subject = $l->t('A guest mentioned you in conversation {call}');
+				if ($notification->getSubject() === 'mention_group') {
+					$groupName = $this->groupManager->getDisplayName($subjectParameters['sourceId']) ?? $subjectParameters['sourceId'];
+					$richSubjectParameters['group'] = [
+						'type' => 'user-group',
+						'id' => $subjectParameters['sourceId'],
+						'name' => $groupName,
+					];
+
+					$subject = $l->t('A guest mentioned group {group} in conversation {call}');
+				} elseif ($notification->getSubject() === 'mention_all') {
+					$subject = $l->t('A guest mentioned everyone in conversation {call}');
+				} else {
+					$subject = $l->t('A guest mentioned you in conversation {call}');
+				}
 			}
 		}
 		$notification = $this->addActionButton($notification, $l->t('View chat'), false);
@@ -527,7 +725,7 @@ class Notifier implements INotifier {
 	 * @throws ParticipantNotFoundException
 	 */
 	protected function getGuestParameter(Room $room, string $actorId): array {
-		$participant = $room->getParticipantByActor(Attendee::ACTOR_GUESTS, $actorId);
+		$participant = $this->participantService->getParticipantByActor($room, Attendee::ACTOR_GUESTS, $actorId);
 		$name = $participant->getAttendee()->getDisplayName();
 		if (trim($name) === '') {
 			throw new ParticipantNotFoundException('Empty name');
@@ -548,6 +746,7 @@ class Notifier implements INotifier {
 	protected function getRoomType(Room $room): string {
 		switch ($room->getType()) {
 			case Room::TYPE_ONE_TO_ONE:
+			case Room::TYPE_ONE_TO_ONE_FORMER:
 				return 'one2one';
 			case Room::TYPE_GROUP:
 				return 'group';
@@ -580,7 +779,7 @@ class Notifier implements INotifier {
 		}
 
 		$roomName = $room->getDisplayName($notification->getUser());
-		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 			$subject = $l->t('{user} invited you to a private conversation');
 			if ($this->participantService->hasActiveSessionsInCall($room)) {
 				$notification = $this->addActionButton($notification, $l->t('Join call'));
@@ -602,6 +801,7 @@ class Notifier implements INotifier {
 							'id' => $room->getId(),
 							'name' => $roomName,
 							'call-type' => $this->getRoomType($room),
+							'icon-url' => $this->avatarService->getAvatarUrl($room),
 						],
 					]
 				);
@@ -627,6 +827,7 @@ class Notifier implements INotifier {
 							'id' => $room->getId(),
 							'name' => $roomName,
 							'call-type' => $this->getRoomType($room),
+							'icon-url' => $this->avatarService->getAvatarUrl($room),
 						],
 					]
 				);
@@ -651,7 +852,7 @@ class Notifier implements INotifier {
 		}
 
 		$roomName = $room->getDisplayName($notification->getUser());
-		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 			$parameters = $notification->getSubjectParameters();
 			$calleeId = $parameters['callee'];
 			$userDisplayName = $this->userManager->getDisplayName($calleeId);
@@ -678,6 +879,7 @@ class Notifier implements INotifier {
 								'id' => $room->getId(),
 								'name' => $roomName,
 								'call-type' => $this->getRoomType($room),
+								'icon-url' => $this->avatarService->getAvatarUrl($room),
 							],
 						]
 					);
@@ -702,6 +904,7 @@ class Notifier implements INotifier {
 							'id' => $room->getId(),
 							'name' => $roomName,
 							'call-type' => $this->getRoomType($room),
+							'icon-url' => $this->avatarService->getAvatarUrl($room),
 						],
 					]
 				);
