@@ -27,8 +27,6 @@ declare(strict_types=1);
 
 namespace OCA\Talk;
 
-use OCA\Talk\Events\ModifyRoomEvent;
-use OCA\Talk\Events\RoomEvent;
 use OCA\Talk\Events\SignalingRoomPropertiesEvent;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Model\Attendee;
@@ -38,11 +36,8 @@ use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\RoomService;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
-use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IDBConnection;
-use OCP\Log\Audit\CriticalActionPerformedEvent;
-use OCP\Security\IHasher;
 use OCP\Server;
 
 class Room {
@@ -59,6 +54,14 @@ class Room {
 	public const TYPE_GROUP = 2;
 	public const TYPE_PUBLIC = 3;
 	public const TYPE_CHANGELOG = 4;
+	public const TYPE_ONE_TO_ONE_FORMER = 5;
+
+	public const RECORDING_NONE = 0;
+	public const RECORDING_VIDEO = 1;
+	public const RECORDING_AUDIO = 2;
+	public const RECORDING_VIDEO_STARTING = 3;
+	public const RECORDING_AUDIO_STARTING = 4;
+	public const RECORDING_FAILED = 5;
 
 	/** @deprecated Use self::TYPE_UNKNOWN */
 	public const UNKNOWN_CALL = self::TYPE_UNKNOWN;
@@ -95,6 +98,7 @@ class Room {
 	public const START_CALL_NOONE = 3;
 
 	public const PARTICIPANT_REMOVED = 'remove';
+	public const PARTICIPANT_REMOVED_ALL = 'remove_all';
 	public const PARTICIPANT_LEFT = 'leave';
 
 	public const EVENT_AFTER_ROOM_CREATE = self::class . '::createdRoom';
@@ -148,6 +152,14 @@ class Room {
 	public const EVENT_BEFORE_SIGNALING_PROPERTIES = self::class . '::beforeSignalingProperties';
 	public const EVENT_BEFORE_SET_MESSAGE_EXPIRATION = self::class . '::beforeSetMessageExpiration';
 	public const EVENT_AFTER_SET_MESSAGE_EXPIRATION = self::class . '::afterSetMessageExpiration';
+	public const EVENT_BEFORE_SET_BREAKOUT_ROOM_MODE = self::class . '::beforeSetBreakoutRoomMode';
+	public const EVENT_AFTER_SET_BREAKOUT_ROOM_MODE = self::class . '::afterSetBreakoutRoomMode';
+	public const EVENT_BEFORE_SET_BREAKOUT_ROOM_STATUS = self::class . '::beforeSetBreakoutRoomStatus';
+	public const EVENT_AFTER_SET_BREAKOUT_ROOM_STATUS = self::class . '::afterSetBreakoutRoomStatus';
+	public const EVENT_BEFORE_SET_CALL_RECORDING = self::class . '::beforeSetCallRecording';
+	public const EVENT_AFTER_SET_CALL_RECORDING = self::class . '::afterSetCallRecording';
+	public const EVENT_BEFORE_AVATAR_SET = self::class . '::preSetAvatar';
+	public const EVENT_AFTER_AVATAR_SET = self::class . '::postSetAvatar';
 
 	public const DESCRIPTION_MAXIMUM_LENGTH = 500;
 
@@ -155,7 +167,6 @@ class Room {
 	private IDBConnection $db;
 	private IEventDispatcher $dispatcher;
 	private ITimeFactory $timeFactory;
-	private IHasher $hasher;
 
 	private int $id;
 	private int $type;
@@ -170,6 +181,7 @@ class Room {
 	private string $name;
 	private string $description;
 	private string $password;
+	private string $avatar;
 	private string $remoteServer;
 	private string $remoteToken;
 	private int $activeGuests;
@@ -182,45 +194,52 @@ class Room {
 	private ?IComment $lastMessage;
 	private string $objectType;
 	private string $objectId;
+	private int $breakoutRoomMode;
+	private int $breakoutRoomStatus;
+	private int $callRecording;
 
 	protected ?string $currentUser = null;
 	protected ?Participant $participant = null;
 
-	public function __construct(Manager $manager,
-								IDBConnection $db,
-								IEventDispatcher $dispatcher,
-								ITimeFactory $timeFactory,
-								IHasher $hasher,
-								int $id,
-								int $type,
-								int $readOnly,
-								int $listable,
-								int $messageExpiration,
-								int $lobbyState,
-								int $sipEnabled,
-								?int $assignedSignalingServer,
-								string $token,
-								string $name,
-								string $description,
-								string $password,
-								string $remoteServer,
-								string $remoteToken,
-								int $activeGuests,
-								int $defaultPermissions,
-								int $callPermissions,
-								int $callFlag,
-								?\DateTime $activeSince,
-								?\DateTime $lastActivity,
-								int $lastMessageId,
-								?IComment $lastMessage,
-								?\DateTime $lobbyTimer,
-								string $objectType,
-								string $objectId) {
+	public function __construct(
+		Manager $manager,
+		IDBConnection $db,
+		IEventDispatcher $dispatcher,
+		ITimeFactory $timeFactory,
+		int $id,
+		int $type,
+		int $readOnly,
+		int $listable,
+		int $messageExpiration,
+		int $lobbyState,
+		int $sipEnabled,
+		?int $assignedSignalingServer,
+		string $token,
+		string $name,
+		string $description,
+		string $password,
+		string $avatar,
+		string $remoteServer,
+		string $remoteToken,
+		int $activeGuests,
+		int $defaultPermissions,
+		int $callPermissions,
+		int $callFlag,
+		?\DateTime $activeSince,
+		?\DateTime $lastActivity,
+		int $lastMessageId,
+		?IComment $lastMessage,
+		?\DateTime $lobbyTimer,
+		string $objectType,
+		string $objectId,
+		int $breakoutRoomMode,
+		int $breakoutRoomStatus,
+		int $callRecording,
+	) {
 		$this->manager = $manager;
 		$this->db = $db;
 		$this->dispatcher = $dispatcher;
 		$this->timeFactory = $timeFactory;
-		$this->hasher = $hasher;
 		$this->id = $id;
 		$this->type = $type;
 		$this->readOnly = $readOnly;
@@ -233,6 +252,7 @@ class Room {
 		$this->name = $name;
 		$this->description = $description;
 		$this->password = $password;
+		$this->avatar = $avatar;
 		$this->remoteServer = $remoteServer;
 		$this->remoteToken = $remoteToken;
 		$this->activeGuests = $activeGuests;
@@ -246,6 +266,9 @@ class Room {
 		$this->lobbyTimer = $lobbyTimer;
 		$this->objectType = $objectType;
 		$this->objectId = $objectId;
+		$this->breakoutRoomMode = $breakoutRoomMode;
+		$this->breakoutRoomStatus = $breakoutRoomStatus;
+		$this->callRecording = $callRecording;
 	}
 
 	public function getId(): int {
@@ -353,7 +376,9 @@ class Room {
 				// Fill the room name with the participants for 1-to-1 conversations
 				$users = $participantService->getParticipantUserIds($this);
 				sort($users);
-				$this->setName(json_encode($users), '');
+				/** @var RoomService $roomService */
+				$roomService = Server::get(RoomService::class);
+				$roomService->setName($this, json_encode($users), '');
 			} elseif (strpos($this->name, '["') !== 0) {
 				// TODO use DI
 				$participantService = Server::get(ParticipantService::class);
@@ -363,12 +388,18 @@ class Room {
 					$users[] = $this->name;
 				}
 				sort($users);
-				$this->setName(json_encode($users), '');
+				/** @var RoomService $roomService */
+				$roomService = Server::get(RoomService::class);
+				$roomService->setName($this, json_encode($users), '');
 			}
 		}
 		return $this->name;
 	}
 
+	public function setName(string $name): void {
+		$this->name = $name;
+	}
+
 	public function getSecondParticipant(string $userId): string {
 		if ($this->getType() !== self::TYPE_ONE_TO_ONE) {
 			throw new \InvalidArgumentException('Not a one-to-one room');
@@ -384,8 +415,8 @@ class Room {
 		return $this->getName();
 	}
 
-	public function getDisplayName(string $userId): string {
-		return $this->manager->resolveRoomDisplayName($this, $userId);
+	public function getDisplayName(string $userId, bool $forceName = false): string {
+		return $this->manager->resolveRoomDisplayName($this, $userId, $forceName);
 	}
 
 	public function getDescription(): string {
@@ -404,6 +435,11 @@ class Room {
 		return $this->activeGuests;
 	}
 
+	public function resetActiveSince(): void {
+		$this->activeGuests = 0;
+		$this->activeSince = null;
+	}
+
 	public function getDefaultPermissions(): int {
 		return $this->defaultPermissions;
 	}
@@ -432,6 +468,10 @@ class Room {
 		return $this->lastActivity;
 	}
 
+	public function setLastActivity(\DateTime $now): void {
+		$this->lastActivity = $now;
+	}
+
 	public function getLastMessage(): ?IComment {
 		if ($this->lastMessageId && $this->lastMessage === null) {
 			$this->lastMessage = $this->manager->loadLastCommentInfo($this->lastMessageId);
@@ -443,6 +483,11 @@ class Room {
 		return $this->lastMessage;
 	}
 
+	public function setLastMessage(IComment $message): void {
+		$this->lastMessage = $message;
+		$this->lastMessageId = (int) $message->getId();
+	}
+
 	public function getObjectType(): string {
 		return $this->objectType;
 	}
@@ -463,6 +508,14 @@ class Room {
 		$this->password = $password;
 	}
 
+	public function setAvatar(string $avatar): void {
+		$this->avatar = $avatar;
+	}
+
+	public function getAvatar(): string {
+		return $this->avatar;
+	}
+
 	public function getRemoteServer(): string {
 		return $this->remoteServer;
 	}
@@ -517,6 +570,7 @@ class Room {
 	 *                                     null to try loading "any"
 	 * @return Participant
 	 * @throws ParticipantNotFoundException When the user is not a participant
+	 * @deprecated
 	 */
 	public function getParticipant(?string $userId, $sessionId = null): Participant {
 		if (!is_string($userId) || $userId === '') {
@@ -569,254 +623,37 @@ class Room {
 		return $this->manager->createParticipantObject($this, $row);
 	}
 
-	/**
-	 * @param string|null $sessionId
-	 * @return Participant
-	 * @throws ParticipantNotFoundException When the user is not a participant
-	 */
-	public function getParticipantBySession(?string $sessionId): Participant {
-		if (!is_string($sessionId) || $sessionId === '' || $sessionId === '0') {
-			throw new ParticipantNotFoundException('Not a user');
+	public function setActiveSince(\DateTime $since, int $callFlag, bool $isGuest): void {
+		if (!$this->activeSince) {
+			$this->activeSince = $since;
 		}
-
-		$query = $this->db->getQueryBuilder();
-		$helper = new SelectHelper();
-		$helper->selectAttendeesTable($query);
-		$helper->selectSessionsTable($query);
-		$query->from('talk_sessions', 's')
-			->leftJoin('s', 'talk_attendees', 'a', $query->expr()->eq('a.id', 's.attendee_id'))
-			->where($query->expr()->eq('s.session_id', $query->createNamedParameter($sessionId)))
-			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($this->getId())))
-			->setMaxResults(1);
-		$result = $query->executeQuery();
-		$row = $result->fetch();
-		$result->closeCursor();
-
-		if ($row === false) {
-			throw new ParticipantNotFoundException('User is not a participant');
-		}
-
-		return $this->manager->createParticipantObject($this, $row);
-	}
-
-	/**
-	 * @param string $pin
-	 * @return Participant
-	 * @throws ParticipantNotFoundException When the pin is not valid (has no participant assigned)
-	 */
-	public function getParticipantByPin(string $pin): Participant {
-		$query = $this->db->getQueryBuilder();
-		$helper = new SelectHelper();
-		$helper->selectAttendeesTable($query);
-		$query->from('talk_attendees', 'a')
-			->where($query->expr()->eq('a.pin', $query->createNamedParameter($pin)))
-			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($this->getId())))
-			->setMaxResults(1);
-		$result = $query->executeQuery();
-		$row = $result->fetch();
-		$result->closeCursor();
-
-		if ($row === false) {
-			throw new ParticipantNotFoundException('User is not a participant');
-		}
-
-		return $this->manager->createParticipantObject($this, $row);
-	}
-
-	/**
-	 * @param int $attendeeId
-	 * @return Participant
-	 * @throws ParticipantNotFoundException When the pin is not valid (has no participant assigned)
-	 */
-	public function getParticipantByAttendeeId(int $attendeeId): Participant {
-		$query = $this->db->getQueryBuilder();
-		$helper = new SelectHelper();
-		$helper->selectAttendeesTable($query);
-		$query->from('talk_attendees', 'a')
-			->where($query->expr()->eq('a.id', $query->createNamedParameter($attendeeId, IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($this->getId())))
-			->setMaxResults(1);
-
-		$result = $query->executeQuery();
-		$row = $result->fetch();
-		$result->closeCursor();
-
-		if ($row === false) {
-			throw new ParticipantNotFoundException('User is not a participant');
-		}
-
-		return $this->manager->createParticipantObject($this, $row);
-	}
-
-	/**
-	 * @param string $actorType
-	 * @param string $actorId
-	 * @return Participant
-	 * @throws ParticipantNotFoundException When the pin is not valid (has no participant assigned)
-	 */
-	public function getParticipantByActor(string $actorType, string $actorId): Participant {
-		if ($actorType === Attendee::ACTOR_USERS) {
-			return $this->getParticipant($actorId, false);
-		}
-
-		$query = $this->db->getQueryBuilder();
-		$helper = new SelectHelper();
-		$helper->selectAttendeesTable($query);
-		$query->from('talk_attendees', 'a')
-			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter($actorType)))
-			->andWhere($query->expr()->eq('a.actor_id', $query->createNamedParameter($actorId)))
-			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($this->getId())))
-			->setMaxResults(1);
-
-		$result = $query->executeQuery();
-		$row = $result->fetch();
-		$result->closeCursor();
-
-		if ($row === false) {
-			throw new ParticipantNotFoundException('User is not a participant');
-		}
-
-		return $this->manager->createParticipantObject($this, $row);
-	}
-
-	public function deleteRoom(): void {
-		$event = new RoomEvent($this);
-		$this->dispatcher->dispatch(self::EVENT_BEFORE_ROOM_DELETE, $event);
-		$delete = $this->db->getQueryBuilder();
-
-		// Delete attendees
-		$delete->delete('talk_attendees')
-			->where($delete->expr()->eq('room_id', $delete->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
-		$delete->executeStatement();
-
-		// Delete room
-		$delete->delete('talk_rooms')
-			->where($delete->expr()->eq('id', $delete->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
-		$delete->executeStatement();
-
-		$this->dispatcher->dispatch(self::EVENT_AFTER_ROOM_DELETE, $event);
-		if (class_exists(CriticalActionPerformedEvent::class)) {
-			$this->dispatcher->dispatchTyped(new CriticalActionPerformedEvent(
-				'Conversation "%s" deleted',
-				['name' => $this->getName()],
-			));
-		}
-	}
-
-	/**
-	 * @param string $newName Currently it is only allowed to rename: self::TYPE_GROUP, self::TYPE_PUBLIC
-	 * @param string|null $oldName
-	 * @return bool True when the change was valid, false otherwise
-	 */
-	public function setName(string $newName, ?string $oldName = null): bool {
-		$oldName = $oldName !== null ? $oldName : $this->getName();
-		if ($newName === $oldName) {
-			return false;
-		}
-
-		$event = new ModifyRoomEvent($this, 'name', $newName, $oldName);
-		$this->dispatcher->dispatch(self::EVENT_BEFORE_NAME_SET, $event);
-
-		$update = $this->db->getQueryBuilder();
-		$update->update('talk_rooms')
-			->set('name', $update->createNamedParameter($newName))
-			->where($update->expr()->eq('id', $update->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
-		$update->executeStatement();
-		$this->name = $newName;
-
-		$this->dispatcher->dispatch(self::EVENT_AFTER_NAME_SET, $event);
-
-		return true;
-	}
-
-	/**
-	 * @param \DateTime $now
-	 * @return bool
-	 */
-	public function setLastActivity(\DateTime $now): bool {
-		$update = $this->db->getQueryBuilder();
-		$update->update('talk_rooms')
-			->set('last_activity', $update->createNamedParameter($now, 'datetime'))
-			->where($update->expr()->eq('id', $update->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
-		$update->executeStatement();
-
-		$this->lastActivity = $now;
-
-		return true;
-	}
-
-	/**
-	 * @param \DateTime $since
-	 * @param int $callFlag
-	 * @param bool $isGuest
-	 * @return bool
-	 */
-	public function setActiveSince(\DateTime $since, int $callFlag, bool $isGuest): bool {
-		if ($isGuest && $this->getType() === self::TYPE_PUBLIC) {
-			$update = $this->db->getQueryBuilder();
-			$update->update('talk_rooms')
-				->set('active_guests', $update->createFunction($update->getColumnName('active_guests') . ' + 1'))
-				->set(
-					'call_flag',
-					$update->expr()->bitwiseOr('call_flag', $callFlag)
-				)
-				->where($update->expr()->eq('id', $update->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
-			$update->executeStatement();
-
+		$this->callFlag |= $callFlag;
+		if ($isGuest) {
 			$this->activeGuests++;
-		} elseif (!$isGuest) {
-			$update = $this->db->getQueryBuilder();
-			$update->update('talk_rooms')
-				->set(
-					'call_flag',
-					$update->expr()->bitwiseOr('call_flag', $callFlag)
-				)
-				->where($update->expr()->eq('id', $update->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
-			$update->executeStatement();
 		}
-
-		if ($this->activeSince instanceof \DateTime) {
-			return false;
-		}
-
-		$update = $this->db->getQueryBuilder();
-		$update->update('talk_rooms')
-			->set('active_since', $update->createNamedParameter($since, IQueryBuilder::PARAM_DATE))
-			->where($update->expr()->eq('id', $update->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
-			->andWhere($update->expr()->isNull('active_since'));
-		$update->executeStatement();
-
-		$this->activeSince = $since;
-
-		return true;
 	}
 
-	public function setLastMessage(IComment $message): void {
-		$update = $this->db->getQueryBuilder();
-		$update->update('talk_rooms')
-			->set('last_message', $update->createNamedParameter((int) $message->getId()))
-			->set('last_activity', $update->createNamedParameter($message->getCreationDateTime(), 'datetime'))
-			->where($update->expr()->eq('id', $update->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)));
-		$update->executeStatement();
-
-		$this->lastMessage = $message;
-		$this->lastMessageId = (int) $message->getId();
-		$this->lastActivity = $message->getCreationDateTime();
+	public function getBreakoutRoomMode(): int {
+		return $this->breakoutRoomMode;
 	}
 
-	public function resetActiveSince(): bool {
-		$update = $this->db->getQueryBuilder();
-		$update->update('talk_rooms')
-			->set('active_guests', $update->createNamedParameter(0, IQueryBuilder::PARAM_INT))
-			->set('active_since', $update->createNamedParameter(null, IQueryBuilder::PARAM_DATE))
-			->set('call_flag', $update->createNamedParameter(0, IQueryBuilder::PARAM_INT))
-			->set('call_permissions', $update->createNamedParameter(Attendee::PERMISSIONS_DEFAULT, IQueryBuilder::PARAM_INT))
-			->where($update->expr()->eq('id', $update->createNamedParameter($this->getId(), IQueryBuilder::PARAM_INT)))
-			->andWhere($update->expr()->isNotNull('active_since'));
+	public function setBreakoutRoomMode(int $mode): void {
+		$this->breakoutRoomMode = $mode;
+	}
 
-		$this->activeGuests = 0;
-		$this->activeSince = null;
+	public function getBreakoutRoomStatus(): int {
+		return $this->breakoutRoomStatus;
+	}
 
-		return (bool) $update->executeStatement();
+	public function setBreakoutRoomStatus(int $status): void {
+		$this->breakoutRoomStatus = $status;
+	}
+
+	public function getCallRecording(): int {
+		return $this->callRecording;
+	}
+
+	public function setCallRecording(int $callRecording): void {
+		$this->callRecording = $callRecording;
 	}
 }
