@@ -23,7 +23,6 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Service;
 
-use OCA\Talk\Manager;
 use OCA\Circles\CirclesManager;
 use OCA\Circles\Model\Circle;
 use OCA\Circles\Model\Member;
@@ -51,8 +50,10 @@ use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Exceptions\UnauthorizedException;
 use OCA\Talk\Federation\FederationManager;
 use OCA\Talk\Federation\Notifications;
+use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\AttendeeMapper;
+use OCA\Talk\Model\BreakoutRoom;
 use OCA\Talk\Model\SelectHelper;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Model\SessionMapper;
@@ -91,20 +92,25 @@ class ParticipantService {
 	private ITimeFactory $timeFactory;
 	private ICacheFactory $cacheFactory;
 
-	public function __construct(IConfig $serverConfig,
-								Config $talkConfig,
-								AttendeeMapper $attendeeMapper,
-								SessionMapper $sessionMapper,
-								SessionService $sessionService,
-								ISecureRandom $secureRandom,
-								IDBConnection $connection,
-								IEventDispatcher $dispatcher,
-								IUserManager $userManager,
-								IGroupManager $groupManager,
-								MembershipService $membershipService,
-								Notifications $notifications,
-								ITimeFactory $timeFactory,
-								ICacheFactory $cacheFactory) {
+	protected array $userCache;
+	protected array $sessionCache;
+
+	public function __construct(
+		IConfig $serverConfig,
+		Config $talkConfig,
+		AttendeeMapper $attendeeMapper,
+		SessionMapper $sessionMapper,
+		SessionService $sessionService,
+		ISecureRandom $secureRandom,
+		IDBConnection $connection,
+		IEventDispatcher $dispatcher,
+		IUserManager $userManager,
+		IGroupManager $groupManager,
+		MembershipService $membershipService,
+		Notifications $notifications,
+		ITimeFactory $timeFactory,
+		ICacheFactory $cacheFactory,
+	) {
 		$this->serverConfig = $serverConfig;
 		$this->talkConfig = $talkConfig;
 		$this->attendeeMapper = $attendeeMapper;
@@ -130,13 +136,71 @@ class ParticipantService {
 		}
 
 		$oldType = $attendee->getParticipantType();
+		if ($oldType === $participantType) {
+			return;
+		}
 
 		$event = new ModifyParticipantEvent($room, $participant, 'type', $participantType, $oldType);
 		$this->dispatcher->dispatch(Room::EVENT_BEFORE_PARTICIPANT_TYPE_SET, $event);
 
 		$attendee->setParticipantType($participantType);
+
+		$promotedToModerator = in_array($participantType, [
+			Participant::OWNER,
+			Participant::MODERATOR,
+		], true);
+		$demotedFromModerator = in_array($oldType, [
+			Participant::OWNER,
+			Participant::MODERATOR,
+		], true);
+
+		if ($promotedToModerator) {
+			// Reset permissions on promotion
+			$attendee->setPermissions(Attendee::PERMISSIONS_DEFAULT);
+		}
+
 		$this->attendeeMapper->update($attendee);
 
+		// XOR so we don't move the participant in and out when they are changed from moderator to owner or vice-versa
+		if (($promotedToModerator xor $demotedFromModerator) && $room->getBreakoutRoomMode() !== BreakoutRoom::MODE_NOT_CONFIGURED) {
+			/** @var Manager $manager */
+			$manager = Server::get(Manager::class);
+
+			$breakoutRooms = $manager->getMultipleRoomsByObject(BreakoutRoom::PARENT_OBJECT_TYPE, $room->getToken());
+
+			foreach ($breakoutRooms as $breakoutRoom) {
+				try {
+					$breakoutRoomParticipant = $this->getParticipantByActor(
+						$breakoutRoom,
+						$attendee->getActorType(),
+						$attendee->getActorId()
+					);
+
+					if ($demotedFromModerator) {
+						// Remove participant from all breakout rooms
+						$this->removeAttendee($breakoutRoom, $breakoutRoomParticipant, Room::PARTICIPANT_REMOVED);
+					} elseif (!$breakoutRoomParticipant->hasModeratorPermissions()) {
+						if ($breakoutRoomParticipant->getAttendee()->getParticipantType() === Participant::USER
+							|| $breakoutRoomParticipant->getAttendee()->getParticipantType() === Participant::USER_SELF_JOINED) {
+							$this->updateParticipantType($breakoutRoom, $breakoutRoomParticipant, Participant::MODERATOR);
+						}
+					}
+				} catch (ParticipantNotFoundException $e) {
+					if ($promotedToModerator) {
+						// Add participant as a moderator when they were not in the room already
+						$this->addUsers($breakoutRoom, [
+							[
+								'actorType' => $attendee->getActorType(),
+								'actorId' => $attendee->getActorId(),
+								'displayName' => $attendee->getDisplayName(),
+								'participantType' => $attendee->getParticipantType(),
+							],
+						]);
+					}
+				}
+			}
+		}
+
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_PARTICIPANT_TYPE_SET, $event);
 	}
 
@@ -145,7 +209,7 @@ class ParticipantService {
 	 * @throws ForbiddenException
 	 */
 	public function updatePermissions(Room $room, Participant $participant, string $method, int $newPermissions): bool {
-		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
 			return false;
 		}
 
@@ -178,6 +242,9 @@ class ParticipantService {
 		$this->dispatcher->dispatch(Room::EVENT_BEFORE_PARTICIPANT_PERMISSIONS_SET, $event);
 
 		$attendee->setPermissions($newPermissions);
+		if ($attendee->getParticipantType() === Participant::USER_SELF_JOINED) {
+			$attendee->setParticipantType(Participant::USER);
+		}
 		$this->attendeeMapper->update($attendee);
 
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_PARTICIPANT_PERMISSIONS_SET, $event);
@@ -435,7 +502,10 @@ class ParticipantService {
 	}
 
 	protected function updateRoomLastMessage(Room $room, IComment $message): void {
-		$room->setLastMessage($message);
+		/** @var RoomService $roomService */
+		$roomService = Server::get(RoomService::class);
+		$roomService->setLastMessage($room, $message);
+
 		$lastMessageCache = $this->cacheFactory->createDistributed('talk/lastmsgid');
 		$lastMessageCache->remove($room->getToken());
 		$unreadCountCache = $this->cacheFactory->createDistributed('talk/unreadcount');
@@ -713,14 +783,14 @@ class ParticipantService {
 			$this->sessionMapper->deleteByAttendeeId($participant->getAttendee()->getId());
 		}
 
-		if ($participant->getAttendee()->getParticipantType() === Participant::USER_SELF_JOINED) {
-			$this->attendeeMapper->delete($participant->getAttendee());
-
-			$attendeeEvent = new AttendeesRemovedEvent($room, [$participant->getAttendee()]);
-			$this->dispatcher->dispatchTyped($attendeeEvent);
-		}
-
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_ROOM_DISCONNECT, $event);
+
+		if ($participant->getAttendee()->getParticipantType() === Participant::USER_SELF_JOINED
+			&& empty($this->sessionMapper->findByAttendeeId($participant->getAttendee()->getId()))) {
+			$user = $this->userManager->get($participant->getAttendee()->getActorId());
+
+			$this->removeUser($room, $user, Room::PARTICIPANT_LEFT);
+		}
 	}
 
 	public function removeAttendee(Room $room, Participant $participant, string $reason, bool $attendeeEventIsTriggeredAlready = false): void {
@@ -728,6 +798,17 @@ class ParticipantService {
 
 		$sessions = $this->sessionService->getAllSessionsForAttendee($participant->getAttendee());
 
+		if ($room->getBreakoutRoomMode() !== BreakoutRoom::MODE_NOT_CONFIGURED) {
+			/** @var BreakoutRoomService $breakoutRoomService */
+			$breakoutRoomService = Server::get(BreakoutRoomService::class);
+			$breakoutRoomService->removeAttendeeFromBreakoutRoom(
+				$room,
+				$participant->getAttendee()->getActorType(),
+				$participant->getAttendee()->getActorId(),
+				false
+			);
+		}
+
 		if ($isUser) {
 			$user = $this->userManager->get($participant->getAttendee()->getActorId());
 			$event = new RemoveUserEvent($room, $participant, $user, $reason, $sessions);
@@ -772,7 +853,7 @@ class ParticipantService {
 		$attendees = [];
 		foreach ($users as $user) {
 			try {
-				$participant = $room->getParticipant($user->getUID());
+				$participant = $this->getParticipant($room, $user->getUID());
 				$participantType = $participant->getAttendee()->getParticipantType();
 
 				$attendees[] = $participant->getAttendee();
@@ -835,7 +916,7 @@ class ParticipantService {
 		$attendees = [];
 		foreach ($users as $user) {
 			try {
-				$participant = $room->getParticipant($user->getUID());
+				$participant = $this->getParticipant($room, $user->getUID());
 				$participantType = $participant->getAttendee()->getParticipantType();
 
 				$attendees[] = $participant->getAttendee();
@@ -853,7 +934,7 @@ class ParticipantService {
 
 	public function removeUser(Room $room, IUser $user, string $reason): void {
 		try {
-			$participant = $room->getParticipant($user->getUID(), false);
+			$participant = $this->getParticipant($room, $user->getUID(), false);
 		} catch (ParticipantNotFoundException $e) {
 			return;
 		}
@@ -861,6 +942,19 @@ class ParticipantService {
 		$attendee = $participant->getAttendee();
 		$sessions = $this->sessionService->getAllSessionsForAttendee($attendee);
 
+		if ($reason !== Room::PARTICIPANT_REMOVED_ALL && $room->getBreakoutRoomMode() !== BreakoutRoom::MODE_NOT_CONFIGURED) {
+			/** @var BreakoutRoomService $breakoutRoomService */
+			$breakoutRoomService = Server::get(BreakoutRoomService::class);
+			$breakoutRoomService->removeAttendeeFromBreakoutRoom(
+				$room,
+				$attendee->getActorType(),
+				$attendee->getActorId(),
+				false
+			);
+		} elseif ($reason === Room::PARTICIPANT_REMOVED_ALL) {
+			$reason = Room::PARTICIPANT_REMOVED;
+		}
+
 		$event = new RemoveUserEvent($room, $participant, $user, $reason, $sessions);
 		$this->dispatcher->dispatch(Room::EVENT_BEFORE_USER_REMOVE, $event);
 
@@ -910,11 +1004,28 @@ class ParticipantService {
 		$attendees = [];
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
+			if ($row['display_name'] !== '' && $row['display_name'] !== null) {
+				// Keep guests with a non-empty display name, so we can still
+				// render the guest display name on chat messages.
+				continue;
+			}
+
+			if ((int) $row['participant_type'] !== Participant::GUEST
+				|| ((int) $row['permissions'] !== Attendee::PERMISSIONS_DEFAULT
+					&& (int) $row['permissions'] !== Attendee::PERMISSIONS_CUSTOM)) {
+				// Keep guests with non-default permissions in case they just reconnect
+				continue;
+			}
+
 			$attendeeIds[] = (int) $row['a_id'];
 			$attendees[] = $this->attendeeMapper->createAttendeeFromRow($row);
 		}
 		$result->closeCursor();
 
+		if (empty($attendeeIds)) {
+			return;
+		}
+
 		$this->attendeeMapper->deleteByIds($attendeeIds);
 
 		$attendeeEvent = new AttendeesRemovedEvent($room, $attendees);
@@ -1183,6 +1294,34 @@ class ParticipantService {
 		return $this->getParticipantsFromQuery($query, $room);
 	}
 
+	/**
+	 * Get all sessions and attendees without a session for the room
+	 *
+	 * This will return multiple items for the same attendee if the attendee
+	 * has multiple sessions in the room.
+	 *
+	 * @param Room[] $rooms
+	 * @return Participant[]
+	 */
+	public function getSessionsAndParticipantsForRooms(array $rooms): array {
+		$roomIds = array_map(static fn (Room $room) => $room->getId(), $rooms);
+		$map = array_combine($roomIds, $rooms);
+
+		$query = $this->connection->getQueryBuilder();
+
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_attendees', 'a')
+			->leftJoin(
+				'a', 'talk_sessions', 's',
+				$query->expr()->eq('s.attendee_id', 'a.id')
+			)
+			->where($query->expr()->in('a.room_id', $query->createNamedParameter($roomIds, IQueryBuilder::PARAM_INT_ARRAY)));
+
+		return $this->getParticipantsForRoomsFromQuery($query, $map);
+	}
+
 	/**
 	 * @param Room $room
 	 * @param int $maxAge
@@ -1267,12 +1406,28 @@ class ParticipantService {
 
 	/**
 	 * @param IQueryBuilder $query
+	 * @param Room $room
 	 * @return Participant[]
 	 */
 	protected function getParticipantsFromQuery(IQueryBuilder $query, Room $room): array {
+		return $this->getParticipantsForRoomsFromQuery($query, [$room->getId() => $room]);
+	}
+
+	/**
+	 * @param IQueryBuilder $query
+	 * @param Room[] $rooms Room ID => Room object
+	 * @psalm-param array<int, Room> $rooms
+	 * @return Participant[]
+	 */
+	protected function getParticipantsForRoomsFromQuery(IQueryBuilder $query, array $rooms): array {
 		$participants = [];
 		$result = $query->executeQuery();
 		while ($row = $result->fetch()) {
+			$room = $rooms[(int) $row['room_id']] ?? null;
+			if ($room === null) {
+				continue;
+			}
+
 			$attendee = $this->attendeeMapper->createAttendeeFromRow($row);
 			if (isset($row['s_id'])) {
 				$session = $this->sessionMapper->createSessionFromRow($row);
@@ -1287,6 +1442,30 @@ class ParticipantService {
 		return $participants;
 	}
 
+	/**
+	 * @param IQueryBuilder $query
+	 * @return Participant
+	 * @throws ParticipantNotFoundException
+	 */
+	protected function getParticipantFromQuery(IQueryBuilder $query, Room $room): Participant {
+		$result = $query->executeQuery();
+		$row = $result->fetch();
+		$result->closeCursor();
+
+		if ($row === false) {
+			throw new ParticipantNotFoundException('User is not a participant');
+		}
+
+		$attendee = $this->attendeeMapper->createAttendeeFromRow($row);
+		if (isset($row['s_id'])) {
+			$session = $this->sessionMapper->createSessionFromRow($row);
+		} else {
+			$session = null;
+		}
+
+		return new Participant($room, $attendee, $session);
+	}
+
 	/**
 	 * @param Room $room
 	 * @param \DateTime|null $maxLastJoined
@@ -1467,4 +1646,148 @@ class ParticipantService {
 
 		return $pin;
 	}
+
+	/**
+	 * @param Room $room
+	 * @param string|null $userId
+	 * @param string|null|false $sessionId Set to false if you don't want to load a session (and save resources),
+	 *                                     string to try loading a specific session
+	 *                                     null to try loading "any"
+	 * @return Participant
+	 * @throws ParticipantNotFoundException When the user is not a participant
+	 */
+	public function getParticipant(Room $room, ?string $userId, $sessionId = null): Participant {
+		if (!is_string($userId) || $userId === '') {
+			throw new ParticipantNotFoundException('Not a user');
+		}
+
+		if (isset($this->userCache[$room->getId()][$userId])) {
+			$participant = $this->userCache[$room->getId()][$userId];
+			if (!$sessionId
+				|| ($participant->getSession() instanceof Session
+					&& $participant->getSession()->getSessionId() === $sessionId)) {
+				return $participant;
+			}
+		}
+
+		$query = $this->connection->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$query->from('talk_attendees', 'a')
+			->where($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)))
+			->andWhere($query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)))
+			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId())))
+			->setMaxResults(1);
+
+		if ($sessionId !== false) {
+			if ($sessionId !== null) {
+				$helper->selectSessionsTable($query);
+				$query->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
+					$query->expr()->eq('s.session_id', $query->createNamedParameter($sessionId)),
+					$query->expr()->eq('a.id', 's.attendee_id')
+				));
+			} else {
+				$helper->selectSessionsTable($query); // FIXME PROBLEM
+				$query->leftJoin('a', 'talk_sessions', 's', $query->expr()->eq('a.id', 's.attendee_id'));
+			}
+		}
+
+		$participant = $this->getParticipantFromQuery($query, $room);
+
+		$this->userCache ??= [];
+		$this->userCache[$room->getId()] ??= [];
+		$this->userCache[$room->getId()][$userId] = $participant;
+		if ($participant->getSession()) {
+			$participantSessionId = $participant->getSession()->getSessionId();
+			$this->sessionCache ??= [];
+			$this->sessionCache[$room->getId()] ??= [];
+			$this->sessionCache[$room->getId()][$participantSessionId] = $participant;
+		}
+
+		return $participant;
+	}
+
+	/**
+	 * @param Room $room
+	 * @param string|null $sessionId
+	 * @return Participant
+	 * @throws ParticipantNotFoundException When the user is not a participant
+	 */
+	public function getParticipantBySession(Room $room, ?string $sessionId): Participant {
+		if (!is_string($sessionId) || $sessionId === '' || $sessionId === '0') {
+			throw new ParticipantNotFoundException('Not a user');
+		}
+
+		$query = $this->connection->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$helper->selectSessionsTable($query);
+		$query->from('talk_sessions', 's')
+			->leftJoin('s', 'talk_attendees', 'a', $query->expr()->eq('a.id', 's.attendee_id'))
+			->where($query->expr()->eq('s.session_id', $query->createNamedParameter($sessionId)))
+			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId())))
+			->setMaxResults(1);
+
+		return $this->getParticipantFromQuery($query, $room);
+	}
+
+	/**
+	 * @param Room $room
+	 * @param string $pin
+	 * @return Participant
+	 * @throws ParticipantNotFoundException When the pin is not valid (has no participant assigned)
+	 */
+	public function getParticipantByPin(Room $room, string $pin): Participant {
+		$query = $this->connection->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$query->from('talk_attendees', 'a')
+			->where($query->expr()->eq('a.pin', $query->createNamedParameter($pin)))
+			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId())))
+			->setMaxResults(1);
+
+		return $this->getParticipantFromQuery($query, $room);
+	}
+
+	/**
+	 * @param Room $room
+	 * @param int $attendeeId
+	 * @return Participant
+	 * @throws ParticipantNotFoundException When the pin is not valid (has no participant assigned)
+	 */
+	public function getParticipantByAttendeeId(Room $room, int $attendeeId): Participant {
+		$query = $this->connection->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$query->from('talk_attendees', 'a')
+			->where($query->expr()->eq('a.id', $query->createNamedParameter($attendeeId, IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId())))
+			->setMaxResults(1);
+
+		return $this->getParticipantFromQuery($query, $room);
+	}
+
+	/**
+	 * @param Room $room
+	 * @param string $actorType
+	 * @param string $actorId
+	 * @return Participant
+	 * @throws ParticipantNotFoundException When the pin is not valid (has no participant assigned)
+	 */
+	public function getParticipantByActor(Room $room, string $actorType, string $actorId): Participant {
+		if ($actorType === Attendee::ACTOR_USERS) {
+			return $this->getParticipant($room, $actorId, false);
+		}
+
+		$query = $this->connection->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectAttendeesTable($query);
+		$query->from('talk_attendees', 'a')
+			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter($actorType)))
+			->andWhere($query->expr()->eq('a.actor_id', $query->createNamedParameter($actorId)))
+			->andWhere($query->expr()->eq('a.room_id', $query->createNamedParameter($room->getId())))
+			->setMaxResults(1);
+
+		return $this->getParticipantFromQuery($query, $room);
+	}
 }
