@@ -24,53 +24,59 @@ declare(strict_types=1);
 namespace OCA\Talk\Service;
 
 use InvalidArgumentException;
-use OCA\Talk\Chat\ChatManager;
+use OCA\Talk\Config;
 use OCA\Talk\Events\ModifyLobbyEvent;
 use OCA\Talk\Events\ModifyRoomEvent;
+use OCA\Talk\Events\RoomEvent;
 use OCA\Talk\Events\VerifyRoomPasswordEvent;
 use OCA\Talk\Exceptions\RoomNotFoundException;
 use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
+use OCA\Talk\Model\BreakoutRoom;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Webinary;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\BackgroundJob\IJobList;
+use OCP\Comments\IComment;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\HintException;
 use OCP\IDBConnection;
 use OCP\IUser;
+use OCP\Log\Audit\CriticalActionPerformedEvent;
 use OCP\Security\Events\ValidatePasswordPolicyEvent;
 use OCP\Security\IHasher;
 use OCP\Share\IManager as IShareManager;
 
 class RoomService {
 	protected Manager $manager;
-	protected ChatManager $chatManager;
 	protected ParticipantService $participantService;
 	protected IDBConnection $db;
 	protected ITimeFactory $timeFactory;
 	protected IShareManager $shareManager;
+	protected Config $config;
 	protected IHasher $hasher;
 	protected IEventDispatcher $dispatcher;
 	protected IJobList $jobList;
 
-	public function __construct(Manager $manager,
-								ChatManager $chatManager,
-								ParticipantService $participantService,
-								IDBConnection $db,
-								ITimeFactory $timeFactory,
-								IShareManager $shareManager,
-								IHasher $hasher,
-								IEventDispatcher $dispatcher,
-								IJobList $jobList) {
+	public function __construct(
+		Manager $manager,
+		ParticipantService $participantService,
+		IDBConnection $db,
+		ITimeFactory $timeFactory,
+		IShareManager $shareManager,
+		Config $config,
+		IHasher $hasher,
+		IEventDispatcher $dispatcher,
+		IJobList $jobList,
+	) {
 		$this->manager = $manager;
-		$this->chatManager = $chatManager;
 		$this->participantService = $participantService;
 		$this->db = $db;
 		$this->timeFactory = $timeFactory;
 		$this->shareManager = $shareManager;
+		$this->config = $config;
 		$this->hasher = $hasher;
 		$this->dispatcher = $dispatcher;
 		$this->jobList = $jobList;
@@ -178,7 +184,12 @@ class RoomService {
 	}
 
 	public function setPermissions(Room $room, string $level, string $method, int $permissions, bool $resetCustomPermissions): bool {
-		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
+			return false;
+		}
+
+		if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
+			// Do not allow manual changing the permissions in breakout rooms
 			return false;
 		}
 
@@ -240,6 +251,10 @@ class RoomService {
 			return false;
 		}
 
+		if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
+			return false;
+		}
+
 		if (!in_array($room->getType(), [Room::TYPE_GROUP, Room::TYPE_PUBLIC], true)) {
 			return false;
 		}
@@ -267,6 +282,32 @@ class RoomService {
 
 		return true;
 	}
+	/**
+	 * @param string $newName Currently it is only allowed to rename: self::TYPE_GROUP, self::TYPE_PUBLIC
+	 * @param string|null $oldName
+	 * @return bool True when the change was valid, false otherwise
+	 */
+	public function setName(Room $room, string $newName, ?string $oldName = null): bool {
+		$oldName = $oldName !== null ? $oldName : $room->getName();
+		if ($newName === $oldName) {
+			return false;
+		}
+
+		$event = new ModifyRoomEvent($room, 'name', $newName, $oldName);
+		$this->dispatcher->dispatch(Room::EVENT_BEFORE_NAME_SET, $event);
+
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('name', $update->createNamedParameter($newName))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setName($newName);
+
+		$this->dispatcher->dispatch(Room::EVENT_AFTER_NAME_SET, $event);
+
+		return true;
+	}
 
 	/**
 	 * @param Room $room
@@ -276,16 +317,17 @@ class RoomService {
 	 * 						file conversations and password request conversations.
 	 * @param \DateTime|null $dateTime
 	 * @param bool $timerReached
+	 * @param bool $dispatchEvents (Only skip if the room is created in the same PHP request)
 	 * @return bool True when the change was valid, false otherwise
 	 */
-	public function setLobby(Room $room, int $newState, ?\DateTime $dateTime, bool $timerReached = false): bool {
+	public function setLobby(Room $room, int $newState, ?\DateTime $dateTime, bool $timerReached = false, bool $dispatchEvents = true): bool {
 		$oldState = $room->getLobbyState(false);
 
 		if (!in_array($room->getType(), [Room::TYPE_GROUP, Room::TYPE_PUBLIC], true)) {
 			return false;
 		}
 
-		if ($room->getObjectType() !== '') {
+		if ($room->getObjectType() !== '' && $room->getObjectType() !== BreakoutRoom::PARENT_OBJECT_TYPE) {
 			return false;
 		}
 
@@ -294,7 +336,9 @@ class RoomService {
 		}
 
 		$event = new ModifyLobbyEvent($room, 'lobby', $newState, $oldState, $dateTime, $timerReached);
-		$this->dispatcher->dispatch(Room::EVENT_BEFORE_LOBBY_STATE_SET, $event);
+		if ($dispatchEvents) {
+			$this->dispatcher->dispatch(Room::EVENT_BEFORE_LOBBY_STATE_SET, $event);
+		}
 
 		$update = $this->db->getQueryBuilder();
 		$update->update('talk_rooms')
@@ -306,11 +350,66 @@ class RoomService {
 		$room->setLobbyState($newState);
 		$room->setLobbyTimer($dateTime);
 
-		$this->dispatcher->dispatch(Room::EVENT_AFTER_LOBBY_STATE_SET, $event);
+		if ($dispatchEvents) {
+			$this->dispatcher->dispatch(Room::EVENT_AFTER_LOBBY_STATE_SET, $event);
+		}
 
 		return true;
 	}
 
+	public function setAvatar(Room $room, string $avatar): bool {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
+			return false;
+		}
+
+		$event = new ModifyRoomEvent($room, 'avatar', $avatar, $room->getAvatar());
+		$this->dispatcher->dispatch(Room::EVENT_BEFORE_AVATAR_SET, $event);
+
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('avatar', $update->createNamedParameter($avatar))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setAvatar($avatar);
+
+		$this->dispatcher->dispatch(Room::EVENT_AFTER_AVATAR_SET, $event);
+		return true;
+	}
+
+	/**
+	 * @param Room $room
+	 * @param integer $status 0 none|1 video|2 audio
+	 * @param Participant|null $participant the Participant that changed the
+	 *        state, null for the current user
+	 * @throws \InvalidArgumentException When the status is invalid, not Room::RECORDING_*
+	 * @throws \InvalidArgumentException When trying to start
+	 */
+	public function setCallRecording(Room $room, int $status = Room::RECORDING_NONE, ?Participant $participant = null): void {
+		if (!$this->config->isRecordingEnabled() && $status !== Room::RECORDING_NONE) {
+			throw new InvalidArgumentException('config');
+		}
+
+		$availableRecordingStatus = [Room::RECORDING_NONE, Room::RECORDING_VIDEO, Room::RECORDING_AUDIO, Room::RECORDING_VIDEO_STARTING, Room::RECORDING_AUDIO_STARTING, Room::RECORDING_FAILED];
+		if (!in_array($status, $availableRecordingStatus)) {
+			throw new InvalidArgumentException('status');
+		}
+
+		$oldStatus = $room->getCallRecording();
+		$event = new ModifyRoomEvent($room, 'callRecording', $status, $oldStatus, $participant);
+		$this->dispatcher->dispatch(Room::EVENT_BEFORE_SET_CALL_RECORDING, $event);
+
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('call_recording', $update->createNamedParameter($status, IQueryBuilder::PARAM_INT))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setCallRecording($status);
+
+		$this->dispatcher->dispatch(Room::EVENT_AFTER_SET_CALL_RECORDING, $event);
+	}
+
 	/**
 	 * @param Room $room
 	 * @param int $newType Currently it is only allowed to change between `Room::TYPE_GROUP` and `Room::TYPE_PUBLIC`
@@ -326,7 +425,23 @@ class RoomService {
 			return false;
 		}
 
-		if (!in_array($newType, [Room::TYPE_GROUP, Room::TYPE_PUBLIC], true)) {
+		if ($room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
+			return false;
+		}
+
+		if (!in_array($newType, [Room::TYPE_GROUP, Room::TYPE_PUBLIC, Room::TYPE_ONE_TO_ONE_FORMER], true)) {
+			return false;
+		}
+
+		if ($newType === Room::TYPE_ONE_TO_ONE_FORMER && $room->getType() !== Room::TYPE_ONE_TO_ONE) {
+			return false;
+		}
+
+		if ($room->getBreakoutRoomMode() !== BreakoutRoom::MODE_NOT_CONFIGURED) {
+			return false;
+		}
+
+		if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
 			return false;
 		}
 
@@ -372,7 +487,10 @@ class RoomService {
 		}
 
 		if (!in_array($room->getType(), [Room::TYPE_GROUP, Room::TYPE_PUBLIC, Room::TYPE_CHANGELOG], true)) {
-			return false;
+			if ($newState !== Room::READ_ONLY || $room->getType() !== Room::TYPE_ONE_TO_ONE_FORMER) {
+				// Allowed for the automated conversation of one-to-one chats to read only former
+				return false;
+			}
 		}
 
 		if (!in_array($newState, [Room::READ_ONLY, Room::READ_WRITE], true)) {
@@ -412,6 +530,10 @@ class RoomService {
 			return false;
 		}
 
+		if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
+			return false;
+		}
+
 		if (!in_array($newState, [
 			Room::LISTABLE_NONE,
 			Room::LISTABLE_USERS,
@@ -497,6 +619,10 @@ class RoomService {
 			return false;
 		}
 
+		if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
+			return false;
+		}
+
 		if ($password !== '') {
 			$event = new ValidatePasswordPolicyEvent($password);
 			$this->dispatcher->dispatchTyped($event);
@@ -537,7 +663,14 @@ class RoomService {
 		];
 	}
 
+	/**
+	 * @throws \InvalidArgumentException When the room is a breakout room
+	 */
 	public function setMessageExpiration(Room $room, int $seconds): void {
+		if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
+			throw new \InvalidArgumentException('room');
+		}
+
 		$event = new ModifyRoomEvent($room, 'messageExpiration', $seconds);
 		$this->dispatcher->dispatch(Room::EVENT_BEFORE_SET_MESSAGE_EXPIRATION, $event);
 
@@ -551,4 +684,171 @@ class RoomService {
 
 		$this->dispatcher->dispatch(Room::EVENT_AFTER_SET_MESSAGE_EXPIRATION, $event);
 	}
+
+	public function setBreakoutRoomMode(Room $room, int $mode): bool {
+		if (!in_array($mode, [
+			BreakoutRoom::MODE_NOT_CONFIGURED,
+			BreakoutRoom::MODE_AUTOMATIC,
+			BreakoutRoom::MODE_MANUAL,
+			BreakoutRoom::MODE_FREE
+		], true)) {
+			return false;
+		}
+
+		$event = new ModifyRoomEvent($room, 'breakoutRoomMode', $mode);
+		$this->dispatcher->dispatch(Room::EVENT_BEFORE_SET_BREAKOUT_ROOM_MODE, $event);
+
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('breakout_room_mode', $update->createNamedParameter($mode, IQueryBuilder::PARAM_INT))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setBreakoutRoomMode($mode);
+
+		$this->dispatcher->dispatch(Room::EVENT_AFTER_SET_BREAKOUT_ROOM_MODE, $event);
+
+		return true;
+	}
+
+	public function setBreakoutRoomStatus(Room $room, int $status): bool {
+		if (!in_array($status, [
+			BreakoutRoom::STATUS_STOPPED,
+			BreakoutRoom::STATUS_STARTED,
+			BreakoutRoom::STATUS_ASSISTANCE_RESET,
+			BreakoutRoom::STATUS_ASSISTANCE_REQUESTED,
+		], true)) {
+			return false;
+		}
+
+		$event = new ModifyRoomEvent($room, 'breakoutRoomStatus', $status);
+		$this->dispatcher->dispatch(Room::EVENT_BEFORE_SET_BREAKOUT_ROOM_STATUS, $event);
+
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('breakout_room_status', $update->createNamedParameter($status, IQueryBuilder::PARAM_INT))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setBreakoutRoomStatus($status);
+
+		$this->dispatcher->dispatch(Room::EVENT_AFTER_SET_BREAKOUT_ROOM_STATUS, $event);
+
+		return true;
+	}
+
+	public function resetActiveSince(Room $room): bool {
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('active_guests', $update->createNamedParameter(0, IQueryBuilder::PARAM_INT))
+			->set('active_since', $update->createNamedParameter(null, IQueryBuilder::PARAM_DATE))
+			->set('call_flag', $update->createNamedParameter(0, IQueryBuilder::PARAM_INT))
+			->set('call_permissions', $update->createNamedParameter(Attendee::PERMISSIONS_DEFAULT, IQueryBuilder::PARAM_INT))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($update->expr()->isNotNull('active_since'));
+
+		$room->resetActiveSince();
+
+		return (bool) $update->executeStatement();
+	}
+
+	/**
+	 * @param \DateTime $since
+	 * @param int $callFlag
+	 * @param bool $isGuest
+	 * @return bool
+	 */
+	public function setActiveSince(Room $room, \DateTime $since, int $callFlag, bool $isGuest): bool {
+		if ($isGuest && $room->getType() === Room::TYPE_PUBLIC) {
+			$update = $this->db->getQueryBuilder();
+			$update->update('talk_rooms')
+				->set('active_guests', $update->createFunction($update->getColumnName('active_guests') . ' + 1'))
+				->set(
+					'call_flag',
+					$update->expr()->bitwiseOr('call_flag', $callFlag)
+				)
+				->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+			$update->executeStatement();
+		} elseif (!$isGuest) {
+			$update = $this->db->getQueryBuilder();
+			$update->update('talk_rooms')
+				->set(
+					'call_flag',
+					$update->expr()->bitwiseOr('call_flag', $callFlag)
+				)
+				->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+			$update->executeStatement();
+		}
+
+		if ($room->getActiveSince() instanceof \DateTime) {
+			$room->setActiveSince($room->getActiveSince(), $callFlag, $isGuest);
+			return false;
+		}
+
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('active_since', $update->createNamedParameter($since, IQueryBuilder::PARAM_DATE))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)))
+			->andWhere($update->expr()->isNull('active_since'));
+		$update->executeStatement();
+
+		$room->setActiveSince($since, $callFlag, $isGuest);
+
+		return true;
+	}
+
+	public function setLastMessage(Room $room, IComment $message): void {
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('last_message', $update->createNamedParameter((int) $message->getId()))
+			->set('last_activity', $update->createNamedParameter($message->getCreationDateTime(), 'datetime'))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setLastMessage($message);
+		$room->setLastActivity($message->getCreationDateTime());
+	}
+
+	public function setLastActivity(Room $room, \DateTime $now): void {
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('last_activity', $update->createNamedParameter($now, 'datetime'))
+			->where($update->expr()->eq('id', $update->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+
+		$room->setLastActivity($now);
+	}
+
+	public function deleteRoom(Room $room): void {
+		$event = new RoomEvent($room);
+		$this->dispatcher->dispatch(Room::EVENT_BEFORE_ROOM_DELETE, $event);
+
+		// Delete all breakout rooms when deleting a parent room
+		if ($room->getBreakoutRoomMode() !== BreakoutRoom::MODE_NOT_CONFIGURED) {
+			$breakoutRooms = $this->manager->getMultipleRoomsByObject(BreakoutRoom::PARENT_OBJECT_TYPE, $room->getToken());
+			foreach ($breakoutRooms as $breakoutRoom) {
+				$this->deleteRoom($breakoutRoom);
+			}
+		}
+
+		// Delete attendees
+		$delete = $this->db->getQueryBuilder();
+		$delete->delete('talk_attendees')
+			->where($delete->expr()->eq('room_id', $delete->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$delete->executeStatement();
+
+		// Delete room
+		$delete = $this->db->getQueryBuilder();
+		$delete->delete('talk_rooms')
+			->where($delete->expr()->eq('id', $delete->createNamedParameter($room->getId(), IQueryBuilder::PARAM_INT)));
+		$delete->executeStatement();
+
+		$this->dispatcher->dispatch(Room::EVENT_AFTER_ROOM_DELETE, $event);
+		if (class_exists(CriticalActionPerformedEvent::class)) {
+			$this->dispatcher->dispatchTyped(new CriticalActionPerformedEvent(
+				'Conversation "%s" deleted',
+				['name' => $room->getName()],
+			));
+		}
+	}
 }
