@@ -23,13 +23,13 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Settings\Admin;
 
-use OCA\Talk\MatterbridgeManager;
 use OCA\Talk\Config;
+use OCA\Talk\Exceptions\WrongPermissionsException;
+use OCA\Talk\MatterbridgeManager;
 use OCA\Talk\Model\Command;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
 use OCA\Talk\Service\CommandService;
-use OCA\Talk\Exceptions\WrongPermissionsException;
 use OCP\AppFramework\Http\TemplateResponse;
 use OCP\AppFramework\Services\IInitialState;
 use OCP\ICacheFactory;
@@ -55,16 +55,18 @@ class AdminSettings implements ISettings {
 	private IL10N $l10n;
 	private IFactory $l10nFactory;
 
-	public function __construct(Config $talkConfig,
-								IConfig $serverConfig,
-								CommandService $commandService,
-								IInitialState $initialState,
-								ICacheFactory $memcacheFactory,
-								IGroupManager $groupManager,
-								MatterbridgeManager $bridgeManager,
-								IUserSession $userSession,
-								IL10N $l10n,
-								IFactory $l10nFactory) {
+	public function __construct(
+		Config $talkConfig,
+		IConfig $serverConfig,
+		CommandService $commandService,
+		IInitialState $initialState,
+		ICacheFactory $memcacheFactory,
+		IGroupManager $groupManager,
+		MatterbridgeManager $bridgeManager,
+		IUserSession $userSession,
+		IL10N $l10n,
+		IFactory $l10nFactory,
+	) {
 		$this->talkConfig = $talkConfig;
 		$this->serverConfig = $serverConfig;
 		$this->commandService = $commandService;
@@ -89,6 +91,7 @@ class AdminSettings implements ISettings {
 		$this->initTurnServers();
 		$this->initSignalingServers();
 		$this->initRequestSignalingServerTrial();
+		$this->initRecording();
 		$this->initSIPBridge();
 
 
@@ -98,14 +101,14 @@ class AdminSettings implements ISettings {
 	}
 
 	protected function initGeneralSettings(): void {
-		$this->initialState->provideInitialState('default_group_notification', (int) $this->serverConfig->getAppValue('spreed', 'default_group_notification', Participant::NOTIFY_MENTION));
+		$this->initialState->provideInitialState('default_group_notification', (int) $this->serverConfig->getAppValue('spreed', 'default_group_notification', (string) Participant::NOTIFY_MENTION));
 		$this->initialState->provideInitialState('conversations_files', (int) $this->serverConfig->getAppValue('spreed', 'conversations_files', '1'));
 		$this->initialState->provideInitialState('conversations_files_public_shares', (int) $this->serverConfig->getAppValue('spreed', 'conversations_files_public_shares', '1'));
-		$this->initialState->provideInitialState('valid_apache_php_configuration', (int) $this->validApachePHPConfiguration());
+		$this->initialState->provideInitialState('valid_apache_php_configuration', $this->validApachePHPConfiguration());
 	}
 
 	protected function initAllowedGroups(): void {
-		$this->initialState->provideInitialState('start_calls', (int) $this->serverConfig->getAppValue('spreed', 'start_calls', Room::START_CALL_EVERYONE));
+		$this->initialState->provideInitialState('start_calls', (int) $this->serverConfig->getAppValue('spreed', 'start_calls', (string) Room::START_CALL_EVERYONE));
 
 		$groups = $this->getGroupDetailsArray($this->talkConfig->getAllowedConversationsGroupIds(), 'start_conversations');
 		$this->initialState->provideInitialState('start_conversations', $groups);
@@ -448,7 +451,7 @@ class AdminSettings implements ISettings {
 			'country' => $guessCountry,
 		]);
 		$this->initialState->provideInitialState('hosted_signaling_server_trial_data',
-			json_decode($this->serverConfig->getAppValue('spreed', 'hosted-signaling-server-account', "[]"), true) ?? []
+			json_decode($this->serverConfig->getAppValue('spreed', 'hosted-signaling-server-account', '{}'), true) ?? []
 		);
 		$languages = $this->l10nFactory->getLanguages();
 		foreach ($languages['commonLanguages'] as $key => $value) {
@@ -472,6 +475,15 @@ class AdminSettings implements ISettings {
 		]);
 	}
 
+	protected function initRecording(): void {
+		$uploadLimit = Util::uploadLimit();
+		$this->initialState->provideInitialState('recording_servers', [
+			'servers' => $this->talkConfig->getRecordingServers(),
+			'secret' => $this->talkConfig->getRecordingSecret(),
+			'uploadLimit' => is_infinite($uploadLimit) ? 0 : $uploadLimit,
+		]);
+	}
+
 	protected function initSIPBridge(): void {
 		$groups = $this->getGroupDetailsArray($this->talkConfig->getSIPGroups(), 'sip_bridge_groups');
 
@@ -502,12 +514,20 @@ class AdminSettings implements ISettings {
 		return $groups;
 	}
 
-	protected function validApachePHPConfiguration(): bool {
+	protected function validApachePHPConfiguration(): string {
+		if (!function_exists('exec')) {
+			return 'unknown';
+		}
+
 		$output = [];
-		@exec('apachectl -M | grep mpm', $output, $returnCode);
+		try {
+			@exec('apachectl -V | grep MPM', $output, $returnCode);
+		} catch (\Throwable $e) {
+			return 'unknown';
+		}
 
 		if ($returnCode > 0) {
-			return true;
+			return 'unknown';
 		}
 
 		$apacheModule = implode("\n", $output);
@@ -515,11 +535,11 @@ class AdminSettings implements ISettings {
 
 		if ($usingFPM) {
 			// Needs to use mpm_event
-			return strpos($apacheModule, 'mpm_event') !== false;
+			return strpos($apacheModule, 'event') !== false ? '' : 'invalid';
 		}
 
 		// Needs to use mpm_prefork
-		return strpos($apacheModule, 'mpm_prefork') !== false;
+		return strpos($apacheModule, 'prefork') !== false ? '' : 'invalid';
 	}
 
 	/**
