@@ -37,6 +37,7 @@ use OCA\Talk\Manager;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Room;
 use OCA\Talk\Service\ParticipantService;
+use OCP\AppFramework\Db\TTransactional;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Cache\CappedMemoryCache;
 use OCP\DB\QueryBuilder\IQueryBuilder;
@@ -65,6 +66,7 @@ use OCP\Share\IShareProvider;
  * modifying the share for the other users in the room.
  */
 class RoomShareProvider implements IShareProvider {
+	use TTransactional;
 	// Special share type for user modified room shares
 	public const SHARE_TYPE_USERROOM = 11;
 
@@ -86,15 +88,15 @@ class RoomShareProvider implements IShareProvider {
 	private CappedMemoryCache $sharesByIdCache;
 
 	public function __construct(
-			IDBConnection $connection,
-			ISecureRandom $secureRandom,
-			IShareManager $shareManager,
-			IEventDispatcher $dispatcher,
-			Manager $manager,
-			ParticipantService $participantService,
-			ITimeFactory $timeFactory,
-			IL10N $l,
-			IMimeTypeLoader $mimeTypeLoader
+		IDBConnection $connection,
+		ISecureRandom $secureRandom,
+		IShareManager $shareManager,
+		IEventDispatcher $dispatcher,
+		Manager $manager,
+		ParticipantService $participantService,
+		ITimeFactory $timeFactory,
+		IL10N $l,
+		IMimeTypeLoader $mimeTypeLoader,
 	) {
 		$this->dbConnection = $connection;
 		$this->secureRandom = $secureRandom;
@@ -153,7 +155,7 @@ class RoomShareProvider implements IShareProvider {
 		}
 
 		try {
-			$participant = $room->getParticipant($share->getSharedBy(), false);
+			$participant = $this->participantService->getParticipant($room, $share->getSharedBy(), false);
 		} catch (ParticipantNotFoundException $e) {
 			// If the sharer is not a participant of the room even if the room
 			// exists the error is still "Room not found".
@@ -181,19 +183,21 @@ class RoomShareProvider implements IShareProvider {
 			)
 		);
 
-		$shareId = $this->addShareToDB(
-			$share->getSharedWith(),
-			$share->getSharedBy(),
-			$share->getShareOwner(),
-			$share->getNodeType(),
-			$share->getNodeId(),
-			$share->getTarget(),
-			$share->getPermissions(),
-			$share->getToken(),
-			$share->getExpirationDate()
-		);
+		$data = $this->atomic(function () use ($share) {
+			$shareId = $this->addShareToDB(
+				$share->getSharedWith(),
+				$share->getSharedBy(),
+				$share->getShareOwner(),
+				$share->getNodeType(),
+				$share->getNodeId(),
+				$share->getTarget(),
+				$share->getPermissions(),
+				$share->getToken(),
+				$share->getExpirationDate()
+			);
 
-		$data = $this->getRawShare($shareId);
+			return $this->getRawShare($shareId);
+		}, $this->dbConnection);
 
 		return $this->createShareObject($data);
 	}
@@ -213,15 +217,15 @@ class RoomShareProvider implements IShareProvider {
 	 * @return int
 	 */
 	private function addShareToDB(
-			string $shareWith,
-			string $sharedBy,
-			string $shareOwner,
-			string $itemType,
-			int $itemSource,
-			string $target,
-			int $permissions,
-			string $token,
-			?\DateTime $expirationDate
+		string $shareWith,
+		string $sharedBy,
+		string $shareOwner,
+		string $itemType,
+		int $itemSource,
+		string $target,
+		int $permissions,
+		string $token,
+		?\DateTime $expirationDate
 	): int {
 		$insert = $this->dbConnection->getQueryBuilder();
 		$insert->insert('share')
@@ -546,7 +550,11 @@ class RoomShareProvider implements IShareProvider {
 	 */
 	public function getSharesInFolder($userId, Folder $node, $reshares, $shallow = true): array {
 		$qb = $this->dbConnection->getQueryBuilder();
-		$qb->select('*')
+		$qb->select('s.*',
+			'f.fileid', 'f.path', 'f.permissions AS f_permissions', 'f.storage', 'f.path_hash',
+			'f.parent AS f_parent', 'f.name', 'f.mimetype', 'f.mimepart', 'f.size', 'f.mtime', 'f.storage_mtime',
+			'f.encrypted', 'f.unencrypted_size', 'f.etag', 'f.checksum'
+		)
 			->from('share', 's')
 			->andWhere($qb->expr()->orX(
 				$qb->expr()->eq('s.item_type', $qb->createNamedParameter('file')),
@@ -577,7 +585,7 @@ class RoomShareProvider implements IShareProvider {
 			$qb->andWhere($qb->expr()->like('f.path', $qb->createNamedParameter($this->dbConnection->escapeLikeParameter($node->getInternalPath()) . '/%')));
 		}
 
-		$qb->orderBy('s.id');
+		$qb->orderBy('s.id', 'ASC');
 
 		$cursor = $qb->executeQuery();
 		$shares = [];
@@ -630,7 +638,7 @@ class RoomShareProvider implements IShareProvider {
 		}
 
 		$qb->setFirstResult($offset);
-		$qb->orderBy('id');
+		$qb->orderBy('id', 'ASC');
 
 		$cursor = $qb->executeQuery();
 		$shares = [];
@@ -843,7 +851,7 @@ class RoomShareProvider implements IShareProvider {
 			)
 				->selectAlias('st.id', 'storage_string_id')
 				->from('share', 's')
-				->orderBy('s.id')
+				->orderBy('s.id', 'ASC')
 				->leftJoin('s', 'filecache', 'f', $qb->expr()->eq('s.file_source', 'f.fileid'))
 				->leftJoin('f', 'storages', 'st', $qb->expr()->eq('f.storage', 'st.numeric_id'));
 
@@ -1092,7 +1100,7 @@ class RoomShareProvider implements IShareProvider {
 			->from('share')
 			->where($qb->expr()->eq('parent', $qb->createNamedParameter($parent->getId())))
 			->andWhere($qb->expr()->eq('share_type', $qb->createNamedParameter(IShare::TYPE_ROOM)))
-			->orderBy('id');
+			->orderBy('id', 'ASC');
 
 		$cursor = $qb->executeQuery();
 		while ($data = $cursor->fetch()) {
